@@ -2,7 +2,7 @@ package GCBorrowings;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -616,18 +616,18 @@ use GCUtils;
         $scrollPanelList->add($self->{listView});
 
         $self->{context} = new Gtk2::Menu;
-        my $returned = Gtk2::MenuItem->new($parent->{lang}->{PanelReturned});
-        $returned->signal_connect('activate', sub {
+        $self->{returned} = Gtk2::MenuItem->new($parent->{lang}->{PanelReturned});
+        $self->{returned}->signal_connect('activate', sub {
             $self->returnItem;
         });
-        $self->{context}->append($returned);
-        my $display = Gtk2::MenuItem->new($parent->{lang}->{BorrowedDisplayInPanel});
-        $display->signal_connect('activate', sub {
+        $self->{context}->append($self->{returned});
+        $self->{display} = Gtk2::MenuItem->new($parent->{lang}->{BorrowedDisplayInPanel});
+        $self->{display}->signal_connect('activate', sub {
             my $iter = $self->{listView}->get_selection->get_selected;
             my $idx = $self->{listModel}->get($iter, 4);
             $self->displayItem($idx);
         });
-        $self->{context}->append($display);
+        $self->{context}->append($self->{display});
         $self->{context}->show_all;
 
         $self->{listView}->signal_connect('button_press_event' => sub {
