@@ -2,7 +2,7 @@ package GCCommandLine;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -137,7 +137,7 @@ use strict;
             foreach (@importersArray)
             {
                 $_->setLangName($options->lang);
-                if ($_->getName =~ /\Q$import/)
+                if (($_->getName =~ /\Q$import/) || ($_ =~ /GCExport::GCExporter$export/))
                 {
                     $self->{importer} = $_;
                     last;
@@ -157,7 +157,7 @@ use strict;
             foreach (@exportersArray)
             {
                 $_->setLangName($options->lang);
-                if ($_->getName eq $export)
+                if (($_->getName eq $export) || ($_ =~ /GCExport::GCExporter$export/))
                 {
                     $self->{exporter} = $_;
                     last;
