@@ -2,7 +2,7 @@ package GCData;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -198,10 +198,28 @@ use strict;
     sub getTitle
     {
         my ($self, $idx) = @_;
-
-        my $realIdx = $idx;
-        $realIdx = $self->{currentItem} if ! defined $idx;
-        return ($self->getItemsListFiltered)->[$realIdx]->{$self->{model}->{commonFields}->{title}};
+        if ($self->{multipleMode})
+        {
+            # Multiple items selected, so just use collection title or filename
+            my $name;
+            if ($self->{parent}->{options}->file)
+            {
+                $name = $self->{parent}->{items}->getInformation->{name}
+                    if $self->{parent}->{items};
+                $name ||= basename($self->{parent}->{options}->file);
+            }
+            else
+            {
+                $name = $self->{parent}->{lang}->{UnsavedCollection};
+            }
+            return $name;
+        }
+        else
+        {
+            my $realIdx = $idx;
+            $realIdx = $self->{currentItem} if ! defined $idx;
+            return ($self->getItemsListFiltered)->[$realIdx]->{$self->{model}->{commonFields}->{title}};
+        }    
     }
 
     sub getCurrent
@@ -264,6 +282,7 @@ use strict;
         }
         
         $panel->dataChanged;
+        $GCGraphicComponent::somethingChanged = 0;
     }
 
     sub display
@@ -469,7 +488,8 @@ use strict;
         my $numbers = $self->{parent}->{itemsView}->getCurrentItems;
 
         my $nbRemoved = 0;
-        foreach my $number(sort @$numbers)
+        # Numerically sort list
+        foreach my $number(sort {$a <=> $b} @$numbers)
         {
             # We need to adjust it because we already removed other ones.
             my $actualNumber = $number - $nbRemoved;
