@@ -2,7 +2,7 @@ package GCDisplay;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -720,6 +720,11 @@ use Gtk2;
         my $self = shift;
         
         $self->show_all;
+        # If saving the search is not possible, hides the corresponding button
+        if (!$self->{canSave})
+        {
+            ($self->action_area->get_children)[3]->hide;
+        }
         $self->{search} = undef;
         my $ended = 0;
         while (!$ended)
@@ -925,6 +930,9 @@ use Gtk2;
         my ($self, $model) = @_;
 
         $self->{model} = $model;
+        # Searches can only be saved for default collections or user collections with a name
+        # (i.e. when the model is not embedded within the collection).
+        $self->{canSave} = ($model->getName) ? 1 : 0;
         $self->{nbFields} = 0;
         $self->{fields} = [];
         $self->{comps} = [];
