@@ -2,7 +2,7 @@ package GCExport::GCExportHTML;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -160,7 +160,7 @@ use GCExport::GCExportBase;
             label => 'HeightImg',
             default => 160,
             min => 50,
-            max => 250,
+            max => 500,
         },   
                         
         {
@@ -233,6 +233,7 @@ use GCExport::GCExportBase;
         $dialog->vbox->show_all;
         $dialog->run;
         $dialog->destroy;
+        $parent->showMe;
     }
     
     sub wantsFieldsSelection
@@ -404,6 +405,23 @@ use GCExport::GCExportBase;
             foreach my $value(@$valuesArray)
             {
                 (my $line = $motif) =~ s/$index/$value/gms;
+                # For generic models, we add an img tag for images
+                # and an a tag for links
+                if (exists $self->{options}->{fieldsInfo}->{$value})
+                {
+                    # If this is an image
+                    if ($self->{options}->{fieldsInfo}->{$value}->{type} eq 'image')
+                    {
+                        # We do it only if it is between 2 tags.
+                        $line =~ s|>\$\$$value\$\$<|><img src="\$\$$value\$\$"/><|;
+                    }
+                    # If this is the item URL
+                    elsif ($value eq $self->{model}->{commonFields}->{url})
+                    {
+                        # We do it only if it is between 2 tags.
+                        $line =~ s|>\$\$$value\$\$<|><a href="\$\$$value\$\$"/>\$\$$self->{model}->{commonFields}->{title}\$\$</a><|;
+                    }
+                }
                 $string .= $line;
             }
             $model =~ s/(\n?)\s*\[LOOP$loopNumber\s+values=$values\s+idx=$index(\s+filter=$filter)?\].*?\[\/LOOP$loopNumber\]/$1$string/gms;
