@@ -2,7 +2,7 @@ package GCImport::GCImportBase;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -101,6 +101,13 @@ use GCExportImport;
         return 0;
     }
     
+    # Returns true if the module should be hidden from
+    # the menu when a collection of an incompatible kind is open.
+    sub shouldBeHidden
+    {
+        return 0;
+    }
+    
     sub generateId
     {
         return 1;
