@@ -2,7 +2,7 @@ package GCImport::GCImportFolder;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -60,6 +60,11 @@ use GCImport::GCImportBase;
         return 1;
     }
     
+    sub shouldBeHidden
+    {
+        return 1;
+    }
+
     sub getFilePatterns
     {
        return ();
@@ -243,7 +248,7 @@ use GCImport::GCImportBase;
             # avoid capturing something else than $T,$A ... make already present () not capturing
             $myRegExp =~ s/(?<!\\)\(/(?:/g;
             my $articles='(?:'.join('|',@{$self->{model}->{parent}->{articles}}).')\'?\b';
-            my $myRegExpArt=qr/^(.*?)(?:, ?($articles))?$/i;
+            our $myRegExpArt=qr/^(.*?)(?:, ?($articles))?$/i;
             
             $myRegExp =~ s/\$A/(.*?(?:, ?$articles)?)/g;
             $myRegExp =~ s/\$N/(.*?(?:, ?$articles)?)/g;
@@ -255,7 +260,7 @@ use GCImport::GCImportBase;
             $myRegExp =~ s/\$S/(\\d{1,2}?)/;
             sub deAlpha{
                 my $s;
-                $_[0]=~$myRegExpArt;
+                $_[0] =~ $myRegExpArt;
                 $s=$1;
                 my $a=$2.' ' if $2 && (substr($2,-1) ne '\'');
                 $s=$a.$s if $a;
@@ -399,6 +404,7 @@ use GCImport::GCImportBase;
             $plugin->{title} = $name;
             $plugin->{type} = 'load';
             $plugin->{urlField} = $self->{model}->{commonFields}->{url};
+            $plugin->{searchField} = $titleField;
 
             #Initialize what will be pushed in the array
             my $infoPlugin = {$titleField => $name};
