@@ -2,7 +2,7 @@ package GCTextLists;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -27,11 +27,12 @@ package GCTextLists;
 #
 
 use strict;
-use locale;
+use locale;        
 
 {
     package GCBaseTextList;
     use base "Gtk2::ScrolledWindow";
+    use GCUtils;
 
     sub new
     {
@@ -224,13 +225,47 @@ use locale;
         $self->convertIdxToIter($idx);
         return $self->changeCurrent($previous, $new, $idx, 0);
     }
-
+    
+    sub updateMenus
+    {    
+        # Update menu items to reflect number of items selected
+        my ($self, $nbSelected) = @_;
+        
+        my $menu = $self->{parent}->{menubar};
+        my @updateList;
+        if ($nbSelected > 1)
+        {
+            @updateList = (
+                [$menu, 'duplicateItem', 'MenuDuplicatePlural'],
+                [$menu, 'deleteCurrentItem', 'MenuEditDeleteCurrentPlural'],
+                [$self->{parent}, 'contextDuplicateItem', 'MenuDuplicatePlural'],
+                [$self->{parent}, 'contextItemDelete', 'MenuEditDeleteCurrentPlural'],
+                [$self->{parent}, 'contextNewWindow', 'MenuNewWindowPlural'],
+            );
+        }
+        else
+        {
+            @updateList = (
+                [$menu, 'duplicateItem', 'MenuDuplicate'],
+                [$menu, 'deleteCurrentItem', 'MenuEditDeleteCurrent'],
+                [$self->{parent}, 'contextDuplicateItem', 'MenuDuplicate'],
+                [$self->{parent}, 'contextItemDelete', 'MenuEditDeleteCurrent'],
+                [$self->{parent}, 'contextNewWindow', 'MenuNewWindow'],
+            );
+        }
+        foreach (@updateList)
+	{
+	    $menu->updateItem($_->[0]->{$_->[1]}, $_->[2]);
+	}
+    }
+    
 }
 
 {
     package GCTextList;
 
     use Gtk2::SimpleList;
+    use GCUtils;
     use base 'GCBaseTextList';
 
     sub new
@@ -292,24 +327,55 @@ use locale;
         $self->{list}->get_selection->signal_connect ('changed' => sub {
             return if $self->{deactivateUpdate};
             my @indexes;
+            my $nbSelected;
             $self->{list}->get_selection->selected_foreach(sub {
                 my ($model, $path, $iter, $self) = @_;
                 push @indexes, $self->{completeModel}->get_value($iter, 1);
+                $nbSelected++;
             }, $self);
             return if scalar @indexes == 0;
             $parent->display(@indexes);
             my $iter = $self->getCurrentIter;
             $self->{currentIterString} = $self->convertIterToString($iter);
+            
+            # Update menus to reflect number of items selected
+            $self->updateMenus($nbSelected);
         });
 
         $self->{list}->signal_connect ('row-activated' => sub {
            $parent->displayInWindow;
         });
         $self->{list}->signal_connect('button_press_event' => sub {
-           my ($widget, $event) = @_;
-           return 0 if $event->button ne 3;
+            my ($widget, $event) = @_;
+            return 0 if $event->button ne 3;
+            
+            # Check if row clicked on is in the current selection
+            my ($path, $column, $cell_x, $cell_y) = $widget->get_path_at_pos( $event->x, $event->y );
+            my $selection = $widget->get_selection;
+            my @rows = $selection->get_selected_rows;
+            my $clickedOnSelection = 0;
+            # Loop through selection to see if current row is selected
+            foreach my $row(@rows)
+            {
+                if ($row->to_string eq $path->to_string)
+                {
+                    $clickedOnSelection = 1;
+                }
+            }
+
+            # Popup the menu
             $self->{parent}->{context}->popup(undef, undef, undef, undef, $event->button, $event->time);
-            return 0;
+            
+            # If row clicked on was in the selection, return true, else return false to clear selection
+            # to clicked on item
+            if ($clickedOnSelection)
+            {
+                return 1;
+            }
+            else
+            {
+                return 0;
+            } 
         });
 
         $self->{list}->signal_connect('key-press-event' => sub {
@@ -390,11 +456,13 @@ use locale;
     sub sortCaseInsensitive
     {
         my ($childModel, $iter1, $iter2, $self) = @_;
+        
         if ($self->{deactivateSortCache})
         {
             my $val1 = uc($childModel->get_value($iter1, 0));
             my $val2 = uc($childModel->get_value($iter2, 0));
-            return $val1 cmp $val2;
+            # Use a natural string sort method
+            return (GCUtils::gccmp($val1, $val2));
         }
         else
         {
@@ -402,7 +470,8 @@ use locale;
             my $idx2 = $childModel->get_value($iter2, 1);
             my $val1 = uc($childModel->get_value($iter1, 0));
             my $val2 = uc($childModel->get_value($iter2, 0));
-            return $val1 cmp $val2;
+            # Use a natural string sort method
+            return (GCUtils::gccmp($val1, $val2));
         }
     }
 
@@ -613,6 +682,7 @@ use locale;
     
     use File::Basename;
     use base 'GCBaseTextList';
+    use GCUtils;
 
     sub new
     {
@@ -933,10 +1003,36 @@ use locale;
         $self->add($self->{list});
         
         $self->{list}->signal_connect('button_press_event' => sub {
-           my ($widget, $event) = @_;
-           return 0 if $event->button ne 3;
+            my ($widget, $event) = @_;
+            return 0 if $event->button ne 3;
+           
+            # Check if row clicked on is in the current selection
+            my ($path, $column, $cell_x, $cell_y) = $widget->get_path_at_pos( $event->x, $event->y );
+            my $selection = $widget->get_selection;
+            my @rows = $selection->get_selected_rows;
+            my $clickedOnSelection = 0;
+            # Loop through selection to see if current row is selected
+            foreach my $row(@rows)
+            {
+                if ($row->to_string eq $path->to_string)
+                {
+                    $clickedOnSelection = 1;
+                }
+            }
+
+            # Popup the menu
             $self->{parent}->{context}->popup(undef, undef, undef, undef, $event->button, $event->time);
-            return 0;
+            
+            # If row clicked on was in the selection, return true, else return false to clear selection
+            # to clicked on item
+            if ($clickedOnSelection)
+            {
+                return 1;
+            }
+            else
+            {
+                return 0;
+            } 
         });
 
         $self->{list}->signal_connect('key-press-event' => sub {
@@ -997,9 +1093,11 @@ use locale;
         my ($selection, $self) = @_;
         return if $self->{deactivateUpdate};
         my @indexes;
+        my $nbSelected;
         $self->{list}->get_selection->selected_foreach(sub {
             my ($model, $path, $iter, $self) = @_;
             push @indexes, $self->convertIterToIdx($iter);
+            $nbSelected++;
         }, $self);
         return if scalar @indexes == 0;
         my $iter = $self->getCurrentIter;
@@ -1009,6 +1107,10 @@ use locale;
         $self->{currentIterString} = $self->{selectedIterString}
             if !$self->{currentRemoved};
         $self->checkLock;
+        
+        # Update menu items to reflect number of items selected
+        $self->updateMenus($nbSelected);
+        
     }
 
     sub savePreferences
@@ -1079,7 +1181,7 @@ use locale;
                                  : ($colId1, $converter1);
             push @val, $converter->($childModel->get_value($iter[$i], $colId));
         }
-        return $val[0] cmp $val[1];
+        return (GCUtils::gccmp($val[0], $val[1]));
     }
 
     sub sortWithParentFirst
@@ -1102,7 +1204,7 @@ use locale;
             # with an iterator not matching model
             my $val1 = $converter->($childModel->get_value($iter1, $colId));
             my $val2 = $converter->($childModel->get_value($iter2, $colId));
-            return $val1 cmp $val2;
+            return (GCUtils::gccmp($val1, $val2));
         }
         else
         {
@@ -1510,36 +1612,7 @@ use locale;
         }
         else
         {
-            if ($field eq $self->{borrowerField})
-            {
-                $value = $self->{parent}->{lang}->{PanelNobody} if (! $value) || ($value eq 'none');
-            }
-            else
-            {
-                if ($type eq 'date')
-                {
-                    $value = GCUtils::timeToStr($value, $self->{parent}->{options}->dateFormat);
-                }
-                elsif ($type =~ /list$/o)
-                {
-                    if ($multiAllowed && $self->{multi})
-                    {
-                        $value = GCPreProcess::multipleListToArray($value);
-                    }
-                    else
-                    {
-                        $value = GCPreProcess::multipleList($value, $type);
-                    }
-                }
-                elsif ($type eq 'options')
-                {
-                    $value = $self->{parent}->{items}->valueToDisplayed($value, $field) || $value;
-                }
-                if ($field eq $self->{titleField})
-                {
-                   $value = $self->{parent}->transformTitle($value);
-                }
-            }
+            $value = $self->{parent}->transformValue($value, $field, ($multiAllowed && $self->{multi}));
         }
         if ($isForSort)
         {
@@ -1622,7 +1695,8 @@ use locale;
 
         while ($master)
         {
-            return $master if $self->getIterCollection($master) eq $realCollection;
+            return $master if ($self->{model}->iter_has_child($master))
+                           && ($self->getIterCollection($master) eq $realCollection);
             $master = $self->{model}->iter_next($master);
         }
         return undef;
