@@ -16,7 +16,7 @@
 ###################################################
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -74,6 +74,11 @@
         Unlockables => 'قابلة لإلغاء الأقفال',
         Unlockable => 'قابلة لإلغاء القفل',
         Howto => 'كيفية إلغاء القفل',
+        Exclusive => 'Exclusive',
+        Resolutions => 'Display resolutions',
+        InstallationSize => 'Size',
+        Region => 'Region',
+        SerialNumber => 'Serial Number',        
 
         General => 'عام',
         Details => 'تفاصيل',
