@@ -15,7 +15,7 @@
 #	
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -35,6 +35,22 @@
 #
 ###################################################
     
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
+
     use strict;
     use base 'Exporter';
 
@@ -55,7 +71,7 @@
 إستعمال <b>الزر الواقع تحت تفاصيل العنصر </b>.',
 
         
-		'AllItemsFiltered' => 'لم يتم العثور على أي عنصر من خلال معيار البحث الذي قمت بتخصيصه',
+		'AllItemsFiltered' => 'لم يتم العثور على أي عنصر من خلال معيار البحث الذي قمت بتخصيصه', # Accepts model codes
      
 #Installation
         'InstallDirInfo' => 'تم تنصيبه ضمن ',
@@ -106,14 +122,19 @@
 #Menus
         'MenuFile' => '_ملف',
             'MenuNewList' => '_مجموعة جديدة',
+            'MenuStats' => 'Statistics',
             'MenuHistory' => '_المجموعات السابقة',
-            'MenuLend' => 'إظهار العناصر _المستعرضة سابقاً',
+            'MenuLend' => 'إظهار العناصر _المستعرضة سابقاً', # Accepts model codes
             'MenuImport' => '_إستيراد',	
             'MenuExport' => '_تصدير',
+            'MenuAddItem' => '_Add Items', # Accepts model codes
     
         'MenuEdit'  => '_تحرير',
-            'MenuDuplicate' => 'مضاعفة العنصر',
-            'MenuEditDeleteCurrent' => '_حذف العنصر',
+            'MenuDuplicate' => 'مضاعفة العنصر',  # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate Items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All Items', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_حذف العنصر', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove Items', # Accepts model codes   
             'MenuEditFields' => '_تغيير حقول المجموعة',
             'MenuEditLockItems' => '_إقفال المجموعة',
     
@@ -122,7 +143,7 @@
                 'MenuSavedSearchesSave' => 'حفظ البحث الحالي',
                 'MenuSavedSearchesEdit' => 'تعديل بحث محفوظ',
             'MenuAdvancedSearch' => 'ب_حث متقدّم',
-            'MenuViewAllItems' => 'عرض _كل العناصر',
+            'MenuViewAllItems' => 'عرض _كل العناصر', # Accepts model codes
             'MenuNoFilter' => '_أي شيء',
     
         'MenuConfiguration' => '_إعدادات',
@@ -141,8 +162,9 @@
             'MenuBugReport' => 'الإبلاغ عن خطأ',
             'MenuAbout' => '_حول جي سي ستار',
     
-        'MenuNewWindow' => 'عرض العنصر بنافذة _جديدة',
-        
+        'MenuNewWindow' => 'عرض العنصر بنافذة _جديدة', # Accepts model codes
+        'MenuNewWindowPlural' => 'Show Items in _New Window', # Accepts model codes
+                
         'ContextExpandAll' => 'توسيع الكل',
         'ContextCollapseAll' => 'طي الكل',
         'ContextChooseImage' => 'قم بإختيار صورة',
@@ -150,22 +172,25 @@
         'ContextImageEditor' => 'محرر الصور',
         'ContextImgFront' => 'الواجهة',
         'ContextImgBack' => 'الخلفية',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
         
         'DialogEnterNumber' => 'قم بإدخال قيمة',
 
-        'RemoveConfirm' => 'هل أنت متأكد من حذف هذا العنصر؟',
+        'RemoveConfirm' => 'هل أنت متأكد من حذف هذا العنصر؟', # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+
         'DefaultNewItem' => 'عنصر جديد',
         'NewItemTooltip' => 'إضافة عنصر جديد',
 		'NoItemFound' => 'لم يتم العثور على أي شيء. هل تود البحث ضمن موقع آخر؟',
         'OpenList' => 'قم بتحديد مجموعة',
 		'SaveList' => 'قم بتحديد مسار حفظ المجموعة',
         'SaveListTooltip' => 'حفظ المجموعة الحالية',
-		'SaveCurrentList' => 'هل تريد حفظ المجموعة الحالية؟',
         'SaveUnsavedChanges' => 'لم يتم حفظ التعديلات على مجموعتك لم تُحفظ. هل تريد حفظ التعديلات؟',
         'SaveDontSave' => 'لا تحفظ',
         'PreferencesTooltip' => 'تفضيلات البرنامج',
         'ViewTooltip' => 'تغيير عرض المجموعة',
-		'PlayTooltip' => 'قراءة ملف الفيديو المرتبط بالعنصر',
+		'PlayTooltip' => 'قراءة ملف الفيديو المرتبط بالعنصر', # Accepts model codes
         'PlayFileNotFound' => 'الملف الذي سيتم إستدعاؤه غير موجود في هذا المسار:',
         'PlayRetry' => 'إعادة القراءة',
 
@@ -188,8 +213,8 @@
         'ErrorModelUserDir' => 'النماذج المعرفة من قبل المستخدم موجودة ضمن: ',
         
         'RandomTooltip' => 'ما الذي ترغب برؤيته هذا المساء؟',
-        'RandomError'=> 'لم يتم تحديد أي عنصر',
-        'RandomEnd'=> 'لا توجد عناصر أكثر من ذلك',
+        'RandomError'=> 'لم يتم تحديد أي عنصر', # Accepts model codes
+        'RandomEnd'=> 'لا توجد عناصر أكثر من ذلك', # Accepts model codes
         'RandomNextTip'=> 'الإقتراح التالي',
         'RandomOkTip'=> 'قبول هذا العنصر',
         
@@ -210,7 +235,8 @@ http://mbnoimi.net/
 mhdbnoimi@gmail.com
 bashir.storm@gmail.com
 mbnoimi@gmail.com',
-        'AboutDesign' => 'تم أنجاز الشعار و تصميم الويب من قبل le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+        تم أنجاز الشعار و تصميم الويب من قبل le Spektre',
 
         'ToolbarRandom' => 'هذه اللّيلة',
 
@@ -260,6 +286,7 @@ mbnoimi@gmail.com',
         'ModelFieldFileAudio' => 'صوت',
         'ModelFieldFileProgram' => 'برنامج',
         'ModelFieldFileUrl' => 'رابط',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'حقول للأستعمال',
         'ModelOptionsFieldsAuto' => 'تلقائي',
         'ModelOptionsFieldsNone' => 'لا شيء',
@@ -289,10 +316,10 @@ mbnoimi@gmail.com',
         'ModelTooltipNumeric' => 'سيتم معاملة جميع المقارنات على أنها أعداد',
         'ModelTooltipQuick' => 'سيتم إضافة قائمة فرعية ضمن قائمة التصفية',
         
-        'ResultsTitle' => 'حدد عنصر',
+        'ResultsTitle' => 'حدد عنصر', # Accepts model codes
         'ResultsNextTip' => 'البحث ضمن الموقع',
         'ResultsPreview' => 'معاينة',
-        'ResultsInfo' => 'بإمكانك إضافة عدة عناصر للمجموعة عن طريق النقر المستمر على زر Ctrl أو Shift ثم إختيار العنصر',
+        'ResultsInfo' => 'بإمكانك إضافة عدة عناصر للمجموعة عن طريق النقر المستمر على زر Ctrl أو Shift ثم إختيار العنصر', # Accepts model codes
         
         'OptionsTitle' => 'التفضيلات',
 		'OptionsExpertMode' => 'متقدّم',
@@ -443,6 +470,11 @@ mbnoimi@gmail.com',
         'FileChooserDirectory' => 'مجلد',
         'FileChooserOpenDirectory' => 'حدد مجلد',
         'FileChooserOverwrite' => 'الملف موجود مسبقاً. هل تود إستبداله؟',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
         #Some default panels
         'PanelCompact' => 'مدمج',
@@ -461,14 +493,17 @@ mbnoimi@gmail.com',
         'PanelImageTitle' => 'حدد صورة',
         'PanelImageNoImage' => 'لا توجد صورة',
         'PanelSelectFileTitle' => 'حدد ملف',
+        'PanelLaunch' => 'Launch',
         'PanelRestoreDefault' => 'إستعادة الإفتراضيات',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Update information from web',
 
         'PanelFrom' =>'من',
         'PanelTo' =>'إلى',
 
         'PanelWeb' => 'عرض المعلومات',
-        'PanelWebTip' => 'عرض المعلومات من الإنترنت حول هذا العنصر',
-        'PanelRemoveTip' => 'حذف العنصر الحالي',
+        'PanelWebTip' => 'عرض المعلومات من الإنترنت حول هذا العنصر', # Accepts model codes
+        'PanelRemoveTip' => 'حذف العنصر الحالي', # Accepts model codes
 
         'PanelDateSelect' => 'حدد التاريخ',
         'PanelNobody' => 'لا أحد',
@@ -483,7 +518,7 @@ mbnoimi@gmail.com',
 
         'PanelLendDate' => 'تاريخ الإعارة',
         'PanelHistory' => 'تاريخ الإعارة',
-        'PanelReturned' => 'عنصر مُعاد',
+        'PanelReturned' => 'عنصر مُعاد', # Accepts model codes
         'PanelReturnDate' => 'تاريخ الإعادة',
         'PanelLendedYes' => 'مُعار',
         'PanelLendedNo' => 'متاح',
@@ -516,6 +551,8 @@ mbnoimi@gmail.com',
         'PluginsAuthor' => 'المؤلف',
         'PluginsLang' => 'اللغة',
         'PluginsUseSite' => 'أستخدم الموقع المحدّد من أجل عمليات البحث المستقبلية',
+        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+        'PluginDisabled' => 'Disabled',
 
         'BorrowersTitle' => 'إعدادات الإستعارة',
         'BorrowersList' => 'المستعيرون',
@@ -534,9 +571,9 @@ mbnoimi@gmail.com',
         'BorrowersImportType' => 'تنسيق الملف:',
         'BorrowersImportFile' => 'ملف:',
 
-        'BorrowedTitle' => 'عناصر مُعارة',
+        'BorrowedTitle' => 'عناصر مُعارة', # Accepts model codes
         'BorrowedDate' => 'منذ',
-        'BorrowedDisplayInPanel' => 'عرض العنصر في النافذة الرئيسية',
+        'BorrowedDisplayInPanel' => 'عرض العنصر في النافذة الرئيسية', # Accepts model codes
 
         'MailTitle' => 'إرسال رسالة إلكترونية',
         'MailFrom' => 'من: ',
@@ -545,8 +582,8 @@ mbnoimi@gmail.com',
         'MailSmtpError' => 'حدث خطأ لدى محاولة الإتصال بملقم SMTP',
         'MailSendmailError' => 'حدث خطأ لدى محاولة الإتصال بواسطة Sendmail',
 
-        'SearchTooltip' => 'البحث بعن عنصر',
-        'SearchTitle' => 'البحث عن عنصر',
+        'SearchTooltip' => 'البحث بعن عنصر', # Accepts model codes
+        'SearchTitle' => 'البحث عن عنصر', # Accepts model codes
         'SearchNoField' => 'No field have been selected for the search box.
 Add some of them in the Filters tab of the collection settings.',
 
@@ -585,7 +622,7 @@ Add some of them in the Filters tab of the collection settings.',
         'PropertiesDescription' => 'الوصف',
         'PropertiesFile' => 'معلومات الملف',
         'PropertiesFilePath' => 'مسار كامل',
-        'PropertiesItemsNumber' => 'عدد المرات',
+        'PropertiesItemsNumber' => 'عدد المرات', # Accepts model codes
         'PropertiesFileSize' => 'حجم',
         'PropertiesFileSizeSymbols' => ['بايت', 'كيلوبايت', 'ميغابايت', 'جيجابايت', 'تيرابايت', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'خصائص المجموعة',
@@ -609,8 +646,8 @@ Add some of them in the Filters tab of the collection settings.',
         'BookmarksNewFolder' => 'مجلد جديد',
 
         'AdvancedSearchType' => 'نوع البحث',
-        'AdvancedSearchTypeAnd' => 'مطابقة كل المعايير',
-        'AdvancedSearchTypeOr' => 'مطايقة معيار واحد على الأقل',
+        'AdvancedSearchTypeAnd' => 'مطابقة كل المعايير', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'مطايقة معيار واحد على الأقل', # Accepts model codes
         'AdvancedSearchCriteria' => 'المعيار',
         'AdvancedSearchAnyField' => 'أي حقل',
         'AdvancedSearchSaveTitle' => 'حفظ البحث',
@@ -624,6 +661,25 @@ Add some of them in the Filters tab of the collection settings.',
         'BugReportPlatform' => 'نظام التشغيل',
         'BugReportMessage' => 'رسالة الخطأ',
         'BugReportInformation' => 'معلومات إضافية',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
+
     );
 }
 1;
