@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -24,6 +24,22 @@
 #
 ###################################################
     
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
+
     use strict;
     use base 'Exporter';
 
@@ -46,7 +62,7 @@
 За да определите коя страница притежава информацията, можете
 да използвате <b>бутона под детайлите на филма</b>.',
         
-        'AllItemsFiltered' => 'Няма филм, отговарящ на критериите ви за търсене',
+        'AllItemsFiltered' => 'Няма филм, отговарящ на критериите ви за търсене', # Accepts model codes
         
 #Installation
         'InstallDirInfo' => 'Инсталиране в ',
@@ -97,14 +113,19 @@
 #Menus
         'MenuFile' => '_Файл',
             'MenuNewList' => '_Нова колекция',
+            'MenuStats' => 'Statistics',
             'MenuHistory' => '_Скоро използвани колекции',
-            'MenuLend' => 'Показване на заети филми',
+            'MenuLend' => 'Показване на заети филми', # Accepts model codes
             'MenuImport' => '_Импорт',	
             'MenuExport' => '_Експорт',
+            'MenuAddItem' => '_Add Item', # Accepts model codes
 
         'MenuEdit'  => '_Редактиране',
-            'MenuDuplicate' => '_Дубликат на филм',
-            'MenuEditDeleteCurrent' => '_Премахване на филм',
+            'MenuDuplicate' => '_Дубликат на филм', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate Items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All Items', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_Премахване на филм', # Accepts model codes  
+            'MenuEditDeleteCurrentPlural' => '_Remove Items', # Accepts model codes  
             'MenuEditFields' => '_Change collection fields',
             'MenuEditLockItems' => '_Заключване на колекция',
 
@@ -113,7 +134,7 @@
                 'MenuSavedSearchesSave' => 'Save current search',
                 'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'A_dvanced Search',
-            'MenuViewAllItems' => 'Показване на _всички филми',
+            'MenuViewAllItems' => 'Показване на _всички филми', # Accepts model codes  
             'MenuNoFilter' => '_Всякакъв',
 
         'MenuConfiguration' => '_Настройки',
@@ -132,7 +153,8 @@
             'MenuBugReport' => 'Report a _bug',
             'MenuAbout' => '_Относно GCstar',
 
-        'MenuNewWindow' => 'Показване на филм в _Нов Прозорец',
+        'MenuNewWindow' => 'Показване на филм в _Нов Прозорец', # Accepts model codes  
+        'MenuNewWindowPlural' => 'Show Items in _New Window', # Accepts model codes
         
         'ContextExpandAll' => 'Expand all',
         'ContextCollapseAll' => 'Collapse all',
@@ -141,22 +163,25 @@
         'ContextImageEditor' => 'Image Editor',
         'ContextImgFront' => 'Front',
         'ContextImgBack' => 'Back',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
 
         'DialogEnterNumber' => 'Please enter value',
 
-        'RemoveConfirm' => 'Сигурни ли сте, че желаето премахването на филма?',
-        'DefaultNewItem' => 'New item',
-        'NewItemTooltip' => 'Добавяне на нов филм',
+        'RemoveConfirm' => 'Сигурни ли сте, че желаето премахването на филма?', # Accepts model codes 
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+        
+        'DefaultNewItem' => 'New item', # Accepts model codes
+        'NewItemTooltip' => 'Добавяне на нов филм', # Accepts model codes
         'NoItemFound' => 'Не е намерен филм. Желаети ли търсене в друг сайт?',
         'OpenList' => 'Моля изберете колекция',
         'SaveList' => 'Моля изберете къде да се съхрани колекцията',
         'SaveListTooltip' => 'Съхраняване на текуща колекция',
-        'SaveCurrentList' => 'Първо определете къде да бъде съхранена текущата колекция',
         'SaveUnsavedChanges' => 'There are unsaved changes in your collection. Do you want to save them?',
         'SaveDontSave' => 'Don\'t save',
         'PreferencesTooltip' => 'Установете предпочитанията си',
         'ViewTooltip' => 'Промяна на изгледа на колекция',
-        'PlayTooltip' => 'Възпроизвеждане на видео, асоцииран с филм',
+        'PlayTooltip' => 'Възпроизвеждане на видео, асоцииран с филм', # Accepts model codes
         'PlayFileNotFound' => 'File to launch was not found in this location:',
         'PlayRetry' => 'Retry',
 
@@ -179,8 +204,8 @@
         'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'Какво да се гледа тази вечер?',
-        'RandomError'=> 'Няме филми, които да не сте гледали',
-        'RandomEnd'=> 'Няма повече филми',
+        'RandomError'=> 'Няме филми, които да не сте гледали', # Accepts model codes
+        'RandomEnd'=> 'Няма повече филми', # Accepts model codes
         'RandomNextTip'=> 'Следващо предложение',
         'RandomOkTip'=> 'Приемане на този филм',
         
@@ -198,7 +223,8 @@ Adolfo González: Програмист
 Автор на логото le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Българският превод е направен от Филип Андонов',
-        'AboutDesign' => 'Лого и дизайн на страницата от le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Лого и дизайн на страницата от le Spektre',
 
         'ToolbarRandom' => 'Довечера',
         
@@ -248,6 +274,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Audio',
         'ModelFieldFileProgram' => 'Program',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Fields to use',
         'ModelOptionsFieldsAuto' => 'Automatic',
         'ModelOptionsFieldsNone' => 'None',
@@ -276,10 +303,10 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'Should the values be consider as numbers for comparison',
         'ModelTooltipQuick' => 'This will add a submenu in the Filters one',
 
-        'ResultsTitle' => 'Избор на филм',
+        'ResultsTitle' => 'Избор на филм', # Accepts model codes
         'ResultsNextTip' => 'Търсене в следващ сайт',
         'ResultsPreview' => 'Preview',
-        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
+        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them', # Accepts model codes
         
         'OptionsTitle' => 'Предпочитания',
 		'OptionsExpertMode' => 'Expert Mode',
@@ -427,6 +454,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Directory',
         'FileChooserOpenDirectory' => 'Избор на директория',
         'FileChooserOverwrite' => 'Този файл вече съществува. Желаете ли презапис?',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
         'PanelCompact' => 'Компактен',
         'PanelReadOnly' => 'Само за четене',
@@ -444,14 +476,17 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Избор на изображение',
         'PanelImageNoImage' => 'No image',
         'PanelSelectFileTitle' => 'Избор на файл',
+        'PanelLaunch' => 'Launch',
         'PanelRestoreDefault' => 'Restore default',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Update information from web',
 
         'PanelFrom' =>'From',
         'PanelTo' =>'To',
 
         'PanelWeb' => 'Показване на информация',
-        'PanelWebTip' => 'Показване на информация от уеб за този филм',
-        'PanelRemoveTip' => 'Премахване на текущ филм',
+        'PanelWebTip' => 'Показване на информация от уеб за този филм', # Accepts model codes
+        'PanelRemoveTip' => 'Премахване на текущ филм', # Accepts model codes
 
         'PanelDateSelect' => 'Избор на дата',
         'PanelNobody' => 'Никой',
@@ -465,7 +500,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Взел',
         'PanelLendDate' => 'Не е наличен от',
         'PanelHistory' => 'История на заемането',
-        'PanelReturned' => 'Върнат филм',
+        'PanelReturned' => 'Върнат филм', # Accepts model codes
         'PanelReturnDate' => 'Дата на връщане',
         'PanelLendedYes' => 'Даден',
         'PanelLendedNo' => 'Наличен',
@@ -498,6 +533,8 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Автор',
         'PluginsLang' => 'Език',
         'PluginsUseSite' => 'Използване на избрания сайт за бъдещи търсения',
+         'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+         'PluginDisabled' => 'Disabled',
 
         'BorrowersTitle' => 'Конфигуриране на наемателя',
 		'BorrowersList' => 'Наематели',
@@ -516,9 +553,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'File format:',
         'BorrowersImportFile' => 'File:',
 
-        'BorrowedTitle' => 'Дадени филми',
+        'BorrowedTitle' => 'Дадени филми', # Accepts model codes
         'BorrowedDate' => 'От',
-        'BorrowedDisplayInPanel' => 'Show item in main window',
+        'BorrowedDisplayInPanel' => 'Show item in main window', # Accepts model codes
 
         'MailTitle' => 'Изпращане на е-поща',
         'MailFrom' => 'От: ',
@@ -527,8 +564,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Проблем при свързване със SMTP сървър',
         'MailSendmailError' => 'Проблем при стартиране на sendmail',
 
-        'SearchTooltip' => 'Търсене на всички филми',
-        'SearchTitle' => 'Търсене на филм',
+        'SearchTooltip' => 'Търсене на всички филми', # Accepts model codes
+        'SearchTitle' => 'Търсене на филм', # Accepts model codes
         'SearchNoField' => 'No field have been selected for the search box.
 Add some of them in the Filters tab of the collection settings.',
 
@@ -567,7 +604,7 @@ Add some of them in the Filters tab of the collection settings.',
         'PropertiesDescription' => 'Description',
         'PropertiesFile' => 'File Information',
         'PropertiesFilePath' => 'Full path',
-        'PropertiesItemsNumber' => 'Number of items',
+        'PropertiesItemsNumber' => 'Number of items', # Accepts model codes
         'PropertiesFileSize' => 'Size',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Collection properties',
@@ -591,8 +628,8 @@ Add some of them in the Filters tab of the collection settings.',
         'BookmarksNewFolder' => 'New folder',
 
         'AdvancedSearchType' => 'Type of search',
-        'AdvancedSearchTypeAnd' => 'Items matching all criteria',
-        'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
+        'AdvancedSearchTypeAnd' => 'Items matching all criteria', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Items matching at least one criterion', # Accepts model codes
         'AdvancedSearchCriteria' => 'Criteria',
         'AdvancedSearchAnyField' => 'Any field',
         'AdvancedSearchSaveTitle' => 'Save search',
@@ -606,6 +643,24 @@ Add some of them in the Filters tab of the collection settings.',
         'BugReportPlatform' => 'Operating system',
         'BugReportMessage' => 'Error message',
         'BugReportInformation' => 'Additional information',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
     );
 }
 1;
