@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -31,19 +31,25 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        CollectionDescription => 'Col·lecció de sèries de TV',
-        Items => 'Sèries',
-        NewItem => 'Nova sèrie',
+    
+        CollectionDescription => 'Col·lecció de sèries de televisió',
+        Items => {  0 => 'Sèries',
+                    1 => 'Sèrie',
+                    X => 'Sèries',
+                    lowercase1 => 'sèrie',
+                    lowercaseX => 'sèries'
+                    },
+        NewItem => 'Sèrie nova',
         Name => 'Nom',
         Season => 'Temporada',
         Part => 'Part',
         Episodes => 'Episodis',
-        FirstAired => 'Emès per primer cop',
-        Time => 'Durada Ep.',
+        FirstAired => 'Primera emissió',
+        Time => 'Durada de l\'episodi',
         Producer => 'Productor',
         Music => 'Música',
      );
-     importTranslation('Films');
+     importTranslation('films');
 }
 
 1;
