@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -24,6 +24,22 @@
 #
 ###################################################
 
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
+
     use strict;
     use base 'Exporter';
 
@@ -46,7 +62,7 @@ l\'autorització explícita dels respectius webs</b>.
 Per a saber quin és el web al que pertany la informació,
 podeu usar <b>el botó situat devall dels detalls de la pel·lícula</b>.',
 
-        'AllItemsFiltered' => 'Cap pel·lícula compleix amb els criteris de filtrat',
+        'AllItemsFiltered' => 'Cap pel·lícula compleix amb els criteris de filtrat', # Accepts model codes
 
 #Installation
         'InstallDirInfo' => 'Instal·la a ',
@@ -97,14 +113,19 @@ podeu usar <b>el botó situat devall dels detalls de la pel·lícula</b>.',
 #Menus
         'MenuFile' => '_Fitxer',
             'MenuNewList' => '_Nova llista de pel·lícules',	
+            'MenuStats' => 'Estadístiques',
             'MenuHistory' => '_Fitxers oberts recentment',
-            'MenuLend' => '_Mostra pel·lícules prestades',	
+            'MenuLend' => '_Mostra pel·lícules prestades', # Accepts model codes
             'MenuImport' => '_Importa',
             'MenuExport' => '_Exporta',	
+            'MenuAddItem' => '_Add Items', # Accepts model codes
 
         'MenuEdit'  => '_Edita',
-       	    'MenuDuplicate' => '_Duplica pel·lícula',
-            'MenuEditDeleteCurrent' => '_Esborra pel·lícula actual',
+       	    'MenuDuplicate' => '_Duplica pel·lícula', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate Items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All Items', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_Esborra pel·lícula actual', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove Items', # Accepts model codes    
             'MenuEditFields' => '_Canvia camps Col·lecció',
             'MenuEditLockItems' => '_Bloqueja la informació',
         
@@ -113,7 +134,7 @@ podeu usar <b>el botó situat devall dels detalls de la pel·lícula</b>.',
                  'MenuSavedSearchesSave' => 'Desa la cerca actual',
                  'MenuSavedSearchesEdit' => 'Modica cerques desades',
             'MenuAdvancedSearch' => '_Cerca avançada',
-            'MenuViewAllItems' => '_Mostra tots les elements',
+            'MenuViewAllItems' => '_Mostra tots les elements', # Accepts model codes
             'MenuNoFilter' => '_Tot',
 
         'MenuConfiguration' => '_Configura',	
@@ -132,7 +153,8 @@ podeu usar <b>el botó situat devall dels detalls de la pel·lícula</b>.',
             'MenuBugReport' => 'Comunica un _error',
             'MenuAbout' => 'A propòsit de _GCstar',	
 
-        'MenuNewWindow' => 'Mostra elements a una nova finestra',
+        'MenuNewWindow' => 'Mostra elements a una nova finestra', # Accepts model codes
+        'MenuNewWindowPlural' => 'Show Items in _New Window', # Accepts model codes
         
         'ContextExpandAll' => 'Expandeix tots',
         'ContextCollapseAll' => 'Colapsa tots',
@@ -141,22 +163,25 @@ podeu usar <b>el botó situat devall dels detalls de la pel·lícula</b>.',
         'ContextOpenWith' => 'Obri _amb',
         'ContextImgFront' => 'A sobre',
         'ContextImgBack' => 'A sota',
+        'ContextChooseFile' => 'Tria un fitxer',
+        'ContextChooseFolder' => 'Tria una carpeta',
 
         'DialogEnterNumber' => 'Entreu un valor',
 
-        'RemoveConfirm' => 'Realment voleu eliminar aquesta pel·lícula?',  
-        'DefaultNewItem' => 'Nou element',
-        'NewItemTooltip' => 'Afegeix un nou element',
+        'RemoveConfirm' => 'Realment voleu eliminar aquesta pel·lícula?',  # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+ 
+        'DefaultNewItem' => 'Nou element', # Accepts model codes
+        'NewItemTooltip' => 'Afegeix un nou element', # Accepts model codes
         'NoItemFound' => 'Cap element trobat. Voleu intentar una nova cerca a un altre lloc?',
         'OpenList' => 'Seleccioneu una col·lecció',
         'SaveList' => 'Seleccioneu on voleu desar la col·lecció',	
         'SaveListTooltip' => 'Desa la col·lecció actual', 
-        'SaveCurrentList' => 'Primer heu de triar a quin fitxer voleu desar la col·lecció actual',
         'SaveUnsavedChanges' => 'Hi ha canvis no desats a la Col·lecció. Voleu desar-los?',
         'SaveDontSave' => 'No ho guardis',
         'PreferencesTooltip' => 'Canvia les preferències',
         'ViewTooltip' => 'Canvia el tipus de col·lecció',
-        'PlayTooltip' => 'Reprodueix el vídeo associat a l\'element',
+        'PlayTooltip' => 'Reprodueix el vídeo associat a l\'element', # Accepts model codes
         'PlayFileNotFound' => 'El fitxer a reproduir no s\'ha trobat en aquest lloc:',
         'PlayRetry' => 'Torna-ho a intentar',
         
@@ -179,8 +204,8 @@ podeu usar <b>el botó situat devall dels detalls de la pel·lícula</b>.',
         'ErrorModelUserDir' => 'Els models definits per l\'usuari són a: ',
 
         'RandomTooltip' => 'Qué voleu veure aquesta nit?',
-        'RandomError'=> 'No queden elements per a seleccionar',
-        'RandomEnd'=> 'No hi ha més elements',
+        'RandomError'=> 'No queden elements per a seleccionar', # Accepts model codes
+        'RandomEnd'=> 'No hi ha més elements', # Accepts model codes
         'RandomNextTip'=> 'Següent suggerència',
         'RandomOkTip'=> 'Accepta aquest element',
                         
@@ -197,7 +222,8 @@ Adolfo González: Programació
 Logos Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Traducció: Ponç J. Llaneras',
-        'AboutDesign' => 'Logo i disseny web per le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logo i disseny web per le Spektre',
         
         'ToolbarRandom' => 'Aquesta nit',
 
@@ -247,6 +273,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Audio',
         'ModelFieldFileProgram' => 'Programa',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Camps a utilitzar',
         'ModelOptionsFieldsAuto' => 'Automàtic',
         'ModelOptionsFieldsNone' => 'Cap',
@@ -275,10 +302,10 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'Els valors es consideran com nombres per a la comparació',
         'ModelTooltipQuick' => 'Aquest afegirà un submenú al de filtres',
 
-        'ResultsTitle' => 'Tria una pel·lícula',
+        'ResultsTitle' => 'Tria una pel·lícula', # Accepts model codes
         'ResultsNextTip' => 'Cerca en el següent lloc',
         'ResultsPreview' => 'Previsualitza',
-        'ResultsInfo' => 'Podeu afegir múltiples elements a la col·lecció pitjant la tecla Ctrl o Majús i seleccionant-los',
+        'ResultsInfo' => 'Podeu afegir múltiples elements a la col·lecció pitjant la tecla Ctrl o Majús i seleccionant-los', # Accepts model codes
 
         'OptionsTitle' => 'Preferències',
 		'OptionsExpertMode' => 'Mode Expert',
@@ -305,13 +332,13 @@ http://le-spektre.org',
         'OptionsAskPlugins' => 'Pregunta',
         'OptionsPluginsMulti' => 'Diversos llocs',
         'OptionsPluginsMultiAsk' => 'Pregunta (Diversos llocs)',
-        'OptionsPluginsMultiPerField' => 'Diversos llocs (per field)',
-        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
-        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
-        'OptionsPluginsMultiPerFieldFirst' => 'First',
-        'OptionsPluginsMultiPerFieldLast' => 'Last',
-        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
-        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
+        'OptionsPluginsMultiPerField' => 'Molts llocs (per camp)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Molts llocs per ordre de selecció de camp',
+        'OptionsPluginsMultiPerFieldDesc' => 'Per a cada camp l\'omplirem amb la primera informació no buida començant per l\'esquerra',
+        'OptionsPluginsMultiPerFieldFirst' => 'Primer',
+        'OptionsPluginsMultiPerFieldLast' => 'Darrer',
+        'OptionsPluginsMultiPerFieldRemove' => 'Elimina',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Llista de camps seleccionats buida',
         'OptionsPluginsList' => 'Defineix la llista',
         'OptionsAskImport' => 'Tria els camps que han d\'importar-se',	
         'OptionsProxy' => 'Empra un proxy',	
@@ -426,6 +453,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Directori',
         'FileChooserOpenDirectory' => 'Tria un directori',	
         'FileChooserOverwrite' => 'Aquest fitxer ja existeix. Voleu substituir-lo?',
+        'FileAllFiles' => 'Tots els fitxers',
+        'FileVideoFiles' => 'Fitxers de vídeo',
+        'FileEbookFiles' => 'Fitxers de llibres electrònics',
+        'FileAudioFiles' => 'Fitxers de so',
+        'FileGCstarFiles' => 'Col·leccions GCstar',
 
         #Some default panels
         'PanelCompact' => 'Compacte',
@@ -434,24 +466,27 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Cerca informació',
         'PanelSearchTip' => 'Cerca informació al web sobre aquest nom',
-        'PanelSearchContextChooseOne' => 'Choose a site ...',
-        'PanelSearchContextMultiSite' => 'Use "Many sites"',
-        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
-        'PanelSearchContextOptions' => 'Change options ...',
+        'PanelSearchContextChooseOne' => 'Selecciona un lloc...',
+        'PanelSearchContextMultiSite' => 'Utilitza "Molts llocs"',
+        'PanelSearchContextMultiSitePerField' => 'Utilitza "Molts llocs per camp"',
+        'PanelSearchContextOptions' => 'Canvia opcions...',
         'PanelImageTipOpen' => 'Feu clic a la imatge per triar-ne una altre.',
         'PanelImageTipView' => 'Feu clic a la imatge per veure-la a mida real.',
         'PanelImageTipMenu' => 'Feu clic amb el botó dret per a més opcions.',
         'PanelImageTitle' => 'Tria una imatge',	
         'PanelImageNoImage' => 'Sense imatge',
         'PanelSelectFileTitle' => 'Tria un fitxer',
+        'PanelLaunch' => 'Launch',
         'PanelRestoreDefault' => 'Restaura els valors per defecte',
+        'PanelRefresh' => 'Actualitza',
+        'PanelRefreshTip' => 'Actualitza la informació des del web',
 
         'PanelFrom' =>'De',
         'PanelTo' =>'Per a',
 
         'PanelWeb' => 'Veure la fitxa a Internet',
-        'PanelWebTip' => 'Veure la fitxa de l\'element a Internet',	
-        'PanelRemoveTip' => 'Elimina l\'element actual', 
+        'PanelWebTip' => 'Veure la fitxa de l\'element a Internet', # Accepts model codes
+        'PanelRemoveTip' => 'Elimina l\'element actual', # Accepts model codes
 
         'PanelDateSelect' => 'Canvia la data',	
         'PanelNobody' => 'Ningú',	
@@ -465,7 +500,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Prestatari',
         'PanelLendDate' => 'Data',
         'PanelHistory' => 'Historial',
-        'PanelReturned' => 'Element retornat',	
+        'PanelReturned' => 'Element retornat', # Accepts model codes	
         'PanelReturnDate' => 'Data de devolució',
         'PanelLendedYes' => 'Prestada',
         'PanelLendedNo' => 'Disponible',
@@ -498,7 +533,9 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Idioma',
         'PluginsUseSite' => 'Utilitza el lloc seleccionat per a futures cerques',
-        
+        'PluginsPreferredTooltip' => 'Lloc recomenat per GCstar', 
+        'PluginDisabled' => 'Desactivat',
+       
         'BorrowersTitle' => 'Configuració dels prestataris',	
         'BorrowersList' => 'Prestataris',
         'BorrowersName' => 'Nom',
@@ -516,9 +553,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'Format del fitxer:',
         'BorrowersImportFile' => 'Fitxer:',
 
-        'BorrowedTitle' => 'Elements prestats',	
+        'BorrowedTitle' => 'Elements prestats', # Accepts model codes
         'BorrowedDate' => 'Des del',
-        'BorrowedDisplayInPanel' => 'Mostra l\'element a la finestra principal',
+        'BorrowedDisplayInPanel' => 'Mostra l\'element a la finestra principal', # Accepts model codes
         
         'MailTitle' => 'Envia un correu electrònic',	
         'MailFrom' => 'De: ',	
@@ -527,8 +564,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Problema de connexió amb el servidor SMTP',	
         'MailSendmailError' => 'Problema executant sendmail',	
 
-        'SearchTooltip' => 'Cerca a tots els elements',
-        'SearchTitle' => 'Cerca elements',	
+        'SearchTooltip' => 'Cerca a tots els elements', # Accepts model codes
+        'SearchTitle' => 'Cerca elements', # Accepts model codes	
         'SearchNoField' => 'No heu seleccionat cap camp a la finestra de cerca.
 Afegiu-ne alguns a la pestanya de filtres de la configuració de col·lecció.',
                 
@@ -567,7 +604,7 @@ Afegiu-ne alguns a la pestanya de filtres de la configuració de col·lecció.',
         'PropertiesDescription' => 'Descripció',
         'PropertiesFile' => 'Informació del fitxer',
         'PropertiesFilePath' => 'Cami complet',
-        'PropertiesItemsNumber' => 'Nombre d\'elements',
+        'PropertiesItemsNumber' => 'Nombre d\'elements', # Accepts model codes
         'PropertiesFileSize' => 'Mida',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Propietats de la col·lecció',
@@ -591,8 +628,8 @@ Afegiu-ne alguns a la pestanya de filtres de la configuració de col·lecció.',
         'BookmarksNewFolder' => 'Nova carpeta',
 
         'AdvancedSearchType' => 'Tipus de cerca',
-        'AdvancedSearchTypeAnd' => 'Elements que compleixen amb tots els criteris',
-        'AdvancedSearchTypeOr' => 'Elements que compleixen al menys amb un criteri',
+        'AdvancedSearchTypeAnd' => 'Elements que compleixen amb tots els criteris', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Elements que compleixen al menys amb un criteri', # Accepts model codes
         'AdvancedSearchCriteria' => 'Criteri',
         'AdvancedSearchAnyField' => 'Any field',
         'AdvancedSearchSaveTitle' => 'Desa la cerca',
@@ -606,6 +643,24 @@ Afegiu-ne alguns a la pestanya de filtres de la configuració de col·lecció.',
         'BugReportPlatform' => 'Sistema Operatiu',
         'BugReportMessage' => 'Missatge d\'error',
         'BugReportInformation' => 'Informació adicional',
+
+#Statistics
+        'Stats3DPie' => 'Pastís 3D',
+        'StatsAccumulate' => 'Acumula valors',
+        'StatsArea' => 'Àrees',
+        'StatsBars' => 'Barres',
+        'StatsDisplayNumber' => 'Mostra nombres',
+        'StatsFieldToUse' => 'Camp a utilitzar',
+        'StatsFontSize' => 'Mida de la font',
+        'StatsGenerate' => 'Genera',
+        'StatsHeight' => 'Alçada',
+        'StatsHistory' => 'Història',
+        'StatsKindOfGraph' => 'Tipus de gràfica',
+        'StatsPie' => 'Pastís',
+        'StatsSave' => 'Desa la imatge de les estadístiques a un fitxer',
+        'StatsShowAllDates' => 'Mostra totes les dates',
+        'StatsSortByNumber' => 'Ordena pel nombre de {lowercaseX}',
+        'StatsWidth' => 'Amplada'
     );
 }
 1;
