@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -67,6 +67,11 @@
         Unlockables => 'Možnosti odemčení',
         Unlockable => 'Odemčení',
         Howto => 'Jak odemknout',
+        Exclusive => 'Exclusive',
+        Resolutions => 'Display resolutions',
+        InstallationSize => 'Size',
+        Region => 'Region',
+        SerialNumber => 'Serial Number',        
 
         General => 'Hlavní',
         Details => 'Detaily',
