@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -23,7 +23,23 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 ###################################################
-    
+
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
+
     use strict;
     use base 'Exporter';
 
@@ -45,7 +61,7 @@ Jakákoliv redistribuce je zakázána bez <b>přímého souhlasu</b> serverů.
 K rozlišení, který server vlastní dané informace, můžete použít
 <b>tlačítko pod detaily každé položky</b>.',
         
-        'AllItemsFiltered' => 'Žádný záznam pro Vaše zadání',
+        'AllItemsFiltered' => 'Žádný záznam pro Vaše zadání', # Accepts model codes
         
 #Installation
         'InstallDirInfo' => 'Instaluji do ',
@@ -96,15 +112,20 @@ K rozlišení, který server vlastní dané informace, můžete použít
 #Menus
         'MenuFile' => '_Soubor',
             'MenuNewList' => '_Nová sbírka',
+            'MenuStats' => 'Statistics',
             'MenuHistory' => 'N_edávné sbírky',
-            'MenuLend' => 'Zobraz _půjčené položky',
+            'MenuLend' => 'Zobraz _půjčené položky', # Accepts model codes
             'MenuImport' => '_Import',	
             'MenuExport' => '_Export',
+            'MenuAddItem' => '_Add Items', # Accepts model codes
     
         'MenuEdit'  => '_Úpravy',
-            'MenuDuplicate' => '_Duplikuj položku',
-            'MenuEditDeleteCurrent' => '_Vymaž položku',
-            'MenuEditFields' => '_Změň pole sbírky',			#Change collection fields
+            'MenuDuplicate' => '_Duplikuj položku', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate Items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All Items', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_Vymaž položku', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove Items', # Accepts model codes   
+            'MenuEditFields' => '_Změň pole sbírky',			# Change collection fields
             'MenuEditLockItems' => '_Uzamkni sbírku',
     
         'MenuDisplay' => '_Filtr',
@@ -112,7 +133,7 @@ K rozlišení, který server vlastní dané informace, můžete použít
                 'MenuSavedSearchesSave' => 'Save current search',
                 'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => '_Pokročilé vyhledávání',
-            'MenuViewAllItems' => 'Zobrazit _všechny položky',
+            'MenuViewAllItems' => 'Zobrazit _všechny položky', # Accepts model codes
             'MenuNoFilter' => '_Vše',
     
         'MenuConfiguration' => '_Nastavení',
@@ -131,7 +152,8 @@ K rozlišení, který server vlastní dané informace, můžete použít
             'MenuBugReport' => 'Nahlásit _chybu',
             'MenuAbout' => '_O aplikaci GCstar',
     
-        'MenuNewWindow' => 'Zobrazit položky v _novém okně',
+        'MenuNewWindow' => 'Zobrazit položky v _novém okně', # Accepts model codes
+        'MenuNewWindowPlural' => 'Show Items in _New Window', # Accepts model codes
         
         'ContextExpandAll' => 'Zobraz vše',
         'ContextCollapseAll' => 'Skryj vše',
@@ -140,22 +162,25 @@ K rozlišení, který server vlastní dané informace, můžete použít
         'ContextImageEditor' => 'Image Editor',
         'ContextImgFront' => 'Front',
         'ContextImgBack' => 'Back',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
 
         'DialogEnterNumber' => 'Prosím zadej hodnotu',
 
-        'RemoveConfirm' => 'Opravdu chcete vymazat tuto položku?',
-        'DefaultNewItem' => 'Nová položka',
-        'NewItemTooltip' => 'Přidat novou položku',
+        'RemoveConfirm' => 'Opravdu chcete vymazat tuto položku?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+
+        'DefaultNewItem' => 'Nová položka', # Accepts model codes
+        'NewItemTooltip' => 'Přidat novou položku', # Accepts model codes
         'NoItemFound' => 'Položka nebyla nalezena. Chcete ji zkusit najít na jiném serveru?',
         'OpenList' => 'Prosím vyberte sbírku',
         'SaveList' => 'Prosím vyberte, kam uložit sbírku',
         'SaveListTooltip' => 'Uložit současnou sbírku',
-        'SaveCurrentList' => 'Napřed specifikujte, kam uložit současnou sbírku',
         'SaveUnsavedChanges' => 'Ve sbírce jste provedli změny. Chcete je nyní uložit?',
         'SaveDontSave' => 'Neukládat',
         'PreferencesTooltip' => 'Umožňuje změnu nastavení',
         'ViewTooltip' => 'Změní zobrazení sbírky',
-        'PlayTooltip' => 'Přehraje video asociované filmem',
+        'PlayTooltip' => 'Přehraje video asociované filmem', # Accepts model codes
         'PlayFileNotFound' => 'File to launch was not found in this location:',
         'PlayRetry' => 'Retry',
 
@@ -178,8 +203,8 @@ K rozlišení, který server vlastní dané informace, můžete použít
         'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'Co budu dělat dnes večer?',
-        'RandomError'=> 'Nic nemáte',
-        'RandomEnd'=> 'Nic dalšího nemáte',
+        'RandomError'=> 'Nic nemáte', # Accepts model codes
+        'RandomEnd'=> 'Nic dalšího nemáte', # Accepts model codes
         'RandomNextTip'=> 'Další tip',
         'RandomOkTip'=> 'Přijmout tento tip',
         
@@ -196,7 +221,8 @@ Adolfo González: Programmer
 Logos Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Český překlad připravil Tomáš Klimek (Tomas.Klimek@gmail.com)',
-        'AboutDesign' => 'Logo a webdesign od le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logo a webdesign od le Spektre',
 
         'ToolbarRandom' => 'Dnes večer',
         
@@ -246,6 +272,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Audio',
         'ModelFieldFileProgram' => 'Program',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Přiřazení polí',
         'ModelOptionsFieldsAuto' => 'Automaticky',
         'ModelOptionsFieldsNone' => 'Nic',
@@ -274,10 +301,10 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'Hodnoty budou považovány za čísla při porovnání',
         'ModelTooltipQuick' => 'Do menu filtr přidá submenu',			#This will add a submenu in the Filters one
 
-        'ResultsTitle' => 'Vyberte si ze seznamu',
+        'ResultsTitle' => 'Vyberte si ze seznamu', # Accepts model codes
         'ResultsNextTip' => 'Hledat na dalším serveru',
         'ResultsPreview' => 'Náhled',
-        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
+        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them', # Accepts model codes
         
         'OptionsTitle' => 'Možnosti',
 		'OptionsExpertMode' => 'Expert Mode',
@@ -425,6 +452,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Directory',
         'FileChooserOpenDirectory' => 'Vyberte adresář pro ukládání obrázků',
         'FileChooserOverwrite' => 'Tento soubor již existuje. Chcete jej přepsat?',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
         'PanelCompact' => 'Kompaktní',
         'PanelReadOnly' => 'Pouze pro čtení',
@@ -442,14 +474,17 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Vyberte obrázek',
         'PanelImageNoImage' => 'Bez obrázku',
         'PanelSelectFileTitle' => 'Vyberte soubor',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Obnovit výchozí nastavení',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Update information from web',
 
         'PanelFrom' =>'Od',
         'PanelTo' =>'Do',
 
         'PanelWeb' => 'Zobrazit informace',
-        'PanelWebTip' => 'Zobrazí informace o vybrané položce na webu',
-        'PanelRemoveTip' => 'Odstraní stávající položku',
+        'PanelWebTip' => 'Zobrazí informace o vybrané položce na webu', # Accepts model codes
+        'PanelRemoveTip' => 'Odstraní stávající položku', # Accepts model codes
 
         'PanelDateSelect' => 'Vyberte datum',
         'PanelNobody' => 'Žádný',
@@ -463,7 +498,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Dlužník',
         'PanelLendDate' => 'Půjčeno od',
         'PanelHistory' => 'Historie zápůjček',
-        'PanelReturned' => 'Položka vrácena',
+        'PanelReturned' => 'Položka vrácena', # Accepts model codes
         'PanelReturnDate' => 'Datum vrácení',
         'PanelLendedYes' => 'Půjčeno',
         'PanelLendedNo' => 'Dostupné',
@@ -496,6 +531,8 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Jazyk',
         'PluginsUseSite' => 'Použít vybraný server pro další hledání',
+        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+        'PluginDisabled' => 'Disabled',
 
         'BorrowersTitle' => 'Konfigurace dlužníků',
         'BorrowersList' => 'Dlužníci',
@@ -514,9 +551,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'Formát souboru:',
         'BorrowersImportFile' => 'Soubor:',
 
-        'BorrowedTitle' => 'Půjčené položky',
+        'BorrowedTitle' => 'Půjčené položky', # Accepts model codes
         'BorrowedDate' => 'Od',
-        'BorrowedDisplayInPanel' => 'Show item in main window',
+        'BorrowedDisplayInPanel' => 'Show item in main window', # Accepts model codes
 
         'MailTitle' => 'Poslat e-mail',
         'MailFrom' => 'Od: ',
@@ -525,8 +562,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Problém s připojením k SMTP serveru',
         'MailSendmailError' => 'Problém se spuštěním sendmailu',
 
-        'SearchTooltip' => 'Prohledává celý seznam',
-        'SearchTitle' => 'Hledání',
+        'SearchTooltip' => 'Prohledává celý seznam', # Accepts model codes
+        'SearchTitle' => 'Hledání', # Accepts model codes
         'SearchNoField' => 'No field have been selected for the search box.
 Add some of them in the Filters tab of the collection settings.',
 
@@ -565,7 +602,7 @@ Add some of them in the Filters tab of the collection settings.',
         'PropertiesDescription' => 'Popis',
         'PropertiesFile' => 'Informace o souboru',
         'PropertiesFilePath' => 'Úplná cesta',
-        'PropertiesItemsNumber' => 'Počet položek',
+        'PropertiesItemsNumber' => 'Počet položek', # Accepts model codes
         'PropertiesFileSize' => 'Velikost',
         'PropertiesFileSizeSymbols' => ['Bytů', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Vlastnosti sbírky',
@@ -589,8 +626,8 @@ Add some of them in the Filters tab of the collection settings.',
         'BookmarksNewFolder' => 'Nový adresář',
 
         'AdvancedSearchType' => 'Typ hledání',
-        'AdvancedSearchTypeAnd' => 'Položky odpovídají všem podmínkám',
-        'AdvancedSearchTypeOr' => 'Položky odpovídají alespoň jedné podmínce',
+        'AdvancedSearchTypeAnd' => 'Položky odpovídají všem podmínkám', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Položky odpovídají alespoň jedné podmínce', # Accepts model codes
         'AdvancedSearchCriteria' => 'Podmínky',
         'AdvancedSearchAnyField' => 'Any field',
         'AdvancedSearchSaveTitle' => 'Save search',
@@ -604,6 +641,24 @@ Add some of them in the Filters tab of the collection settings.',
         'BugReportPlatform' => 'Operační systém',
         'BugReportMessage' => 'Chybová zpráva',
         'BugReportInformation' => 'Další informace',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
     );
 }
 1;
