@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -40,7 +40,7 @@
         'Title' => 'Seitentitel',
         'InfoFile' => 'Liste erstellt: ',
         'InfoDir' => 'Bilder gespeichert unter: ',
-        'HeightImg' => 'Höhe der zu exportierende Bilder (in Pixeln): ',
+        'HeightImg' => 'Höhe der zu exportierenden Bilder (in Pixeln): ',
         'OpenFileInBrowser' => 'Erzeugte Datei im Webbrowser öffnen',
         'Note' => 'Liste erstellt mit <a href="http://www.gcstar.org/">GCstar</a>',
         'InputTitle' => 'Suchtext eingeben',
