@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -32,7 +32,7 @@
     our %lang = (
         'Where' => 'Wo soll gesucht werden',
         'Default' => 'Vorgabeverzeichnis von Alexandria',
-        'Specified' => 'Verzeichnis wie untern angegeben',
+        'Specified' => 'Verzeichnis wie unten angegeben',
      );
 }
 
