@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,6 +33,9 @@
         'Charset' => 'Zeichenkodierung',
         'Header' => 'Erste Zeile ignorieren',
         'Separator' => 'Feldtrenner',
+        'Plugin' => 'Zu verwendende Seite',
+        'UseFirst' => 'Bei mehreren Ergebnissen erstes verwenden',
+        'SearchField' => 'verwende dieses Feld für die Suche',
      );
 }
 
