@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -49,13 +49,13 @@
         'NoResultTooltip'=> 'Vorgehensweise wenn das Plugin kein Ergebnis liefert',
         'RemoveTooltipWholeWord' => 'Wörter entfernen wenn sie als gesamtes Wort erscheinen',
         'RemoveRegularExpr' => 'Reguläre Ausdrücke',
-        'RemoveTooltipRegularExpr' => 'Zähle \'To be removed from names\' als Regulären Perl Ausdruck',
+        'RemoveTooltipRegularExpr' => 'Zähle \'To be removed from names\' als regulären Perl Ausdruck',
         'SkipFileAlreadyInCollection' => 'Nur unbekannte Dateien hinzufügen',
         'SkipFileAlreadyInCollectionTooltip' => 'Nur Dateien hinzufügen, die nicht Teil der Sammlung sind',
         'SkipFileNo' => 'Nein',
         'SkipFileFullPath' => 'basierend auf kompletten Pfad',
         'SkipFileFileName' => 'basierend auf komplettem Pfad',
-        'SkipFileFileNameAndUpdate' => 'basierend auf komplettem Pfad (neuen Pfad für bewegte Dateien eintragen)',       
+        'SkipFileFileNameAndUpdate' => 'basierend auf komplettem Pfad (neuen Pfad für bewegte Dateien eintragen)',
         'InfoFromFileNameRegExp' => 'Verarbeite Dateinamen mit diesem regulären Ausdruck',
         'InfoFromFileNameRegExpTooltip' => 'Nachfolgende Informationen können für die Verarbeitugn verwendet werden (nach dem Entfernen der Dateiendung).\nLeer lassen, wenn nicht benötigt wird.\nBekannte Felder: \n$T:Titel, $A:Alphabetisierte Titel, $Y:Veröffentlichungsdatum, $S:Jahrgang, $E:Episode, $N:Alphabetisierter Serienname, $x:Nummer der Folge, $y: Anzahl Gesamtfolgen',
 
