@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -34,12 +34,13 @@
     
         CollectionDescription => 'Episodensammlung von Fernsehserien',
         Items => {
-			0 => 'Episode',
-			1 => 'Episode',
-			X => 'Episoden'},
-        NewItem => 'Neue Episode',
+			0 => 'Folge',
+			1 => 'Folge',
+			X => 'Folgen'},
+        NewItem => 'Neue Folge',
         NewSeries => 'Neue Serie',
-        Episode => 'Episode',
+        Episode => 'Folge',
+        Writer => 'Drehbuch',
     );
     # Both of them are required as importTranslation doesn't recurse
     importTranslation('films');
