@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -41,7 +41,7 @@
         Name => 'Name',
         Season => 'Staffel',
         Part => 'Teil',
-        Episodes => 'Episode',
+        Episodes => 'Folge',
         FirstAired => 'Erstausstrahlung',
         Time => 'Länge',
         Producer => 'Produzent',
