@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -32,9 +32,12 @@
     our %lang = (
     
         CollectionDescription => 'Büchersammlung',
-        Items => 'Bücher',
+        Items => {0 => 'Buch',
+          1 => 'Buch',
+          X => 'Bücher',
+          },
         NewItem => 'Neues Buch',
-    
+
         Isbn => 'ISBN',
         Title => 'Titel',
         Cover => 'Umschlag',
@@ -49,12 +52,13 @@
         Pages => 'Seiten',
         Read => 'Gelesen',
         Acquisition => 'Anschaffungsdatum',
-        Edition => 'Edition',
+        Edition => 'Auflage',
         Format => 'Format',
         Comments => 'Kommentare',
         Url => 'Webseite',
         Translator => 'Übersetzung',
         Artist => 'Künstler',
+        DigitalFile => 'Digitalversion',
 
         General => 'Allgemein',
         Details => 'Details',
