@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,8 +33,9 @@
     
         CollectionDescription => 'Comicheftsammlung',
         Items => {0 => 'Comicheft',
-                  1 => 'Comicheft',
-                  X => 'Comichefte'},
+          1 => 'Comicheft',
+          X => 'Comichefte'
+                 },
         NewItem => 'Neues Comicheft',
     
     
@@ -49,17 +50,17 @@
         Publisher => 'Herausgeber',
         Synopsis => 'Zusammenfassung',
         Collection => 'Sammlung',
-        PublishDate => 'Veröffentlichungsdatum',
+        PublishDate => 'Erscheinungsdatum',
         PrintingDate => 'Druckdatum',
         ISBN => 'ISBN',
         Type => 'Typ',
-		Category => 'Kategorie',
+        Category => 'Kategorie',
         Format => 'Format',
         NumberBoards => 'Anzahl der Boards',
-		Signing => 'Signiert',
+        Signing => 'signiert',
         Cost => 'Preis',
         Rating => 'Bewertung',
-        Comment => 'Kommentare',
+        Comment => 'Bemerkungen',
         Url => 'Internetseite',
 
         FilterRatingSelect => 'Bewertung _mindestens...',
