@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -32,10 +32,13 @@
     our %lang = (
     
         CollectionDescription => 'Filmsammlung',
-        Items => 'Filme',
+        Items => {0 => 'Film',
+                  1 => 'Film',
+                  X => 'Filme',
+                  },
+
         NewItem => 'Neuer Film',
-    
-    
+
         Id => 'Kennung',
         Title => 'Titel',
         Date => 'Datum',
@@ -51,7 +54,7 @@
         Role => 'Rolle',
         Comment => 'Kommentar',
         Synopsis => 'Beschreibung',
-        Seen => 'Gesehen',
+        Seen => 'gesehen',
         Number => '# der Medien',
         Format => 'Format',
         Region => 'Region',
@@ -60,7 +63,7 @@
         Audio => 'Audio',
         Video => 'Videoformat',
         Trailer => 'Videodatei',
-        Serie => 'Sammlung',
+        Serie => 'Serie',
         Rank => 'Teil/Folge',
         Subtitles => 'Untertitel',
 
