@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -64,13 +64,18 @@
         Unlockables => 'Lösungen',
         Unlockable => 'Ziel',
         Howto => 'Lösungsweg',
+        Exclusive => 'Exclusive',
+        Resolutions => 'Bildschirmauflösungen',
+        InstallationSize => 'Größe',
+        Region => 'Region',
+        SerialNumber => 'Seriennummer',
 
         General => 'Allgemein',
         Details => 'Details',
         Tips => 'Tipps',
         Information => 'Information',
 
-        FilterRatingSelect => 'Bewertung _mindestens ...',
+        FilterRatingSelect => 'Bewertung _mindestens...',
      );
 }
 
