@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -32,9 +32,12 @@
     our %lang = (
     
         CollectionDescription => 'Musiksammlung',
-        Items => 'Alben',
+        Items => {0 => 'Album',
+          1 => 'Album',
+          X => 'Alben',
+          },
         NewItem => 'Neues Album',
-    
+
         Unique => 'ISRC/EAN',
         Title => 'Titel',
         Cover => 'Cover',
