@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -31,21 +31,25 @@
 
     our %lang = (
     
-        CollectionDescription => 'Periodicals collection',
-        Items => {0 => 'Periodical',
-                  1 => 'Periodical',
-                  X => 'Periodicals'},
-        NewItem => 'New periodical',
+        CollectionDescription => 'Zeitschriftensammlung',
+        Items => {0 => 'Heft',
+                  1 => 'Heft',
+                  X => 'Hefte'},
+        NewItem => 'Neues Heft',
     
-        Title => 'Title',
-        Cover => 'Cover',
-        Periodical => 'Periodical',
-        Number => 'Number',
-        Date => 'Date',
-        Subject => 'Subject',
-        Articles => 'Articles',
+        Title => 'Titel',
+        Cover => 'Titelseite',
+        Periodical => 'Zeitschrift',
+        Number => 'Nummer',
+        Date => 'Datum',
+        Subject => 'Stichworte',
+        Articles => 'Inhalt',
 
-        General => 'General',
+        Article => 'Artikel',
+        Page => 'Seite',
+        Résumé => 'Zusammenfassung',
+
+        General => 'Allgemein',
      );
 }
 
