@@ -65,11 +65,11 @@
         PrintingVariety => 'Druck',
         IssueDate => 'Erstausgabedatum',
         EndOfIssue => 'gültig bis',
-        Issue => 'Issue',
+        Issue => 'Auflage',
         Grade => 'Erhaltung',
         Status => 'Status',
         Adjusted => 'Adjusted',
-        Cancellation => 'Cancellation',
+        Cancellation => 'Entwertung',
         CancellationCondition => 'Stempelqualität',
         GumCondition => 'Zustand der Gummierung',
         PerforationCondition => 'Zustand der Perforation',
@@ -89,17 +89,17 @@
         AirMail => 'Luftpost',
         MilitaryStamp => 'Feldpost',
         Official => 'offiziell',
-        PostageDue => 'Postage due',
-        Regular => 'Regular',
-        Revenue => 'Revenue',
+        PostageDue => 'Nachgebühr',
+        Regular => 'Regulär',
+        Revenue => 'Erlös',
         SpecialDelivery => 'Sondermarke',
-        StrikeStamp => 'Strike stamp',
-        TelegraphStamp => 'Telegraph stamp',
-        WarStamp => 'War stamp',
-        WarTaxStamp => 'War tax stamp',
+        StrikeStamp => 'Streikmarke',
+        TelegraphStamp => 'Telegrafenmarke',
+        WarStamp => 'Feldpostmarke',
+        WarTaxStamp => 'Kriegssteuermarke',
 
-        Booklet => 'Booklet',
-        BookletPane => 'Booklet Pane',
+        Booklet => 'Markenheftchen',
+        BookletPane => 'Heftchenblatt',
         Card => 'Postkarte',
         Coil => 'Rolle',
         Envelope => 'Umschlag',
@@ -107,59 +107,59 @@
         Sheet => 'Bogen',
         Single => 'Einzelexemplar',
 
-        Heliogravure => 'Heliogravure',
-        Lithography => 'Lithography',
+        Heliogravure => 'Heliogravüre',
+        Lithography => 'Lithographie',
         Offset => 'Offset',
-        Photogravure => 'Photogravure',
-        RecessPrinting => 'Tiefdruck',
-        Typography => 'Typography',
+        Photogravure => 'Rastertiefdruck',
+        RecessPrinting => 'Stichtiefdruck',
+        Typography => 'Schriftsatz',
 
         OriginalGum => 'Originalgummierung',
         Ungummed => 'ungummiert',
         Regummed => 'nachgummiert',
 
-        Chalky => 'Chalky',
-        ChinaPaper => 'China paper',
-        Coarsed => 'Coarsed',
-        Glossy => 'glänzend',
+        Chalky => 'gestrichenes Papier',
+        ChinaPaper => 'Chinapapier',
+        Coarsed => 'Rauh',
+        Glossy => 'Glänzend',
         Granite => 'Granite',
-        Laid => 'Laid',
+        Laid => 'Gestreift',
         Manila => 'Manila',
         Native => 'Native',
-        Pelure => 'Pelure',
-        Quadrille => 'Quadrille',
-        Ribbed => 'Ribbed',
-        Rice => 'Rice',
-        Silk => 'Silk',
-        Smoothed => 'Smoothed',
-        Thick => 'Thick',
-        Thin => 'Thin',
-        Wove => 'Wove',
+        Pelure => 'Zigarettenpapier',
+        Quadrille => 'Gegittert',
+        Ribbed => 'Riffelung',
+        Rice => 'Reis',
+        Silk => 'Seide',
+        Smoothed => 'Geglättet',
+        Thick => 'Dick',
+        Thin => 'Dünn',
+        Wove => 'Gewebt',
 
-        CoarsedPerforation => 'Coarsed perforation',
-        CombPerforation => 'Comb perforation',
-        CompoundPerforation => 'Compound perforation',
-        DamagedPerforation => 'Damaged perforation',
-        DoublePerforation => 'Double perforation',
-        HarrowPerforation => 'Harrow perforation',
-        LinePerforation => 'Line perforation',
-        NoPerforation => 'No perforation',
+        CoarsedPerforation => 'Rauhe Perforation',
+        CombPerforation => 'Gekämmte Perforation',
+        CompoundPerforation => 'Gemischte Perforation',
+        DamagedPerforation => 'Beschädigte Perforation',
+        DoublePerforation => 'Doppelte Oerforation',
+        HarrowPerforation => 'Eckige Perforation',
+        LinePerforation => 'Gerade Perforation',
+        NoPerforation => 'Keine Perforation',
 
-        CancellationToOrder => 'Cancellation To Order',
+        CancellationToOrder => 'Gefälligkeitsstempel',
         FancyCancellation => 'Sonderstempel',
         FirstDayCancellation => 'Ersttagsstempel',
-        NumeralCancellation => 'Numeral cancellation',
-        PenMarked => 'Pen-Marked',
-        RailroadCancellation => 'Railroad cancellation',
-        SpecialCancellation => 'Special cancellation',
+        NumeralCancellation => 'Nummernstempel',
+        PenMarked => 'Federzugentwertung',
+        RailroadCancellation => 'Eisenbahnentwertung',
+        SpecialCancellation => 'Spezielle Entwertung',
 
-        Superb => 'Superb',
-        ExtraFine => 'Extra-Fine',
-        VeryFine => 'Very fine',
-        FineVeryFine => 'Fine/Very fine',
-        Fine => 'Fine',
-        Average => 'Average',
-        Poor => 'Schlecht',
+        Superb => 'Luxuserhaltung',
+        ExtraFine => 'Kabinetterhaltung',
+        VeryFine => 'Prachterhaltung',
+        FineVeryFine => 'Feinsterhaltung',
+        Fine => 'Feinerhaltung',
+        Average => 'Durchschnittserhaltung',
+        Poor => 'Knochenerhaltung',
 
         Owned => 'im Besitz',
         Ordered => 'bestellt',
@@ -171,18 +171,18 @@
         HeavyCancellation => 'starker Stempel',
         ModerateCancellation => 'normaler Stempel',
 
-        MintNeverHinged => 'Mint never hinged',
-        MintLightHinged => 'Mint light hinged',
-        HingedRemnant => 'Hinged remnant',
-        HeavilyHinged => 'Heavily hinged',
-        LargePartOriginalGum => 'Large part original gum',
-        SmallPartOriginalGum => 'Small part original gum',
-        NoGum => 'No gum',
+        MintNeverHinged => 'Prägung niemals gefaltet',
+        MintLightHinged => 'Prägung leicht gefaltet',
+        HingedRemnant => 'Faltung sichtbar',
+        HeavilyHinged => 'Stark gefaltet',
+        LargePartOriginalGum => 'Große Teile der originalen Gummierung',
+        SmallPartOriginalGum => 'Kleine Teile der originalen Gummierung',
+        NoGum => 'Keine Gummierung',
 
-        Perfect => 'Perfect',
-        VeryNice => 'Very nice',
-        Nice => 'Nice',
-        Incomplete => 'Incomplete',
+        Perfect => 'Perfekt',
+        VeryNice => 'Sehr gut',
+        Nice => 'Gut',
+        Incomplete => 'Unvollständig',
      );
 }
 
