@@ -272,7 +272,7 @@ Logo und Webdesign von le Spektre',
         'ModelFieldFileAudio' => 'Audio',
         'ModelFieldFileProgram' => 'Programm',
         'ModelFieldFileUrl' => 'URL',
-        'ModelFieldFileEbook' => 'Ebook',
+        'ModelFieldFileEbook' => 'E-Book',
         'ModelOptionsFields' => 'zu benutzende Felder',
         'ModelOptionsFieldsAuto' => 'Automatisch',
         'ModelOptionsFieldsNone' => 'Keine',
@@ -297,7 +297,7 @@ Logo und Webdesign von le Spektre',
         'ModelTooltipHistory' => 'Alle hier eingegebenen Werte werden in einer Liste gespeichert und können darüber auch wieder ausgewählt werden',
         'ModelTooltipFormat' => 'Das Format wird benutzt, um eine geeignete Anwendung mit dem "Öffnen"-Knopf zu verbinden',
         'ModelTooltipLending' => 'Fügt Felder zur Verwaltung der Ausleihe hinzu',
-        'ModelTooltipTagging' => 'Fügt Felder zur Verwaltung von Tags hinzu',
+        'ModelTooltipTagging' => 'Fügt Felder zur Verwaltung von Markierungen hinzu',
         'ModelTooltipNumeric' => 'In Vergleichsoperationen wird der Wert als Zahl interpretiert',
         'ModelTooltipQuick' => 'Fügt ein Untermenü zu "Filter" hinzu',
 
@@ -384,7 +384,7 @@ Logo und Webdesign von le Spektre',
         'OptionsRestoreAccelerators' => 'Schnellzugriffe wiederherstellen',
         'OptionsHistory' => 'Größe des Verlaufs',
         'OptionsClearHistory' => 'Verlauf löschen',
-        'OptionsStyle' => 'Skin',
+        'OptionsStyle' => 'Erscheinungsbild',
         'OptionsDontAsk' => 'Nicht mehr fragen',
         'OptionsPathProgramsGroup' => 'Anwendungsprogramme',
         'OptionsProgramsSystem' => 'Nutze systemweite Einstellungen',
@@ -517,9 +517,9 @@ Logo und Webdesign von le Spektre',
         'PanelLendedYes' => 'Verliehen',
         'PanelLendedNo' => 'Verfügbar',
 
-        'PanelTags' => 'Tags',
+        'PanelTags' => 'Markierungen',
         'PanelFavourite' => 'Favoriten',
-        'TagsAssigned' => 'Zugeordnete Tags', 
+        'TagsAssigned' => 'Zugeordnete Markierungen', 
 
         'PanelUser' => 'Nutzerfeld',
 
@@ -585,7 +585,7 @@ Füge einige davon in der Filtersektion unter Einstellungen hinzu.',
         'QueryReplaceOld' => 'Bisheriger Name',
         'QueryReplaceNew' => 'Neuer Name',
         'QueryReplaceLaunch' => 'Ersetzen',
-        
+
         'ImportWindowTitle' => 'Wählen Sie die zu importierenden Felder',
         'ImportViewPicture' => 'Bild ansehen',
         'ImportSelectAll' => 'Alles auswählen',
