@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -37,11 +37,11 @@
           'SuffixesTooltip' => 'Να ληφθεί υπ\'όψη η λίστα με διαχωρισμό με κόμμα  των suffixes ή με τις επεκτάσεις των αρχείων',
           'Remove' => 'Να διαγραφεί από τα ονόματα',
           'RemoveTooltip' => 'Η λίστα των λέξεων διαχωρισμένες με κόμμα που θα πρέπει να διαγραφεί από τα ονόματα αρχείων για την δημιουργία ονόματος αναζήτησης',
-        'Ask'=> 'Ask',
-        'AskEnd'=> 'Ask all at end',
-        'AddWithoutInfo'=> 'Add without infos',
-        'DontAdd'=> 'Do not add',
-        'TakeFirst' => 'Select first',
+        'Ask'=> 'Ερώτηση',
+        'AskEnd'=> 'ερώτηση όλων στο τέλο',
+        'AddWithoutInfo'=> 'Προσθήκη χωρίς πληροφορίες',
+        'DontAdd'=> 'Να μην προστεθεί',
+        'TakeFirst' => 'Επιλογή πρώτου',
         'MultipleResult'=> 'Αγνόησε όταν υπάρχουν περισσότερο από 1 απαντήσεις',
  		'MultipleResultTooltip'=> 'Το αρχείο θα προστεθεί χωρίς αναζήτηση πληροφοριών αν υπάρχουν περισσότερο από 1 απαντήσεις',
  		'RemoveWholeWord' => 'Αφαίρεση μόνο ολόκληρων λέξεων',
@@ -54,11 +54,10 @@
  		'SkipFileFullPath' => 'βασισμένο σε ολόκληρη τη διαδρομή',
  		'SkipFileFileName' => 'βασισμένο στο όνομα αρχείου',
  		'SkipFileFileNameAndUpdate' => 'βασισμένο στο όνομα αρχείου (αλλά με ενημέρωση διαδρομής στη συλλογή)',  
-        'NoResult'=> 'No results',
-        'NoResultTooltip'=> 'What do we do when no search results is return by the plugin',
-        'InfoFromFileNameRegExp' => 'Parse file name with this regular expression',
-        'InfoFromFileNameRegExpTooltip' => 'Use this to retrieve infos from filename (applied after removing extension).\nLeave empty if not needed.\nKnown fields : \n$T:Title, $A:Alphabetised title, $Y:Release date, $S:Season, $E:Episode, $N:Alphabetised serie name, $x:Part number, $y: Total part number',
-
+        'NoResult'=> 'Κανένα αποτέλεσμα',
+        'NoResultTooltip'=> 'Τι θα γίνεται αν δεν βρεθούν αποτελέσματα αναζήτησης από το πρόσθετο',
+        'InfoFromFileNameRegExp' => 'Ανάλυση ονόματος αρχείου με αυτη την κανονική έκφραση',
+        'InfoFromFileNameRegExpTooltip' => 'Χρήση αυτού για ανάκτηση πληροφοριών από το όνομα αρχείου (εφαρμόζεται μετά την αφαίρεση της επέκτασης). Αφήστε κενό αν δεν χρησιμοποιείται. Γνωστά πεδία: $T:Τίτλος, $A:Τίτλος αλφαβητικά, $Y:Ημερομηνία έκδοσης, $S:Σεζόν, $E:Επισόδειο, $N:Όνομα σειράς αλφαβητικά, $x:Αριθμός μέρους, $y: Σύνολο αριθμού μερών',
      );
 
     # As this plugin shares some values with ImportList, it adds them from it
