@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -23,7 +23,23 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 ###################################################
-    
+
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
+
     use strict;
     use base 'Exporter';
 
@@ -46,7 +62,7 @@ search plugins) προορίζονται για <b>προσωπική χρήση
 Για να προσδιορίσετε από ποιο site προέρχονται οι πληροφορίες, μπορείτε 
 να χρησιμοποιήσετε το κουμπί κάτω από το σημείο <b>λεπτομέρειες</b>.',
         
-        'AllItemsFiltered' => 'Δεν βρέθηκαν αποτελέσματα σύμφωνα με τα κριτήρια αναζήτησης',
+        'AllItemsFiltered' => 'Δεν βρέθηκαν αποτελέσματα σύμφωνα με τα κριτήρια αναζήτησης', # Accepts model codes
         
 #Installation
         'InstallDirInfo' => 'Εγκατάσταση σε ',
@@ -97,14 +113,19 @@ search plugins) προορίζονται για <b>προσωπική χρήση
 #Menus
         'MenuFile' => '_Αρχείο',
             'MenuNewList' => '_Νέα συλλογή',
+            'MenuStats' => 'Στατιστικά',
             'MenuHistory' => 'Αν_οιγμένα πρόσφατα',
-            'MenuLend' => 'Ε_μφάνιση διανεισμένων στοιχείων',
+            'MenuLend' => 'Ε_μφάνιση διανεισμένων στοιχείων', # Accepts model codes
             'MenuImport' => 'Ει_σαγωγή',	
             'MenuExport' => 'Εξα_γωγή',
+            'MenuAddItem' => '_Add Items', # Accepts model codes 
     
         'MenuEdit'  => '_Επεξεργασία',
-            'MenuDuplicate' => '_Δημιουργία διπλότυπου',
-            'MenuEditDeleteCurrent' => '_Αφαίρεση στοιχείου',
+            'MenuDuplicate' => '_Δημιουργία διπλότυπου', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate Items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All Items', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_Αφαίρεση στοιχείου', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove Items', # Accepts model codes    
             'MenuEditFields' => 'Α_ντικατάσταση πεδίων',
             'MenuEditLockItems' => '_Κλείδωμα Συλλογής',
     
@@ -113,7 +134,7 @@ search plugins) προορίζονται για <b>προσωπική χρήση
                 'MenuSavedSearchesEdit' => 'Επεξεργασία αποθηκευμένων αναζητήσεων',
                 'MenuSavedSearchesSave' => 'Αποθήκευση τρέχουσας αναζήτησης',
             'MenuAdvancedSearch' => 'Ε_ξελιγμένη αναζήτηση',
-            'MenuViewAllItems' => 'Εμφάνιση _Όλων ',
+            'MenuViewAllItems' => 'Εμφάνιση _Όλων ', # Accepts model codes
             'MenuNoFilter' => '_Όλα',
     
         'MenuConfiguration' => '_Ρυθμίσεις',
@@ -132,7 +153,8 @@ search plugins) προορίζονται για <b>προσωπική χρήση
             'MenuBugReport' => 'Αναφορά _bug',
             'MenuAbout' => '_Σχετικά με το GCstar',
     
-        'MenuNewWindow' => 'Εμφάνιση στοιχείων σε _Νέο Παράθυρο',
+        'MenuNewWindow' => 'Εμφάνιση στοιχείων σε _Νέο Παράθυρο', # Accepts model codes
+        'MenuNewWindowPlural' => 'Εμφάνιση στοιχείων σε _Νέο Παράθυρο', # Accepts model codes
         
         'ContextExpandAll' => 'Επέκταση όλων',
         'ContextCollapseAll' => 'Σύμπτυξη όλων',
@@ -141,22 +163,25 @@ search plugins) προορίζονται για <b>προσωπική χρήση
         'ContextOpenWith' => 'Άνοιγμα _με',
         'ContextImgFront' => 'Εξώφυλλο',
         'ContextImgBack' => 'Πίσω φύλλο',
+        'ContextChooseFile' => 'Επιλογή αρχείου',
+        'ContextChooseFolder' => 'Επιλογή φακέλου',
         
         'DialogEnterNumber' => 'Παρακαλώ εισάγετε τιμή',
 
-        'RemoveConfirm' => 'Θέλετε πραγματικά να διαγραφεί το στοιχείο;',
-        'DefaultNewItem' => 'Νέο στοιχείο',
-        'NewItemTooltip' => 'Προσθήκη νέου στοιχείου',
+        'RemoveConfirm' => 'Θέλετε πραγματικά να διαγραφεί το στοιχείο;', # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+        
+        'DefaultNewItem' => 'Νέο στοιχείο', # Accepts model codes
+        'NewItemTooltip' => 'Προσθήκη νέου στοιχείου', # Accepts model codes
         'NoItemFound' => 'Δεν βρέθηκαν αποτελέσματα. Αναζήτηση σε άλλη ιστοσελίδα;',
         'OpenList' => 'Παρακαλώ επιλέξτε συλλογή',
         'SaveList' => 'Παρακαλώ επιλέξτε που να γίνει η αποθήκευση της συλλογής',
         'SaveListTooltip' => 'Αποθήκευση της συλλογής',
-        'SaveCurrentList' => 'Πρώτα επιλέξτε που θα γίνει η αποθήκευση της συλλογής',
         'SaveUnsavedChanges' => 'Υπάρχουν νέες εγγραφές στην συλλογή σας. Θέλετε να τις αποθηκεύσετε;',
         'SaveDontSave' => 'Να μην αποθηκευθούν',
         'PreferencesTooltip' => 'Ρύθμιση προτιμήσεων',
         'ViewTooltip' => 'Τρόπος εμφάνισης της συλλογής',
-        'PlayTooltip' => 'Σχετικό Video',
+        'PlayTooltip' => 'Σχετικό Video', # Accepts model codes
         'PlayFileNotFound' => 'Δεν βρέθηκε το αρχείο σε αυτήν την τοποθεσία:',
         'PlayRetry' => 'Επανάληψη',
 
@@ -179,8 +204,8 @@ search plugins) προορίζονται για <b>προσωπική χρήση
         'ErrorModelUserDir' => 'Τα καθορισμένα από τον χρήστη μοντέλα βρίσκονται μέσα στο: ',
         
         'RandomTooltip' => 'Τι θα δω απόψε; ',
-        'RandomError'=> 'Δεν υπάρχει επιλέξιμο στοιχείο',
-        'RandomEnd'=> 'Δεν υπάρχουν άλλα στοιχεία',
+        'RandomError'=> 'Δεν υπάρχει επιλέξιμο στοιχείο', # Accepts model codes
+        'RandomEnd'=> 'Δεν υπάρχουν άλλα στοιχεία', # Accepts model codes
         'RandomNextTip'=> 'Επόμενη πρόταση',
         'RandomOkTip'=> 'Αποδοχή αυτού του στοιχείου',
         
@@ -197,7 +222,8 @@ Adolfo González: Προγραμματιστής
 Logos Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Γλενταδάκης Δημήτρης dglent@gmail.com',
-        'AboutDesign' => 'Logo and webdesign by le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logo and webdesign by le Spektre',
 
         'ToolbarRandom' => 'Απόψε',
 
@@ -247,6 +273,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Ήχος',
         'ModelFieldFileProgram' => 'Πρόγραμμα',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Χρήση των πεδίων',
         'ModelOptionsFieldsAuto' => 'Αυτόματα',
         'ModelOptionsFieldsNone' => 'Κανένα',
@@ -275,10 +302,10 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'Θα πρέπει οι τιμές να θεωρούνται ως αριθμητικές για τις συγκρίσεις',
         'ModelTooltipQuick' => 'Αυτό θα προσθέσει ένα υπο-μενού στο μενού Φίλτρα',
         
-        'ResultsTitle' => 'Επιλέξτε ένα στοιχείο',
+        'ResultsTitle' => 'Επιλέξτε ένα στοιχείο', # Accepts model codes
         'ResultsNextTip' => 'Αναζήτηση στο επόμενο site',
         'ResultsPreview' => 'Προεσκόπηση',
-        'ResultsInfo' => 'Μπορείτε να προσθέσετε περισσότερα στοιχεία στην συλλογή, επιλέγοντας τα στοιχεία κρατώντας πατημένο το πλήκτρο Ctrl ή Shift',
+        'ResultsInfo' => 'Μπορείτε να προσθέσετε περισσότερα στοιχεία στην συλλογή, επιλέγοντας τα στοιχεία κρατώντας πατημένο το πλήκτρο Ctrl ή Shift', # Accepts model codes
         
         'OptionsTitle' => 'Προτιμήσεις',
 		'OptionsExpertMode' => 'Λειτουργία για προχωρημένους',
@@ -305,13 +332,13 @@ http://le-spektre.org',
 		'OptionsAskPlugins' => 'Αναζήτηση (Όλα τα sites)',
 		'OptionsPluginsMulti' => 'Πολλαπλά sites',
 		'OptionsPluginsMultiAsk' => 'Αναζήτηση (Μερικά sites)',
-        'OptionsPluginsMultiPerField' => 'Πολλαπλά sites (per field)',
-        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
-        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
-        'OptionsPluginsMultiPerFieldFirst' => 'First',
-        'OptionsPluginsMultiPerFieldLast' => 'Last',
-        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
-        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
+        'OptionsPluginsMultiPerField' => 'Πολλές ιστοσελίδες (ανά πεδίο)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Πολλες ιστοσελίδες ανά σειρά επιλογής',
+        'OptionsPluginsMultiPerFieldDesc' => 'Για κάθε πεδίο θα συμπληρώνουμε το πεδίο με την πρώτη μη κενή πληροφορία αρχίζοντας απο τ ααριστερά',
+        'OptionsPluginsMultiPerFieldFirst' => 'Πρώτο',
+        'OptionsPluginsMultiPerFieldLast' => 'Τελευταίο',
+        'OptionsPluginsMultiPerFieldRemove' => 'Αφαίρεση',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Λίστα κενών επιλεγμένων πεδίων',
 		'OptionsPluginsList' => 'Ορισμός λίστας',
         'OptionsAskImport' => 'Επιλεξτε τα πεδια για εισαγωγή',
 		'OptionsProxy' => 'Χρήση proxy',
@@ -426,6 +453,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Κατάλογος',
         'FileChooserOpenDirectory' => 'Επιλέξτε έναν κατάλογο',
         'FileChooserOverwrite' => 'Το αρχείο υπάρχει ήδη. Θέλετε να το αντικαταστήσετε;',
+        'FileAllFiles' => 'Όλα τα αρχεία',
+        'FileVideoFiles' => 'Αρχεία βίντεο',
+        'FileEbookFiles' => 'Αρχεία e-book',
+        'FileAudioFiles' => 'Αρχεία ήχου',
+        'FileGCstarFiles' => 'Συλλογές GCstar',
 
         #Some default panels
         'PanelCompact' => 'Συγκεντρωτικά',
@@ -434,24 +466,27 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Λήψη στοιχείων',
         'PanelSearchTip' => 'Αναζήτηση στο Internet πληροφορίες γι\' αυτό το όνομα',
-        'PanelSearchContextChooseOne' => 'Choose a site ...',
-        'PanelSearchContextMultiSite' => 'Use "Many sites"',
-        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
-        'PanelSearchContextOptions' => 'Change options ...',
+        'PanelSearchContextChooseOne' => 'Επιλογή ιστοσελίδας ...',
+        'PanelSearchContextMultiSite' => 'Χρήση «πολλών ιστοσελίδων»',
+        'PanelSearchContextMultiSitePerField' => 'Χρήση «πολλών ιστοσελίδων ανά πεδίο»',
+        'PanelSearchContextOptions' => 'Αλλαγή επιλογών ...',
         'PanelImageTipOpen' => 'Πατήστε στην εικόνα για να επιλέξτε άλλη.',
         'PanelImageTipView' => 'Πατήστε στην εικόνα για να τη δείτε σε πραγματικό μέγεθος.',
         'PanelImageTipMenu' => ' Δεξί κλικ για περισσότερες επιλογές.',
         'PanelImageTitle' => 'Επιλέξτε μια εικόνα',
         'PanelImageNoImage' => 'Καμία εικόνα',
         'PanelSelectFileTitle' => 'Επιλέξτε ένα αρχείο',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Επαναφορά προεπιλογής',
+        'PanelRefresh' => 'Ενημέρωση',
+        'PanelRefreshTip' => 'Ενημέρωση πληροφοριών από το διαδίκτυο',
 
         'PanelFrom' =>'Από',
         'PanelTo' =>'Εως',
 
         'PanelWeb' => 'Εμφάνιση πληροφοριών από το Internet',
-        'PanelWebTip' => 'Εμφάνιση πληροφοριών αυτού του στοιχείου στο  Internet',
-        'PanelRemoveTip' => 'Διαγραφή ανωτέρω στοιχείου',
+        'PanelWebTip' => 'Εμφάνιση πληροφοριών αυτού του στοιχείου στο  Internet', # Accepts model codes
+        'PanelRemoveTip' => 'Διαγραφή ανωτέρω στοιχείου', # Accepts model codes
 
         'PanelDateSelect' => 'Αλλαγή',
         'PanelNobody' => 'Κανένας',
@@ -465,7 +500,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Δανειολήπτες',
         'PanelLendDate' => 'Ημερομηνία δανεισμού',
         'PanelHistory' => 'Ιστορικό δανεισμών',
-        'PanelReturned' => 'Εχει επιστραφεί',
+        'PanelReturned' => 'Εχει επιστραφεί', # Accepts model codes
         'PanelReturnDate' => 'Ημερομηνία επιστροφής',
         'PanelLendedYes' => 'Δανεισμένο',
         'PanelLendedNo' => 'Διαθέσιμο',
@@ -498,6 +533,8 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Γράφτηκε από',
         'PluginsLang' => 'Γλώσσα',
         'PluginsUseSite' => 'Χρήση της επιλεγμένης ιστοσελίδας για τις αναζητήσεις',
+        'PluginsPreferredTooltip' => 'Η ιστοσελίδα συνιστάται από το GCstar',
+        'PluginDisabled' => 'Απενεργοποιημένο',
 
         'BorrowersTitle' => 'Διαχείριση των δανειοληπτών',
         'BorrowersList' => 'Δανειολήπτες',
@@ -516,9 +553,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'Τύπος αρχείου :',
         'BorrowersImportFile' => 'Αρχείο:',
 
-        'BorrowedTitle' => 'Δανεισμένα στοιχεία',
+        'BorrowedTitle' => 'Δανεισμένα στοιχεία', # Accepts model codes
         'BorrowedDate' => 'Από',
-        'BorrowedDisplayInPanel' => 'Εμφάνιση του στοιχείου στο κυρίως παράθυρο',
+        'BorrowedDisplayInPanel' => 'Εμφάνιση του στοιχείου στο κυρίως παράθυρο', # Accepts model codes
 
         'MailTitle' => 'Στείλτε e-mail',
         'MailFrom' => 'Αποστολέας : ',
@@ -527,8 +564,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Πρόβλημα σύνδεσης με τον SMTP server',
         'MailSendmailError' => 'Πρόβλημα κατά την εκκίνηση του sendmail',
 
-        'SearchTooltip' => 'Αναζήτηση σε όλα τα στοιχεία',
-        'SearchTitle' => 'Αναζήτηση',
+        'SearchTooltip' => 'Αναζήτηση σε όλα τα στοιχεία', # Accepts model codes
+        'SearchTitle' => 'Αναζήτηση', # Accepts model codes
         'SearchNoField' => 'Δεν έχετε επιλέξει κάποιο πεδίο για το κουτί αναζήτησης.
 Προσθέστε μερικά στην καρτέλα με τα φίλτρα στις ρυθμίσεις της συλλογής.',
 
@@ -567,7 +604,7 @@ http://le-spektre.org',
         'PropertiesDescription' => 'Περιγραφή',
         'PropertiesFile' => 'Πληροφορίες αρχείου',
         'PropertiesFilePath' => 'Πλήρη διαδρομή',
-        'PropertiesItemsNumber' => 'Αριθμός στοιχείων',
+        'PropertiesItemsNumber' => 'Αριθμός στοιχείων', # Accepts model codes
         'PropertiesFileSize' => 'Μέγεθος',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Ιδιότητες συλλογής',
@@ -591,8 +628,8 @@ http://le-spektre.org',
         'BookmarksNewFolder' => 'Νέος κατάλογος',
 
         'AdvancedSearchType' => 'Τύπος αναζήτησης',
-        'AdvancedSearchTypeAnd' => 'Στοιχεία που ταιριάζουν με όλα τα κριτήρια',
-        'AdvancedSearchTypeOr' => 'Στοιχεία που ταιριάζουν τουλάχιστον με ένα κριτήριο',
+        'AdvancedSearchTypeAnd' => 'Στοιχεία που ταιριάζουν με όλα τα κριτήρια', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Στοιχεία που ταιριάζουν τουλάχιστον με ένα κριτήριο', # Accepts model codes
         'AdvancedSearchCriteria' => 'Κριτήρια',
         'AdvancedSearchAnyField' => 'Όλα τα πεδία',
         'AdvancedSearchSaveTitle' => 'Αποθήκευση αναζήτησης',
@@ -606,6 +643,24 @@ http://le-spektre.org',
         'BugReportPlatform' => 'Λειτουργικό σύστημα',
         'BugReportMessage' => 'Μήνυμα σφάλματος',
         'BugReportInformation' => 'Πρόσθετες πληροφορίες',
+
+#Statistics
+        'Stats3DPie' => 'Πίτα 3Δ',
+        'StatsAccumulate' => 'Σύνοψη τιμών',
+        'StatsArea' => 'Περιοχές',
+        'StatsBars' => 'Μπάρες',
+        'StatsDisplayNumber' => 'Εμφάνιση αριθμών',
+        'StatsFieldToUse' => 'Πεδίο προς χρήση',
+        'StatsFontSize' => 'Μέγεθος γραμματοσειράς',
+        'StatsGenerate' => 'Δημιουργία',
+        'StatsHeight' => 'Ύψος',
+        'StatsHistory' => 'Ιστορικό',
+        'StatsKindOfGraph' => 'Τύπος γραφήματος',
+        'StatsPie' => 'Πίτα',
+        'StatsSave' => 'Αποθήκευση εικόνας στατιστικων σε αρχείο',
+        'StatsShowAllDates' => 'Εμφάνιση όλων των ημερομηνιών',
+        'StatsSortByNumber' => 'Ταξινόμηση ανά αριθμό {lowercaseX}',
+        'StatsWidth' => 'Πλάτος',
     );
 }
 1;
