@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,7 +33,12 @@
     our %lang = (
     
         CollectionDescription => 'TV Shows (series) collection',
-        Items => 'Series',
+        Items => {  0 => 'Series',
+                    1 => 'Series',
+                    X => 'Series',
+                    lowercase1 => 'series',
+                    lowercaseX => 'series'
+                    },
         NewItem => 'New series',
         Name => 'Name',
         Season => 'Season',
@@ -44,7 +49,7 @@
         Producer => 'Producer',
         Music => 'Music',
      );
-     importTranslation('Films');
+     importTranslation('films');
 }
 
 1;
