@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -32,9 +32,12 @@
     our %lang = (
     
         CollectionDescription => 'Board games collection',
-        Items => {0 => 'Game',
+        Items => {0 => 'Games',
                   1 => 'Game',
-                  X => 'Games'},
+                  X => 'Games',
+                  lowercase1 => 'game',
+                  lowercaseX => 'games'
+                  },
         NewItem => 'New game',
     
         Id => 'Id',
