@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -32,9 +32,12 @@
     our %lang = (
     
         CollectionDescription => 'Comics collection',
-        Items => {0 => 'Comic',
+        Items => {0 => 'Comics',
                   1 => 'Comic',
-                  X => 'Comics'},
+                  X => 'Comics',
+                  lowercase1 => 'comic',
+                  lowercaseX => 'comics'
+                  },
         NewItem => 'New comic',
     
     
