@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -32,9 +32,12 @@
     our %lang = (
     
         CollectionDescription => 'Movies collection',
-        Items => {0 => 'Movie',
+        Items => {0 => 'Movies',
                   1 => 'Movie',
-                  X => 'Movies'},
+                  X => 'Movies',
+                  lowercase1 => 'movie',
+                  lowercaseX => 'movies'
+                  },
         NewItem => 'New movie',
     
     
