@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -32,9 +32,12 @@
     our %lang = (
     
         CollectionDescription => 'Periodicals collection',
-        Items => {0 => 'Periodical',
+        Items => {0 => 'Periodicals',
                   1 => 'Periodical',
-                  X => 'Periodicals'},
+                  X => 'Periodicals',
+                  lowercase1 => 'periodical',
+                  lowercaseX => 'periodicals'
+                  },
         NewItem => 'New periodical',
     
         Title => 'Title',
