@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -24,6 +24,22 @@
 #
 ###################################################
     
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
+    
     use strict;
     use base 'Exporter';
 
@@ -46,7 +62,7 @@ Any redistribution is forbidden without the site\'s
 To determine which site owns the information, you
 may use the <b>button below item details</b>.',
         
-        'AllItemsFiltered' => 'No item matches your filter criteria',
+        'AllItemsFiltered' => 'No {lowercaseX} match your filter criteria', # Accepts model codes
         
 #Installation
         'InstallDirInfo' => 'Installing in ',
@@ -97,14 +113,19 @@ may use the <b>button below item details</b>.',
 #Menus
         'MenuFile' => '_File',
             'MenuNewList' => '_New Collection',
+            'MenuStats' => 'Statistics',
             'MenuHistory' => '_Recent Collections',
-            'MenuLend' => 'Display _Borrowed Items',
+            'MenuLend' => 'Display _Borrowed {X}', # Accepts model codes
             'MenuImport' => '_Import',	
             'MenuExport' => '_Export',
+            'MenuAddItem' => '_Add {1}', # Accepts model codes
     
         'MenuEdit'  => '_Edit',
-            'MenuDuplicate' => 'Du_plicate Item',
-            'MenuEditDeleteCurrent' => '_Remove Item',
+            'MenuDuplicate' => 'Du_plicate {1}', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate {X}', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All {X}', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_Remove {1}', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove {X}', # Accepts model codes    
             'MenuEditFields' => '_Change Collection Fields',
             'MenuEditLockItems' => '_Lock Collection',
     
@@ -113,7 +134,7 @@ may use the <b>button below item details</b>.',
                 'MenuSavedSearchesSave' => 'Save Current Search',
                 'MenuSavedSearchesEdit' => 'Modify Saved Searches',
             'MenuAdvancedSearch' => 'A_dvanced Search',
-            'MenuViewAllItems' => 'Show _All Items',
+            'MenuViewAllItems' => 'Show _All {X}', # Accepts model codes
             'MenuNoFilter' => '_Any',
     
         'MenuConfiguration' => '_Settings',
@@ -132,7 +153,8 @@ may use the <b>button below item details</b>.',
             'MenuBugReport' => 'Report a Problem',
             'MenuAbout' => '_About GCstar',
     
-        'MenuNewWindow' => 'Show Item in _New Window',
+        'MenuNewWindow' => 'Show {1} in _New Window', # Accepts model codes
+        'MenuNewWindowPlural' => 'Show {X} in _New Window', # Accepts model codes
         
         'ContextExpandAll' => 'Expand All',
         'ContextCollapseAll' => 'Collapse All',
@@ -141,22 +163,25 @@ may use the <b>button below item details</b>.',
         'ContextImageEditor' => 'Image Editor',
         'ContextImgFront' => 'Front',
         'ContextImgBack' => 'Back',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
 
         'DialogEnterNumber' => 'Please enter value',
 
-        'RemoveConfirm' => 'Do you really want to remove this item?',
-        'DefaultNewItem' => 'New item',
-        'NewItemTooltip' => 'Add a new item',
+        'RemoveConfirm' => 'Do you really want to remove this {lowercase1}?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these {lowercaseX}?', # Accepts model codes
+
+        'DefaultNewItem' => 'New {lowercase1}', # Accepts model codes
+        'NewItemTooltip' => 'Add a new {lowercase1}', # Accepts model codes
         'NoItemFound' => 'Nothing was found. Would you like to search another site?',
         'OpenList' => 'Please select collection',
         'SaveList' => 'Please choose where to save the collection',
         'SaveListTooltip' => 'Save current collection',
-        'SaveCurrentList' => 'First specify where to save the current collection',
         'SaveUnsavedChanges' => 'There are unsaved changes in your collection. Do you want to save them?',
         'SaveDontSave' => 'Don\'t save',
         'PreferencesTooltip' => 'Set your preferences',
         'ViewTooltip' => 'Change collection display',
-        'PlayTooltip' => 'Launch file associated to the item',
+        'PlayTooltip' => 'Launch file associated to the {lowercase1}', # Accepts model codes
         'PlayFileNotFound' => 'File to launch was not found in this location:',
         'PlayRetry' => 'Retry',
 
@@ -179,8 +204,8 @@ may use the <b>button below item details</b>.',
         'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'What to see this evening?',
-        'RandomError'=> 'You have no items which could be chosen',
-        'RandomEnd'=> 'There are no more items',
+        'RandomError'=> 'You have no {lowercaseX} that could be chosen', # Accepts model codes
+        'RandomEnd'=> 'You have no more {lowercaseX} to choose from!', # Accepts model codes
         'RandomNextTip'=> 'Next suggestion',
         'RandomOkTip'=> 'Accept this suggestion',
         
@@ -197,7 +222,8 @@ Adolfo González: Programmer
 Logos Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'English translation by Christian Jodar and Jason Day',
-        'AboutDesign' => 'Logo and webdesign by le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logo and webdesign by le Spektre',
 
         'UnsavedCollection' => 'Unsaved Collection',
 
@@ -247,6 +273,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Audio',
         'ModelFieldFileProgram' => 'Program',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Fields to use',
         'ModelOptionsFieldsAuto' => 'Automatic',
         'ModelOptionsFieldsNone' => 'None',
@@ -285,11 +312,13 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Author',
         'PluginsLang' => 'Language',
         'PluginsUseSite' => 'Use selected site for future searches',
+        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+        'PluginDisabled' => 'Disabled',
 
-        'ResultsTitle' => 'Select an item',
+        'ResultsTitle' => 'Select a {lowercase1}', # Accepts model codes
         'ResultsNextTip' => 'Search in next site',
         'ResultsPreview' => 'Preview',
-        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
+        'ResultsInfo' => 'You can add multiple {lowercaseX} to the collection by holding down the Ctrl or the Shift key and selecting them', # Accepts model codes
 
         'ImportWindowTitle' => 'Select Fields to be Imported',
         'ImportViewPicture' => 'View Picture',
@@ -462,6 +491,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Directory',
         'FileChooserOpenDirectory' => 'Select a directory',
         'FileChooserOverwrite' => 'This file already exists. Do you want to overwrite it?',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
 #Some default panels
         'PanelCompact' => 'Compact',
@@ -480,15 +514,18 @@ http://le-spektre.org',
         'PanelImageTipMenu' => ' Right click for more options.',
         'PanelImageTitle' => 'Select a picture',
         'PanelImageNoImage' => 'No image',
-        'PanelSelectFileTitle' => 'Select a file',
+        'PanelSelectFileTitle' => 'Select File',
+        'PanelLaunch' => 'Launch',
         'PanelRestoreDefault' => 'Restore Default',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Automatically update blank fields',
 
         'PanelFrom' =>'From',
         'PanelTo' =>'To',
 
         'PanelWeb' => 'View Information',
-        'PanelWebTip' => 'View information on the web about this item',
-        'PanelRemoveTip' => 'Remove current item',
+        'PanelWebTip' => 'View information on the web about this {lowercase1}', # Accepts model codes
+        'PanelRemoveTip' => 'Remove current {lowercase1}', # Accepts model codes
 
         'PanelDateSelect' => 'Select',
         'PanelNobody' => 'Nobody',
@@ -502,7 +539,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Borrower',
         'PanelLendDate' => 'Out Since',
         'PanelHistory' => 'Lending History',
-        'PanelReturned' => 'Item Returned',
+        'PanelReturned' => '{1} Returned', # Accepts model codes
         'PanelReturnDate' => 'Return date',
         'PanelLendedYes' => 'Lended',
         'PanelLendedNo' => 'Available',
@@ -546,9 +583,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'File format:',
         'BorrowersImportFile' => 'File:',
 
-        'BorrowedTitle' => 'Borrowed items',
+        'BorrowedTitle' => 'Borrowed {lowercaseX}', # Accepts model codes
         'BorrowedDate' => 'Since',
-        'BorrowedDisplayInPanel' => 'Show item in main window',
+        'BorrowedDisplayInPanel' => 'Show {1} in Main Window', # Accepts model codes
 
 #Mail
         'MailTitle' => 'Send an e-mail',
@@ -559,14 +596,14 @@ http://le-spektre.org',
         'MailSendmailError' => 'Problem when launching sendmail',
 
 #Search dialog
-        'SearchTooltip' => 'Search all items',
-        'SearchTitle' => 'Item Search',
+        'SearchTooltip' => 'Search all {lowercaseX}', # Accepts model codes
+        'SearchTitle' => '{1} Search', # Accepts model codes
         'SearchNoField' => 'No field have been selected for the search box.
 Add some of them in the Filters tab of the collection settings.',
 
         'AdvancedSearchType' => 'Type of search',
-        'AdvancedSearchTypeAnd' => 'Items matching all criteria',
-        'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
+        'AdvancedSearchTypeAnd' => '{X} matching all criteria', # Accepts model codes
+        'AdvancedSearchTypeOr' => '{X} matching at least one criterion', # Accepts model codes
         'AdvancedSearchCriteria' => 'Criteria',
         'AdvancedSearchAnyField' => 'Any field',
         'AdvancedSearchSaveTitle' => 'Save search',
@@ -589,7 +626,7 @@ Add some of them in the Filters tab of the collection settings.',
         'PropertiesDescription' => 'Description',
         'PropertiesFile' => 'File Information',
         'PropertiesFilePath' => 'Full path',
-        'PropertiesItemsNumber' => 'Number of items',
+        'PropertiesItemsNumber' => 'Number of {lowercaseX}', # Accepts model codes
         'PropertiesFileSize' => 'Size',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Collection properties',
@@ -621,6 +658,24 @@ Add some of them in the Filters tab of the collection settings.',
         'BugReportMessage' => 'Error message',
         'BugReportInformation' => 'Additional information',
 
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
+
 #Not used yet
         'GenresTitle' => 'Genre Conversion',
         'GenresCategoryName' => 'Genre to use',
@@ -628,6 +683,24 @@ Add some of them in the Filters tab of the collection settings.',
         'GenresLoad' => 'Load a list',
         'GenresExport' => 'Save list to a file',
         'GenresModify' => 'Edit conversion',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
     );
 }
 1;
