@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,6 +33,9 @@
         'Charset' => 'Codificación de caracteres',
         'Header' => 'Ignorar primera linea',
         'Separator' => 'Delimitador',
+        'Plugin' => 'Sitio a usar',
+        'UseFirst' => 'Seleccionar el primero si hay muchos resultados',
+        'SearchField' => 'Search for items using',
      );
 }
 
