@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,7 +33,26 @@
     our %lang = (
     
         CollectionDescription => 'Colección de series de televisión (episodios)',
-        Items => 'Episodios',
+        Items => {0 => 'Episodio',
+                  1 => 'Episodio',
+                  lowercase1 => 'episodio',
+                  X => 'Episodios',
+                  lowercaseX => 'episodios',
+                  P1 => 'El Episodio',
+                  lowercaseP1 => 'el episodio',
+                  U1 => 'Un Episodio',
+                  lowercaseU1 => 'un episodio',
+                  AP1 => 'Al Episodio',
+                  lowercaseAP1 => 'al episodio',
+                  DP1 => 'Del Episodio',
+                  lowercaseDP1 => 'del episodio',
+                  PX => 'Los Episodios',
+                  lowercasePX => 'los episodios',
+                  E1 => 'Este Episodio',
+                  lowercaseE1 => 'este episodio',
+                  EX => 'Estos Episodios',
+                  lowercaseEX => 'estos episodios'             
+                  },
         NewItem => 'Episodio nuevo',
         NewSeries => 'Nueva serie',
         Episode => 'Episodio',
