@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,7 +33,26 @@
     our %lang = (
     
         CollectionDescription => 'Colección de series de television (series)',
-        Items => 'Series',
+        Items => {0 => 'Serie',
+                  1 => 'Serie',
+                  lowercase1 => 'serie',
+                  X => 'Series',
+                  lowercaseX => 'series',
+                  P1 => 'La Serie',
+                  lowercaseP1 => 'la serie',
+                  U1 => 'Una Serie',
+                  lowercaseU1 => 'una serie',
+                  AP1 => 'A La Serie',
+                  lowercaseAP1 => 'a la serie',
+                  DP1 => 'De la Serie',
+                  lowercaseDP1 => 'de la serie',
+                  PX => 'Las Series',
+                  lowercasePX => 'las series',
+                  E1 => 'Esta Serie',
+                  lowercaseE1 => 'esta serie',
+                  EX => 'Estas Series',
+                  lowercaseEX => 'estas series'             
+                  },
         NewItem => 'Nueva serie',
         Name => 'Nombre',
         Season => 'Temporada',
