@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -32,7 +32,27 @@
     our %lang = (
     
         CollectionDescription => 'Colección de libros',
-        Items => 'Libros',
+        Items => {0 => 'Libro',
+                  1 => 'Libro',
+                  lowercase1 => 'libro',
+                  X => 'Libros',
+                  lowercaseX => 'libros',
+                  P1 => 'El Libro',
+                  lowercaseP1 => 'el libro',
+                  U1 => 'Un Libro',
+                  lowercaseU1 => 'un libro',
+                  AP1 => 'Al Libro',
+                  lowercaseAP1 => 'al libro',
+                  DP1 => 'Del Libro',
+                  lowercaseDP1 => 'del libro',
+                  PX => 'Los Libros',
+                  lowercasePX => 'los libros',
+                  E1 => 'Este Libro',
+                  lowercaseE1 => 'este libro',
+                  EX => 'Estos Libros',
+                  lowercaseEX => 'estos libros'             
+                  },        
+
         NewItem => 'Nuevo libro',
     
         Isbn => 'ISBN',
@@ -55,6 +75,7 @@
         Url => 'Página web',
         Translator => 'Traductor',
         Artist => 'Artista',
+        DigitalFile => 'Digital version',
 
         General => 'General',
         Details => 'Detalles',
