@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -34,7 +34,24 @@
         CollectionDescription => 'Colección de cómics',
         Items => {0 => 'Cómics',
                   1 => 'Cómic',
-                  X => 'Cómics'},
+                  lowercase1 => 'cómic',
+                  X => 'Cómics',
+                  lowercaseX => 'cómics',
+                  P1 => 'El Cómic',
+                  lowercaseP1 => 'el cómics',
+                  U1 => 'Un Cómic',
+                  lowercaseU1 => 'un cómic',
+                  AP1 => 'Al Cómic',
+                  lowercaseAP1 => 'al cómic',
+                  DP1 => 'Del Cómic',
+                  lowercaseDP1 => 'del cómic',
+                  PX => 'Los Cómics',
+                  lowercasePX => 'los cómics',
+                  E1 => 'Este Cómic',
+                  lowercaseE1 => 'este cómic',
+                  EX => 'Estos Cómics',
+                  lowercaseEX => 'estos cómics'
+                  },
         NewItem => 'Cómic nuevo',
     
     
