@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -32,7 +32,27 @@
     our %lang = (
     
         CollectionDescription => 'Colección de películas',
-        Items => 'Películas',
+        Items => {0 => 'Película',
+                  1 => 'Película',
+                  lowercase1 => 'película',
+                  X => 'Películas',
+                  lowercaseX => 'películas',
+                  P1 => 'La Película',
+                  lowercaseP1 => 'la película',
+                  U1 => 'Una Película',
+                  lowercaseU1 => 'una película',
+                  AP1 => 'A la Película',
+                  lowercaseAP1 => 'a la película',
+                  DP1 => 'De la Película',
+                  lowercaseDP1 => 'de la película',
+                  PX => 'Las Películas',
+                  lowercasePX => 'las películas',
+                  E1 => 'Esta Película',
+                  lowercaseE1 => 'esta película',
+                  EX => 'Estas Películas',
+                  lowercaseEX => 'estas películas'             
+                  },        
+        
         NewItem => 'Nueva película',
     
     
