@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -32,8 +32,27 @@
     our %lang = (
     
         CollectionDescription => 'Colección de música',
-        Items => 'Albums',
-        NewItem => 'Album nuevo',
+        Items => {0 => 'Álbum',
+                  1 => 'Álbum',
+                  lowercase1 => 'Álbum',
+                  X => 'Álbumes',
+                  lowercaseX => 'álbumes',
+                  P1 => 'El Álbum',
+                  lowercaseP1 => 'el álbum',
+                  U1 => 'Un Álbum',
+                  lowercaseU1 => 'un álbum',
+                  AP1 => 'Al Álbum',
+                  lowercaseAP1 => 'al álbum',
+                  DP1 => 'Del Álbum',
+                  lowercaseDP1 => 'del álbum',
+                  PX => 'Los Álbumes',
+                  lowercasePX => 'los álbumes',
+                  E1 => 'Este Álbum',
+                  lowercaseE1 => 'este álbum ',
+                  EX => 'Estos Álbumes',
+                  lowercaseEX => 'estos álbumes'             
+                  },
+        NewItem => 'Álbum nuevo',
     
         Unique => 'ISRC/EAN',
         Title => 'Título',
