@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -32,10 +32,28 @@
     our %lang = (
     
         CollectionDescription => 'Periodicals collection',
-        Items => {0 => 'Periodical',
-                  1 => 'Periodical',
-                  X => 'Periodicals'},
-        NewItem => 'New periodical',
+        Items => {0 => 'Revista',
+                  1 => 'Revista',
+                  lowercase1 => 'revista',
+                  X => 'Revistas',
+                  lowercaseX => 'revistas',
+                  P1 => 'La Revista',
+                  lowercaseP1 => 'la revista',
+                  U1 => 'Una Revista',
+                  lowercaseU1 => 'una revista',
+                  AP1 => 'A la Revista',
+                  lowercaseAP1 => 'a la revista',
+                  DP1 => 'De la Revista',
+                  lowercaseDP1 => 'de la revista',
+                  PX => 'Las Revistas',
+                  lowercasePX => 'las revistas',
+                  E1 => 'Esta Revista',
+                  lowercaseE1 => 'esta revista',
+                  EX => 'Estas Revistas',
+                  lowercaseEX => 'estas revistas'             
+                  },                  
+                  
+        NewItem => 'Nueva revista',
     
         Title => 'Title',
         Cover => 'Cover',
