@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -24,6 +24,22 @@
 #
 ###################################################
 
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
+
     use strict;
     use base 'Exporter';
 
@@ -46,7 +62,7 @@ explícita autorización de las respectivas webs</b>.
 Para saber cual es la web a la que pertenece la información,
 puede usar <b>el botón situado debajo de los detalles de la película</b>.',
 
-        'AllItemsFiltered' => 'Ninguna películas cumple con los criterios de filtrado',
+        'AllItemsFiltered' => 'Ninguna {lowercaseX} cumple con los criterios de filtrado', # Accepts model codes
 
 #Installation
         'InstallDirInfo' => 'Instalar en ',
@@ -97,14 +113,19 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
 #Menus
         'MenuFile' => '_Archivo',	
             'MenuNewList' => '_Nueva lista de películas',	
+            'MenuStats' => 'Statistics',
             'MenuHistory' => '_Ficheros abiertos recientemente',
-            'MenuLend' => '_Ver películas prestadas',	
+            'MenuLend' => '_Ver {lowercaseX} prestadas', # Accepts model codes
             'MenuImport' => '_Importar',
             'MenuExport' => '_Exportar',	
+            'MenuAddItem' => '_Add {lowercase1}', # Accepts model codes
 
         'MenuEdit'  => '_Editar',
-       	    'MenuDuplicate' => '_Duplicar película',
-            'MenuEditDeleteCurrent' => '_Eliminar película actual',
+            'MenuDuplicate' => '_Duplicar {lowercase1}', # Accepts model codes
+            'MenuDuplicatePlural' => '_Duplicar {lowercaseX}', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _all {lowercaseX}', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_Eliminar {lowercase1} actual',, # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Eliminar {lowercaseX} actual', # Accepts model codes
             'MenuEditFields' => '_Cambiar campos de la colección',
             'MenuEditLockItems' => '_Bloquear la información',
         
@@ -113,7 +134,7 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
                 'MenuSavedSearchesSave' => 'Guardar búsqueda actual',
                 'MenuSavedSearchesEdit' => 'Modificar búsquedas guardadas',
             'MenuAdvancedSearch' => 'Búsqueda _avanzada',
-            'MenuViewAllItems' => '_Ver todas las películas',	
+            'MenuViewAllItems' => '_Ver todas {lowercasePX}', # Accepts model codes	
             'MenuNoFilter' => '_Todas las películas',	
 
         'MenuConfiguration' => '_Configuración',	
@@ -132,7 +153,8 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
             'MenuBugReport' => 'Comunicar un _fallo',
             'MenuAbout' => 'A propósito de _GCstar',	
 
-        'MenuNewWindow' => 'Mostrar películas en una nueva ventana',
+        'MenuNewWindow' => 'Mostrar {lowercase1} en una nueva ventana', # Accepts model codes
+        'MenuNewWindowPlural' => 'Mostrar {lowercaseX} en una nueva ventana', # Accepts model codes
         
         'ContextExpandAll' => 'Expandir todo',
         'ContextCollapseAll' => 'Contraer todo',
@@ -141,22 +163,25 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
         'ContextImageEditor' => 'Editor de Imágenes',  
         'ContextImgFront' => 'Frontal',
         'ContextImgBack' => 'Trasera',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
 
         'DialogEnterNumber' => 'Introduzca un valor por favor',
 
-        'RemoveConfirm' => '¿Realmente quiere eliminar esta película?',  
+        'RemoveConfirm' => '¿Realmente quiere eliminar {lowercaseE1}?', # Accepts model codes 
+        'RemoveConfirmPlural' => '¿Realmente quiere eliminar {lowercaseEX}?', # Accepts model codes
+
         'DefaultNewItem' => 'Elemento nuevo',
         'NewItemTooltip' => 'Añadir una nueva película',
         'NoItemFound' => 'Ninguna película encontrada. ¿Quiere intentar una nueva búsqueda en otro sitio?',
         'OpenList' => '¿Qué lista de películas abrir?',	
         'SaveList' => '¿En qué fichero quiere guardar el listado?',	
         'SaveListTooltip' => 'Guardar el listado actual', 
-        'SaveCurrentList' => 'Primero debe eligir en que fichero quiere guardar el listado actual',
         'SaveUnsavedChanges' => 'Hay cambios sin guardar en su colección. ¿Quiere guardarlos?',
         'SaveDontSave' => 'No guardar',
         'PreferencesTooltip' => 'Cambiar sus preferencias',
         'ViewTooltip' => 'Cambiar el tipo de lista',
-        'PlayTooltip' => 'Reproducir archivo de video asociado a la película',
+        'PlayTooltip' => 'Reproducir archivo de video asociado {lowercaseAP1}', # Accepts model codes
         'PlayFileNotFound' => 'No se encontró el fichero a reproducir:',
         'PlayRetry' => 'Reintentar',
         
@@ -179,10 +204,10 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
         'ErrorModelUserDir' => 'Los modelos definidos por el usuario están en: ',
 
         'RandomTooltip' => '¿Qué quieres ver esta noche?',
-        'RandomError'=> 'No quedan películas sin ver',
-        'RandomEnd'=> 'No hay mas películas',
+        'RandomError'=> 'No quedan {lowercaseX} sin ver', # Accepts model codes
+        'RandomEnd'=> 'No hay mas {lowercaseX}', # Accepts model codes
         'RandomNextTip'=> 'Siguiente sugerencia',
-        'RandomOkTip'=> 'Aceptar esta película',
+        'RandomOkTip'=> 'Aceptar {lowercaseE1}',
                         
         'AboutTitle' => 'A propósito de GCstar',
         'AboutDesc' => 'Gestión de Colecciones',
@@ -197,7 +222,8 @@ Adolfo González Blázquez : Programación
 Logos Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Traducción : Adolfo González Blázquez',
-        'AboutDesign' => 'Logo y diseño web por le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logo y diseño web por le Spektre',
         
         'ToolbarRandom' => 'Esta noche',
 
@@ -247,6 +273,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Audio',
         'ModelFieldFileProgram' => 'Programa',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Campos a usar',
         'ModelOptionsFieldsAuto' => 'Automático',
         'ModelOptionsFieldsNone' => 'Ninguno',
@@ -275,10 +302,10 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => '¿Se deberían considerar los valores como números para las comparaciones?',
         'ModelTooltipQuick' => 'Esto añadirá un submenu dentro del menu de Filtros',
 
-        'ResultsTitle' => 'Elija una película',
+        'ResultsTitle' => 'Elija {lowercaseU1}', # Accepts model codes
         'ResultsNextTip' => 'Buscar en el siguiente sitio',
         'ResultsPreview' => 'Previsualizar',
-        'ResultsInfo' => 'Puedes añadir varios elementos a la colección presionando Control ó Mayúsculas y seleccionándolos',
+        'ResultsInfo' => 'Puedes añadir varios elementos a la colección presionando Control ó Mayúsculas y seleccionándolos', # Accepts model codes
 
         'OptionsTitle' => 'Preferencias',
 		'OptionsExpertMode' => 'Modo experto',
@@ -426,6 +453,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Directorio',
         'FileChooserOpenDirectory' => 'Elija un directorio',
         'FileChooserOverwrite' => 'Este fichero ya existe. ¿Quiere sustituirlo?',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
         'PanelCompact' => 'Compacto',
         'PanelReadOnly' => 'Sólo Lectura',
@@ -443,14 +475,17 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Seleccionar una imagen',	
         'PanelImageNoImage' => 'Sin imagen',
         'PanelSelectFileTitle' => 'Seleccione un fichero',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Restaurar predeterminado',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Update information from web',
 
         'PanelFrom' =>'De',
         'PanelTo' =>'Para',
 
         'PanelWeb' => 'Ver la ficha en Internet',
-        'PanelWebTip' => 'Ver la ficha de la película en Internet',	
-        'PanelRemoveTip' => 'Eliminar la película anteriormente mencionada', 
+        'PanelWebTip' => 'Ver la ficha {lowercaseDP1} en Internet', # Accepts model codes	
+        'PanelRemoveTip' => 'Eliminar {lowercaseP1} anteriormente mencionada',  # Accepts model codes
 
         'PanelDateSelect' => 'Cambiar la fecha',	
         'PanelNobody' => 'Nadie',	
@@ -464,7 +499,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Prestatario',
         'PanelLendDate' => 'Fecha',
         'PanelHistory' => 'Historial',
-        'PanelReturned' => 'Película devuelta',	
+        'PanelReturned' => '{1} devuelta', # Accepts model codes	
         'PanelReturnDate' => 'Fecha de devolución',
         'PanelLendedYes' => 'Prestada',
         'PanelLendedNo' => 'Disponible',
@@ -497,6 +532,8 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Idioma',
         'PluginsUseSite' => 'Usar sitio seleccionado para futuras búsquedas',
+        'PluginsPreferredTooltip' => 'Sitio recomendado por GCstar',
+        'PluginDisabled' => 'Disabled', 
         
         'BorrowersTitle' => 'Configuración de los prestatarios',	
         'BorrowersList' => 'Prestatarios',	
@@ -515,9 +552,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'Formato del fichero:',
         'BorrowersImportFile' => 'Fichero:',
 
-        'BorrowedTitle' => 'Películas prestadas',	
+        'BorrowedTitle' => '{X} prestadas', # Accepts model codes		
         'BorrowedDate' => 'Desde el',	
-        'BorrowedDisplayInPanel' => 'Mostrar elemento en la ventana principal',
+        'BorrowedDisplayInPanel' => 'Mostrar {lowercase1} en la ventana principal', # Accepts model codes	
 
         'MailTitle' => 'Enviar un correo electrónico',	
         'MailFrom' => 'De: ',	
@@ -526,8 +563,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Problema de conexión con el servidor',	
         'MailSendmailError' => 'Problema ejecutando sendmail',	
 
-        'SearchTooltip' => 'Buscar en todas las películas',	
-        'SearchTitle' => 'Búsqueda de películas',	
+        'SearchTooltip' => 'Buscar en todas {lowercasePX}', # Accepts model codes		
+        'SearchTitle' => 'Búsqueda de {lowercasePX}', # Accepts model codes		
         'SearchNoField' => 'No field have been selected for the search box.
 Add some of them in the Filters tab of the collection settings.',
                 
@@ -566,7 +603,7 @@ Add some of them in the Filters tab of the collection settings.',
         'PropertiesDescription' => 'Descripción',
         'PropertiesFile' => 'Información del fichero',
         'PropertiesFilePath' => 'Ruta completa',
-        'PropertiesItemsNumber' => 'Número de elementos',
+        'PropertiesItemsNumber' => 'Número de {lowercaseX}', # Accepts model codes
         'PropertiesFileSize' => 'Tamaño',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Propiedades de la colección',
@@ -590,8 +627,8 @@ Add some of them in the Filters tab of the collection settings.',
         'BookmarksNewFolder' => 'Nueva carpeta',
 
         'AdvancedSearchType' => 'Tipo de búsqueda',
-        'AdvancedSearchTypeAnd' => 'Elementos que cumplan todos los criterios',
-        'AdvancedSearchTypeOr' => 'Elementos que cunplan al menos un criterio',
+        'AdvancedSearchTypeAnd' => '{X} que cumplan todos los criterios', # Accepts model codes
+        'AdvancedSearchTypeOr' => '{X} que cunplan al menos un criterio', # Accepts model codes
         'AdvancedSearchCriteria' => 'Critero',
         'AdvancedSearchAnyField' => 'Cualquier campo',
         'AdvancedSearchSaveTitle' => 'Guardar búsqueda',
@@ -605,6 +642,24 @@ Add some of them in the Filters tab of the collection settings.',
         'BugReportPlatform' => 'Sistema operativo',
         'BugReportMessage' => 'Mensaje de error',
         'BugReportInformation' => 'Información adicional',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
     );
 }
 1;
