@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,6 +33,9 @@
         'Charset' => 'Codage',
         'Header' => 'Ignorer la première ligne',
         'Separator' => 'Séparateur',
+        'Plugin' => 'Site à utiliser',
+        'UseFirst' => 'Choisir le 1er si plusieurs résultats',
+        'SearchField' => 'Chercher en utilisant',
      );
 }
 
