@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -35,7 +35,15 @@
         CollectionDescription => 'Collection de séries TV',
         Items => {0 => 'Série',
                   1 => 'Série',
-                  X => 'Séries'},
+                  X => 'Séries',
+                  I1 => 'Une série',
+                  D1 => 'La série',
+                  DX => 'Les séries',
+                  DD1 => 'De la série',
+                  M1 => 'Cette série',
+                  C1 => 'e série',
+                  DA1 => 'e série',
+                  DAX => 'e séries'},
         NewItem => 'Nouvelle série',
         Name => 'Nom',
         Season => 'Saison',
