@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -34,7 +34,15 @@
         CollectionDescription => 'Collection de livres',
         Items => {0 => 'Livre',
                   1 => 'Livre',
-                  X => 'Livres'},
+                  X => 'Livres',
+                  I1 => 'Un livre',
+                  D1 => 'Le livre',
+                  DX => 'Les livres',
+                  DD1 => 'Du livre',
+                  M1 => 'Ce livre',
+                  C1 => ' livre',
+                  DA1 => 'e livre',
+                  DAX => 'e livres'},
         NewItem => 'Nouveau livre',
     
         Isbn => 'ISBN',
@@ -57,6 +65,7 @@
         Url => 'Page web',
         Translator => 'Traducteur',
         Artist => 'Artiste',
+        DigitalFile => 'Digital version',
 
         General => 'Fiche',
         Details => 'Détails',
