@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -34,7 +34,15 @@
         CollectionDescription => 'Collection de films',
         Items => {0 => 'Film',
                   1 => 'Film',
-                  X => 'Films'},
+                  X => 'Films',
+                  I1 => 'Un film',
+                  D1 => 'Le film',
+                  DX => 'Les films',
+                  DD1 => 'Du film',
+                  M1 => 'Ce film',
+                  C1 => ' film',
+                  DA1 => 'e film',
+                  DAX => 'e films'},
         NewItem => 'Nouveau film',
     
     
