@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -35,7 +35,15 @@
         #Items => 'Jeux',
         Items => {0 => 'Jeu',
                   1 => 'Jeu',
-                  X => 'Jeux'},
+                  X => 'Jeux',
+                  I1 => 'Un jeu',
+                  D1 => 'Le jeu',
+                  DX => 'Les jeux',
+                  DD1 => 'Du jeu',
+                  M1 => 'Ce jeu',
+                  C1 => ' élément',
+                  DA1 => 'e jeu',
+                  DAX => 'e jeux'},
         NewItem => 'Nouveau jeu',
     
         Id => 'Identifiant',
@@ -66,6 +74,11 @@
         Unlockables => 'Déblocables',
         Unlockable => 'Déblocable',
         Howto => 'Comment débloquer',
+        Exclusive => 'Exclusivité',
+        Resolutions => 'Résolutions',
+        InstallationSize => 'Taille',
+        Region => 'Région',
+        SerialNumber => 'Numéro de série',        
 
         General => 'Général',
         Details => 'Détails',
