@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -34,7 +34,15 @@
         CollectionDescription => 'Collection musicale',
         Items => {0 => 'Album',
                   1 => 'Album',
-                  X => 'Albums'},
+                  X => 'Albums',
+                  I1 => 'Un album',
+                  D1 => 'L\'album',
+                  DX => 'Les albums',
+                  DD1 => 'De l\'album',
+                  M1 => 'Cet album',
+                  C1 => ' album',
+                  DA1 => '\'album',
+                  DAX => '\'albums'},
         NewItem => 'Nouvel album',
     
         Unique => 'ISRC/EAN',
