@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,6 +33,9 @@
         'Charset' => 'Conxunto de caracteres',
         'Header' => 'Ignorar a primeira liña',
         'Separator' => 'Separador',
+        'Plugin' => 'Utilizar o sitio web',
+        'UseFirst' => 'Seleccionar o primeiro dos resultados',
+        'SearchField' => 'Search for items using',
      );
 }
 
