@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -23,7 +23,23 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 ###################################################
-    
+
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
+   
     use strict;
     use base 'Exporter';
 
@@ -46,7 +62,7 @@ Calquera redistribución está prohibida sen a
 Para determinar a que web pertence a información, debe
 utilizar <b>o botón situado debaixo dos detalles do elemento</b>.',
         
-        'AllItemsFiltered' => 'Non hai elementos cumpran os criterios de filtrado',
+        'AllItemsFiltered' => 'Non hai elementos cumpran os criterios de filtrado', # Accepts model codes
         
 #Installation
         'InstallDirInfo' => 'Instalar en ',
@@ -97,14 +113,19 @@ utilizar <b>o botón situado debaixo dos detalles do elemento</b>.',
 #Menus
         'MenuFile' => '_Ficheiro',
             'MenuNewList' => '_Nova Colección',
+            'MenuStats' => 'Statistics',
             'MenuHistory' => 'Coleccións _Recentes',
-            'MenuLend' => 'Amosar Elementos _Prestados',
+            'MenuLend' => 'Amosar Elementos _Prestados', # Accepts model codes
             'MenuImport' => '_Importar',	
             'MenuExport' => '_Exportar',
+            'MenuAddItem' => '_Add Items', # Accepts model codes
     
         'MenuEdit'  => '_Editar',
-            'MenuDuplicate' => 'Du_plicar elemento',
-            'MenuEditDeleteCurrent' => 'Elimina_r Elemento',
+            'MenuDuplicate' => 'Du_plicar elemento', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate Items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All Items', # Accepts model codes
+            'MenuEditDeleteCurrent' => 'Elimina_r Elemento', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove Items', # Accepts model codes 
             'MenuEditFields' => '_Cambiar campos da colección',
             'MenuEditLockItems' => '_Bloquear Colección',
     
@@ -113,7 +134,7 @@ utilizar <b>o botón situado debaixo dos detalles do elemento</b>.',
                 'MenuSavedSearchesSave' => 'Save current search',
                 'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'Procura A_vanzada ',
-            'MenuViewAllItems' => '_Amosar todos os elementos',
+            'MenuViewAllItems' => '_Amosar todos os elementos', # Accepts model codes
             'MenuNoFilter' => '_Calquera',
     
         'MenuConfiguration' => '_Configuración',
@@ -132,31 +153,35 @@ utilizar <b>o botón situado debaixo dos detalles do elemento</b>.',
             'MenuBugReport' => 'Comunicar un problema',
             'MenuAbout' => '_Acerca de GCstar',
     
-        'MenuNewWindow' => 'Amosar elemento nunha _Nova Xanela',
+        'MenuNewWindow' => 'Amosar elemento nunha _Nova Xanela', # Accepts model codes
+        'MenuNewWindowPlural' => 'Show Items in _New Window', # Accepts model codes
         
         'ContextExpandAll' => 'Expandir todo',
         'ContextCollapseAll' => 'Contraer todo',
-         'ContextChooseImage' => 'Choose _Image',
+        'ContextChooseImage' => 'Choose _Image',
         'ContextOpenWith' => 'Open Wit_h',
         'ContextImageEditor' => 'Image Editor',
         'ContextImgFront' => 'Front',
         'ContextImgBack' => 'Back',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
        
         'DialogEnterNumber' => 'Introduza un valor',
 
-        'RemoveConfirm' => 'Está seguro de que quere eliminar este elemento?',
-        'DefaultNewItem' => 'Novo elemento',
-        'NewItemTooltip' => 'Engadir un novo elemento',
+        'RemoveConfirm' => 'Está seguro de que quere eliminar este elemento?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+
+        'DefaultNewItem' => 'Novo elemento', # Accepts model codes
+        'NewItemTooltip' => 'Engadir un novo elemento', # Accepts model codes
         'NoItemFound' => 'Non se atopou nada. Gustaríalle buscar en outra páxina web?',
         'OpenList' => 'Seleccine unha colección',
         'SaveList' => 'Escolla onde gardar a colección',
         'SaveListTooltip' => 'Gardar a colección actual',
-        'SaveCurrentList' => 'Especifique primeiro onde gardar a colección actual',
         'SaveUnsavedChanges' => 'Hai cambios na colección que non se gardaron todavía. Quere gardalos?',
         'SaveDontSave' => 'Non gardar',
         'PreferencesTooltip' => 'Aplicar as súas configuracións',
         'ViewTooltip' => 'Cambiar o tipo de visualización',
-        'PlayTooltip' => 'Reproducir un video asociado ao elemento',
+        'PlayTooltip' => 'Reproducir un video asociado ao elemento', # Accepts model codes
         'PlayFileNotFound' => 'File to launch was not found in this location:',
         'PlayRetry' => 'Retry',
 
@@ -179,8 +204,8 @@ utilizar <b>o botón situado debaixo dos detalles do elemento</b>.',
         'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'Que pode ver esta noite ?',
-        'RandomError'=> 'Non pode seleccionar ningún elemento',
-        'RandomEnd'=> 'Non hai máis elementos',
+        'RandomError'=> 'Non pode seleccionar ningún elemento', # Accepts model codes
+        'RandomEnd'=> 'Non hai máis elementos', # Accepts model codes
         'RandomNextTip'=> 'Seguinte suxerencia',
         'RandomOkTip'=> 'Aceptar este elemento',
         
@@ -197,7 +222,8 @@ Adolfo González: Programador
 Logos Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Traducción ao Galego por Daniel Espiñeira',
-        'AboutDesign' => 'Logo e deseño web por le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logo e deseño web por le Spektre',
 
         'ToolbarRandom' => 'Esta noite',
 
@@ -247,6 +273,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Audio',
         'ModelFieldFileProgram' => 'Programa',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Usar campos',
         'ModelOptionsFieldsAuto' => 'Automático',
         'ModelOptionsFieldsNone' => 'Ningún',
@@ -275,10 +302,10 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'Deben considerarse os valores como número na comparación?',
         'ModelTooltipQuick' => 'Isto engadirá un submenú no menú de Filtros',
         
-        'ResultsTitle' => 'Seleccionar un elemento',
+        'ResultsTitle' => 'Seleccionar un elemento', # Accepts model codes
         'ResultsNextTip' => 'Procurarr na seguinte Web',
         'ResultsPreview' => 'Previsualizar',
-        'ResultsInfo' => 'Pode engadir varios elementos á colección seleccionandoos mentres preme Ctrl ou Shift',
+        'ResultsInfo' => 'Pode engadir varios elementos á colección seleccionandoos mentres preme Ctrl ou Shift', # Accepts model codes
         
         'OptionsTitle' => 'Preferencias',
 		'OptionsExpertMode' => 'Expert Mode',
@@ -426,6 +453,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Directory',
         'FileChooserOpenDirectory' => 'Seleccione un directorio',
         'FileChooserOverwrite' => 'Este ficheiro xa existe. Quere sobreescribilo?',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
         #Some default panels
         'PanelCompact' => 'Compacto',
@@ -444,14 +476,17 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Seleccione una imaxe',
         'PanelImageNoImage' => 'Sen imaxe',
         'PanelSelectFileTitle' => 'Seleccione un ficheiro',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Restaurar predeterminado',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Update information from web',
 
         'PanelFrom' =>'Desde',
         'PanelTo' =>'A',
 
         'PanelWeb' => 'Ver información',
-        'PanelWebTip' => 'Ver información na web acerca deste elemento',
-        'PanelRemoveTip' => 'Eliminar elemento actual',
+        'PanelWebTip' => 'Ver información na web acerca deste elemento', # Accepts model codes
+        'PanelRemoveTip' => 'Eliminar elemento actual', # Accepts model codes
 
         'PanelDateSelect' => 'Seleccionar',
         'PanelNobody' => 'Ninguén',
@@ -465,7 +500,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Prestatario',
         'PanelLendDate' => 'Fora desde',
         'PanelHistory' => 'Historial de préstamo',
-        'PanelReturned' => 'Elemento devolto',
+        'PanelReturned' => 'Elemento devolto', # Accepts model codes
         'PanelReturnDate' => 'Data de devolución',
         'PanelLendedYes' => 'Prestado',
         'PanelLendedNo' => 'Dispoñible',
@@ -498,6 +533,8 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Linguaxe',
         'PluginsUseSite' => 'Utilizar sitio web seleccionado para outras procuras no futuro',
+        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+        'PluginDisabled' => 'Disabled',
 
         'BorrowersTitle' => 'Configuración do prestatario',
         'BorrowersList' => 'Prestatarios',
@@ -516,9 +553,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'Formato do ficheiro:',
         'BorrowersImportFile' => 'Ficheiro:',
 
-        'BorrowedTitle' => 'Elementos prestados',
+        'BorrowedTitle' => 'Elementos prestados', # Accepts model codes
         'BorrowedDate' => 'Desde',
-        'BorrowedDisplayInPanel' => 'Show item in main window',
+        'BorrowedDisplayInPanel' => 'Show item in main window', # Accepts model codes
 
         'MailTitle' => 'Enviar un correo electrónico',
         'MailFrom' => 'Desde: ',
@@ -527,8 +564,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Houbo un problema conectando có servidor SMTP',
         'MailSendmailError' => 'Houbo un problema ao lanzar sendmail',
 
-        'SearchTooltip' => 'Procurar todos os elementos',
-        'SearchTitle' => 'Procura de elementos',
+        'SearchTooltip' => 'Procurar todos os elementos', # Accepts model codes
+        'SearchTitle' => 'Procura de elementos', # Accepts model codes
         'SearchNoField' => 'No field have been selected for the search box.
 Add some of them in the Filters tab of the collection settings.',
 
@@ -567,7 +604,7 @@ Add some of them in the Filters tab of the collection settings.',
         'PropertiesDescription' => 'Descripción',
         'PropertiesFile' => 'Información de ficheiro',
         'PropertiesFilePath' => 'Ruta completa',
-        'PropertiesItemsNumber' => 'Número de elementos',
+        'PropertiesItemsNumber' => 'Número de elementos', # Accepts model codes
         'PropertiesFileSize' => 'Tamaño',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Propiedades da colección',
@@ -591,8 +628,8 @@ Add some of them in the Filters tab of the collection settings.',
         'BookmarksNewFolder' => 'Novo cartafol',
 
         'AdvancedSearchType' => 'Tipo de procura',
-        'AdvancedSearchTypeAnd' => 'Elementos que cumpren todos os criterios de procura',
-        'AdvancedSearchTypeOr' => 'Elementos que cumpren polo menos un criterio',
+        'AdvancedSearchTypeAnd' => 'Elementos que cumpren todos os criterios de procura', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Elementos que cumpren polo menos un criterio', # Accepts model codes
         'AdvancedSearchCriteria' => 'Criterios',
         'AdvancedSearchAnyField' => 'Calquer campo',
         'AdvancedSearchSaveTitle' => 'Save search',
@@ -606,6 +643,24 @@ Add some of them in the Filters tab of the collection settings.',
         'BugReportPlatform' => 'Sistema Operativo',
         'BugReportMessage' => 'Mensaxe de erro',
         'BugReportInformation' => 'Información adicional',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
     );
 }
 1;
