@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,6 +33,9 @@
         'Charset' => 'Karakterkódolás',
         'Header' => 'Az első sor mellőzése',
         'Separator' => 'Elválasztó',
+        'Plugin' => 'Használandó oldal',
+        'UseFirst' => 'Az első kijelölése több talál esetén',
+        'SearchField' => 'Search for items using',
      );
 }
 
