@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -31,12 +31,12 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'Name' => 'Folder',
-        'Recursive' => 'Browse sub-folders',
-        'Suffixes' => 'Suffixes or extensions of the files',
-        'SuffixesTooltip' => 'A comma-separated list of suffixes or extensions of files to consider',
-        'Remove' => 'To be removed from names',
-        'RemoveTooltip' => 'A comma-seperated list of words that should be removed from file names to create the fetched names',
+        'Name' => 'Mappa',
+        'Recursive' => 'Almappák böngészése',
+        'Suffixes' => 'A fájlok toldalékai, vagy kiterjesztései',
+        'SuffixesTooltip' => 'A fájlok toldalékainak, vagy kiterjesztéseinek vesszővel elválasztott listájának megtekintése',
+        'Remove' => 'Eltávolítva a nevekből',
+        'RemoveTooltip' => 'A vesszővel elválasztott szavak listája, amiket el kellett távolítani a fájlnevekből a rövidített nevekhez',
         'Ask'=> 'Ask',
         'AskEnd'=> 'Ask all at end',
         'AddWithoutInfo'=> 'Add without infos',
