@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -32,11 +32,11 @@
 
     our %lang = (
     
-        CollectionDescription => 'TV Shows (episodes) collection',
-        Items => 'Episodes',
-        NewItem => 'New episode',
-        NewSeries => 'New series',
-        Episode => 'Episode',
+        CollectionDescription => 'TV Show-k (epizódok) gyűjteménye',
+        Items => 'Epizódok',
+        NewItem => 'Új epizód',
+        NewSeries => 'Új sorozatok',
+        Episode => 'Epizód',
     );
     # Both of them are required as importTranslation doesn't recurse
     importTranslation('films');
