@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -32,17 +32,17 @@
 
     our %lang = (
     
-        CollectionDescription => 'TV Shows (series) collection',
-        Items => 'Series',
-        NewItem => 'New series',
-        Name => 'Name',
-        Season => 'Season',
-        Part => 'Part',
-        Episodes => 'Episodes',
+        CollectionDescription => 'TV Show-k (sorozatok) gyűjteménye',
+        Items => 'Sorozatok',
+        NewItem => 'Új sorozatok',
+        Name => 'Név',
+        Season => 'Évad',
+        Part => 'Rész',
+        Episodes => 'Epizódok',
         FirstAired => 'First Aired',
-        Time => 'Ep. Length',
+        Time => 'Ep. hossza',
         Producer => 'Producer',
-        Music => 'Music',
+        Music => 'Zene',
      );
      importTranslation('Films');
 }
