@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -31,42 +31,42 @@
 
     our %lang = (
     
-        CollectionDescription => 'Comics collection',
-        Items => {0 => 'Comics',
-                  1 => 'Comic',
-                  X => 'Comics'},
-        NewItem => 'New comic',
+        CollectionDescription => 'Képregénygyűjtemény',
+        Items => {0 => 'Képregények',
+                  1 => 'Képregény',
+                  X => 'Képregények'},
+        NewItem => 'Új képregény',
     
     
         Id => 'Id',
-        Name => 'Name',
-        Series => 'Series',
-        Volume => 'Volume',
-        Title => 'Title',
-        Writer => 'Writer',
-        Illustrator => 'Illustrator',
-        Colourist => 'Colourist',
-        Publisher => 'Publisher',
-        Synopsis => 'Synopsis',
-        Collection => 'Collection',
-        PublishDate => 'Publish Date',
-        PrintingDate => 'Printing Date',
+        Name => 'Név',
+        Series => 'Sorozatok',
+        Volume => 'Kötet',
+        Title => 'Cím',
+        Writer => 'Író',
+        Illustrator => 'Illusztátor',
+        Colourist => 'Szinező',
+        Publisher => 'Kiadó',
+        Synopsis => 'Összegzés',
+        Collection => 'Gyűjtemény',
+        PublishDate => 'Kiadás dátuma',
+        PrintingDate => 'Nyomtatás dátuma',
         ISBN => 'ISBN',
-        Type => 'Type',
-		Category => 'Category',
-        Format => 'Format',
-        NumberBoards => 'Number of Boards',
-		Signing => 'Signing',
-        Cost => 'Cost',
-        Rating => 'Rating',
-        Comment => 'Comments',
-        Url => 'Web page',
+        Type => 'Típus',
+		Category => 'Kategória',
+        Format => 'Formátum',
+        NumberBoards => 'Táblák száma',
+		Signing => 'Jelölés',
+        Cost => 'Ár',
+        Rating => 'Értékelés',
+        Comment => 'Megjegyzések',
+        Url => 'Weboldal',
 
-        FilterRatingSelect => 'Rating At _Least...',
+        FilterRatingSelect => 'Értékelés _legalább...',
 
-        Main => 'Main items',
-        General => 'General',
-        Details => 'Details',
+        Main => 'Fő elemek',
+        General => 'Általános',
+        Details => 'Részletek',
      );
 }
 
