@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -56,7 +56,7 @@
         Seen => 'Megnézve',
         Number => '# Média',
         Format => 'Média',
-        Region => 'Region',
+        Region => 'Régió',
         Identifier => 'Azonosító',
         Url => 'Weboldal',
         Audio => 'Hang',
