@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -23,7 +23,23 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 ###################################################
-    
+  
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
+  
     use strict;
     use base 'Exporter';
 
@@ -46,7 +62,7 @@ Bármilyen újraközlés az oldal
 <b>Az elemek alatti gomb</b> megnyomásával nyomonkövethetjük,
 hogy melyik oldalról valók az információk.',
         
-        'AllItemsFiltered' => 'Nincs megfelelő elem a keresési feltételeidhez',
+        'AllItemsFiltered' => 'Nincs megfelelő elem a keresési feltételeidhez', # Accepts model codes
         
 #Installation
         'InstallDirInfo' => 'Telepítés ide',
@@ -97,29 +113,34 @@ hogy melyik oldalról valók az információk.',
 #Menus
         'MenuFile' => '_Fájl',
             'MenuNewList' => '_Új gyűjtemény',
+            'MenuStats' => 'Statistics',
             'MenuHistory' => 'K_orábbi gyűjtemények',
-            'MenuLend' => 'Kölcsönadott _elemek megjelenítése',
+            'MenuLend' => 'Kölcsönadott _elemek megjelenítése', # Accepts model codes
             'MenuImport' => '_Importálás',	
             'MenuExport' => 'E_xportálás',
+            'MenuAddItem' => '_Add Items', # Accepts model codes
     
         'MenuEdit'  => '_Szerkesztés',
-            'MenuDuplicate' => 'Elem _kettőzése',
-            'MenuEditDeleteCurrent' => '_Elem eltávolítása',
+            'MenuDuplicate' => 'Elem _kettőzése', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate Items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All Items', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_Elem eltávolítása', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove Items', # Accepts model codes    
             'MenuEditFields' => '_Gyűjtemény mezőinek megváltoztatása',
             'MenuEditLockItems' => 'Gyűjtemény _zárolása',
     
         'MenuDisplay' => 'S_zűrő',
-            'MenuSavedSearches' => 'Saved searches',
-                'MenuSavedSearchesSave' => 'Save current search',
-                'MenuSavedSearchesEdit' => 'Modify saved searches',
+            'MenuSavedSearches' => 'Elmentett keresések',
+                'MenuSavedSearchesSave' => 'A jelenlegi keresés elmentése',
+                'MenuSavedSearchesEdit' => 'Elmentett keresések módosítása',
             'MenuAdvancedSearch' => 'Haladó keresés',
-            'MenuViewAllItems' => '_Elemek mutatása',
+            'MenuViewAllItems' => '_Elemek mutatása', # Accepts model codes
             'MenuNoFilter' => '_Minden',
     
         'MenuConfiguration' => '_Beállítások',
             'MenuDisplayOptions' => '_Megjelenítendő elemek',
             'MenuBorrowers' => '_Kölcsönvevők',
-            'MenuToolbarConfiguration' => '_Toolbar Controls',
+            'MenuToolbarConfiguration' => '_Eszköztár beállítása',
             'MenuGenresConversion' => '_Jellemzők konvertálása',
         
         'MenuBookmarks' => 'S_aját gyűjtemények',
@@ -132,33 +153,36 @@ hogy melyik oldalról valók az információk.',
             'MenuBugReport' => 'Hibajelentés _küldése',
             'MenuAbout' => '_A GCstar-ról',
     
-        'MenuNewWindow' => 'Megjelenítés új _ablakban',
+        'MenuNewWindow' => 'Megjelenítés új _ablakban', # Accepts model codes
+        'MenuNewWindowPlural' => 'Show Items in _New Window', # Accepts model codes
         
         'ContextExpandAll' => 'Szálak kibontása',
         'ContextCollapseAll' => 'Szálak összecsukása',
-        'ContextChooseImage' => 'Choose _Image',
-        'ContextOpenWith' => 'Open Wit_h',
-        'ContextImageEditor' => 'Image Editor',
-        'ContextImgFront' => 'Front',
-        'ContextImgBack' => 'Back',
+        'ContextChooseImage' => 'Válassz _Képet',
+        'ContextOpenWith' => 'Megnyitás ezze_l',
+        'ContextImageEditor' => 'Képszerkesztő',
+        'ContextImgFront' => 'Borító',
+        'ContextImgBack' => 'Hátlap',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
        
         'DialogEnterNumber' => 'Addj meg egy értéket',
 
-        'RemoveConfirm' => 'Valóban el akarod távolítani az elemet?',
-        'DefaultNewItem' => 'Új elem',
-        'NewItemTooltip' => 'Új elem hozzáadása',
+        'RemoveConfirm' => 'Valóban el akarod távolítani az elemet?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+        'DefaultNewItem' => 'Új elem', # Accepts model codes
+        'NewItemTooltip' => 'Új elem hozzáadása', # Accepts model codes
         'NoItemFound' => 'Nincs találat. Akarsz egy másik oldalon keresni?',
         'OpenList' => 'Jelölj ki egy gyűjteményt',
         'SaveList' => 'Válaszd ki, hogy hova legyen mentve a gyűjtemény!',
         'SaveListTooltip' => 'Jelenlegi gyűjtemény mentése',
-        'SaveCurrentList' => 'Határozd meg, hogy hova legyen mentve a jelenlegi gyűjtemény',
         'SaveUnsavedChanges' => 'Nem mentett változások vannak a gyűjteményedben. Akarod őket menteni?',
         'SaveDontSave' => 'Ne mentse',
         'PreferencesTooltip' => 'Beállítások',
         'ViewTooltip' => 'A gyűjtemény megjelenítésének változtatása',
-        'PlayTooltip' => 'Az elemhez kapcsolódó videó lejátszása',
-        'PlayFileNotFound' => 'File to launch was not found in this location:',
-        'PlayRetry' => 'Retry',
+        'PlayTooltip' => 'Az elemhez kapcsolódó videó lejátszása', # Accepts model codes
+        'PlayFileNotFound' => 'Ezen a helyen nem található az indítandó fájl:',
+        'PlayRetry' => 'Újra',
 
         'StatusSave' => 'Mentés...',
         'StatusLoad' => 'Betöltés...',
@@ -169,18 +193,18 @@ hogy melyik oldalról valók az információk.',
         'SaveError' => 'Nem lehet menteni a listát. Ellenőrízd a jogokat és a szabad tárhelyet.',
         'OpenError' => 'Nem lehet megnyitni a listát. Ellenőrízd a jogokat.',
 		'OpenFormatError' => 'Nem lehet megnyitni a listát. Hibás formátum.',
-        'OpenVersionWarning' => 'Collection was created with a more recent version of GCstar. If you save it, you may loose some data.',
-        'OpenVersionQuestion' => 'Do you still want to continue?',
+        'OpenVersionWarning' => 'A gyűjtemény egy újabb verziójú GCstar-ral készült. Ha elmented, elveszthetsz néhány adatot.',
+        'OpenVersionQuestion' => 'Biztosan folytatni akarod?',
         'ImageError' => 'A képek mentéséhez kiválasztott könyvtár helytelen. Válassz egy másikat.',
         'OptionsCreationError'=> 'Nem lehet létrehozni a beállítás-fájlt: ',
         'OptionsOpenError'=> 'Nem lehet megnyitni a beállítás-fájlt: ',
         'OptionsSaveError'=> 'Nem lehet menteni a beállítás-fájlt: ',
-        'ErrorModelNotFound' => 'Model not found: ',
-        'ErrorModelUserDir' => 'User defined models are in: ',
+        'ErrorModelNotFound' => 'Sablon nem található: ',
+        'ErrorModelUserDir' => 'A felhasználó által meghatározott sablonok: ',
         
         'RandomTooltip' => 'Mit nézünk ma este ?',
-        'RandomError'=> 'Nincs kijelölhető elem',
-        'RandomEnd'=> 'Nincs több elem',
+        'RandomError'=> 'Nincs kijelölhető elem', # Accepts model codes
+        'RandomEnd'=> 'Nincs több elem', # Accepts model codes
         'RandomNextTip'=> 'Következő javaslat',
         'RandomOkTip'=> 'Elem elfogadása',
         
@@ -197,11 +221,12 @@ Adolfo González: Programozó
 Logók Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Magyar fordítás: Takács László Krisztián tlk at t-online dot hu',
-        'AboutDesign' => 'Logó és webdizájn: le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logó és webdizájn: le Spektre',
 
         'ToolbarRandom' => 'Ma este',
 
-        'UnsavedCollection' => 'Unsaved Collection',
+        'UnsavedCollection' => 'Nem mentett Gyűjtemény',
         'ModelsSelect' => 'A gyűjtemény típusának kiválasztása',
         'ModelsPersonal' => 'Személyes sablonok',
         'ModelsDefault' => 'Alapértelmezett sablonok',
@@ -223,9 +248,9 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Maximális:',
         'ModelFieldList' => 'Értékek listája:',
         'ModelFieldListLegend' => '<i>Vesszővel elválasztva</i>',
-        'ModelFieldDisplayAs' => 'Display as:',
-        'ModelFieldDisplayAsText' => 'Text',
-        'ModelFieldDisplayAsGraphical' => 'Rating Control',
+        'ModelFieldDisplayAs' => 'Megjelenik mint:',
+        'ModelFieldDisplayAsText' => 'Szöveg',
+        'ModelFieldDisplayAsGraphical' => 'Kategória Beállítás',
         'ModelFieldTypeShortText' => 'Rövid szöveg',
         'ModelFieldTypeLongText' => 'Hosszú szöveg',
         'ModelFieldTypeYesNo' => 'Igen/Nem',
@@ -247,6 +272,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Hang',
         'ModelFieldFileProgram' => 'Program',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Mezők használata',
         'ModelOptionsFieldsAuto' => 'Automatikus',
         'ModelOptionsFieldsNone' => 'Semmi',
@@ -260,8 +286,8 @@ http://le-spektre.org',
         'ModelFilterActivated' => 'A keresősávban kell legyen',
         'ModelFilterComparison' => 'Összehasonlítás',
         'ModelFilterContain' => 'Tartalmazza',
-        'ModelFilterDoesNotContain' => 'Does not contain',
-        'ModelFilterRegexp' => 'Regular expression',
+        'ModelFilterDoesNotContain' => 'Nem tartalmazza',
+        'ModelFilterRegexp' => 'Pontos kifejezés',
         'ModelFilterRange' => 'Sorozat',
         'ModelFilterNumeric' => 'Számalapú összehasonlítás',
         'ModelFilterQuick' => 'Gyorsszűrő létrehozása',
@@ -275,30 +301,30 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'Az értékek az összehasonlításban számként lesznek jelölve',
         'ModelTooltipQuick' => 'Almenü hozzáadása a szűrőkhöz',
         
-        'ResultsTitle' => 'Elem kijelölése',
+        'ResultsTitle' => 'Elem kijelölése', # Accepts model codes
         'ResultsNextTip' => 'Keresés a következő oldalon',
         'ResultsPreview' => 'Előnézet',
-        'ResultsInfo' => 'Több elem hozzáadása lehetséges a gyűjteményhez. Nyomd le a Crtl vagy a Shift gombot, és válassz',
+        'ResultsInfo' => 'Több elem hozzáadása lehetséges a gyűjteményhez. Nyomd le a Crtl vagy a Shift gombot, és válassz', # Accepts model codes
         
         'OptionsTitle' => 'Beállítások',
-        'OptionsExpertMode' => 'Expert Mode',
-        'OptionsPrograms' => 'Specify applications to use for different media, leave blank to use system defaults',
+        'OptionsExpertMode' => 'Haladó mód',
+        'OptionsPrograms' => 'Bizonyos alkalmazások használata különböző médiákhoz, hagyd üresen az alapbeállítások használatához',
         'OptionsBrowser' => 'Böngésző',
         'OptionsPlayer' => 'Videólejátszó',
         'OptionsAudio' => 'Hanglejátszó',
-        'OptionsImageEditor' => 'Image editor',
-        'OptionsCdDevice' => 'CD device',
+        'OptionsImageEditor' => 'Képszerkesztő',
+        'OptionsCdDevice' => 'CD-eszköz',
         'OptionsImages' => 'Képek',
         'OptionsUseRelativePaths' => 'Relatív elérési utak használata a képekhez',
         'OptionsLayout' => 'Elrendezés',
         'OptionsStatus' => 'Állapotjelző mutatása',
-        'OptionsUseStars' => 'Use stars to display ratings',
+        'OptionsUseStars' => 'Csillagok használata az értékelések kijelzéséhez',
         'OptionsWarning' => 'Figyelem: A beállítások csak a program újraindítása után lépnek életbe.',
         'OptionsRemoveConfirm' => 'Kérjen megerősítést az elem törlése előtt',
         'OptionsAutoSave' => 'Gyűjtemény automatikus mentése',
         'OptionsAutoLoad' => 'Előző gyűjtemény betöltése induláskor',
         'OptionsSplash' => 'Bejelentkező képernyő mutatása',
-        'OptionsTearoffMenus' => 'Enable tear-off menus',
+        'OptionsTearoffMenus' => 'Előjegyzési menük engedélyezése',
         'OptionsSpellCheck' => 'Helyesírásellenőrző használata a hosszú, szöveges mezőkhöz',
         'OptionsProgramTitle' => 'Használandó program kiválasztása',
 		'OptionsPlugins' => 'Oldal, ahol adatot keres',
@@ -339,7 +365,7 @@ http://le-spektre.org',
         'OptionsTransform' => 'Névelők helye a címek végén',
         'OptionsArticles' => 'Névelők (vesszővel elválasztva)',
         'OptionsSearchStop' => 'A keresés leállítható',
-        'OptionsBigPics' => 'Use big pictures when available',
+        'OptionsBigPics' => 'Nagy képek használata, ha lehetséges',
         'OptionsAlwaysOriginal' => 'A fő cím használata eredeti címként, ha az nem elérhető',
         'OptionsRestoreAccelerators' => 'Gyorsítók visszaállítása',
         'OptionsHistory' => 'Előzmények mérete',
@@ -376,7 +402,7 @@ http://le-spektre.org',
         'ImagesOptionsFg'=> 'Kiválasztás',
         'ImagesOptionsBgTooltip' => 'Háttérszín változtatása',
         'ImagesOptionsFgTooltip'=> 'Kijelölés színének változtatása',
-        'ImagesOptionsResizeImgList' => 'Automatically change number of columns',
+        'ImagesOptionsResizeImgList' => 'Az oszlopok számának automatikus változtatása',
         'ImagesOptionsSizeLabel' => 'Méret',
         'ImagesOptionsSizeList' => {0 => 'Nagyon kicsi', 1 => 'Kicsi', 2 => 'Közepes', 3 => 'Nagy', 4 => 'Nagyon nagy'},
         'ImagesOptionsSizeTooltip' => 'Képméret kiválasztása',
@@ -423,9 +449,14 @@ http://le-spektre.org',
         'ImportGenerateId' => 'Azonosító létrehozása minden elemhez',
 
         'FileChooserOpenFile' => 'Válaszd ki a használandó fájlt!',
-        'FileChooserDirectory' => 'Directory',
+        'FileChooserDirectory' => 'Könyvtár',
         'FileChooserOpenDirectory' => 'Könyvtár kiválasztása',
         'FileChooserOverwrite' => 'A fájl már létezik. Felül akarod írni?',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
         #Some default panels
         'PanelCompact' => 'Egyszerű',
@@ -444,14 +475,17 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Kép kiválasztása',
         'PanelImageNoImage' => 'Nincs kép',
         'PanelSelectFileTitle' => 'Fájl kiválasztása',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Visszaállítás',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Update information from web',
 
         'PanelFrom' =>'Feladó',
         'PanelTo' =>'Címzett',
 
         'PanelWeb' => 'Információk megtekintése',
-        'PanelWebTip' => 'Információ megtekintése az interneten erről az elemről',
-        'PanelRemoveTip' => 'Jelenlegi elem eltávolítása',
+        'PanelWebTip' => 'Információ megtekintése az interneten erről az elemről', # Accepts model codes
+        'PanelRemoveTip' => 'Jelenlegi elem eltávolítása', # Accepts model codes
 
         'PanelDateSelect' => 'Kijelöl',
         'PanelNobody' => 'Senki',
@@ -465,7 +499,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Kölcsönvevő',
         'PanelLendDate' => 'Kölcsönadás ideje',
         'PanelHistory' => 'Kölcsönzési előzmények',
-        'PanelReturned' => 'Visszaadva',
+        'PanelReturned' => 'Visszaadva', # Accepts model codes
         'PanelReturnDate' => 'Visszaadás dátuma',
         'PanelLendedYes' => 'Kölcsönadva',
         'PanelLendedNo' => 'Elérhető',
@@ -484,10 +518,10 @@ http://le-spektre.org',
         'ToolbarAllTooltip' => 'Elemek mutatása',
         'ToolbarGroupBy' => 'Csoportosítás',
         'ToolbarGroupByTooltip' => 'Jelöld ki a lista elemeinek csoportosításához használni kívánt mezőt',
-        'ToolbarQuickSearch' => 'Quick search',
-        'ToolbarQuickSearchLabel' => 'Search',
-        'ToolbarQuickSearchTooltip' => 'Select the field to search in. Enter the search terms and press Enter',
-        'ToolbarSeparator' => ' Separator',
+        'ToolbarQuickSearch' => 'Gyorskeresés',
+        'ToolbarQuickSearchLabel' => 'Keresés',
+        'ToolbarQuickSearchTooltip' => 'Válaszd ki azt a mezőt, amiben keresnél. Üsd be a kifejezéseket és nyomj Entert',
+        'ToolbarSeparator' => ' Elválasztó',
         
         'PluginsTitle' => 'Elem keresése',
         'PluginsQuery' => 'Kérdés',
@@ -498,6 +532,8 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Szerző',
         'PluginsLang' => 'Nyelv',
         'PluginsUseSite' => 'A kiválasztott oldal használata további keresésekhez',
+        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+        'PluginDisabled' => 'Disabled',
 
         'BorrowersTitle' => 'Kölcsönvevők beállításai',
         'BorrowersList' => 'Kölcsönvevők',
@@ -516,9 +552,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'Fájlformátum:',
         'BorrowersImportFile' => 'Fájl:',
 
-        'BorrowedTitle' => 'Kölcsönadott elemek',
+        'BorrowedTitle' => 'Kölcsönadott elemek', # Accepts model codes
         'BorrowedDate' => 'Kölcsönadás ideje',
-        'BorrowedDisplayInPanel' => 'Show item in main window',
+        'BorrowedDisplayInPanel' => 'Elemek megjelenítése a fő ablakban', # Accepts model codes
 
         'MailTitle' => 'E-mail küldése',
         'MailFrom' => 'Feladó: ',
@@ -527,8 +563,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Hiba az SMTP szerverhez való kapcsolódáskor',
         'MailSendmailError' => 'Hiba a sendmail futtatásakor',
 
-        'SearchTooltip' => 'Elemek keresése',
-        'SearchTitle' => 'Elem keresése',
+        'SearchTooltip' => 'Elemek keresése', # Accepts model codes
+        'SearchTitle' => 'Elem keresése', # Accepts model codes
         'SearchNoField' => 'No field have been selected for the search box.
 Add some of them in the Filters tab of the collection settings.',
 
@@ -561,17 +597,17 @@ Add some of them in the Filters tab of the collection settings.',
         'GenresModify' => 'Változások szerkesztése',
 
         'PropertiesName' => 'Gyűjtemény neve',
-        'PropertiesLang' => 'Language code',
+        'PropertiesLang' => 'Nyelv kód',
         'PropertiesOwner' => 'Tulajdonos',
         'PropertiesEmail' => 'E-mail cím',
         'PropertiesDescription' => 'Leírás',
         'PropertiesFile' => 'Fájlinformáció',
         'PropertiesFilePath' => 'Elérési út',
-        'PropertiesItemsNumber' => 'Elemek száma',
+        'PropertiesItemsNumber' => 'Elemek száma', # Accepts model codes
         'PropertiesFileSize' => 'Méret',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Gyűjtemény tulajdonságai',
-        'PropertiesDefaultPicture' => 'Default picture',
+        'PropertiesDefaultPicture' => 'Alapértelmezett kép',
 
         'MailProgramsTitle' => 'Levelezőprogramok',
         'MailProgramsName' => 'Név',
@@ -591,21 +627,39 @@ Add some of them in the Filters tab of the collection settings.',
         'BookmarksNewFolder' => 'Új könyvtár',
 
         'AdvancedSearchType' => 'Keresés típusa',
-        'AdvancedSearchTypeAnd' => 'Minden kritériumnak megfelelő elemek',
-        'AdvancedSearchTypeOr' => 'Legalább egy kritériumnak megfelelő elemek',
+        'AdvancedSearchTypeAnd' => 'Minden kritériumnak megfelelő elemek', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Legalább egy kritériumnak megfelelő elemek', # Accepts model codes
         'AdvancedSearchCriteria' => 'Kritérium',
         'AdvancedSearchAnyField' => 'Bármely mező',
-        'AdvancedSearchSaveTitle' => 'Save search',
-        'AdvancedSearchSaveName' => 'Name',
-        'AdvancedSearchSaveOverwrite' => 'A saved search already exists with that name. Please use a different one.',
-        'AdvancedSearchUseCase' => 'Case sensitive',
-        'AdvancedSearchIgnoreDiacritics' => 'Ignore accents and other diacritics',
+        'AdvancedSearchSaveTitle' => 'Keresés elmentése',
+        'AdvancedSearchSaveName' => 'Név',
+        'AdvancedSearchSaveOverwrite' => 'Ezzel a névvel már létezik elmentett keresés. Válassz egy másikat.',
+        'AdvancedSearchUseCase' => 'Ügyel a nagybetűs írásmódra',
+        'AdvancedSearchIgnoreDiacritics' => 'Különleges karakterek mellőzése',
  
         'BugReportSubject' => 'Hibajelentés a GCstar-tól',
         'BugReportVersion' => 'Verzió',
         'BugReportPlatform' => 'Operációsrendszer',
         'BugReportMessage' => 'Hibaüzenet',
         'BugReportInformation' => 'További információk',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
     );
 }
 1;
