@@ -33,6 +33,9 @@
         'Charset' => 'Charset',
         'Header' => 'Abaikan baris pertama',
         'Separator' => 'Pemisah',
+        'Plugin' => 'Situs yang akan digunakan',
+        'UseFirst' => 'Pilih yang paling pertama jika hasilnya banyak',
+        'SearchField' => 'Search for items using',
      );
 }
 
