@@ -23,7 +23,23 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 ###################################################
-    
+
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
+
     use strict;
     use base 'Exporter';
 
@@ -46,7 +62,7 @@ Any redistribution is forbidden without the site\'s
 To determine which site owns the information, you
 may use the <b>button below item details</b>.',
         
-        'AllItemsFiltered' => 'Tidak ada yang cocok dengan kriteria pemilahan',
+        'AllItemsFiltered' => 'Tidak ada yang cocok dengan kriteria pemilahan', # Accepts model codes
         
 #Installation
         'InstallDirInfo' => 'Di install di ',
@@ -97,14 +113,19 @@ may use the <b>button below item details</b>.',
 #Menus
         'MenuFile' => '_File',
             'MenuNewList' => '_Koleksi Baru',
+            'MenuStats' => 'Statistics',
             'MenuHistory' => '_Recent Collections',
-            'MenuLend' => 'Tampilkan _Item yang dipinjam',
+            'MenuLend' => 'Tampilkan _Item yang dipinjam', # Accepts model codes
             'MenuImport' => '_Import',	
             'MenuExport' => '_Export',
+            'MenuAddItem' => '_Add Items', # Accepts model codes
     
         'MenuEdit'  => '_Ubah',
-            'MenuDuplicate' => 'Du_plicate item',
-            'MenuEditDeleteCurrent' => '_Remove item',
+            'MenuDuplicate' => 'Du_plicate item', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate Items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All Items', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_Remove item', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove Items', # Accepts model codes    
             'MenuEditFields' => '_Change collection fields',
             'MenuEditLockItems' => '_Lock Collection',
     
@@ -113,7 +134,7 @@ may use the <b>button below item details</b>.',
                 'MenuSavedSearchesSave' => 'Simpan pencarian yang sekarang',
                 'MenuSavedSearchesEdit' => 'Ubah simpanan pencarian',
             'MenuAdvancedSearch' => 'A_dvanced Search',
-            'MenuViewAllItems' => 'Show _All items',
+            'MenuViewAllItems' => 'Show _All items', # Accepts model codes
             'MenuNoFilter' => '_Any',
     
         'MenuConfiguration' => '_Settings',
@@ -132,7 +153,8 @@ may use the <b>button below item details</b>.',
             'MenuBugReport' => 'Report a _bug',
             'MenuAbout' => '_About GCstar',
     
-        'MenuNewWindow' => 'Show item in _New Window',
+        'MenuNewWindow' => 'Show item in _New Window', # Accepts model codes
+        'MenuNewWindowPlural' => 'Show items in _New Window', # Accepts model codes
         
         'ContextExpandAll' => 'Expand all',
         'ContextCollapseAll' => 'Collapse all',
@@ -141,22 +163,24 @@ may use the <b>button below item details</b>.',
         'ContextImageEditor' => 'Buka dengan pengedit gambar',
         'ContextImgFront' => 'Front',
         'ContextImgBack' => 'Back',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
         
         'DialogEnterNumber' => 'Please enter value',
 
-        'RemoveConfirm' => 'Do you really want to remove this item?',
-        'DefaultNewItem' => 'New item',
-        'NewItemTooltip' => 'Add a new item',
+        'RemoveConfirm' => 'Do you really want to remove this item?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+        'DefaultNewItem' => 'New item', # Accepts model codes
+        'NewItemTooltip' => 'Add a new item', # Accepts model codes
         'NoItemFound' => 'Tidak menemukan apapun. Apa anda mau mencari di situs yang lain?',
         'OpenList' => 'Harap pilih koleksi',
         'SaveList' => 'Harap pilih lokasi penyimpanan koleksi',
         'SaveListTooltip' => 'Save current collection',
-        'SaveCurrentList' => 'First specify where to save the current collection',
         'SaveUnsavedChanges' => 'There are unsaved changes in your collection. Do you want to save them?',
         'SaveDontSave' => 'Jangan disimpan',
         'PreferencesTooltip' => 'Set your preferences',
         'ViewTooltip' => 'Change collection display',
-        'PlayTooltip' => 'Play video associated to the item',
+        'PlayTooltip' => 'Play video associated to the item', # Accepts model codes
         'PlayFileNotFound' => 'File to launch was not found in this location:',
         'PlayRetry' => 'Retry',
 
@@ -179,8 +203,8 @@ may use the <b>button below item details</b>.',
         'ErrorModelUserDir' => 'Model buatan pengguna ada di: ',
         
         'RandomTooltip' => 'What to see this evening ?',
-        'RandomError'=> 'You have no item that could be selected',
-        'RandomEnd'=> 'There are no more items',
+        'RandomError'=> 'You have no item that could be selected', # Accepts model codes
+        'RandomEnd'=> 'There are no more items', # Accepts model codes
         'RandomNextTip'=> 'Next suggestion',
         'RandomOkTip'=> 'Accept this item',
         
@@ -197,7 +221,8 @@ Adolfo González: Programmer
 Logos Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Terjemahan bahasa Ingrris oleh Yuda Nugrahadi',
-        'AboutDesign' => 'Logo dan desain web oleh le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logo dan desain web oleh le Spektre',
 
         'ToolbarRandom' => 'Malam ini',
 
@@ -247,6 +272,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Audio',
         'ModelFieldFileProgram' => 'Program',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Fields to use',
         'ModelOptionsFieldsAuto' => 'Otomatis',
         'ModelOptionsFieldsNone' => 'Tidak ada',
@@ -275,10 +301,10 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'Should the values be consider as numbers for comparison',
         'ModelTooltipQuick' => 'This will add a submenu in the Filters one',
         
-        'ResultsTitle' => 'Select an item',
+        'ResultsTitle' => 'Select an item', # Accepts model codes
         'ResultsNextTip' => 'Cari di situs berikutnya',
         'ResultsPreview' => 'Pratayang',
-        'ResultsInfo' => 'Anda dapat menambah barang lebih dari satu ke koleksi dengan menekan+tahan tombol Ctrl atau Shift dan pilih barang yang akan dimasukkan',
+        'ResultsInfo' => 'Anda dapat menambah barang lebih dari satu ke koleksi dengan menekan+tahan tombol Ctrl atau Shift dan pilih barang yang akan dimasukkan', # Accepts model codes
         
         'OptionsTitle' => 'Preferences',
 		'OptionsExpertMode' => 'Expert Mode',
@@ -426,6 +452,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Direktori',
         'FileChooserOpenDirectory' => 'Pilih direktori',
         'FileChooserOverwrite' => 'This file already exists. Do you want to overwrite it?',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
         #Some default panels
         'PanelCompact' => 'Compact',
@@ -444,14 +475,17 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Pilih gambar',
         'PanelImageNoImage' => 'Tidak ada gambar',
         'PanelSelectFileTitle' => 'Pilih sebuah file',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Restore default',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Update information from web',
 
         'PanelFrom' =>'Dari',
         'PanelTo' =>'Ke',
 
         'PanelWeb' => 'View Information',
-        'PanelWebTip' => 'View information on the web about this item',
-        'PanelRemoveTip' => 'Remove current item',
+        'PanelWebTip' => 'View information on the web about this item', # Accepts model codes
+        'PanelRemoveTip' => 'Remove current item', # Accepts model codes
 
         'PanelDateSelect' => 'Select a Date',
         'PanelNobody' => 'Nobody',
@@ -465,7 +499,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Peminjam',
         'PanelLendDate' => 'Keluar sejak',
         'PanelHistory' => 'Sejarah peminjaman',
-        'PanelReturned' => 'Barang dikembalikan',
+        'PanelReturned' => 'Barang dikembalikan', # Accepts model codes
         'PanelReturnDate' => 'Tanggal pengembalian',
         'PanelLendedYes' => 'Lended',
         'PanelLendedNo' => 'Tersedia',
@@ -498,6 +532,8 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Author',
         'PluginsLang' => 'Bahasa',
         'PluginsUseSite' => 'Gunakan situs yang dipilih untuk pencarian seterusnya',
+        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+        'PluginDisabled' => 'Disabled',
 
         'BorrowersTitle' => 'Borrower Configuration',
         'BorrowersList' => 'Peminjam',
@@ -516,9 +552,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'Format file:',
         'BorrowersImportFile' => 'File:',
 
-        'BorrowedTitle' => 'Barang yang dipinjam',
+        'BorrowedTitle' => 'Barang yang dipinjam', # Accepts model codes
         'BorrowedDate' => 'Sejak',
-        'BorrowedDisplayInPanel' => 'Show item in main window',
+        'BorrowedDisplayInPanel' => 'Show item in main window', # Accepts model codes
 
         'MailTitle' => 'Send an e-mail',
         'MailFrom' => 'Dari: ',
@@ -527,8 +563,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Problem when connecting to SMTP server',
         'MailSendmailError' => 'Problem when launching sendmail',
 
-        'SearchTooltip' => 'Search all items',
-        'SearchTitle' => 'Item Search',
+        'SearchTooltip' => 'Search all items', # Accepts model codes
+        'SearchTitle' => 'Item Search', # Accepts model codes
         'SearchNoField' => 'No field have been selected for the search box.
 Add some of them in the Filters tab of the collection settings.',
 
@@ -567,7 +603,7 @@ Add some of them in the Filters tab of the collection settings.',
         'PropertiesDescription' => 'Description',
         'PropertiesFile' => 'File Information',
         'PropertiesFilePath' => 'Full path',
-        'PropertiesItemsNumber' => 'Number of items',
+        'PropertiesItemsNumber' => 'Number of items', # Accepts model codes
         'PropertiesFileSize' => 'Size',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Collection properties',
@@ -591,8 +627,8 @@ Add some of them in the Filters tab of the collection settings.',
         'BookmarksNewFolder' => 'New folder',
 
         'AdvancedSearchType' => 'Type of search',
-        'AdvancedSearchTypeAnd' => 'Items matching all criteria',
-        'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
+        'AdvancedSearchTypeAnd' => 'Items matching all criteria', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Items matching at least one criterion', # Accepts model codes
         'AdvancedSearchCriteria' => 'Criteria',
         'AdvancedSearchAnyField' => 'Any field',
         'AdvancedSearchSaveTitle' => 'Simpan pencarian',
@@ -606,6 +642,24 @@ Add some of them in the Filters tab of the collection settings.',
         'BugReportPlatform' => 'Sistem operasi',
         'BugReportMessage' => 'Pesan error',
         'BugReportInformation' => 'Informasi tambahan',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
     );
 }
 1;
