@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -40,6 +40,9 @@
         'Charset' => 'Charset',
         'Header' => 'Ignora la prima linea',
         'Separator' => 'Delimitatore',
+        'Plugin' => 'Lato da utilizzare',
+        'UseFirst' => 'In caso di piu\' risultati utilizza il primo',
+        'SearchField' => 'Search for items using',
      );
 }
 
