@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -38,8 +38,10 @@
 
     our %lang = (
     
-        CollectionDescription => 'Biblioteca (Tian)',
-        Items => 'Libri',
+        CollectionDescription => 'Biblioteca',
+        Items => {0 => 'Libri',
+                  1 => 'Libri',
+                  X => 'Libris'},
         NewItem => 'Libro nuovo',
     
         Isbn => 'ISBN',
@@ -62,6 +64,7 @@
         Url => 'Pagina web',
         Translator => 'Traduttore',
         Artist => 'Scrittore',
+        DigitalFile => 'Digital version',
 
         General => 'Generale',
         Details => 'Dettagli',
