@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -38,11 +38,12 @@
 
     our %lang = (
     
-        CollectionDescription => 'Filmoteca (Tian)',
-        Items => 'Film',
+        CollectionDescription => 'Filmoteca',
+        Items => {0 => 'Film',
+                  1 => 'Film',
+                  X => 'Film'},
         NewItem => 'Nuovo film',
     
-    
         Id => 'Id',
         Title => 'Titolo',
         Date => 'Data',
