@@ -88,7 +88,7 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
        	'InstallWithMenu' => 'Aggiungere GCstar al menu\' Applicazioni',
        	'InstallNoPermission' => 'Errore: Diritti di scrittura mancanti per la directory selezionata',
         'InstallMissingMandatory' => 'Alcune dipendenze necessarie sono mancanti. Non e\' possibile installare GCstar sinche\' esse non sono presenti nel sistema.',
-        'InstallMissingOptional' => 'Mancano alcune dipendenze opzionali, elencate qui sotto. There are listed under. GCstar verra\' installato ma alcune funzioni non saranno disponibili.',
+        'InstallMissingOptional' => 'Mancano alcune dipendenze opzionali, elencate qui sotto. GCstar verra\' installato ma alcune funzioni non saranno disponibili.',
         'InstallMissingNone' => 'Tutte le dipendenze sono soddisfatte. Continuare con l\'installazione di GCstar.',
         'InstallOK' => 'OK',
         'InstallMissing' => 'Mancante',
@@ -107,7 +107,7 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
         'SplashInit' => 'Inizializzazione',
         'SplashLoad' => 'Caricamento Collezione',
         'SplashDisplay' => 'Visualizzazione Collezione',
-        'SplashSort' => 'Sorting Collection',
+        'SplashSort' => 'Ordinamento Collezione',
         'SplashDone' => 'Finito!',
 
 #Import from GCfilms
@@ -118,26 +118,26 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
 #Menus
         'MenuFile' => 'File',
             'MenuNewList' => '_Nuova collezione',
-            'MenuStats' => 'Statistics',
+            'MenuStats' => 'Statistiche',
             'MenuHistory' => 'Ultime collezioni aperte',
             'MenuLend' => 'Visualizza articoli prestati', # Accepts model codes
             'MenuImport' => '_Importa',
             'MenuExport' => '_Esporta',
-            'MenuAddItem' => '_Add Items', # Accepts model codes
+            'MenuAddItem' => '_Aggiungi articolo', # Accepts model codes
 
 		'MenuEdit'  => 'Modifica',
             'MenuDuplicate' => '_Duplica articolo', # Accepts model codes
-            'MenuDuplicatePlural' => 'Du_plicate articolos', # Accepts model codes
-            'MenuEditSelectAllItems' => 'Select _All Articolos', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plica articoli', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Seleziona tutti gli articoli', # Accepts model codes
             'MenuEditDeleteCurrent' => '_Rimuovi articolo corrente',, # Accepts model codes
-            'MenuEditDeleteCurrentPlural' => '_Remove articolo', # Accepts model codes  
+            'MenuEditDeleteCurrentPlural' => '_Rimuovi articolo', # Accepts model codes  
             'MenuEditFields' => '_Cambia campi della collezione',
     		'MenuEditLockItems' => 'B_locca la collezione',
 
         'MenuDisplay' => 'F_iltri',
-            'MenuSavedSearches' => 'Saved searches',
-                'MenuSavedSearchesSave' => 'Save current search',
-                'MenuSavedSearchesEdit' => 'Modify saved searches',
+            'MenuSavedSearches' => 'Ricerche salvate',
+                'MenuSavedSearchesSave' => 'Salva ricerca corrente',
+                'MenuSavedSearchesEdit' => 'Modifica ricerche salvate',
             'MenuAdvancedSearch' => 'Ricerca Avanzata',
             'MenuViewAllItems' => 'Mostr_a tutti gli articoli', # Accepts model codes
             'MenuNoFilter' => 'Tutti',
@@ -145,7 +145,7 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
         'MenuConfiguration' => 'Configurazione',
             'MenuDisplayOptions' => 'Visualizzazione articoli',
             'MenuBorrowers' => 'Gestione prestiti',
-            'MenuToolbarConfiguration' => '_Toolbar controls',
+            'MenuToolbarConfiguration' => 'Configura _Toolbar',
             'MenuGenresConversion' => '_Conversione di Genere',
 
         'MenuBookmarks' => '_Collezioni',
@@ -163,18 +163,18 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
         
         'ContextExpandAll' => 'Espandi tutti',
         'ContextCollapseAll' => 'Collassa tutti',
-        'ContextChooseImage' => 'Choose _Image',
-        'ContextOpenWith' => 'Open Wit_h',
-        'ContextImageEditor' => 'Image Editor', 
-        'ContextImgFront' => 'Front',
-        'ContextImgBack' => 'Back',
-        'ContextChooseFile' => 'Choose a File',
-        'ContextChooseFolder' => 'Choose a Folder',
+        'ContextChooseImage' => 'Scegli _Immagine',
+        'ContextOpenWith' => 'Apri con ...',
+        'ContextImageEditor' => 'Modifica Immagine', 
+        'ContextImgFront' => 'Fronte',
+        'ContextImgBack' => 'Retro',
+        'ContextChooseFile' => 'Scegli file',
+        'ContextChooseFolder' => 'Scegli cartella',
 
-        'DialogEnterNumber' => 'Immetere valore',
+        'DialogEnterNumber' => 'Immettere valore',
 
         'RemoveConfirm' => 'Desideri davvero rimuovere questo articolo?', # Accepts model codes
-        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Desideri davvero rimuovere questi articoli?', # Accepts model codes
         'DefaultNewItem' => 'Nuovo articolo', # Accepts model codes
         'NewItemTooltip' => 'Aggiungi un nuovo articolo', # Accepts model codes
         'NoItemFound' => 'Nessun articolo trovato. Effettuare una ricerca su un altro sito?',
@@ -186,8 +186,8 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
         'PreferencesTooltip' => 'Impostazione preferenze',
         'ViewTooltip' => 'Cambia visualizzazione',
         'PlayTooltip' => 'Mostra il video associato all\'articolo', # Accepts model codes
-        'PlayFileNotFound' => 'File to launch was not found in this location:',
-        'PlayRetry' => 'Retry',
+        'PlayFileNotFound' => 'Il file da riprodurre non è stato trovato nella posizione:',
+        'PlayRetry' => 'Riprova',
 
         'StatusSave' => 'Salvataggio...',
         'StatusLoad' => 'Caricamento...',
@@ -198,14 +198,14 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
         'SaveError' => 'Impossibile salvare la collezione! Controllare i diritti di accesso e lo spazio libero sul disco.',
         'OpenError' => 'Impossibile caricare la collezione! Controllare i diritti di accesso.',
         'OpenFormatError' => 'Impossibile interpretare la collezione! Formato probabilmente scorretto.',
-        'OpenVersionWarning' => 'Collection was created with a more recent version of GCstar. If you save it, you may loose some data.',
-        'OpenVersionQuestion' => 'Do you still want to continue?',
+        'OpenVersionWarning' => 'La collezione e\' stata creata con una versione piu\' recente di GCStar. Salvandola, potresti perdere dei dati.',
+        'OpenVersionQuestion' => 'Sei sicuro di voler continuare?',
         'ImageError' => 'Directory non corretta! Selezionarne un\'altra.',
         'OptionsCreationError'=> 'Generazione file opzioni impossibile: ',
         'OptionsOpenError'=> 'Caricamento file opzioni impossibile: ',
         'OptionsSaveError'=> 'Salvataggio file opzioni impossibile: ',
-        'ErrorModelNotFound' => 'Model not found: ',
-        'ErrorModelUserDir' => 'User defined models are in: ',
+        'ErrorModelNotFound' => 'Modello non trovato: ',
+        'ErrorModelUserDir' => 'I modelli definiti dagli utenti sono in: ',
 
         'RandomTooltip' => 'Articoli non visti',
         'RandomError'=> 'Non ci sono articoli non visti', # Accepts model codes
@@ -232,7 +232,7 @@ Logo e webdesign di le Spektre',
 
         'ToolbarRandom' => 'Non visti',
 
-        'UnsavedCollection' => 'Unsaved Collection',
+        'UnsavedCollection' => 'Collezione non salvata',
         'ModelsSelect' => 'Selezionare un modello/collezione',
         'ModelsPersonal' => 'Personali',
         'ModelsDefault' => 'Predefiniti',
@@ -254,8 +254,8 @@ Logo e webdesign di le Spektre',
         'ModelFieldMax' => 'Massimo:',
         'ModelFieldList' => 'Lista valori:',
         'ModelFieldListLegend' => '<i>separati da virgole</i>',
-        'ModelFieldDisplayAs' => 'Display as:',
-        'ModelFieldDisplayAsText' => 'Text',
+        'ModelFieldDisplayAs' => 'Mostra come:',
+        'ModelFieldDisplayAsText' => 'Testo',
         'ModelFieldDisplayAsGraphical' => 'Rating Control',
         'ModelFieldTypeShortText' => 'Testo corto',
         'ModelFieldTypeLongText' => 'Testo lungo',
@@ -288,12 +288,12 @@ Logo e webdesign di le Spektre',
         'ModelOptionsFieldsPlay' => 'Per pulsante Play',
         'ModelCollectionSettings' => 'Impostazioni collezione',
         'ModelCollectionSettingsLending' => 'Prestabile',
-        'ModelCollectionSettingsTagging' => 'Items can be tagged',
+        'ModelCollectionSettingsTagging' => 'Etichettabile',
         'ModelFilterActivated' => 'Nel box di ricerca',
         'ModelFilterComparison' => 'Comparazione',
         'ModelFilterContain' => 'Contiene',
-        'ModelFilterDoesNotContain' => 'Does not contain',
-        'ModelFilterRegexp' => 'Regular expression',
+        'ModelFilterDoesNotContain' => 'Non contiene',
+        'ModelFilterRegexp' => 'Espressione regolare',
         'ModelFilterRange' => 'Campo',
         'ModelFilterNumeric' => 'Comparazione numerica',
         'ModelFilterQuick' => 'Creazione filtro veloce',
@@ -303,51 +303,51 @@ Logo e webdesign di le Spektre',
         'ModelTooltipHistory' => 'I valori precedentemente inseriti devono essere salvati in una lista associata al campo?',
         'ModelTooltipFormat' => 'Questo formato viene utilizzato per determinare l\'azione necessaria per aprire il file mediante il tasto Play',
         'ModelTooltipLending' => 'Aggiunge alcuni campi per la gestione dei prestiti',
-        'ModelTooltipTagging' => 'This will add some fields to manage tags',
+        'ModelTooltipTagging' => 'Aggiunge alcuni campi per la gestione delle etichette (tags)',
         'ModelTooltipNumeric' => 'Nella comparazione i valori sono considerati numeri',
         'ModelTooltipQuick' => 'Aggiunge una voce di submenu\' nel menu\' filtri',
 
         'ResultsTitle' => 'Seleziona un articolo', # Accepts model codes
         'ResultsNextTip' => 'Cerca nel prossimo sito',
         'ResultsPreview' => 'Anteprima',
-        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them', # Accepts model codes
+        'ResultsInfo' => 'Puoi utilizzare più risultati selezionandoli, tenendo premuto il tasto Ctrl o Shift', # Accepts model codes
         
         'OptionsTitle' => 'Preferenze',
-		'OptionsExpertMode' => 'Expert Mode',
-        'OptionsPrograms' => 'Specify applications to use for different media, leave blank to use system defaults',
+		'OptionsExpertMode' => 'Modalita\' per esperti',
+        'OptionsPrograms' => 'Specifica le applicazioni da utilizzare per i differenti media, lasciare vuoto per utilizzare quelle di sistema',
         'OptionsBrowser' => 'Web browser',
         'OptionsPlayer' => 'Video player',
         'OptionsAudio' => 'Audio player',
-        'OptionsImageEditor' => 'Image editor',
-        'OptionsCdDevice' => 'CD device',
+        'OptionsImageEditor' => 'Editor di immagini',
+        'OptionsCdDevice' => 'Unita\' CD',
         'OptionsImages' => 'Indice di immagini',
         'OptionsUseRelativePaths' => 'Utilizza percorsi relativi per le immagini',
         'OptionsLayout' => 'Maschera',
         'OptionsStatus' => 'Visualizza la barra di stato in fondo alla finestra',
-        'OptionsUseStars' => 'Use stars to display ratings',
+        'OptionsUseStars' => 'Usa stelle per mostrare l\'indice di gradimento',
         'OptionsWarning' => 'Attenzione:  Le modifiche eventualmente appportate in questo pannello avranno effetto solo dopo il riavvio dell\' applicazione GCstar!!!',
         'OptionsRemoveConfirm' => 'Chiedi conferma prima di rimuovere un articolo dalla collezione',
         'OptionsAutoSave' => 'Salva automaticamente la collezione',
         'OptionsAutoLoad' => 'All\'avvio carica l\'ultima collezione trattata',
         'OptionsSplash' => 'Mostra splashscreen',
-        'OptionsTearoffMenus' => 'Enable tear-off menus',
+        'OptionsTearoffMenus' => 'Abilita il tear-off menu\'',
         'OptionsSpellCheck' => 'Use spelling checker for long text fields',
         'OptionsProgramTitle' => 'Seleziona il programma per essere usato',
 		'OptionsPlugins' => 'Siti da utilizzare per le informazioni degli articoli',
 		'OptionsAskPlugins' => 'Chiedi (Tutti i siti)',
 		'OptionsPluginsMulti' => 'Diversi siti',
 		'OptionsPluginsMultiAsk' => 'Chiedi (Diversi siti)',
-        'OptionsPluginsMultiPerField' => 'Diversi siti (per field)',
-        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
-        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
-        'OptionsPluginsMultiPerFieldFirst' => 'First',
-        'OptionsPluginsMultiPerFieldLast' => 'Last',
-        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
-        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
+        'OptionsPluginsMultiPerField' => 'Diversi siti (configurazione campi)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Diversi siti (configurazione campi)',
+        'OptionsPluginsMultiPerFieldDesc' => 'Per ciascun campo selezionato verra\' ritornata la prima informazione non vuota partendo da sinistra',
+        'OptionsPluginsMultiPerFieldFirst' => 'Primo',
+        'OptionsPluginsMultiPerFieldLast' => 'Ultimo',
+        'OptionsPluginsMultiPerFieldRemove' => 'Rimuovi',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Pulisci campi selezionati',
 		'OptionsPluginsList' => 'Configura la lista',
         'OptionsAskImport' => 'Seleziona i campi da importare',
 		'OptionsProxy' => 'Usa un proxy',
-		'OptionsCookieJar' => 'Use this cookie jar file',
+		'OptionsCookieJar' => 'Use questo cookie jar file',
         'OptionsLang' => 'Lingua',
         'OptionsMain' => 'Principale',
         'OptionsPaths' => 'Percorsi',
@@ -358,10 +358,10 @@ Logo e webdesign di le Spektre',
         'OptionsToolbars' => {0 => 'Nessuno', 1 => 'Piccolo', 2 => 'Grande', 3 => 'System setting'},
         'OptionsToolbarPosition' => 'Posizione',
         'OptionsToolbarPositions' => {0 => 'In alto', 1 => 'In basso', 2 => 'A sinistra', 3 => 'A destra'},
-        'OptionsExpandersMode' => 'Expanders too long',
-        'OptionsExpandersModes' => {'asis' => 'Do nothing', 'cut' => 'Cut', 'wrap' => 'Line wrap'},
+        'OptionsExpandersMode' => 'Informazioni troppo lunghe',
+        'OptionsExpandersModes' => {'asis' => 'Non fare niente', 'cut' => 'Taglia', 'wrap' => 'A capo automatico'},
         'OptionsDateFormat' => 'Date Format',
-        'OptionsDateFormatTooltip' => 'Format is the one used by strftime(3). Default is %d/%m/%Y',
+        'OptionsDateFormatTooltip' => 'Il formato è quello utilizzato dalla funzione strftime(3). Il valore di default è %d/%m/%Y',
         'OptionsView' => 'Visualizzazione articoli',
         'OptionsViews' => {0 => 'Testo', 1 => 'Immagine', 2 => 'Dettagli'},
         'OptionsColumns' => 'Colonne',
@@ -371,9 +371,9 @@ Logo e webdesign di le Spektre',
         'OptionsTransform' => 'Mettere gli articoli alla fine dei titoli',
         'OptionsArticles' => 'Articoli (separare mediante virgola)',
         'OptionsSearchStop' => 'L\'utente può arrestare una ricerca',
-        'OptionsBigPics' => 'Use big pictures when available',
+        'OptionsBigPics' => 'Usa immagini grandi quando disponibili',
         'OptionsAlwaysOriginal' => 'Utilizza il titolo principale come originale in mancanza di uno specificato',
-        'OptionsRestoreAccelerators' => 'Restore accelerators',
+        'OptionsRestoreAccelerators' => 'Abilita combinazioni di tasti',
         'OptionsHistory' => 'Dimensione della cronologia',
         'OptionsClearHistory' => 'Cancella cronologia',
 		'OptionsStyle' => 'Skin',
@@ -408,7 +408,7 @@ Logo e webdesign di le Spektre',
         'ImagesOptionsFg'=> 'Selezione',
         'ImagesOptionsBgTooltip' => 'Cambia colore di sfondo',
         'ImagesOptionsFgTooltip'=> 'Cambia il colore di selezione',
-        'ImagesOptionsResizeImgList' => 'Automatically change number of columns',
+        'ImagesOptionsResizeImgList' => 'Cambia automaticamente il numero di colonne',
         'ImagesOptionsSizeLabel' => 'Dimensione',
         'ImagesOptionsSizeList' => {0 => 'Ultra piccola', 1 => 'Piccola', 2 => 'Media', 3 => 'Grande', 4 => 'Extra Grande'},
         'ImagesOptionsSizeTooltip' => 'Seleziona dimensioni immagine',
@@ -416,10 +416,10 @@ Logo e webdesign di le Spektre',
         'DetailedOptionsTitle' => 'Impostazioni lista dettagliata',
         'DetailedOptionsImageSize' => 'Dimensioni immagine',
         'DetailedOptionsGroupItems' => 'Raggruppa gli articoli per',
-        'DetailedOptionsSecondarySort' => 'Sort field for children',
+        'DetailedOptionsSecondarySort' => 'Ordina gli articoli per',
 		'DetailedOptionsFields' => 'Scegli i campi da visualizzare',
-        'DetailedOptionsGroupedFirst' => 'Keep together orphaned items',
-        'DetailedOptionsAddCount' => 'Add number of elements on categories',
+        'DetailedOptionsGroupedFirst' => 'Raggruppa insieme gli articoli orfani',
+        'DetailedOptionsAddCount' => 'Aggiungi il numero di elementi alle categorie',
 
         'ExtractButton' => 'Informazioni',
         'ExtractTitle' => 'Informazioni file',
@@ -428,15 +428,15 @@ Logo e webdesign di le Spektre',
         'FieldsListOpen' => 'Caricare un elenco di campi da un file',
         'FieldsListSave' => 'Salvare un elenco di campi in un file',
         'FieldsListError' => 'L\'elenco di campi non puo\' essere utilizzato con questo modello di collezione',
-        'FieldsListIgnore' => '--- Ignore',
+        'FieldsListIgnore' => '--- Ignora',
 
         'ExportTitle' => 'Gestione elenco campi da esportare',
         'ExportFilter' => 'Esportare solo i campi visualizzati',
         'ExportFieldsTitle' => 'Campi da esportare',
         'ExportFieldsTip' => 'Campi prescelti per l\'esportazione',
         'ExportWithPictures' => 'Copiare le immagini in una sottodirectory',
-        'ExportSortBy' => 'Sort by',
-        'ExportOrder' => 'Order',
+        'ExportSortBy' => 'Ordina per',
+        'ExportOrder' => 'Ordine',
 
         'ImportListTitle' => 'Importazione della collezione:',
         'ImportExportData' => 'Dati',
@@ -458,11 +458,11 @@ Logo e webdesign di le Spektre',
         'FileChooserDirectory' => 'Directory',
         'FileChooserOpenDirectory' => 'Seleziona un indice',
         'FileChooserOverwrite' => 'Questa collezione esiste gia\', sovrascriverla?',
-        'FileAllFiles' => 'All Files',
-        'FileVideoFiles' => 'Video Files',
-        'FileEbookFiles' => 'Ebook Files',
-        'FileAudioFiles' => 'Audio Files',
-        'FileGCstarFiles' => 'GCstar Collections',
+        'FileAllFiles' => 'Tutti i file',
+        'FileVideoFiles' => 'Video File',
+        'FileEbookFiles' => 'Ebook File',
+        'FileAudioFiles' => 'Audio File',
+        'FileGCstarFiles' => 'Collezioni GCStar',
 
         'PanelCompact' => 'Compattare',
         'PanelReadOnly' => 'Sola lettura',
@@ -470,10 +470,10 @@ Logo e webdesign di le Spektre',
 
         'PanelSearchButton' => 'Recupera informazioni',
         'PanelSearchTip' => 'Cerca informazioni secondo il titolo dell\'articolo inserito',
-        'PanelSearchContextChooseOne' => 'Choose a site ...',
-        'PanelSearchContextMultiSite' => 'Use "Many sites"',
-        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
-        'PanelSearchContextOptions' => 'Change options ...',
+        'PanelSearchContextChooseOne' => 'Scegli un sito ...',
+        'PanelSearchContextMultiSite' => 'Use "Diversi siti"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Diversi siti (configurazione campi)"',
+        'PanelSearchContextOptions' => 'Cambia opzioni ...',
         'PanelImageTipOpen' => 'Clicca sull\'immagine per sceglierne un\'altra.',
         'PanelImageTipView' => 'Clicca sull\'immagine per visualizzare in grandezza naturale.',
         'PanelImageTipMenu' => 'Clicca tasto destro per piu\' opzioni.',
@@ -482,11 +482,11 @@ Logo e webdesign di le Spektre',
         'PanelSelectFileTitle' => 'Seleziona un file',
         'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Ripristina predefiniti',
-        'PanelRefresh' => 'Update',
-        'PanelRefreshTip' => 'Update information from web',
+        'PanelRefresh' => 'Aggiorna',
+        'PanelRefreshTip' => 'Aggiorna le informazioni dal web',
 
-        'PanelFrom' =>'From',
-        'PanelTo' =>'To',
+        'PanelFrom' =>'Da',
+        'PanelTo' =>'A',
 
         'PanelWeb' => 'Leggi informazioni dell\'articolo',
         'PanelWebTip' => 'Leggi informazioni su questo articolo e disponibili sul web', # Accepts model codes
@@ -497,7 +497,7 @@ Logo e webdesign di le Spektre',
         'PanelUnknown' => 'Sconosciuta',
         'PanelAdded' => 'Aggiungi data',
         'PanelRating' => 'Valutazione',
-        'PanelPressRating' => 'Press Rating',
+        'PanelPressRating' => 'Press ratings',
         'PanelLocation' => 'Luogo',
         
         'PanelLending' => 'Prestiti',
@@ -509,11 +509,11 @@ Logo e webdesign di le Spektre',
         'PanelLendedYes' => 'Prestato',
         'PanelLendedNo' => 'Disponibile',
 
-        'PanelTags' => 'Tags',
-        'PanelFavourite' => 'Favourite',
-        'TagsAssigned' => 'Assigned Tags', 
+        'PanelTags' => 'Etichette (Tags)',
+        'PanelFavourite' => 'Preferiti',
+        'TagsAssigned' => 'Etichette assegnate', 
 
-        'PanelUser' => 'User fields',
+        'PanelUser' => 'Campi utente',
 
         'CheckUndef' => 'Nessun problema',
         'CheckYes' => 'Sì',
@@ -523,10 +523,10 @@ Logo e webdesign di le Spektre',
         'ToolbarAllTooltip' => 'Visualizza tutti gli articoli',
         'ToolbarGroupBy' => 'Raggruppa per',
         'ToolbarGroupByTooltip' => 'Selezionare il campo da utilizzare per raggruppare gli articoli della collezione',
-        'ToolbarQuickSearch' => 'Quick search',
-        'ToolbarQuickSearchLabel' => 'Search',
-        'ToolbarQuickSearchTooltip' => 'Select the field to search in. Enter the search terms and press Enter',
-        'ToolbarSeparator' => ' Separator',
+        'ToolbarQuickSearch' => 'Ricerca rapida',
+        'ToolbarQuickSearchLabel' => 'Ricerca',
+        'ToolbarQuickSearchTooltip' => 'Seleziona il campo in cui ricercare. Inserisci le parole da ricercare e premi Invio',
+        'ToolbarSeparator' => ' Separatore',
                
         'PluginsTitle' => 'Cerca un articolo',
         'PluginsQuery' => 'Query',
@@ -537,8 +537,8 @@ Logo e webdesign di le Spektre',
         'PluginsAuthor' => 'Autore',
         'PluginsLang' => 'Lingua',
         'PluginsUseSite' => 'Utilizza il sito selezionato per ricerche future',
-        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
-        'PluginDisabled' => 'Disabled',
+        'PluginsPreferredTooltip' => 'Sito raccomandato da GCstar',
+        'PluginDisabled' => 'Disabilitato',
 
         'BorrowersTitle' => 'Configurazione prestiti',
         'BorrowersList' => 'Beneficiari dei prestiti',
@@ -559,7 +559,7 @@ Logo e webdesign di le Spektre',
 
         'BorrowedTitle' => 'Articoli prestati', # Accepts model codes
         'BorrowedDate' => 'Il',
-        'BorrowedDisplayInPanel' => 'Show item in main window', # Accepts model codes
+        'BorrowedDisplayInPanel' => 'Mostra articolo nella schermata principale', # Accepts model codes
 
         'MailTitle' => 'Manda una e-mail',
         'MailFrom' => 'Da: ',
@@ -570,8 +570,8 @@ Logo e webdesign di le Spektre',
 
         'SearchTooltip' => 'Cerca nella collezione', # Accepts model codes
         'SearchTitle' => 'Cerca', # Accepts model codes
-        'SearchNoField' => 'No field have been selected for the search box.
-Add some of them in the Filters tab of the collection settings.',
+        'SearchNoField' => 'Nessun campo è stato selezionato nel box di ricerca.
+Aggiungine uno o più nella scheda Filtri, nelle impostazioni per la collezione.',
         
         'QueryReplaceField' => 'Campo da sostituire',
         'QueryReplaceOld' => 'Nome corrente',
@@ -602,7 +602,7 @@ Add some of them in the Filters tab of the collection settings.',
         'GenresModify' => 'Modifica conversione',
 
         'PropertiesName' => 'Nome collezione',
-        'PropertiesLang' => 'Language code',
+        'PropertiesLang' => 'Codice lingua',
         'PropertiesOwner' => 'Proprietario',
         'PropertiesEmail' => 'e-mail',
         'PropertiesDescription' => 'Descrizione',
@@ -635,36 +635,36 @@ Add some of them in the Filters tab of the collection settings.',
         'AdvancedSearchTypeAnd' => 'Articoli soddisfacenti tutti i criteri (AND)', # Accepts model codes
         'AdvancedSearchTypeOr' => 'Articoli soddisfacenti almeno un criterio (OR)', # Accepts model codes
         'AdvancedSearchCriteria' => 'Criteri',
-        'AdvancedSearchAnyField' => 'Any field',
-        'AdvancedSearchSaveTitle' => 'Save search',
-        'AdvancedSearchSaveName' => 'Name',
-        'AdvancedSearchSaveOverwrite' => 'A saved search already exists with that name. Please use a different one.',
-        'AdvancedSearchUseCase' => 'Case sensitive',
-        'AdvancedSearchIgnoreDiacritics' => 'Ignore accents and other diacritics',
+        'AdvancedSearchAnyField' => 'Qualsiasi campo',
+        'AdvancedSearchSaveTitle' => 'Salva ricerca',
+        'AdvancedSearchSaveName' => 'Nome',
+        'AdvancedSearchSaveOverwrite' => 'Una ricerca salvata esiste già con questo nome. Utilizzare un nome differente.',
+        'AdvancedSearchUseCase' => 'Distinzione maiuscole/minuscole',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignora accenti ed altri caratteri speciali',
 
-        'BugReportSubject' => 'Bug report generated from GCstar',
-        'BugReportVersion' => 'Version',
-        'BugReportPlatform' => 'Operating system',
-        'BugReportMessage' => 'Error message',
-        'BugReportInformation' => 'Additional information',
+        'BugReportSubject' => 'Bug report generato da GCstar',
+        'BugReportVersion' => 'Versione',
+        'BugReportPlatform' => 'Sistema operativo',
+        'BugReportMessage' => 'Messaggio d\'errore',
+        'BugReportInformation' => 'Informazioni addizionali',
 
 #Statistics
-        'StatsFieldToUse' => 'Field to use',
-        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
-        'StatsGenerate' => 'Generate',
-        'StatsKindOfGraph' => 'Kind of graphic',
-        'StatsBars' => 'Bars',
-        'StatsPie' => 'Pie',
-        'Stats3DPie' => '3D Pie',
-        'StatsArea' => 'Areas',
+        'StatsFieldToUse' => 'Campi da usare',
+        'StatsSortByNumber' => 'Ordina per numero di {lowercaseX}',
+        'StatsGenerate' => 'Genera',
+        'StatsKindOfGraph' => 'Tipo di grafico',
+        'StatsBars' => 'Barre',
+        'StatsPie' => 'Torta',
+        'Stats3DPie' => 'Torta 3D',
+        'StatsArea' => 'Aree',
         'StatsHistory' => 'History',
-        'StatsWidth' => 'Width',
-        'StatsHeight' => 'Height',
-        'StatsFontSize' => 'Font size',
-        'StatsDisplayNumber' => 'Show numbers',
-        'StatsSave' => 'Save statistics image to a file',
-        'StatsAccumulate' => 'Accumulate values',
-        'StatsShowAllDates' => 'Show all dates',
+        'StatsWidth' => 'Lunghezza',
+        'StatsHeight' => 'Altezza',
+        'StatsFontSize' => 'Dimensione carattere',
+        'StatsDisplayNumber' => 'Mostra numeri',
+        'StatsSave' => 'Salva statistiche su file',
+        'StatsAccumulate' => 'Accumula valori',
+        'StatsShowAllDates' => 'Mostra tutte le date',
     );
 }
 1;
