@@ -64,6 +64,11 @@
         Unlockables => 'ontgrendelbare',
         Unlockable => 'ontgrendelbaar',
         Howto => 'Hoe te ontgrendelen',
+        Exclusive => 'Exclusive',
+        Resolutions => 'Display resolutions',
+        InstallationSize => 'Size',
+        Region => 'Region',
+        SerialNumber => 'Serial Number',        
 
         General => 'Algemeen',
         Details => 'Details',
