@@ -23,7 +23,23 @@
 #  Foundation, Inc, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
 ###################################################
-    
+   
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
+ 
     use strict;
     use base 'Exporter';
 
@@ -45,7 +61,7 @@ Om te bepalen welke site eigenaar van de informatie is,
 
 kunt u gebruik maken van de <b>onderstaande knop item details</b>.',
         
-        'AllItemsFiltered' => 'Geen item komt overeen met je filtercriteria',
+        'AllItemsFiltered' => 'Geen item komt overeen met je filtercriteria', # Accepts model codes
         
 #Installation
         'InstallDirInfo' => 'Installeren in ',
@@ -96,14 +112,19 @@ kunt u gebruik maken van de <b>onderstaande knop item details</b>.',
 #Menus
         'MenuFile' => '_Bestand',
             'MenuNewList' => '_Nieuwe collectie',
+            'MenuStats' => 'Statistics',
             'MenuHistory' => '_Recente collecties',
-            'MenuLend' => 'Toon _Uitgeleende items',
+            'MenuLend' => 'Toon _Uitgeleende items', # Accepts model codes
             'MenuImport' => '_Importeer',	
             'MenuExport' => '_Exporteer',
+            'MenuAddItem' => '_Add Items', # Accepts model codes    
     
         'MenuEdit'  => '_Bewerken',
-            'MenuDuplicate' => 'Du_pliceer item',
-            'MenuEditDeleteCurrent' => '_Verwijder item',
+            'MenuDuplicate' => 'Du_pliceer item', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_pliceer items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All items', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_Verwijder item', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove items', # Accepts model codes 
             'MenuEditFields' => 'Ve_rander collectievelden',
             'MenuEditLockItems' => '_Blokkeer collectie',
     
@@ -112,7 +133,7 @@ kunt u gebruik maken van de <b>onderstaande knop item details</b>.',
                 'MenuSavedSearchesSave' => 'Bewaar huidige zoekopdracht',
                 'MenuSavedSearchesEdit' => 'Modificeer opgeslagen zoekopdrachten',
             'MenuAdvancedSearch' => 'Geavanceer_de zoekopdracht',
-            'MenuViewAllItems' => 'Toon _Alle items',
+            'MenuViewAllItems' => 'Toon _Alle items', # Accepts model codes
             'MenuNoFilter' => '_Om het even welk',
     
         'MenuConfiguration' => 'In_stellingen',
@@ -131,7 +152,8 @@ kunt u gebruik maken van de <b>onderstaande knop item details</b>.',
             'MenuBugReport' => 'Rappor_teer een probleem',
             'MenuAbout' => '_Over GCstar',
     
-        'MenuNewWindow' => 'Toon item in _Nieuw Venster',
+        'MenuNewWindow' => 'Toon item in _Nieuw Venster', # Accepts model codes
+        'MenuNewWindowPlural' => 'Toon items in _Nieuw Venster', # Accepts model codes
         
         'ContextExpandAll' => 'Alles _uitvouwen',
         'ContextCollapseAll' => 'Alles _samenvouwen',
@@ -140,22 +162,24 @@ kunt u gebruik maken van de <b>onderstaande knop item details</b>.',
         'ContextImageEditor' => 'Afbeeldingsbewerker',
         'ContextImgFront' => 'Voorkant',
         'ContextImgBack' => 'Achterkant',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
 
         'DialogEnterNumber' => 'Voer een waarde in',
 
-        'RemoveConfirm' => 'Ben je zeker dat je dit item wilt verwijderen?',
-        'DefaultNewItem' => 'Nieuw item',
-        'NewItemTooltip' => 'Voeg een nieuw item toe',
+        'RemoveConfirm' => 'Ben je zeker dat je dit item wilt verwijderen?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+        'DefaultNewItem' => 'Nieuw item', # Accepts model codes
+        'NewItemTooltip' => 'Voeg een nieuw item toe', # Accepts model codes
         'NoItemFound' => 'Niets gevonden. Wil je in een andere website zoeken?',
         'OpenList' => 'Kies collectie',
         'SaveList' => 'Kies waar je de collectie wilt opslaan',
         'SaveListTooltip' => 'Bewaar huidige collectie',
-        'SaveCurrentList' => 'Kies eerst waar je de huidige collectie wilt opslaan',
         'SaveUnsavedChanges' => 'Er zijn niet opgeslagen wijzigingen in je collectie. Wil je die opslaan?',
         'SaveDontSave' => 'Niet opslaan',
         'PreferencesTooltip' => 'Instellingen',
         'ViewTooltip' => 'Verander collectiebeeld',
-        'PlayTooltip' => 'Open bestand geassocieerd met dit item',
+        'PlayTooltip' => 'Open bestand geassocieerd met dit item', # Accepts model codes
         'PlayFileNotFound' => 'Bestand niet gevonden op deze plaats:',
         'PlayRetry' => 'Opnieuw',
 
@@ -178,8 +202,8 @@ kunt u gebruik maken van de <b>onderstaande knop item details</b>.',
         'ErrorModelUserDir' => 'Door gebruiker gedefinieerde modellen staan in: ',
         
         'RandomTooltip' => 'Wat te bekijken deze avond?',
-        'RandomError'=> 'Je hebt geen selecteerbare items',
-        'RandomEnd'=> 'Er zijn geen items meer',
+        'RandomError'=> 'Je hebt geen selecteerbare items', # Accepts model codes
+        'RandomEnd'=> 'Er zijn geen items meer', # Accepts model codes
         'RandomNextTip'=> 'Volgende suggestie',
         'RandomOkTip'=> 'Accepteer dit item',
         
@@ -196,7 +220,8 @@ Adolfo González: programmeur
 Logo Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Engelse vertaling door Kim',
-        'AboutDesign' => 'Logo en webdesign door le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logo en webdesign door le Spektre',
 
         'UnsavedCollection' => 'Niet opgeslagen collectie',
         'ModelsSelect' => 'Kies een collectietype',
@@ -244,6 +269,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Geluid',
         'ModelFieldFileProgram' => 'Programma',
         'ModelFieldFileUrl' => 'Link',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Velden om te gebruiken',
         'ModelOptionsFieldsAuto' => 'Automatisch',
         'ModelOptionsFieldsNone' => 'Geen',
@@ -272,10 +298,10 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'Moeten de waarden worden beschouwd als nummers om te vergelijken',
         'ModelTooltipQuick' => 'Dit voegt een submenu toe bij de filters',
         
-        'ResultsTitle' => 'Kies een item',
+        'ResultsTitle' => 'Kies een item', # Accepts model codes
         'ResultsNextTip' => 'Zoek in de volgende website',
         'ResultsPreview' => 'Voorvertoning',
-        'ResultsInfo' => 'Je kan meerdere items toevoegen aan de collectie met Ctrl of Shift',
+        'ResultsInfo' => 'Je kan meerdere items toevoegen aan de collectie met Ctrl of Shift', # Accepts model codes
         
         'OptionsTitle' => 'Voorkeuren',
 		'OptionsExpertMode' => 'Geavanceerde opties',
@@ -423,6 +449,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Map',
         'FileChooserOpenDirectory' => 'Kies een map',
         'FileChooserOverwrite' => 'Dit bestand bestaat al. Wil je het overschrijven?',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
         #Some default panels
         'PanelCompact' => 'Compact',
@@ -441,14 +472,17 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Kies een afbeelding',
         'PanelImageNoImage' => 'Geen afbeelding',
         'PanelSelectFileTitle' => 'Kies een bestand',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Herstel standaard',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Update information from web',
 
         'PanelFrom' =>'Van',
         'PanelTo' =>'Naar',
 
         'PanelWeb' => 'Bekijk informatie',
-        'PanelWebTip' => 'Bekijk informatie op het internet voor dit item',
-        'PanelRemoveTip' => 'Verwijder huidig item',
+        'PanelWebTip' => 'Bekijk informatie op het internet voor dit item', # Accepts model codes
+        'PanelRemoveTip' => 'Verwijder huidig item', # Accepts model codes
 
         'PanelDateSelect' => 'Kies',
         'PanelNobody' => 'Niemand',
@@ -462,7 +496,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Lener',
         'PanelLendDate' => 'Uitgeleend sinds',
         'PanelHistory' => 'Uitleengeschiedenis',
-        'PanelReturned' => 'Item teruggebracht',
+        'PanelReturned' => 'Item teruggebracht', # Accepts model codes
         'PanelReturnDate' => 'Datum teruggave',
         'PanelLendedYes' => 'Ooit uitgeleend',
         'PanelLendedNo' => 'Beschikbaar',
@@ -496,6 +530,8 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Auteur',
         'PluginsLang' => 'Taal',
         'PluginsUseSite' => 'Gebruik geselecteerde website voor verdere zoekacties',
+        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+        'PluginDisabled' => 'Disabled',
 
         'BorrowersTitle' => 'Lenersconfiguratie',
         'BorrowersList' => 'Leners',
@@ -514,9 +550,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'Bestandsformaat:',
         'BorrowersImportFile' => 'Bestand:',
 
-        'BorrowedTitle' => 'Uitgeleende items',
+        'BorrowedTitle' => 'Uitgeleende items', # Accepts model codes
         'BorrowedDate' => 'Sinds',
-        'BorrowedDisplayInPanel' => 'Toon item in hoofdvenster',
+        'BorrowedDisplayInPanel' => 'Toon item in hoofdvenster', # Accepts model codes
 
         'MailTitle' => 'Stuur een e-mail',
         'MailFrom' => 'Van: ',
@@ -525,8 +561,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Probleem bij verbinding met SMTP-server',
         'MailSendmailError' => 'Probleem wanneer sendmail gestart wordt',
 
-        'SearchTooltip' => 'Zoek alle items',
-        'SearchTitle' => 'Zoek item',
+        'SearchTooltip' => 'Zoek alle items', # Accepts model codes
+        'SearchTitle' => 'Zoek item', # Accepts model codes
         'SearchNoField' => 'No field have been selected for the search box.
 Add some of them in the Filters tab of the collection settings.',
 
@@ -565,7 +601,7 @@ Add some of them in the Filters tab of the collection settings.',
         'PropertiesDescription' => 'Beschrijving',
         'PropertiesFile' => 'Bestandsinformatie',
         'PropertiesFilePath' => 'Volledig pad',
-        'PropertiesItemsNumber' => 'Aantal items',
+        'PropertiesItemsNumber' => 'Aantal items', # Accepts model codes
         'PropertiesFileSize' => 'Grootte',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Collectie eigenschappen',
@@ -589,8 +625,8 @@ Add some of them in the Filters tab of the collection settings.',
         'BookmarksNewFolder' => 'Nieuwe map',
 
         'AdvancedSearchType' => 'Zoektype',
-        'AdvancedSearchTypeAnd' => 'Items komen met alle criteria overeen',
-        'AdvancedSearchTypeOr' => 'Items komen met minstens één criterium overeen',
+        'AdvancedSearchTypeAnd' => 'Items komen met alle criteria overeen', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Items komen met minstens één criterium overeen', # Accepts model codes
         'AdvancedSearchCriteria' => 'Criteria',
         'AdvancedSearchAnyField' => 'Elk veld',
         'AdvancedSearchSaveTitle' => 'Bewaar zoekopdracht',
@@ -604,6 +640,24 @@ Add some of them in the Filters tab of the collection settings.',
         'BugReportPlatform' => 'Besturingssysteem',
         'BugReportMessage' => 'Fout bericht',
         'BugReportInformation' => 'Extra informatie',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
     );
 }
 1;
