@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,6 +33,9 @@
         'Charset' => 'Kodowanie znaków',
         'Header' => 'Ignoruj pierwszą linie',
         'Separator' => 'Separator',
+        'Plugin' => 'Strona używana',
+        'UseFirst' => 'Wybierz pierwszy, jeżeli dużo wyników',
+        'SearchField' => 'Search for items using',        
      );
 }
 
