@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -23,6 +23,22 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 ###################################################
+
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
     
     use strict;
     use base 'Exporter';
@@ -46,7 +62,7 @@ autoryzacji, <b>zabroniona</b>.
 Aby dowiedzieć się skąd pochodzą dane pobrane
 można użyć <b>przycisku pod szczegółami</b>.',
         
-        'AllItemsFiltered' => 'Brak pozycji pasujących do filtru',
+        'AllItemsFiltered' => 'Brak pozycji pasujących do filtru', # Accepts model codes
         
 #Installation
         'InstallDirInfo' => 'Instalacja w ',
@@ -97,14 +113,19 @@ można użyć <b>przycisku pod szczegółami</b>.',
 #Menus
         'MenuFile' => 'Plik',
             'MenuNewList' => 'Nowy Zbiór',
+            'MenuStats' => 'Statistics',
             'MenuHistory' => 'Ostatnio używany Zbiór',
-            'MenuLend' => 'Wyświetl wypożyczone',
+            'MenuLend' => 'Wyświetl wypożyczone', # Accepts model codes
             'MenuImport' => 'Import',	
             'MenuExport' => 'Eksport',
+            'MenuAddItem' => '_Add Items', # Accepts model codes
     
         'MenuEdit'  => 'Edycja',
-            'MenuDuplicate' => 'Kopiuj bieżącą pozycję',
-            'MenuEditDeleteCurrent' => 'Usuń bieżącą pozycję',
+            'MenuDuplicate' => 'Kopiuj bieżącą pozycję',, # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate Items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All {X}', # Accepts model codes
+            'MenuEditDeleteCurrent' => 'Usuń bieżącą pozycję',, # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove Items', # Accepts model codes   
             'MenuEditFields' => 'Zmień pola Zbioru',
             'MenuEditLockItems' => 'Zablokuj Zbiory',
     
@@ -113,7 +134,7 @@ można użyć <b>przycisku pod szczegółami</b>.',
                  'MenuSavedSearchesSave' => 'Zapisz bieżące wyszukiwanie',
                  'MenuSavedSearchesEdit' => 'Edytuj zapisane wyszukiwania',
             'MenuAdvancedSearch' => 'Wyszukiwanie zaawansowane',
-            'MenuViewAllItems' => 'Pokaż wszystkie pozycje',
+            'MenuViewAllItems' => 'Pokaż wszystkie pozycje', # Accepts model codes
             'MenuNoFilter' => 'Wszystkie',
     
         'MenuConfiguration' => 'Ustawienia',
@@ -132,8 +153,9 @@ można użyć <b>przycisku pod szczegółami</b>.',
             'MenuBugReport' => 'Zgłoś błąd',
             'MenuAbout' => 'O programie',
     
-        'MenuNewWindow' => 'Pokaż w nowym oknie',
-        
+        'MenuNewWindow' => 'Pokaż w nowym oknie', # Accepts model codes
+        'MenuNewWindowPlural' => 'Show Items in _New Window', # Accepts model codes
+                
         'ContextExpandAll' => 'Rozwiń wszystkie',
         'ContextCollapseAll' => 'Zwiń wszystkie',
         'ContextChooseImage' => 'Wyb_ierz obraz',
@@ -141,22 +163,24 @@ można użyć <b>przycisku pod szczegółami</b>.',
         'ContextImageEditor' => 'Otwórz w edytorze graficznym',
         'ContextImgFront' => 'Przód',
         'ContextImgBack' => 'Tył',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
     
         'DialogEnterNumber' => 'Wprowadź wartość',
 
-        'RemoveConfirm' => 'Czy naprawdę chcesz usunąć tą pozycję?',
-        'DefaultNewItem' => 'Nowa pozycja',
-        'NewItemTooltip' => 'Dodaj nową pozycję',
+        'RemoveConfirm' => 'Czy naprawdę chcesz usunąć tą pozycję?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+        'DefaultNewItem' => 'Nowa pozycja', # Accepts model codes
+        'NewItemTooltip' => 'Dodaj nową pozycję', # Accepts model codes
         'NoItemFound' => 'Nie znaleziono tej pozycji, czy chcesz przeszukać następną witrynę?',
         'OpenList' => 'Wybierz Zbiór',
         'SaveList' => 'Gdzie mam zapisać Zbiór?',
         'SaveListTooltip' => 'Zapisz Zbiór',
-        'SaveCurrentList' => 'Określ, gdzie mam zapisać Zbiór',
         'SaveUnsavedChanges' => 'Zmiany w Twoim Zbiorze nie zostały zapisane. Czy chcesz je zapisać?',
         'SaveDontSave' => 'Nie zapisuj',
         'PreferencesTooltip' => 'Ustaw swoje preferencje',
         'ViewTooltip' => 'Zmień sposób wyświetlania Zbioru',
-        'PlayTooltip' => 'Odtwórz wideo połączone z filmem',
+        'PlayTooltip' => 'Odtwórz wideo połączone z filmem', # Accepts model codes
         'PlayFileNotFound' => 'W podanym miejscu nie ma pliku do odtworzenia:',
         'PlayRetry' => 'Ponów',
 
@@ -179,8 +203,8 @@ można użyć <b>przycisku pod szczegółami</b>.',
         'ErrorModelUserDir' => 'Szablony zdefiniowane przez użytkownika znajdują się w: ',
 
         'RandomTooltip' => 'Co by tu dziś ...?',
-        'RandomError'=> 'Wszystko już było',
-        'RandomEnd'=> 'Nie mam więcej propozycji',
+        'RandomError'=> 'Wszystko już było', # Accepts model codes
+        'RandomEnd'=> 'Nie mam więcej propozycji', # Accepts model codes
         'RandomNextTip'=> 'Kolejna propozycja',
         'RandomOkTip'=> 'Wybierz',
 
@@ -197,7 +221,8 @@ Adolfo González: Programmer
 Logos Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Tłumaczenie: kepin & zomers, WG',
-        'AboutDesign' => 'Logo i webmaster: le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logo i webmaster: le Spektre',
 
         'ToolbarRandom' => 'Dziś wieczorem',
 
@@ -247,6 +272,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Audio',
         'ModelFieldFileProgram' => 'Program',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Wykorzystane pola',
         'ModelOptionsFieldsAuto' => 'Automatycznie',
         'ModelOptionsFieldsNone' => 'Wcale',
@@ -275,10 +301,10 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'Wartości będą traktowane jako liczby przy porównaniu',
         'ModelTooltipQuick' => 'Dodaje podmenu w menu Filtrów',
 
-        'ResultsTitle' => 'Wybierz pozycję',
+        'ResultsTitle' => 'Wybierz pozycję', # Accepts model codes
         'ResultsNextTip' => 'Szukaj na następnej witrynie',
         'ResultsPreview' => 'Podgląd',
-        'ResultsInfo' => 'Do Zbioru możesz dodać wiele pozycji jednocześnie, wybierając je trzymaj wciśnięty klawisz Ctrl lub Shift',
+        'ResultsInfo' => 'Do Zbioru możesz dodać wiele pozycji jednocześnie, wybierając je trzymaj wciśnięty klawisz Ctrl lub Shift', # Accepts model codes
         
         'OptionsTitle' => 'Preferencje',
 		'OptionsExpertMode' => 'Ustawienia zaawansowane',
@@ -426,6 +452,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Katalog',
         'FileChooserOpenDirectory' => 'Wybierz katalog',
         'FileChooserOverwrite' => 'Plik już istnieje. Czy chcesz go zastąpić?',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
         'PanelCompact' => 'Kompaktowy',
         'PanelReadOnly' => 'Tylko do odczytu',
@@ -443,14 +474,17 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Wybierz zdjęcie',
         'PanelImageNoImage' => 'Brak zdjęcia',
         'PanelSelectFileTitle' => 'Wybierz plik',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Przywróć domyślne',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Update information from web',
 
         'PanelFrom' =>'Od',
         'PanelTo' =>'Do',
 
         'PanelWeb' => 'Sprawdź informacje',
-        'PanelWebTip' => 'Sprawdź w sieci informacje o tej pozycji',
-        'PanelRemoveTip' => 'Usuń bieżącą pozycję',
+        'PanelWebTip' => 'Sprawdź w sieci informacje o tej pozycji', # Accepts model codes
+        'PanelRemoveTip' => 'Usuń bieżącą pozycję', # Accepts model codes
 
         'PanelDateSelect' => 'Wybierz datę',
         'PanelNobody' => 'Nikt',
@@ -464,7 +498,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Dłużnik',
         'PanelLendDate' => 'Data pożyczenia',
         'PanelHistory' => 'Historia wypożyczania',
-        'PanelReturned' => 'Pozycja zwrócona',
+        'PanelReturned' => 'Pozycja zwrócona', # Accepts model codes
         'PanelReturnDate' => 'Data zwrotu',
         'PanelLendedYes' => 'Pożyczone',
         'PanelLendedNo' => 'Dostępne',
@@ -497,6 +531,8 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Język',
         'PluginsUseSite' => 'Używaj wybranej witryny w kolejnych wyszukiwaniach',
+        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+        'PluginDisabled' => 'Disabled',
 
         'BorrowersTitle' => 'Konfiguracja dłużnika',
         'BorrowersList' => 'Dłużnicy',
@@ -515,9 +551,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'Format pliku:',
         'BorrowersImportFile' => 'Plik:',
 
-        'BorrowedTitle' => 'Pożyczone pozycje',
+        'BorrowedTitle' => 'Pożyczone pozycje', # Accepts model codes
         'BorrowedDate' => 'Od',
-        'BorrowedDisplayInPanel' => 'Pokaż tą pozycję w głównym oknie',
+        'BorrowedDisplayInPanel' => 'Pokaż tą pozycję w głównym oknie', # Accepts model codes
 
         'MailTitle' => 'Wyślij e-mail',
         'MailFrom' => 'Od: ',
@@ -526,8 +562,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Problem z serwerem SMTP',
         'MailSendmailError' => 'Błąd załadowania funkcji sendmail',
 
-        'SearchTooltip' => 'Szukaj we wszystkich pozycjach',
-        'SearchTitle' => 'Wyszukiwanie',
+        'SearchTooltip' => 'Szukaj we wszystkich pozycjach', # Accepts model codes
+        'SearchTitle' => 'Wyszukiwanie', # Accepts model codes
         'SearchNoField' => 'Nie wybrano żadnego pola dla wyszukiwania.
 Dodaj kilka w zakładce Filtry okienka ustawień Zbioru.',
 
@@ -566,7 +602,7 @@ Dodaj kilka w zakładce Filtry okienka ustawień Zbioru.',
         'PropertiesDescription' => 'Opis',
         'PropertiesFile' => 'Informacje o pliku',
         'PropertiesFilePath' => 'Pełna ścieżka',
-        'PropertiesItemsNumber' => 'Ilość pozycji',
+        'PropertiesItemsNumber' => 'Ilość pozycji', # Accepts model codes
         'PropertiesFileSize' => 'Rozmiar',
         'PropertiesFileSizeSymbols' => ['Bajtów', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Właściwości Zbioru',
@@ -590,8 +626,8 @@ Dodaj kilka w zakładce Filtry okienka ustawień Zbioru.',
         'BookmarksNewFolder' => 'Nowy katalog',
 
         'AdvancedSearchType' => 'Typ wyszukiwania',
-        'AdvancedSearchTypeAnd' => 'Pozycje spełniające wszystkie warunki',
-        'AdvancedSearchTypeOr' => 'Pozycje spełniające co najmniej jeden z warunków',
+        'AdvancedSearchTypeAnd' => 'Pozycje spełniające wszystkie warunki', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Pozycje spełniające co najmniej jeden z warunków', # Accepts model codes
         'AdvancedSearchCriteria' => 'Warunki',
         'AdvancedSearchAnyField' => 'Any field',
         'AdvancedSearchSaveTitle' => 'Zapisz wyszukiwanie',
@@ -605,6 +641,24 @@ Dodaj kilka w zakładce Filtry okienka ustawień Zbioru.',
         'BugReportPlatform' => 'System operacyjny',
         'BugReportMessage' => 'Treść zgłoszenia',
         'BugReportInformation' => 'Informacje dodatkowe',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
     );
 }
 
