@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -23,6 +23,22 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 ###################################################
+
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
     
     use strict;
     use base 'Exporter';
@@ -46,7 +62,7 @@ do site.
 Para escolher em qual site deseja buscar a informação, você
 pode usar o <b>botão abaixo dos detalhes do item</b>.',
         
-        'AllItemsFiltered' => 'Nenhum item cumpre com os critérios do filtro',
+        'AllItemsFiltered' => 'Nenhum item cumpre com os critérios do filtro', # Accepts model codes
         
 #Installation
         'InstallDirInfo' => 'Instalar em ',
@@ -97,14 +113,19 @@ pode usar o <b>botão abaixo dos detalhes do item</b>.',
 #Menus
         'MenuFile' => '_Arquivo',	
             'MenuNewList' => '_Nova coleção',	
+            'MenuStats' => 'Statistics',
             'MenuHistory' => 'Coleções _recentes',
-            'MenuLend' => '_Ver itens emprestados',	
+            'MenuLend' => '_Ver itens emprestados', # Accepts model codes
             'MenuImport' => '_Importar',
             'MenuExport' => '_Exportar',	
+            'MenuAddItem' => '_Add Items', # Accepts model codes
 
         'MenuEdit'  => '_Editar',
-       	    'MenuDuplicate' => '_Duplicar item',
-            'MenuEditDeleteCurrent' => '_Apagar item',
+            'MenuDuplicate' => '_Duplicar item', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate Items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All Items', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_Apagar item', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove Items', # Accepts model codes    
             'MenuEditFields' => '_Trocar campos da coleção',
             'MenuEditLockItems' => '_Bloquear coleção',
         
@@ -113,7 +134,7 @@ pode usar o <b>botão abaixo dos detalhes do item</b>.',
                 'MenuSavedSearchesSave' => 'Save current search',
                 'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'Busca _avançada',
-            'MenuViewAllItems' => '_Ver todos os itens',	
+            'MenuViewAllItems' => '_Ver todos os itens', # Accepts model codes	
             'MenuNoFilter' => '_Todos',	
 
         'MenuConfiguration' => '_Configurações',	
@@ -132,8 +153,9 @@ pode usar o <b>botão abaixo dos detalhes do item</b>.',
             'MenuBugReport' => '_Reportar um problema',
             'MenuAbout' => '_Sobre',	
 
-        'MenuNewWindow' => 'Mostrar item em uma nova janela',
-        
+        'MenuNewWindow' => 'Mostrar item em uma nova janela', # Accepts model codes
+        'MenuNewWindowPlural' => 'Show Items in _New Window', # Accepts model codes
+                
         'ContextExpandAll' => 'Expandir tudo',
         'ContextCollapseAll' => 'Contrair todo',
         'ContextChooseImage' => 'Choose _Image',
@@ -141,22 +163,24 @@ pode usar o <b>botão abaixo dos detalhes do item</b>.',
         'ContextImageEditor' => 'Image Editor',
         'ContextImgFront' => 'Front',
         'ContextImgBack' => 'Back',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
 
         'DialogEnterNumber' => 'Por favor, introduza um valor',
 
-        'RemoveConfirm' => 'Tem certeza que quer apagar este item?',  
-        'DefaultNewItem' => 'Novo item',
-        'NewItemTooltip' => 'Adicionar um novo item',
+        'RemoveConfirm' => 'Tem certeza que quer apagar este item?', # Accepts model codes 
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes 
+        'DefaultNewItem' => 'Novo item', # Accepts model codes
+        'NewItemTooltip' => 'Adicionar um novo item', # Accepts model codes
         'NoItemFound' => 'Nada foi encontrado. Deseja tentar a busca em outro site?',
         'OpenList' => 'Por favor, selecione uma coleção',	
         'SaveList' => 'Selecione onde deseja salvar a coleção',	
         'SaveListTooltip' => 'Salvar coleção atual', 
-        'SaveCurrentList' => 'Primeiro deve escolher onde quer salvar a coleção atual',
         'SaveUnsavedChanges' => 'Existe mudanças na coleção atual. Deseja salvá-las',
         'SaveDontSave' => 'Não salvar',
         'PreferencesTooltip' => 'Selecionar preferências',
         'ViewTooltip' => 'Trocar o tipo de coleção',
-        'PlayTooltip' => 'Reproduzir arquivo de vídeo associado ao item',
+        'PlayTooltip' => 'Reproduzir arquivo de vídeo associado ao item', # Accepts model codes
         'PlayFileNotFound' => 'File to launch was not found in this location:',
         'PlayRetry' => 'Retry',
         
@@ -179,8 +203,8 @@ pode usar o <b>botão abaixo dos detalhes do item</b>.',
         'ErrorModelUserDir' => 'User defined models are in: ',
 
         'RandomTooltip' => 'O que quer ver esta noite?',
-        'RandomError'=> 'Você não possui itens selecionáveis',
-        'RandomEnd'=> 'Não tem mais itens',
+        'RandomError'=> 'Você não possui itens selecionáveis', # Accepts model codes
+        'RandomEnd'=> 'Não tem mais itens', # Accepts model codes
         'RandomNextTip'=> 'Segunda sugestão',
         'RandomOkTip'=> 'Aceitar este item',
                         
@@ -197,7 +221,8 @@ Adolfo González : Programador
 Logos Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Tradução para português (Brasil): Daniel Valença',
-        'AboutDesign' => 'Logo e webdesign por le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logo e webdesign por le Spektre',
         
         'ToolbarRandom' => 'Esta noite',
 
@@ -247,6 +272,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Áudio',
         'ModelFieldFileProgram' => 'Programa',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Campos a usar',
         'ModelOptionsFieldsAuto' => 'Automático',
         'ModelOptionsFieldsNone' => 'Nenhum',
@@ -275,10 +301,10 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'Os valores devem ser considerados como números para comparação?',
         'ModelTooltipQuick' => 'Isto irá adicionar um sub-menu dentro do menu de Filtros',
 
-        'ResultsTitle' => 'Selecione um item',
+        'ResultsTitle' => 'Selecione um item', # Accepts model codes
         'ResultsNextTip' => 'Buscar no próximo site',
         'ResultsPreview' => 'Prévia',
-        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
+        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them', # Accepts model codes
 
         'OptionsTitle' => 'Preferências',
 		'OptionsExpertMode' => 'Expert Mode',
@@ -426,6 +452,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Directory',
         'FileChooserOpenDirectory' => 'Escolha uma pasta',
         'FileChooserOverwrite' => 'Este arquivo já existe. Deseja sobrescrevê-lo?',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
         #Some default panels
         'PanelCompact' => 'Compacto',
@@ -444,14 +475,17 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Selecionar uma imagem',	
         'PanelImageNoImage' => 'Sem imagem',
         'PanelSelectFileTitle' => 'Selecione um arquivo',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Restaurar padrões',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Update information from web',
 
         'PanelFrom' =>'De',
         'PanelTo' =>'Para',
 
         'PanelWeb' => 'Ver informação',
-        'PanelWebTip' => 'Ver informação na Internet sobre este item',	
-        'PanelRemoveTip' => 'Apagar item atual', 
+        'PanelWebTip' => 'Ver informação na Internet sobre este item', # Accepts model codes	
+        'PanelRemoveTip' => 'Apagar item atual', # Accepts model codes 
 
         'PanelDateSelect' => 'Selecionar',	
         'PanelNobody' => 'Ninguém',	
@@ -465,7 +499,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Devedor',
         'PanelLendDate' => 'Fora desde',
         'PanelHistory' => 'Histórico',
-        'PanelReturned' => 'Item devolvido',	
+        'PanelReturned' => 'Item devolvido', # Accepts model codes	
         'PanelReturnDate' => 'Data de devolução',
         'PanelLendedYes' => 'Emprestada',
         'PanelLendedNo' => 'Disponível',
@@ -498,6 +532,8 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Idioma',
         'PluginsUseSite' => 'Usar site selecionado para futuras buscas',
+        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+        'PluginDisabled' => 'Disabled',
         
         'BorrowersTitle' => 'Configuração dos devedores',	
         'BorrowersList' => 'Devedores',	
@@ -516,9 +552,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'Formato do arquivo:',
         'BorrowersImportFile' => 'Arquivo:',
 
-        'BorrowedTitle' => 'Itens emprestados',	
+        'BorrowedTitle' => 'Itens emprestados', # Accepts model codes	
         'BorrowedDate' => 'Desde',	
-        'BorrowedDisplayInPanel' => 'Show item in main window',
+        'BorrowedDisplayInPanel' => 'Show item in main window', # Accepts model codes
 
         'MailTitle' => 'Enviar um e-mail',	
         'MailFrom' => 'De: ',	
@@ -527,8 +563,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Problema de conexão com o servidor SMTP',	
         'MailSendmailError' => 'Problema na execução do sendmail',	
 
-        'SearchTooltip' => 'Buscar em todos itens',	
-        'SearchTitle' => 'Busca de itens',	
+        'SearchTooltip' => 'Buscar em todos itens', # Accepts model codes	
+        'SearchTitle' => 'Busca de itens', # Accepts model codes	
         'SearchNoField' => 'No field have been selected for the search box.
 Add some of them in the Filters tab of the collection settings.',
                 
@@ -567,7 +603,7 @@ Add some of them in the Filters tab of the collection settings.',
         'PropertiesDescription' => 'Descrição',
         'PropertiesFile' => 'Informação do arquivo',
         'PropertiesFilePath' => 'Caminho completo',
-        'PropertiesItemsNumber' => 'Número de itens',
+        'PropertiesItemsNumber' => 'Número de itens', # Accepts model codes
         'PropertiesFileSize' => 'Tamanho',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Propriedades da coleção',
@@ -591,8 +627,8 @@ Add some of them in the Filters tab of the collection settings.',
         'BookmarksNewFolder' => 'Nova pasta',
 
         'AdvancedSearchType' => 'Tipo de busca',
-        'AdvancedSearchTypeAnd' => 'Itens que cumpram todos os critérios',
-        'AdvancedSearchTypeOr' => 'Itens que cumpram pelo menos um critério',
+        'AdvancedSearchTypeAnd' => 'Itens que cumpram todos os critérios', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Itens que cumpram pelo menos um critério', # Accepts model codes
         'AdvancedSearchCriteria' => 'Critério',
         'AdvancedSearchAnyField' => 'Any field',
         'AdvancedSearchSaveTitle' => 'Save search',
@@ -606,6 +642,24 @@ Add some of them in the Filters tab of the collection settings.',
         'BugReportPlatform' => 'Operating system',
         'BugReportMessage' => 'Error message',
         'BugReportInformation' => 'Additional information',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
     );
 }
 1;
