@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -23,6 +23,22 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 ###################################################
+
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
     
     use strict;
     use base 'Exporter';
@@ -46,7 +62,7 @@ explicită</b> a sitului web.
 Pentru a determina ce sit web este proprietarul informaţiei,
 puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
         
-        'AllItemsFiltered' => 'Nici un element nu se potriveşte criteriilor dumneavoastră de filtrare',
+        'AllItemsFiltered' => 'Nici un element nu se potriveşte criteriilor dumneavoastră de filtrare', # Accepts model codes
         
 #Installation
         'InstallDirInfo' => 'Instalare în ',
@@ -97,14 +113,19 @@ puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
 #Menus
         'MenuFile' => '_Fişier',
             'MenuNewList' => 'Colecţie _nouă',
+            'MenuStats' => 'Statistics',
             'MenuHistory' => 'Colecţii _recente',
-            'MenuLend' => 'Afişează elementele î_mprumutate',
+            'MenuLend' => 'Afişează elementele î_mprumutate', # Accepts model codes
             'MenuImport' => '_Importă',	
             'MenuExport' => '_Exportă',
+            'MenuAddItem' => '_Add Items', # Accepts model codes
     
         'MenuEdit'  => '_Editare',
-            'MenuDuplicate' => '_Duplică element',
-            'MenuEditDeleteCurrent' => 'Ş_terge element',
+            'MenuDuplicate' => '_Duplică element', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate Items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All Items', # Accepts model codes
+            'MenuEditDeleteCurrent' => 'Ş_terge element', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove Items', # Accepts model codes    
             'MenuEditFields' => 'S_chimbă câmpurile colecţiei',
             'MenuEditLockItems' => 'B_lochează colecţia',
     
@@ -113,7 +134,7 @@ puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
                 'MenuSavedSearchesSave' => 'Save current search',
                 'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'Căutare a_vansată',
-            'MenuViewAllItems' => 'Afişează to_ate elementele',
+            'MenuViewAllItems' => 'Afişează to_ate elementele', # Accepts model codes
             'MenuNoFilter' => '_Oricare',
 
         'MenuConfiguration' => '_Setări',
@@ -132,7 +153,8 @@ puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
             'MenuBugReport' => 'Raportează un _bug',
             'MenuAbout' => '_Despre GCstar',
     
-        'MenuNewWindow' => 'Afişează elementul în fereastră _nouă',
+        'MenuNewWindow' => 'Afişează elementul în fereastră _nouă', # Accepts model codes
+        'MenuNewWindowPlural' => 'Show Items in _New Window', # Accepts model codes
         
         'ContextExpandAll' => 'Desfă tot',
         'ContextCollapseAll' => 'Strânge tot',
@@ -141,22 +163,24 @@ puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
         'ContextImageEditor' => 'Image Editor',
         'ContextImgFront' => 'Front',
         'ContextImgBack' => 'Back',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
 
         'DialogEnterNumber' => 'Vă rugăm introduceţi o valoare',
 
-        'RemoveConfirm' => 'Sunteţi sigur că doriţi să ştergeţi acest element?',
-        'DefaultNewItem' => 'Element nou',
-        'NewItemTooltip' => 'Adaugă un element nou',
+        'RemoveConfirm' => 'Sunteţi sigur că doriţi să ştergeţi acest element?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+        'DefaultNewItem' => 'Element nou', # Accepts model codes
+        'NewItemTooltip' => 'Adaugă un element nou', # Accepts model codes
         'NoItemFound' => 'Nu a fost găsit nimic. Doriţi să căutaţi pe alt sit?',
         'OpenList' => 'Vă rugăm selectaţi colecţia',
         'SaveList' => 'Vă rugăm alegeţi unde să salvaţi colecţia',
         'SaveListTooltip' => 'Salvează colecţia curentă',
-        'SaveCurrentList' => 'Mai întâi specificaţi unde să fie salvată colecţia curentă',
         'SaveUnsavedChanges' => 'Aveţi modificări nesalvate în colecţia dumneavoastră. Doriţi să le salvaţi?',
         'SaveDontSave' => 'Nu salva',
         'PreferencesTooltip' => 'Setaţi preferinţele dumneavoastră',
         'ViewTooltip' => 'Schimbă afişarea colecţiei',
-        'PlayTooltip' => 'Redă fişierul video asociat acestui element',
+        'PlayTooltip' => 'Redă fişierul video asociat acestui element', # Accepts model codes
         'PlayFileNotFound' => 'File to launch was not found in this location:',
         'PlayRetry' => 'Retry',
 
@@ -179,8 +203,8 @@ puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
         'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'Ce să vedem în acestă seară?',
-        'RandomError'=> 'Nu aveţi nici un element care să poate fi selectat',
-        'RandomEnd'=> 'Nu mai sunt alte elemente',
+        'RandomError'=> 'Nu aveţi nici un element care să poate fi selectat', # Accepts model codes
+        'RandomEnd'=> 'Nu mai sunt alte elemente', # Accepts model codes
         'RandomNextTip'=> 'Următoarea sugestie',
         'RandomOkTip'=> 'Acceptă acest element',
         
@@ -197,7 +221,8 @@ Adolfo González : Programator
 Copyright logo le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Traducerea în română de către Mugurel Tudor',
-        'AboutDesign' => 'Logo şi design web de către le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logo şi design web de către le Spektre',
 
         'ToolbarRandom' => 'În seara asta',
         
@@ -247,6 +272,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Audio',
         'ModelFieldFileProgram' => 'Program',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Câmpuri folosite',
         'ModelOptionsFieldsAuto' => 'Automat',
         'ModelOptionsFieldsNone' => 'Nici unul',
@@ -275,10 +301,10 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'Dacă valorile trebuie considerate ca numere în comparaţii',
         'ModelTooltipQuick' => 'Aceasta va adăuga un submeniu la Filtre',
 
-        'ResultsTitle' => 'Selectaţi un element',
+        'ResultsTitle' => 'Selectaţi un element', # Accepts model codes
         'ResultsNextTip' => 'Caută pe următorul sit',
         'ResultsPreview' => 'Previzualizare',
-        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
+        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them', # Accepts model codes
         
         'OptionsTitle' => 'Preferinţe',
 		'OptionsExpertMode' => 'Expert Mode',
@@ -426,6 +452,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Directory',
         'FileChooserOpenDirectory' => 'Selectaţi un director',
         'FileChooserOverwrite' => 'Acest fişier deja există. Doriţi să îl suprascrieţi?',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
         'PanelCompact' => 'Compact',
         'PanelReadOnly' => 'Doar pentru citire',
@@ -443,14 +474,17 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Selectaţi o imagine',
         'PanelImageNoImage' => 'Nici o imagine',
         'PanelSelectFileTitle' => 'Selectaţi un fişier',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Restaurează valorile implicite',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Update information from web',
 
         'PanelFrom' =>'De la',
         'PanelTo' =>'Către',
 
         'PanelWeb' => 'Mai multe informaţii',
-        'PanelWebTip' => 'Afişează informaţii de pe web despre acest element',
-        'PanelRemoveTip' => 'Şterge elementul curent',
+        'PanelWebTip' => 'Afişează informaţii de pe web despre acest element', # Accepts model codes
+        'PanelRemoveTip' => 'Şterge elementul curent', # Accepts model codes
 
         'PanelDateSelect' => 'Selectaţi o dată',
         'PanelNobody' => 'Nimeni',
@@ -464,7 +498,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Împrumutat',
         'PanelLendDate' => 'Din data',
         'PanelHistory' => 'Istoric împrumuturi',
-        'PanelReturned' => 'Element returnat',
+        'PanelReturned' => 'Element returnat', # Accepts model codes
         'PanelReturnDate' => 'Data returnării',
         'PanelLendedYes' => 'Împrumutat',
         'PanelLendedNo' => 'Disponibil',
@@ -497,6 +531,8 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Limbă',
         'PluginsUseSite' => 'Foloseşte situl selectat pentru viitoarele căutări',
+        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+        'PluginDisabled' => 'Disabled',
 
         'BorrowersTitle' => 'Configurare împrumuturi',
         'BorrowersList' => 'Persoane care au împrumutat',
@@ -515,9 +551,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'Format fişier:',
         'BorrowersImportFile' => 'Fişier:',
 
-        'BorrowedTitle' => 'Elemente împrumutate',
+        'BorrowedTitle' => 'Elemente împrumutate', # Accepts model codes
         'BorrowedDate' => 'Din data de',
-        'BorrowedDisplayInPanel' => 'Show item in main window',
+        'BorrowedDisplayInPanel' => 'Show item in main window', # Accepts model codes
 
         'MailTitle' => 'Trimite un email',
         'MailFrom' => 'De la: ',
@@ -526,8 +562,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Problemă la conectarea la serverul SMTP',
         'MailSendmailError' => 'Problemă la lansarea sendmail',
 
-        'SearchTooltip' => 'Caută toate elementele',
-        'SearchTitle' => 'Căutare element',
+        'SearchTooltip' => 'Caută toate elementele', # Accepts model codes
+        'SearchTitle' => 'Căutare element', # Accepts model codes
         'SearchNoField' => 'No field have been selected for the search box.
 Add some of them in the Filters tab of the collection settings.',
 
@@ -566,7 +602,7 @@ Add some of them in the Filters tab of the collection settings.',
         'PropertiesDescription' => 'Descriere',
         'PropertiesFile' => 'Informaţii fişier',
         'PropertiesFilePath' => 'Cale completă',
-        'PropertiesItemsNumber' => 'Număr de elemente',
+        'PropertiesItemsNumber' => 'Număr de elemente', # Accepts model codes
         'PropertiesFileSize' => 'Mărime',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Proprietăţi colecţie',
@@ -590,8 +626,8 @@ Add some of them in the Filters tab of the collection settings.',
         'BookmarksNewFolder' => 'Dosar nou',
 
         'AdvancedSearchType' => 'Tipul de căutare',
-        'AdvancedSearchTypeAnd' => 'Elemente se potrivesc la toate criteriile',
-        'AdvancedSearchTypeOr' => 'Elementele se potrivesc la cel puţin un criteriu',
+        'AdvancedSearchTypeAnd' => 'Elemente se potrivesc la toate criteriile', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Elementele se potrivesc la cel puţin un criteriu', # Accepts model codes
         'AdvancedSearchCriteria' => 'Criteriu',
         'AdvancedSearchAnyField' => 'Orice câmp',
         'AdvancedSearchSaveTitle' => 'Save search',
@@ -605,6 +641,24 @@ Add some of them in the Filters tab of the collection settings.',
         'BugReportPlatform' => 'Sistem de operare',
         'BugReportMessage' => 'Mesaj de eroare',
         'BugReportInformation' => 'Informaţii adiţionale',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
     );
 }
 1;
