@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -23,6 +23,22 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 ###################################################
+
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
     
     use strict;
     use base 'Exporter';
@@ -46,7 +62,7 @@
 Для того что определить какой сайт является владельцем информации 
 вы можете использоватье <b>кнопку на закладке детальной информации о фильме</b>.',
         
-        'AllItemsFiltered' => 'Нет фильмов удовлетворяющих вашим критериям',
+        'AllItemsFiltered' => 'Нет фильмов удовлетворяющих вашим критериям', # Accepts model codes
         
 #Installation
         'InstallDirInfo' => 'Инсталлировать в ',
@@ -97,14 +113,19 @@
 #Menus
         'MenuFile' => '_Файл',
             'MenuNewList' => '_Новая коллекция',
+            'MenuStats' => 'Statistics',
             'MenuHistory' => '_Последние коллеции',
-            'MenuLend' => 'Показать фильмы на _Руках',
+            'MenuLend' => 'Показать фильмы на _Руках', # Accepts model codes
             'MenuImport' => '_Импорт',	
             'MenuExport' => '_Экспорт',
+            'MenuAddItem' => '_Add Items', # Accepts model codes
 
         'MenuEdit'  => '_Редактирование',
-            'MenuDuplicate' => '_Дублировать фильм',
-            'MenuEditDeleteCurrent' => '_Удалить фильм',
+            'MenuDuplicate' => '_Дублировать фильм', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate Items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All Items', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_Удалить фильм', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove Items', # Accepts model codes    
             'MenuEditFields' => '_Изменить поля коллекции',
             'MenuEditLockItems' => '_Зафиксировать коллекцию',
     
@@ -113,7 +134,7 @@
                 'MenuSavedSearchesSave' => 'Save current search',
                 'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'Расширенный _Поиск',
-            'MenuViewAllItems' => 'Показать _ВСЕ фильмы',
+            'MenuViewAllItems' => 'Показать _ВСЕ фильмы', # Accepts model codes
             'MenuNoFilter' => '_Любой',
     
         'MenuConfiguration' => '_Настройки',
@@ -132,7 +153,8 @@
             'MenuBugReport' => 'Отправить отчёт об _ошибке',
             'MenuAbout' => '_О GCstar',
     
-        'MenuNewWindow' => 'Показать фильм в _Новом Окне',
+        'MenuNewWindow' => 'Показать фильм в _Новом Окне', # Accepts model codes
+        'MenuNewWindowPlural' => 'Show Items in _New Window', # Accepts model codes
         
         'ContextExpandAll' => 'Развернуть всё',
         'ContextCollapseAll' => 'Свернуть всё',
@@ -141,22 +163,24 @@
         'ContextImageEditor' => 'Image Editor',
         'ContextImgFront' => 'Front',
         'ContextImgBack' => 'Back',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
     
         'DialogEnterNumber' => 'Пожалуйста введите занчение',
 
-        'RemoveConfirm' => 'Вы действительно хотите удалить этот фильм?',
-        'DefaultNewItem' => 'Новый элемент',
-        'NewItemTooltip' => 'Добавить новый фильм',
+        'RemoveConfirm' => 'Вы действительно хотите удалить этот фильм?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+        'DefaultNewItem' => 'Новый элемент', # Accepts model codes
+        'NewItemTooltip' => 'Добавить новый фильм', # Accepts model codes
         'NoItemFound' => 'Фильм не был найде. Хотите поискать на другом сайте?',
         'OpenList' => 'Пожалуйста выберите коллекцию',
         'SaveList' => 'Пожалуйста выберите куда сохранить коллекцию',
         'SaveListTooltip' => 'Сохранить текущую коллекцию',
-        'SaveCurrentList' => 'Сначала укажите куда сохранить текущую коллекцию',
         'SaveUnsavedChanges' => 'В вашей коллекций есть несохранённые изменения, хотите их сохранить?',
         'SaveDontSave' => 'Не сохранять',
         'PreferencesTooltip' => 'Установите свои предпочтения',
         'ViewTooltip' => 'Изменить отоюражение коллекции',
-        'PlayTooltip' => 'Воспроизвести видео ассоциируемое с фильмом',
+        'PlayTooltip' => 'Воспроизвести видео ассоциируемое с фильмом', # Accepts model codes
         'PlayFileNotFound' => 'File to launch was not found in this location:',
         'PlayRetry' => 'Retry',
 
@@ -179,8 +203,8 @@
         'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'Чего бы посмотреть сегодня вечером ?',
-        'RandomError'=> 'У вас нет непросмотренных фильмов',
-        'RandomEnd'=> 'Больше нет фильмов',
+        'RandomError'=> 'У вас нет непросмотренных фильмов', # Accepts model codes
+        'RandomEnd'=> 'Больше нет фильмов', # Accepts model codes
         'RandomNextTip'=> 'Следущее предложение',
         'RandomOkTip'=> 'Я согласен на этот фильм',
         
@@ -197,7 +221,8 @@ Adolfo González: Программист
 Логотипы Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Русский перевод Андрей Гуселетов',
-        'AboutDesign' => 'Логотипы и вэб-дизайн : le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Логотипы и вэб-дизайн : le Spektre',
 
         'ToolbarRandom' => 'Сегодня вечером',
         
@@ -247,6 +272,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Аудио',
         'ModelFieldFileProgram' => 'Программа',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Использовать поля',
         'ModelOptionsFieldsAuto' => 'Автоматически',
         'ModelOptionsFieldsNone' => 'Нет',
@@ -275,10 +301,10 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'Должны ли значения считаться цифрами при сравнении',
         'ModelTooltipQuick' => 'Это добавит подменю в фильтры',
 
-        'ResultsTitle' => 'Выберите фильм',
+        'ResultsTitle' => 'Выберите фильм', # Accepts model codes
         'ResultsNextTip' => 'искать на следующем сайте',
         'ResultsPreview' => 'Предпросмотр',
-        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
+        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them', # Accepts model codes
         
         'OptionsTitle' => 'Предпочтения',
 		'OptionsExpertMode' => 'Expert Mode',
@@ -426,6 +452,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Directory',
         'FileChooserOpenDirectory' => 'Выберите директорию',
         'FileChooserOverwrite' => 'Такой файл уже существует. Вы хотите перезаписать его?',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
         'PanelCompact' => 'Компактно',
         'PanelReadOnly' => 'Только для чтения',
@@ -443,14 +474,17 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Выберите картинку',
         'PanelImageNoImage' => 'No image',
         'PanelSelectFileTitle' => 'Выберите файл',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Restore default',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Update information from web',
 
         'PanelFrom' =>'От',
         'PanelTo' =>'Куда',
 
         'PanelWeb' => 'Смотреть информацию',
-        'PanelWebTip' => 'Посмотреть информацию в Интернет об этом фильме',
-        'PanelRemoveTip' => 'Удалить текущий фильм',
+        'PanelWebTip' => 'Посмотреть информацию в Интернет об этом фильме', # Accepts model codes
+        'PanelRemoveTip' => 'Удалить текущий фильм', # Accepts model codes
 
         'PanelDateSelect' => 'Выберите дату',
         'PanelNobody' => 'Никто',
@@ -464,7 +498,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Должник',
         'PanelLendDate' => 'С ',
         'PanelHistory' => 'История',
-        'PanelReturned' => 'Фильм возвращён',
+        'PanelReturned' => 'Фильм возвращён', # Accepts model codes
         'PanelReturnDate' => 'Дата возврата',
         'PanelLendedYes' => 'Взято напрокат',
         'PanelLendedNo' => 'Доступно',
@@ -497,6 +531,8 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Автор',
         'PluginsLang' => 'Язык',
         'PluginsUseSite' => 'Использовать выбранный сайт для последующего поиска',
+        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+        'PluginDisabled' => 'Disabled',
 
         'BorrowersTitle' => 'Конфигурация должника',
         'BorrowersList' => 'Должники',
@@ -515,9 +551,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'Формат файла:',
         'BorrowersImportFile' => 'Файл:',
 
-        'BorrowedTitle' => 'На руках',
+        'BorrowedTitle' => 'На руках', # Accepts model codes
         'BorrowedDate' => 'С ',
-        'BorrowedDisplayInPanel' => 'Show item in main window',
+        'BorrowedDisplayInPanel' => 'Show item in main window', # Accepts model codes
 
         'MailTitle' => 'Послать e-mail',
         'MailFrom' => 'От: ',
@@ -526,8 +562,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Проблемы в процессе присоединения к SMTP серверу',
         'MailSendmailError' => 'Проблемы при запуске sendmail',
 
-        'SearchTooltip' => 'Искать все фильмы',
-        'SearchTitle' => 'Поиск фильмов',
+        'SearchTooltip' => 'Искать все фильмы', # Accepts model codes
+        'SearchTitle' => 'Поиск фильмов', # Accepts model codes
         'SearchNoField' => 'No field have been selected for the search box.
 Add some of them in the Filters tab of the collection settings.',
 
@@ -566,7 +602,7 @@ Add some of them in the Filters tab of the collection settings.',
         'PropertiesDescription' => 'Описание',
         'PropertiesFile' => 'Информация о файле',
         'PropertiesFilePath' => 'Полный путь',
-        'PropertiesItemsNumber' => 'Количество элементов',
+        'PropertiesItemsNumber' => 'Количество элементов', # Accepts model codes
         'PropertiesFileSize' => 'Размер',
         'PropertiesFileSizeSymbols' => ['Байт', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Свойства коллекции',
@@ -590,8 +626,8 @@ Add some of them in the Filters tab of the collection settings.',
         'BookmarksNewFolder' => 'Новая папка',
 
         'AdvancedSearchType' => 'Тип поиска',
-        'AdvancedSearchTypeAnd' => 'Элементы удовлетворяющие всем критериям',
-        'AdvancedSearchTypeOr' => 'Элементы удовлетворяющие по крайней мере одному критерию',
+        'AdvancedSearchTypeAnd' => 'Элементы удовлетворяющие всем критериям', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Элементы удовлетворяющие по крайней мере одному критерию', # Accepts model codes
         'AdvancedSearchCriteria' => 'Критерий',
         'AdvancedSearchAnyField' => 'Any field',
         'AdvancedSearchSaveTitle' => 'Save search',
@@ -605,6 +641,24 @@ Add some of them in the Filters tab of the collection settings.',
         'BugReportPlatform' => 'Operating system',
         'BugReportMessage' => 'Error message',
         'BugReportInformation' => 'Additional information',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
     );
 }
 1;
