@@ -23,7 +23,23 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 ###################################################
-    
+
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
+
     use strict;
     use base 'Exporter';
 
@@ -43,7 +59,7 @@ Svaka daljna distribucija je zabranjena bez <b>jasne dozvole</b> sajta.
 
 Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugme ispod podataka o filmu</b>.',
         
-        'AllItemsFiltered' => 'Nijedan film ne odgovara zadatom kriterijumu',
+        'AllItemsFiltered' => 'Nijedan film ne odgovara zadatom kriterijumu', # Accepts model codes
         
 #Installation
     	'InstallDirInfo' => 'Instaliraj u',
@@ -94,14 +110,19 @@ Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugm
 #Menus
     	'MenuFile' => '_Fajl',
     		'MenuNewList' => '_Nova Kolekcija',
+            'MenuStats' => 'Statistics',
     		'MenuHistory' => '_Poslednje Kolekcije',
-    		'MenuLend' => 'Prikaži Po_zajmljene Filmove',
+    		'MenuLend' => 'Prikaži Po_zajmljene Filmove', # Accepts model codes
     		'MenuImport' => '_Uvezi',	
     		'MenuExport' => '_Izvezi',
+            'MenuAddItem' => '_Add Items', # Accepts model codes
     
     	'MenuEdit'  => '_Izmeni',
-       	    'MenuDuplicate' => '_Dupliraj Film',
-    		'MenuEditDeleteCurrent' => '_Obriši Film',
+            'MenuDuplicate' => '_Dupliraj Film', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate Items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All Items', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_Obriši Film', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove Items', # Accepts model codes 
             'MenuEditFields' => '_Change collection fields',
     		'MenuEditLockItems' => '_Zaključaj Kolekciju',
     
@@ -110,7 +131,7 @@ Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugm
                 'MenuSavedSearchesSave' => 'Save current search',
                 'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'A_dvanced Search',
-    		'MenuViewAllItems' => 'Prikaži _Sve Filmove',
+    		'MenuViewAllItems' => 'Prikaži _Sve Filmove', # Accepts model codes
             'MenuNoFilter' => '_Bilo Koji',
     
     	'MenuConfiguration' => '_Podešavanja',
@@ -129,8 +150,9 @@ Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugm
             'MenuBugReport' => 'Report a _bug',
     		'MenuAbout' => '_O GCstar',
     
-    	'MenuNewWindow' => 'Prikaži Film U _Novom Prozoru',
-        
+    	'MenuNewWindow' => 'Prikaži Film U _Novom Prozoru', # Accepts model codes
+        'MenuNewWindowPlural' => 'Show Items in _New Window', # Accepts model codes
+                
         'ContextExpandAll' => 'Expand all',
         'ContextCollapseAll' => 'Collapse all',
         'ContextChooseImage' => 'Choose _Image',
@@ -138,22 +160,24 @@ Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugm
         'ContextImageEditor' => 'Image Editor', 
         'ContextImgFront' => 'Front',
         'ContextImgBack' => 'Back',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
 
         'DialogEnterNumber' => 'Please enter value',
 
-        'RemoveConfirm' => 'Da listvarno želite da obrišete ovaj film?',
-        'DefaultNewItem' => 'New item',
-        'NewItemTooltip' => 'Dodaj novi film',
+        'RemoveConfirm' => 'Da listvarno želite da obrišete ovaj film?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+        'DefaultNewItem' => 'New item', # Accepts model codes
+        'NewItemTooltip' => 'Dodaj novi film', # Accepts model codes
         'NoItemFound' => 'Film nije pronađen. Da li želite da pretražite drugi sajt?',
         'OpenList' => 'Odaberite kolekciju',
         'SaveList' => 'Odaberite gde ćete da sačuvate kolekciju',
         'SaveListTooltip' => 'Sačuvaj trenutnu kolekciju',
-        'SaveCurrentList' => 'Prvi precizirajte gde želite da sačuvate trenutnu kolekciju',
         'SaveUnsavedChanges' => 'There are unsaved changes in your collection. Do you want to save them?',
         'SaveDontSave' => 'Don\'t save',
         'PreferencesTooltip' => 'Podesite svoje parametre',
         'ViewTooltip' => 'Promenite prikaz kolekcije',
-        'PlayTooltip' => 'Pustite film',
+        'PlayTooltip' => 'Pustite film', # Accepts model codes
         'PlayFileNotFound' => 'File to launch was not found in this location:',
         'PlayRetry' => 'Retry',
 
@@ -176,8 +200,8 @@ Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugm
         'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'Šta gledati večeras ?',
-        'RandomError'=> 'Nemate neodgledanih filmova',
-        'RandomEnd'=> 'Nemate više filmova',
+        'RandomError'=> 'Nemate neodgledanih filmova', # Accepts model codes
+        'RandomEnd'=> 'Nemate više filmova', # Accepts model codes
         'RandomNextTip'=> 'Sledeći predlog',
         'RandomOkTip'=> 'Biram ovaj film',
         
@@ -194,7 +218,8 @@ Adolfo González: Programer
 Logo Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Prevod na srpski Mario Tomić (http://www.mariotomic.com)',
-        'AboutDesign' => 'Logo i web dizajn le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logo i web dizajn le Spektre',
 
         'ToolbarRandom' => 'Večeras',
         
@@ -244,6 +269,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Audio',
         'ModelFieldFileProgram' => 'Program',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Fields to use',
         'ModelOptionsFieldsAuto' => 'Automatic',
         'ModelOptionsFieldsNone' => 'None',
@@ -272,10 +298,10 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'Should the values be consider as numbers for comparison',
         'ModelTooltipQuick' => 'This will add a submenu in the Filters one',
         
-        'ResultsTitle' => 'Odaberite film',
+        'ResultsTitle' => 'Odaberite film', # Accepts model codes
         'ResultsNextTip' => 'Pretraži sledeći sajt',
         'ResultsPreview' => 'Preview',
-        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
+        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them', # Accepts model codes
         
         'OptionsTitle' => 'Podešavanja',
 		'OptionsExpertMode' => 'Expert Mode',
@@ -423,6 +449,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Directory',
         'FileChooserOpenDirectory' => 'Odaberite direktorijum',
         'FileChooserOverwrite' => 'Ovaj fajl već postoji. Da li želite da ga zamenite novim fajlom?',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
         'PanelCompact' => 'Sažeti',
         'PanelReadOnly' => 'Samo Za čitanje',
@@ -440,14 +471,17 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Odaberi sliku',
         'PanelImageNoImage' => 'No image',
         'PanelSelectFileTitle' => 'Odaberi fajl',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Restore default',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Update information from web',
 
         'PanelFrom' =>'From',
         'PanelTo' =>'To',
 
         'PanelWeb' => 'Pogledaj Informacije',
-        'PanelWebTip' => 'Pogledaj Informacije o ovom filmu na internetu',
-        'PanelRemoveTip' => 'Obriši ovaj film',
+        'PanelWebTip' => 'Pogledaj Informacije o ovom filmu na internetu', # Accepts model codes
+        'PanelRemoveTip' => 'Obriši ovaj film', # Accepts model codes
 
         'PanelDateSelect' => 'Odaberi datum',
         'PanelNobody' => 'Niko',
@@ -461,7 +495,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Pozajmio',
         'PanelLendDate' => 'Pozajmljen Od',
         'PanelHistory' => 'Istorija Pozajmljivanja',
-        'PanelReturned' => 'Vraćen Film',
+        'PanelReturned' => 'Vraćen Film', # Accepts model codes
         'PanelReturnDate' => 'Datum vraćanja',
         'PanelLendedYes' => 'Pozajmljen',
         'PanelLendedNo' => 'Ovde',
@@ -494,6 +528,8 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Jezik',
         'PluginsUseSite' => 'Koristi odabrani sajt za sledeće pretrage',
+        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+        'PluginDisabled' => 'Disabled',
 
         'BorrowersTitle' => 'Opcije za pozajmljivače',
         'BorrowersList' => 'Pozajmljivači',
@@ -512,9 +548,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'File format:',
         'BorrowersImportFile' => 'File:',
 
-        'BorrowedTitle' => 'Pozajmljeni filmovi',
+        'BorrowedTitle' => 'Pozajmljeni filmovi', # Accepts model codes
         'BorrowedDate' => 'Od',
-        'BorrowedDisplayInPanel' => 'Show item in main window',
+        'BorrowedDisplayInPanel' => 'Show item in main window', # Accepts model codes
 
         'MailTitle' => 'Pošalji mu e-mail',
         'MailFrom' => 'Od: ',
@@ -523,8 +559,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Problem sa povezivanjem na server za slanje maila (SMTP server)',
         'MailSendmailError' => 'Problem sa startovanjem mail servera (sendmail)',
 
-        'SearchTooltip' => 'Pretraži sve filmove',
-        'SearchTitle' => 'Traži film',
+        'SearchTooltip' => 'Pretraži sve filmove', # Accepts model codes
+        'SearchTitle' => 'Traži film', # Accepts model codes
         'SearchNoField' => 'No field have been selected for the search box.
 Add some of them in the Filters tab of the collection settings.',
 
@@ -563,7 +599,7 @@ Add some of them in the Filters tab of the collection settings.',
         'PropertiesDescription' => 'Description',
         'PropertiesFile' => 'File Information',
         'PropertiesFilePath' => 'Full path',
-        'PropertiesItemsNumber' => 'Number of items',
+        'PropertiesItemsNumber' => 'Number of items', # Accepts model codes
         'PropertiesFileSize' => 'Size',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Collection properties',
@@ -587,8 +623,8 @@ Add some of them in the Filters tab of the collection settings.',
         'BookmarksNewFolder' => 'New folder',
 
         'AdvancedSearchType' => 'Type of search',
-        'AdvancedSearchTypeAnd' => 'Items matching all criteria',
-        'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
+        'AdvancedSearchTypeAnd' => 'Items matching all criteria', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Items matching at least one criterion', # Accepts model codes
         'AdvancedSearchCriteria' => 'Criteria',
         'AdvancedSearchAnyField' => 'Any field',
         'AdvancedSearchSaveTitle' => 'Save search',
@@ -602,6 +638,24 @@ Add some of them in the Filters tab of the collection settings.',
         'BugReportPlatform' => 'Operating system',
         'BugReportMessage' => 'Error message',
         'BugReportInformation' => 'Additional information',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
     );
 }
 1;
