@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,6 +33,9 @@
         'Charset' => 'Teckenkodning',
         'Header' => 'Ignorera första raden',
         'Separator' => 'Separator',
+        'Plugin' => 'Hemsida att använda',
+        'UseFirst' => 'Välj först en av många resultat',
+        'SearchField' => 'Search for items using',        
      );
 }
 
