@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -37,16 +37,16 @@
         'SuffixesTooltip' => 'En komma-separerad lista av suffix eller filändelser att betrakta',
         'Remove' => 'Att ta bort från namn',
         'RemoveTooltip' => 'En komma-separerad lista av ord som bör tas bort från filnamn för att skapa de hämtade filnamnen från',
-        'Ask'=> 'Ask',
-        'AskEnd'=> 'Ask all at end',
-        'AddWithoutInfo'=> 'Add without infos',
-        'DontAdd'=> 'Do not add',
-        'TakeFirst' => 'Select first',
+        'Ask'=> 'Fråga',
+        'AskEnd'=> 'Fråga alla vid slute',
+        'AddWithoutInfo'=> 'Lägg till utan info',
+        'DontAdd'=> 'Lägg inte till',
+        'TakeFirst' => 'Välj först',
         'MultipleResult'=> 'Multiple results',
         'MultipleResultTooltip'=> 'What do we do when more than 1 result is return by the plugin',
         'RemoveWholeWord' => 'Ta enbart bort hela ord',
-        'NoResult'=> 'No results',
-        'NoResultTooltip'=> 'What do we do when no search results is return by the plugin',
+        'NoResult'=> 'Inga resultat',
+        'NoResultTooltip'=> 'Vad skall vi göra när inga sökresultat returneras av plugin:et',
         'RemoveTooltipWholeWord' => 'Ord kommer enbart tas bort ifall de förekommer som ett helt ord',
         'RemoveRegularExpr' => 'Reguljärt uttryck',
         'RemoveTooltipRegularExpr' => 'Tänk på att \'Ta bort från namn\' är ett reguljärt uttryck i perl',
@@ -56,8 +56,8 @@
         'SkipFileFullPath' => 'based on full path',
         'SkipFileFileName' => 'based on file name',
         'SkipFileFileNameAndUpdate' => 'baserad på filnamnet (men uppdatera sökväg i samlingen)',
-        'InfoFromFileNameRegExp' => 'Parse file name with this regular expression',
-        'InfoFromFileNameRegExpTooltip' => 'Use this to retrieve infos from filename (applied after removing extension).\nLeave empty if not needed.\nKnown fields : \n$T:Title, $A:Alphabetised title, $Y:Release date, $S:Season, $E:Episode, $N:Alphabetised serie name, $x:Part number, $y: Total part number',
+        'InfoFromFileNameRegExp' => 'Parsa filnamn med reguljärt uttryck',
+        'InfoFromFileNameRegExpTooltip' => 'Använd detta för att införskaffa info från filnamn (tillämpat efter borttagning av ändelse). Lämna tomt ifall ej nödvändig. Kända fält: $T:Titel, $A:Alfabetisk titel, $Y:Releasedatum, $S:Säsong, $E:Episod, $N:Alfabetiskt serienamn, $x:Avsnittsnummer, $y:Totalt antal avsnitt',
 
      );
 
