@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -47,20 +47,21 @@
         Rank => 'Grad',
         Bookdescription => 'Beskrivning',
         Pages => 'Antal sidor',
-        Read => 'Läs',
-        Acquisition => 'Förvärvningsdatum',
+        Read => 'Läst',
+        Acquisition => 'Förvärvsdatum',
         Edition => 'Utgåva',
         Format => 'Format',
         Comments => 'Kommentarer',
         Url => 'Hemsida',
         Translator => 'Översättare',
-        Artist => 'Artist',
+        Artist => 'Illustratör',
+        DigitalFile => 'Digital version',
 
         General => 'Allmänt',
         Details => 'Detaljer',
 
         ReadNo => 'Ej läst',
-        ReadYes => 'Läs',
+        ReadYes => 'Läst',
      );
 }
 
