@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -23,6 +23,22 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 ###################################################
+
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
     
     use strict;
     use base 'Exporter';
@@ -43,7 +59,7 @@ Alla nydistribueringar är förbjudna utan respektive hemsidors <b>explicita med
 
 För att avgöra vilken hemsida som äger informationen, så kan du använda <b>knappen under artikelns detaljer</b>.',
         
-        'AllItemsFiltered' => 'Inga artiklar matchar ditt filteringskriterium',
+        'AllItemsFiltered' => 'Inga artiklar matchar ditt filteringskriterium', # Accepts model codes
         
 #Installation
         'InstallDirInfo' => 'Installera i ',
@@ -94,14 +110,19 @@ För att avgöra vilken hemsida som äger informationen, så kan du använda <b>
 #Menus
         'MenuFile' => '_Arkiv',
             'MenuNewList' => '_Ny Samling',
+            'MenuStats' => 'Statistik',
             'MenuHistory' => '_Tidigare Samlingar',
-            'MenuLend' => 'Visa _Lånade Artiklar',
+            'MenuLend' => 'Visa _Lånade Artiklar', # Accepts model codes
             'MenuImport' => '_Importera',	
             'MenuExport' => '_Exportera',
+            'MenuAddItem' => '_Add Items', # Accepts model codes
     
         'MenuEdit'  => '_Redigera',
-            'MenuDuplicate' => 'Ko_piera artikel',
-            'MenuEditDeleteCurrent' => '_Ta bort artikel',
+            'MenuDuplicate' => 'Ko_piera artikel', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate Items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All Items', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_Ta bort artikel', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove Items', # Accepts model codes  
             'MenuEditFields' => '_Ändra samlingens fält',
             'MenuEditLockItems' => '_Lås Samling',
     
@@ -110,7 +131,7 @@ För att avgöra vilken hemsida som äger informationen, så kan du använda <b>
                 'MenuSavedSearchesSave' => 'Spara aktuell sökning',
                 'MenuSavedSearchesEdit' => 'Modifiera sparade sökningar',
             'MenuAdvancedSearch' => 'A_vancerad Sök',
-            'MenuViewAllItems' => 'Visa _Alla artiklar',
+            'MenuViewAllItems' => 'Visa _Alla artiklar', # Accepts model codes
             'MenuNoFilter' => '_Någon',
     
         'MenuConfiguration' => '_Inställningar',
@@ -129,7 +150,8 @@ För att avgöra vilken hemsida som äger informationen, så kan du använda <b>
             'MenuBugReport' => 'Rapportera en _bugg',
             'MenuAbout' => '_Om GCstar',
     
-        'MenuNewWindow' => 'Visa artikel i _Nytt Fönster',
+        'MenuNewWindow' => 'Visa artikel i _Nytt Fönster', # Accepts model codes
+        'MenuNewWindowPlural' => 'Show Items in _New Window', # Accepts model codes
         
         'ContextExpandAll' => 'Expandera alla',
         'ContextCollapseAll' => 'Komprimera alla',
@@ -138,22 +160,24 @@ För att avgöra vilken hemsida som äger informationen, så kan du använda <b>
         'ContextOpenWith' => 'Öppna me_d',
         'ContextImgFront' => 'Framsida',
         'ContextImgBack' => 'Baksida',
+        'ContextChooseFile' => 'Välj en Fil',
+        'ContextChooseFolder' => 'Välj en Mapp',
         
         'DialogEnterNumber' => 'Var god ange ett värde',
 
-        'RemoveConfirm' => 'Är du säker på att du vill ta bort denna artikel?',
-        'DefaultNewItem' => 'Ny artikel',
-        'NewItemTooltip' => 'Lägg till en ny artikel',
+        'RemoveConfirm' => 'Är du säker på att du vill ta bort denna artikel?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+        'DefaultNewItem' => 'Ny artikel', # Accepts model codes
+        'NewItemTooltip' => 'Lägg till en ny artikel', # Accepts model codes
         'NoItemFound' => 'Ingenting hittades. Vill du söka på en annan hemsida?',
         'OpenList' => 'Var god välj samling',
         'SaveList' => 'Var god välj vart du vill spara samlingen',
         'SaveListTooltip' => 'Spara aktuell samling',
-        'SaveCurrentList' => 'Specificera först vart du vill spara aktuell samling',
         'SaveUnsavedChanges' => 'Det finns osparade ändringar i din samling. Vill du spara dem?',
         'SaveDontSave' => 'Spara inte',
         'PreferencesTooltip' => 'Ställ in dina inställningar',
         'ViewTooltip' => 'Ändra samlingsvisning',
-        'PlayTooltip' => 'Spela video associerad med artikel',
+        'PlayTooltip' => 'Spela video associerad med artikel', # Accepts model codes
         'PlayFileNotFound' => 'Filen att spela hittades ej på denna platsen:',
         'PlayRetry' => 'Försök igen',
 
@@ -176,8 +200,8 @@ För att avgöra vilken hemsida som äger informationen, så kan du använda <b>
         'ErrorModelUserDir' => 'Användardefinierade modeller finns i: ',
         
         'RandomTooltip' => 'Vad ska vi se ikväll ?',
-        'RandomError'=> 'Du har inga artiklar som kan bli valda',
-        'RandomEnd'=> 'Det finns inga fler artiklar',
+        'RandomError'=> 'Du har inga artiklar som kan bli valda', # Accepts model codes
+        'RandomEnd'=> 'Det finns inga fler artiklar', # Accepts model codes
         'RandomNextTip'=> 'Nästa förslag',
         'RandomOkTip'=> 'Acceptera denna artikel',
         
@@ -193,7 +217,8 @@ Adolfo González: Programmerare
         'AboutLicense' => 'Distribuerad under GNU GPL Licensen, Logotyper Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Svensk översättning av anonym medarbetare',
-        'AboutDesign' => 'Logotyper och webbdesign skapad av le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logotyper och webbdesign skapad av le Spektre',
 
         'ToolbarRandom' => 'Ikväll',
 
@@ -243,6 +268,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Ljud',
         'ModelFieldFileProgram' => 'Program',
         'ModelFieldFileUrl' => 'Länk',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Fält att använda',
         'ModelOptionsFieldsAuto' => 'Automatisk',
         'ModelOptionsFieldsNone' => 'Ingen',
@@ -271,10 +297,10 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'Bör värdena anses som nummer för jämförelse',
         'ModelTooltipQuick' => 'Detta kommer lägga till en undermeny i Filtermenyn',
         
-        'ResultsTitle' => 'Välj en artikel',
+        'ResultsTitle' => 'Välj en artikel', # Accepts model codes
         'ResultsNextTip' => 'Sök på nästa hemsida',
         'ResultsPreview' => 'Förhandsgranska',
-        'ResultsInfo' => 'Du kan lägga till flera produkter till en samling genom att hålla ner Ctrl- eller Skift-tangenten för att markera dem',
+        'ResultsInfo' => 'Du kan lägga till flera produkter till en samling genom att hålla ner Ctrl- eller Skift-tangenten för att markera dem', # Accepts model codes
         
         'OptionsTitle' => 'Inställningar',
 		'OptionsExpertMode' => 'Expert Läge',
@@ -301,14 +327,14 @@ http://le-spektre.org',
         'OptionsAskPlugins' => 'Fråga (Alla hemsidor)',
         'OptionsPluginsMulti' => 'Många hemsidor',
         'OptionsPluginsMultiAsk' => 'Fråga (Många hemsidor)',
-        'OptionsPluginsMultiPerField' => 'Många hemsidor (per field)',
-        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
-        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
-        'OptionsPluginsMultiPerFieldFirst' => 'First',
-        'OptionsPluginsMultiPerFieldLast' => 'Last',
-        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
-        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
-        'OptionsPluginsList' => 'Ställ in lista',
+        'OptionsPluginsMultiPerField' => 'Många sajter (per fält)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Många sajter per ordning av valt fäl',
+        'OptionsPluginsMultiPerFieldDesc' => 'För varje fält kommer vi fylla i fältet med den första icke-tomma informationen med början från vänster',
+        'OptionsPluginsMultiPerFieldFirst' => 'Första',
+        'OptionsPluginsMultiPerFieldLast' => 'Sista',
+        'OptionsPluginsMultiPerFieldRemove' => 'Ta bort',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Töm valda fältlistor',
+        'OptionsPluginsList' => 'Välj lista',
         'OptionsAskImport' => 'Välj fält som ska importeras',
         'OptionsProxy' => 'Använd en proxy',
         'OptionsCookieJar' => 'Använd denna kak-jarfil',
@@ -423,6 +449,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Mapp',
         'FileChooserOpenDirectory' => 'Välj en katalog',
         'FileChooserOverwrite' => 'Den här filen existerar redan. Vill du skriva över den?',
+        'FileAllFiles' => 'Alla Filer',
+        'FileVideoFiles' => 'Video Filer',
+        'FileEbookFiles' => 'Ebook Filer',
+        'FileAudioFiles' => 'Audio Filer',
+        'FileGCstarFiles' => 'GCstar Samlingar',
 
         #Some default panels
         'PanelCompact' => 'Kompakt',
@@ -431,24 +462,27 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Hämta Information',
         'PanelSearchTip' => 'Sök webben för information om detta namn',
-        'PanelSearchContextChooseOne' => 'Choose a site ...',
-        'PanelSearchContextMultiSite' => 'Use "Many sites"',
-        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
-        'PanelSearchContextOptions' => 'Change options ...',
+        'PanelSearchContextChooseOne' => 'Välj en sajt...',
+        'PanelSearchContextMultiSite' => 'Använd "Många sajter"',
+        'PanelSearchContextMultiSitePerField' => 'Använd "Många sajter per fält"',
+        'PanelSearchContextOptions' => 'Ändra inställningar...',
         'PanelImageTipOpen' => 'Klicka på bilden för att välja en annan.',
         'PanelImageTipView' => 'Klicka på bilden för att visa den i dess riktiga storlek.',
         'PanelImageTipMenu' => ' Högerklicka för ytterligare alternativ.',
         'PanelImageTitle' => 'Välj en bild',
         'PanelImageNoImage' => 'Ingen bild',
         'PanelSelectFileTitle' => 'Välj en fil',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Återställ förvald',
+        'PanelRefresh' => 'Uppdatera',
+        'PanelRefreshTip' => 'Uppdatera information från webben',
 
         'PanelFrom' =>'Från',
         'PanelTo' =>'Till',
 
         'PanelWeb' => 'Visa Information',
-        'PanelWebTip' => 'Visa information på webben om denna artikel',
-        'PanelRemoveTip' => 'Ta bort aktuell artikel',
+        'PanelWebTip' => 'Visa information på webben om denna artikel', # Accepts model codes
+        'PanelRemoveTip' => 'Ta bort aktuell artikel', # Accepts model codes
 
         'PanelDateSelect' => 'Välj',
         'PanelNobody' => 'Ingen',
@@ -462,7 +496,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Låntagare',
         'PanelLendDate' => 'Utlånad sedan',
         'PanelHistory' => 'Utlåningshistorik',
-        'PanelReturned' => 'Artikel Returnerad',
+        'PanelReturned' => 'Artikel Returnerad', # Accepts model codes
         'PanelReturnDate' => 'Returnerad datum',
         'PanelLendedYes' => 'Lånad',
         'PanelLendedNo' => 'Tillgänglig',
@@ -495,6 +529,8 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Författare',
         'PluginsLang' => 'Språk',
         'PluginsUseSite' => 'Använd valda hemsidor för framtida sökningar',
+        'PluginsPreferredTooltip' => 'Sajt rekommenderad av GCstar',
+        'PluginDisabled' => 'Avaktiverad',
 
         'BorrowersTitle' => 'Konfigurera låntagare',
         'BorrowersList' => 'Låntagare',
@@ -513,9 +549,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'Filformat:',
         'BorrowersImportFile' => 'Fil:',
 
-        'BorrowedTitle' => 'Lånade artiklar',
+        'BorrowedTitle' => 'Lånade artiklar', # Accepts model codes
         'BorrowedDate' => 'Sedan',
-        'BorrowedDisplayInPanel' => 'Visa artikel i huvudfönstret',
+        'BorrowedDisplayInPanel' => 'Visa artikel i huvudfönstret', # Accepts model codes
 
         'MailTitle' => 'Skicka e-post',
         'MailFrom' => 'Från: ',
@@ -524,8 +560,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Problem med att ansluta till SMTP servern',
         'MailSendmailError' => 'Problem med att köra sendmail',
 
-        'SearchTooltip' => 'Sök alla artiklar',
-        'SearchTitle' => 'Artikelsökning',
+        'SearchTooltip' => 'Sök alla artiklar', # Accepts model codes
+        'SearchTitle' => 'Artikelsökning', # Accepts model codes
         'SearchNoField' => 'Inget fält har markerats för sökrutan. Lägg till några av dem i fliken  
 Filter under samlingens inställningar.',
 
@@ -564,7 +600,7 @@ Filter under samlingens inställningar.',
         'PropertiesDescription' => 'Beskrivning',
         'PropertiesFile' => 'Filinformation',
         'PropertiesFilePath' => 'Full sökväg',
-        'PropertiesItemsNumber' => 'Antal artiklar',
+        'PropertiesItemsNumber' => 'Antal artiklar', # Accepts model codes
         'PropertiesFileSize' => 'Storlek',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Egenskap för samling',
@@ -588,8 +624,8 @@ Filter under samlingens inställningar.',
         'BookmarksNewFolder' => 'Ny mapp',
 
         'AdvancedSearchType' => 'Typ av sökning',
-        'AdvancedSearchTypeAnd' => 'Artiklarna matchade alla kriterier',
-        'AdvancedSearchTypeOr' => 'Artiklarna matchade åtminstone ett kriterium',
+        'AdvancedSearchTypeAnd' => 'Artiklarna matchade alla kriterier', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Artiklarna matchade åtminstone ett kriterium', # Accepts model codes
         'AdvancedSearchCriteria' => 'Kriterium',
         'AdvancedSearchAnyField' => 'Any field',
         'AdvancedSearchSaveTitle' => 'Spara sökning',
@@ -603,6 +639,24 @@ Filter under samlingens inställningar.',
         'BugReportPlatform' => 'Operativsystem',
         'BugReportMessage' => 'Felmeddelande',
         'BugReportInformation' => 'Ytterligare information',
+
+#Statistics
+        'StatsFieldToUse' => 'Fält att använd',
+        'StatsSortByNumber' => 'Sortera på nummer av {x}',
+        'StatsGenerate' => 'Generera',
+        'StatsKindOfGraph' => 'Typ av grafik',
+        'StatsBars' => 'Staplar',
+        'StatsPie' => 'Tårtdiagra',
+        'Stats3DPie' => '3D diagram',
+        'StatsArea' => 'Areor',
+        'StatsHistory' => 'Historik',
+        'StatsWidth' => 'Bredd',
+        'StatsHeight' => 'Höjd',
+        'StatsFontSize' => 'Teckenstorlek',
+        'StatsDisplayNumber' => 'Visa nummer',
+        'StatsSave' => 'Spara statistik-bild till fil',
+        'StatsAccumulate' => 'Samla ihop värden',
+        'StatsShowAllDates' => 'Visa alla datum',
     );
 }
 1;
