@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,6 +33,9 @@
         'Charset' => 'Charset',
         'Header' => 'İlk satırı yoksay',
         'Separator' => 'Ayırıcı',
+        'Plugin' => 'Kullanıcak site',
+        'UseFirst' => 'Eğer bir çok sonuç varsa ilkini seç',
+        'SearchField' => 'Search for items using',        
      );
 }
 
