@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -62,6 +62,11 @@
         Unlockables => 'Kilitlenmiş Özellikler',
         Unlockable => 'Kilitlenen',
         Howto => 'Nasıl çözülür?',
+        Exclusive => 'Exclusive',
+        Resolutions => 'Display resolutions',
+        InstallationSize => 'Size',
+        Region => 'Region',
+        SerialNumber => 'Serial Number',        
         
         General => 'Genel',
         Details => 'Detay',
