@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -23,6 +23,22 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 ###################################################
+
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
     
     use strict;
     use base 'Exporter';
@@ -46,7 +62,7 @@
 Щоб визначити, який сайт володіє інформацією,
 можна скористатись <b>кнопкою на вкладці подробиць про фільм</b>.',
         
-        'AllItemsFiltered' => 'Не знайдено відповідностей вашому запиту',
+        'AllItemsFiltered' => 'Не знайдено відповідностей вашому запиту', # Accepts model codes
         
 #Installation
         'InstallDirInfo' => 'Встановити до ',
@@ -97,14 +113,19 @@
 #Menus
         'MenuFile' => '_Файл',
             'MenuNewList' => '_Нова колекція',
+            'MenuStats' => 'Statistics',
             'MenuHistory' => '_Останні колекції',
-            'MenuLend' => 'Показати _позичені',
+            'MenuLend' => 'Показати _позичені', # Accepts model codes
             'MenuImport' => '_Імпорт',	
             'MenuExport' => '_Експорт',
+            'MenuAddItem' => '_Add Items', # Accepts model codes
     
         'MenuEdit'  => '_Редагування',
-            'MenuDuplicate' => '_Дублювати фільм',
-            'MenuEditDeleteCurrent' => '_Усунути фільм',
+            'MenuDuplicate' => '_Дублювати фільм', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate Items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All Items', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_Усунути фільм', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove Items', # Accepts model codes  
             'MenuEditFields' => '_Змінити поля колекції',
             'MenuEditLockItems' => 'За_блокувати колекцію',
     
@@ -113,7 +134,7 @@
                 'MenuSavedSearchesSave' => 'Save current search',
                 'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => '_Розширений пошук',
-            'MenuViewAllItems' => 'Показати _всі записи',
+            'MenuViewAllItems' => 'Показати _всі записи', # Accepts model codes
             'MenuNoFilter' => '_Усі',
     
         'MenuConfiguration' => '_Параметри',
@@ -132,7 +153,8 @@
             'MenuBugReport' => '_Надіслати звіт про помилку',
             'MenuAbout' => '_Про GCstar',
     
-        'MenuNewWindow' => 'Показати запис у _новому вікні',
+        'MenuNewWindow' => 'Показати запис у _новому вікні', # Accepts model codes
+        'MenuNewWindowPlural' => 'Show Items in _New Window', # Accepts model codes
         
         'ContextExpandAll' => 'Розгорнути усі',
         'ContextCollapseAll' => 'Згорнути усі',
@@ -141,22 +163,24 @@
         'ContextImageEditor' => 'Image Editor',
         'ContextImgFront' => 'Front',
         'ContextImgBack' => 'Back',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
         
         'DialogEnterNumber' => 'Будь ласка, введіть значення',
 
-        'RemoveConfirm' => 'Ви дійсно хочете усунути цей запис?',
-        'DefaultNewItem' => 'Новий запис',
-        'NewItemTooltip' => 'Додати новий запис',
+        'RemoveConfirm' => 'Ви дійсно хочете усунути цей запис?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+        'DefaultNewItem' => 'Новий запис', # Accepts model codes
+        'NewItemTooltip' => 'Додати новий запис', # Accepts model codes
         'NoItemFound' => 'Нічого не знайдено. Ви хочете шукати на іншому сайті?',
         'OpenList' => 'Будь ласка, оберіть колекцію',
         'SaveList' => 'Будь ласка, виберіть куди зберегти колекцію',
         'SaveListTooltip' => 'Зберегти поточну колекцію',
-        'SaveCurrentList' => 'Спочатку оберіть куди зберегти поточну колекцію',
         'SaveUnsavedChanges' => 'Є незбережені зміни у вашій колекції. Ви хочете їх зберегти?',
         'SaveDontSave' => 'Не зберігати',
         'PreferencesTooltip' => 'Налаштуйте ваші уподобання',
         'ViewTooltip' => 'Змініть показ колекції',
-        'PlayTooltip' => 'Програвати відео, зв\'язане з записом',
+        'PlayTooltip' => 'Програвати відео, зв\'язане з записом', # Accepts model codes
         'PlayFileNotFound' => 'File to launch was not found in this location:',
         'PlayRetry' => 'Retry',
 
@@ -179,8 +203,8 @@
         'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'Що подивитись сьогодні ввечері ?',
-        'RandomError'=> 'У вас немає вибраних записів',
-        'RandomEnd'=> 'Немає більше записів',
+        'RandomError'=> 'У вас немає вибраних записів', # Accepts model codes
+        'RandomEnd'=> 'Немає більше записів', # Accepts model codes
         'RandomNextTip'=> 'Наступна пропозиція',
         'RandomOkTip'=> 'Прийняти цей запис',
         
@@ -197,7 +221,8 @@ Adolfo González : програміст
 Права на логотипи належать le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Український переклад виконав Ailandar',
-        'AboutDesign' => 'Логотип та вебдизайн le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Логотип та вебдизайн le Spektre',
 
         'ToolbarRandom' => 'Цього вечора',
 
@@ -247,6 +272,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Аудіо',
         'ModelFieldFileProgram' => 'Програма',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Використовувати поля',
         'ModelOptionsFieldsAuto' => 'Автоматично',
         'ModelOptionsFieldsNone' => 'Ніяк',
@@ -275,10 +301,10 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'Значення можуть використовуватись як числа при порівнянні',
         'ModelTooltipQuick' => 'Це додає підменю у меню Фільтри',
         
-        'ResultsTitle' => 'Виберіть об\'єкт',
+        'ResultsTitle' => 'Виберіть об\'єкт', # Accepts model codes
         'ResultsNextTip' => 'Шукати на наступному сайті',
         'ResultsPreview' => 'Попередній перегляд',
-        'ResultsInfo' => 'Ви можете додавати декілька записів до колекції утримуючи клавішу Ctrl або Shift та вибираючи записи',
+        'ResultsInfo' => 'Ви можете додавати декілька записів до колекції утримуючи клавішу Ctrl або Shift та вибираючи записи', # Accepts model codes
         
         'OptionsTitle' => 'Параметри',
         'OptionsExpertMode' => 'Expert Mode',
@@ -427,6 +453,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Directory',
         'FileChooserOpenDirectory' => 'Оберіть теку',
         'FileChooserOverwrite' => 'Це поле уже існує. Ви хочете його переписати?',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
         #Some default panels
         'PanelCompact' => 'Компактний',
@@ -445,14 +476,17 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Вибрати зображення',
         'PanelImageNoImage' => 'Немає зображення',
         'PanelSelectFileTitle' => 'Оберіть файл',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Відновити типову',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Update information from web',
 
         'PanelFrom' =>'Від',
         'PanelTo' =>'До',
 
         'PanelWeb' => 'Перегляд інформації',
-        'PanelWebTip' => 'Перегляд інформації в інтернеті про даний запис',
-        'PanelRemoveTip' => 'Усунути поточний запис',
+        'PanelWebTip' => 'Перегляд інформації в інтернеті про даний запис', # Accepts model codes
+        'PanelRemoveTip' => 'Усунути поточний запис', # Accepts model codes
 
         'PanelDateSelect' => 'Обрати',
         'PanelNobody' => 'Ніхто',
@@ -466,7 +500,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Боржник',
         'PanelLendDate' => 'Позичив',
         'PanelHistory' => 'Історія позичок',
-        'PanelReturned' => 'Річ повернута',
+        'PanelReturned' => 'Річ повернута', # Accepts model codes
         'PanelReturnDate' => 'Дата повернення',
         'PanelLendedYes' => 'Позичено',
         'PanelLendedNo' => 'Доступно',
@@ -499,6 +533,8 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Автор',
         'PluginsLang' => 'Мова',
         'PluginsUseSite' => 'Використовувати поточний сайт для майбутніх пошуків',
+        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+        'PluginDisabled' => 'Disabled',
 
         'BorrowersTitle' => 'Налаштування боржників',
         'BorrowersList' => 'Боржники',
@@ -517,9 +553,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'Формат файлу:',
         'BorrowersImportFile' => 'Файл:',
 
-        'BorrowedTitle' => 'Позичені речі',
+        'BorrowedTitle' => 'Позичені речі', # Accepts model codes
         'BorrowedDate' => 'З',
-        'BorrowedDisplayInPanel' => 'Show item in main window',
+        'BorrowedDisplayInPanel' => 'Show item in main window', # Accepts model codes
 
         'MailTitle' => 'Надіслати e-mail',
         'MailFrom' => 'Від: ',
@@ -528,8 +564,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Проблема підключення до SMTP сервера',
         'MailSendmailError' => 'Проблема запуску sendmail',
 
-        'SearchTooltip' => 'Шукати всі записи',
-        'SearchTitle' => 'Пошук запису',
+        'SearchTooltip' => 'Шукати всі записи', # Accepts model codes
+        'SearchTitle' => 'Пошук запису', # Accepts model codes
         'SearchNoField' => 'No field have been selected for the search box.
 Add some of them in the Filters tab of the collection settings.',
 
@@ -568,7 +604,7 @@ Add some of them in the Filters tab of the collection settings.',
         'PropertiesDescription' => 'Опис',
         'PropertiesFile' => 'Інформація про файл',
         'PropertiesFilePath' => 'Повний шлях',
-        'PropertiesItemsNumber' => 'Кількість записів',
+        'PropertiesItemsNumber' => 'Кількість записів', # Accepts model codes
         'PropertiesFileSize' => 'Розмір',
         'PropertiesFileSizeSymbols' => ['Байтів', 'Кб', 'Мб', 'Гб', 'Тб', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Властивості колекції',
@@ -592,8 +628,8 @@ Add some of them in the Filters tab of the collection settings.',
         'BookmarksNewFolder' => 'Нова тека',
 
         'AdvancedSearchType' => 'Тип пошуку',
-        'AdvancedSearchTypeAnd' => 'Записи, що відповідають всім критеріям',
-        'AdvancedSearchTypeOr' => 'Записи, що відповідають хоча б одному критерію',
+        'AdvancedSearchTypeAnd' => 'Записи, що відповідають всім критеріям', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Записи, що відповідають хоча б одному критерію', # Accepts model codes
         'AdvancedSearchCriteria' => 'Критерій',
         'AdvancedSearchAnyField' => 'Будь-яке поле',
         'AdvancedSearchSaveTitle' => 'Save search',
@@ -607,6 +643,24 @@ Add some of them in the Filters tab of the collection settings.',
         'BugReportPlatform' => 'Операційна система',
         'BugReportMessage' => 'Повідомлення про помилку',
         'BugReportInformation' => 'Додаткова інформація',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
     );
 }
 1;
