@@ -2,7 +2,7 @@ package GCMenu;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -31,6 +31,7 @@ use strict;
 
     use GCExport;
     use GCImport;
+    use GCStats;
 
     sub addHistoryMenu
     {
@@ -122,7 +123,49 @@ use strict;
         $self->{model} = $model;
         $self->createFilters($model,
                              $model->{fieldsInfo});
-        $self->initExportList($model);
+        $self->initExportImportList($model);
+        
+        # Update menu labels which are collection dependant
+        $self->updateMenus;
+
+    }
+    
+    sub updateItem
+    {
+        my ($self, $item, $label) = @_;
+        foreach my $child($item->get_children)
+        {
+            if ($child->isa('Gtk2::Label'))
+            {
+                $child->set_label($self->{parent}->{lang}->{$label});
+            }
+        }
+    }
+
+    sub updateMenus
+    {
+        my ($self) = @_;
+        
+        # Update labels which are collection dependant
+	# list for each item is: [parent, item name, label index in language]
+        foreach (
+                 # Menu labels
+                 [$self, 'viewAllItems', 'MenuViewAllItems'],
+                 [$self, 'menuLend', 'MenuLend'],
+                 [$self, 'duplicateItem', 'MenuDuplicate'],
+                 [$self, 'newitem', 'MenuAddItem'],
+                 [$self, 'deleteCurrentItem', 'MenuEditDeleteCurrent'],
+                 [$self, 'selectAllItem', 'MenuEditSelectAllItems'],
+                 # Context menu labels
+                 [$self->{parent}, 'contextNewWindow', 'MenuNewWindow'],
+                 [$self->{parent}, 'contextDuplicateItem', 'MenuDuplicate'],
+                 [$self->{parent}, 'contextSelectAllItem', 'MenuEditSelectAllItems'],
+                 [$self->{parent}, 'contextItemDelete', 'MenuEditDeleteCurrent'],
+                 [$self->{parent}, 'contextViewAllItems', 'MenuViewAllItems'],
+                )
+	{
+	    $self->updateItem($_->[0]->{$_->[1]}, $_->[2]);
+	}
     }
 
     sub initFilters
@@ -198,12 +241,13 @@ use strict;
         $self->unblock;
     }
     
-    sub initExportList
+    sub initExportImportList
     {
         my ($self, $model) = @_;
         
         my $modelName = $model->getName;
-        #It will hide the export modules that don't support current model
+        #It will hide the export/import modules that don't support current model
+        # This code may be factorized.
         foreach my $exporter(@GCExport::exportersArray)
         {
             my $item = $self->{exporters}->{$exporter->getName};
@@ -218,6 +262,20 @@ use strict;
             $item->hide if !$show;
             $item->show if $show;
         }
+        foreach my $importer(@GCImport::importersArray)
+        {
+            my $item = $self->{importers}->{$importer->getName};
+            my @models = @{$importer->getModels};
+            my $show = 0;
+            $show = 1 if (!$importer->shouldBeHidden || !@models);
+            foreach (@models)
+            {
+                $show = 1 if $modelName eq $_;
+                last if $show;
+            }
+            $item->hide if !$show;
+            $item->show if $show;
+        }
     }
     
     sub createFilters
@@ -433,7 +491,7 @@ use strict;
         });
         $self->{userFiltersMenu}->append($editUserFilter);
 
-            $self->{userFiltersItem}->show_all;
+        $self->{userFiltersItem}->show_all;
         $self->{menuDisplay}->show_all;
     }
 
@@ -581,12 +639,12 @@ use strict;
         $self->{menuFile}->append(Gtk2::SeparatorMenuItem->new);
         ############################
 
-        my $newitem = Gtk2::ImageMenuItem->new_from_stock('gtk-add');
-        $newitem->set_accel_path('<main>/File/gtk-add');
-        $newitem->signal_connect ('activate' => sub {
-            $self->{parent}->newItem;
+        $self->{newitem} = Gtk2::ImageMenuItem->new_from_stock('gtk-add');
+        $self->{newitem}->set_accel_path('<main>/File/gtk-add');
+        $self->{newitem}->signal_connect ('activate' => sub { 
+                   $self->{parent}->newItem;
         });
-        $self->{menuFile}->append($newitem);
+        $self->{menuFile}->append($self->{newitem});
 
         my $properties = Gtk2::ImageMenuItem->new_from_stock('gtk-properties');
         $properties->set_accel_path('<main>/File/gtk-properties');
@@ -595,12 +653,22 @@ use strict;
         });
         $self->{menuFile}->append($properties);
 
-        my $lend = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuLend});
-        $lend->set_accel_path('<main>/File/Borrowers');
-        $lend->signal_connect ('activate' => sub {
-            $self->{parent}->showBorrowed;
+        if ($GCStats::statisticsActivated)
+        {
+            my $statistics = Gtk2::ImageMenuItem->new_with_mnemonic($parent->{lang}->{MenuStats});
+            $statistics->set_accel_path('<main>/File/Stats');
+            $statistics->signal_connect ('activate' => sub {
+                $self->{parent}->stats;
+            });
+            $self->{menuFile}->append($statistics);
+        }
+
+        $self->{menuLend} = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuLend});
+        $self->{menuLend}->set_accel_path('<main>/File/Borrowers');
+        $self->{menuLend}->signal_connect ('activate' => sub {
+             $self->{parent}->showBorrowed;
         });
-        $self->{menuFile}->append($lend);
+        $self->{menuFile}->append($self->{menuLend});
 
         $self->{menuFile}->append(Gtk2::SeparatorMenuItem->new);
         ############################
@@ -619,7 +687,7 @@ use strict;
         $self->{menuImport} = Gtk2::Menu->new;
         $self->{menuImport}->set_accel_path('<main>/Import');
         $self->{menuImport}->set_accel_group($self->{accel});
-        my %importItems;
+        $self->{importers} = {};
         my $langName = $parent->{options}->lang;
         foreach my $importer(@GCImport::importersArray)
         {
@@ -629,11 +697,11 @@ use strict;
             $item->signal_connect ('activate' => sub {
                 $self->{parent}->import($importer);
             });
-            $importItems{$name} = $item;
+            $self->{importers}->{$name} = $item;
         }
-        foreach my $importerName(sort keys %importItems)
+        foreach my $importerName(sort keys %{$self->{importers}})
         {
-            $self->{menuImport}->append($importItems{$importerName});
+            $self->{menuImport}->append($self->{importers}->{$importerName});
         }        
         $importItem->set_submenu($self->{menuImport});
         $self->{menuFile}->append($importItem);        
@@ -687,26 +755,26 @@ use strict;
             $self->{menuEdit}->append($eto);
         }
 
-        my $duplicateItem = Gtk2::ImageMenuItem->new_from_stock('gtk-dnd');
-        $duplicateItem->set_accel_path('<main>/Edit/gtk-dnd');
-        $duplicateItem->signal_connect('activate' , sub {
+        $self->{duplicateItem} = Gtk2::ImageMenuItem->new_from_stock('gtk-dnd');
+        $self->{duplicateItem}->set_accel_path('<main>/Edit/gtk-dnd');
+        $self->{duplicateItem}->signal_connect('activate' , sub {
             $self->{parent}->duplicateItem;
         });
-        $self->{menuEdit}->append($duplicateItem);
+        $self->{menuEdit}->append($self->{duplicateItem});
 
-        my $selectAllItem = Gtk2::ImageMenuItem->new_from_stock('gtk-select-all');
-        $selectAllItem->set_accel_path('<main>/Edit/gtk-select-all');
-        $selectAllItem->signal_connect('activate' , sub {
+        $self->{selectAllItem} = Gtk2::ImageMenuItem->new_from_stock('gtk-select-all');
+        $self->{selectAllItem}->set_accel_path('<main>/Edit/gtk-select-all');
+        $self->{selectAllItem}->signal_connect('activate' , sub {
             $self->{parent}->selectAll;
         });
-        $self->{menuEdit}->append($selectAllItem);
+        $self->{menuEdit}->append($self->{selectAllItem});
 
-        my $deleteCurrentItem = Gtk2::ImageMenuItem->new_from_stock('gtk-delete');
-        $deleteCurrentItem->set_accel_path('<main>/Edit/gtk-delete');
-        $deleteCurrentItem->signal_connect('activate' , sub {
+        $self->{deleteCurrentItem} = Gtk2::ImageMenuItem->new_from_stock('gtk-delete');
+        $self->{deleteCurrentItem}->set_accel_path('<main>/Edit/gtk-delete');
+        $self->{deleteCurrentItem}->signal_connect('activate' , sub {
             $self->{parent}->deleteCurrentItem;
         });
-        $self->{menuEdit}->append($deleteCurrentItem);
+        $self->{menuEdit}->append($self->{deleteCurrentItem});
 
         $self->{menuEdit}->append(Gtk2::SeparatorMenuItem->new);
         ############################
@@ -791,14 +859,14 @@ use strict;
         $self->{menuDisplay}->append(new Gtk2::SeparatorMenuItem);
         ############################
 
-        my $viewAllItems = Gtk2::ImageMenuItem->new_with_mnemonic($parent->{lang}->{MenuViewAllItems});
-        $viewAllItems->set_accel_path('<main>/Display/All');
+        $self->{'viewAllItems'} = Gtk2::ImageMenuItem->new_with_mnemonic($parent->{lang}->{MenuViewAllItems});
+        $self->{'viewAllItems'}->set_accel_path('<main>/Display/All');
         my $refreshImage = Gtk2::Image->new_from_stock('gtk-refresh', 'menu');
-        $viewAllItems->set_image($refreshImage);
-        $viewAllItems->signal_connect('activate' , sub {
+        $self->{'viewAllItems'}->set_image($refreshImage);
+        $self->{'viewAllItems'}->signal_connect('activate' , sub {
                 $self->selectAll
         });
-        $self->{menuDisplay}->append($viewAllItems);
+        $self->{menuDisplay}->append($self->{'viewAllItems'});
 
         $self->{displayItem} = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuDisplay});
         $self->{displayItem}->set_submenu($self->{menuDisplay});
@@ -1422,6 +1490,35 @@ use strict;
 
         $self->createUserFilters($model);
 
+        # Update tooltip text
+        $self->{parent}->{tooltips}->set_tip($self->{controls}->{'gtk-add'},
+                                             $self->{lang}->{NewItemTooltip})
+	    if $self->{controls}->{'gtk-add'};
+        $self->{parent}->{tooltips}->set_tip($self->{controls}->{'gtk-find'},
+                                             $self->{lang}->{SearchTooltip})
+	    if $self->{controls}->{'gtk-find'};
+        $self->{parent}->{tooltips}->set_tip($self->{controls}->{'gtk-refresh'},
+                                             $self->{lang}->{ToolbarAllTooltip})
+	    if $self->{controls}->{'gtk-refresh'};
+        
+        # Update add button text
+        my $addText = $self->{lang}->{MenuAddItem};
+        $addText =~ s/\_//g;
+        my $widget = $self->{controls}->{'gtk-add'}->get_children;
+        while ($widget)
+        {
+            if ($widget->isa(Gtk2::Label::))
+            {
+                $widget->set_text($addText);
+                last;
+            }
+            elsif ($widget->isa(Gtk2::Image::))
+            {
+                last;
+            }
+            $widget = $widget->get_children;
+        }
+
         # Hide tonight button if needed
         if ($self->{controls}->{'gtk-execute'})
         {
@@ -1433,6 +1530,9 @@ use strict;
         if ($self->{controls}->{'gtk-media-play'})
         {
             $self->{controls}->{'gtk-media-play'}->show;
+            # Update button tooltip
+            $self->{parent}->{tooltips}->set_tip($self->{controls}->{'gtk-media-play'},
+                                                 $self->{lang}->{PlayTooltip});
             $self->{controls}->{'gtk-media-play'}->hide if !$model->hasPlay;
         }
 
@@ -1613,7 +1713,8 @@ use strict;
             if ($id =~ /^gtk-/)
             {
                 my $stockItem = Gtk2::Stock->lookup($id);
-                (my $label = $stockItem->{label}) =~ s/_//g;
+                # Make sure string has model dependant parts translated:
+                (my $label = $self->{parent}->GCLang::getGenericModelString($stockItem->{label})) =~ s/_//g;
                 my $pixbuf = $self->{parent}->render_icon($id, 'menu');                            
                 push @data, [$pixbuf, $label];
                 $self->{conversionMap}->{$label} = $id if $init;
