@@ -2,7 +2,7 @@ package GCPanel;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -332,15 +332,20 @@ use strict;
     {
         my ($self, $format, $info) = @_;
 
-        my $label;
+        my $label = $format;
+        
+        # Remove from format conditional part using this format:
+        # =field.....=
+        $label =~ s/\=(\w*)([^\=]*)\=/($self->{show}->{$1}) ? $2 : ''/eg;
+        
         # Allow formatting using %fields[format]%
         if ($info)
         {
-            ($label = $format) =~ s/%(.*?)(\[(.*?)\])*%/$3 ? sprintf($3,$info->{$1}) : $info->{$1}/eg;
+            $label =~ s/%(.*?)(\[(.*?)\])*%/$3 ? sprintf($3,$info->{$1}) : $info->{$1}/eg;
         }
         else
         {
-            ($label = $format) =~ s/%(.*?)(\[(.*?)\])*%/$3 ? sprintf($3,$self->{$1}->getValue(1)) : $self->{$1}->getValue(1)/eg;
+            $label =~ s/%(.*?)(\[(.*?)\])*%/$3 ? sprintf($3,$self->{$1}->getValue(1)) : $self->{$1}->getValue(1)/eg;
         }
         if ($label =~ /^=(.*)$/)
         {
@@ -348,6 +353,13 @@ use strict;
         }
 
         $label =~ s/@(.*?)@/$self->{model}->getDisplayedText($1)/eg;
+        
+        # Strings between ^ cannot be on the end or on the beginning.
+        # Typically used for separators
+        $label =~ s/^\^([^\^]*)\^//;
+        $label =~ s/\^([^\^]*)\^$//;
+        $label =~ s/\^//g;
+        
         return $label;
     }
     
@@ -358,9 +370,8 @@ use strict;
         if ($expander->{collapsedTemplate}
         && ($expander->get_expanded xor $init))
         {
-            #$expander->setValue($expander->{originalLabel}.$self->{parent}->{lang}->{Separator}.
-            #                    $self->formatLabel($expander->{collapsedTemplate}));
-            $expander->setValue($expander->{originalLabel}.$self->{parent}->{lang}->{Separator},
+            my $label = $self->formatLabel($expander->{collapsedTemplate});
+            $expander->setValue($expander->{originalLabel}.($label ? $self->{parent}->{lang}->{Separator} : ""),
                                 $self->formatLabel($expander->{collapsedTemplate}));
         }
         else
@@ -464,10 +475,12 @@ use strict;
             }
             else
             {
-                if (($container->get_children) && (!$container->get_homogeneous))
+                my $margin = $self->{halfMargin};
+                $margin = 0 if (exists $info->{nomargin}) && ($info->{nomargin} eq 'true');
+                if (($container->get_children) && (!$container->get_homogeneous) && ($margin > 0))
                 {
                     my $marginBox = new Gtk2::HBox(0,0);
-                    $container->pack_start($marginBox, 0, 0, $self->{halfMargin});
+                    $container->pack_start($marginBox, 0, 0, $margin);
                 }
                 $container->pack_start($widget, $expand, $expand, 0)
                     if ref($widget) ne 'HASH';
@@ -555,9 +568,25 @@ use strict;
             }
             elsif ($_->{type} eq 'launcher')
             {
-                $widget = Gtk2::Button->new_from_stock('gtk-media-play');
                 my $valueWidget = $self->{$_->{for}};
                 my $format = $self->{model}->{fieldsInfo}->{$_->{for}}->{format};
+                
+                # If the launcher is for a video or music file, label the button 'play'
+                if (($format eq 'video') || ($format eq 'audio'))
+                {
+                    $widget = Gtk2::Button->new_from_stock('gtk-media-play');
+                }
+                elsif ($format eq 'program')
+                {
+                    # For program launchers, label the button 'launch'
+                    $widget = Gtk2::Button->new($self->{parent}->{lang}->{PanelLaunch});
+                }
+                else
+                {
+                    # Label the button 'open'
+                    $widget = Gtk2::Button->new_from_stock('gtk-open');
+                }
+                
                 $widget->signal_connect('clicked' => sub {
                     $self->{parent}->launch($valueWidget->getValue, $format);
                 });
@@ -676,6 +705,11 @@ use strict;
                 $widget->set_border_width($_->{border});
             }
             
+            if (exists $_->{collapse})
+            {
+                $widget->{collapse} = $_->{collapse};            
+            }
+            
             if ($isContainer)
             {
                 $self->createLayout($_, $box, $widget, $noTab);
@@ -1024,11 +1058,22 @@ use strict;
                 if ($self->{displayedValues}->{$name});
             if ($self->{$name})
             {
+                # Hide collapsible fields if the field is empty
+                if (($text !~ m/\S+/) && ($self->{$name}->{collapse}))
+                {
+                    $self->{$name}->hide;
+                }
+                else
+                {
+                    # Otherwise, make sure the field is shown
+                    $self->{$name}->show;                    
+                }
+            
                 if ($self->{$name}->acceptMarkup)
                 {
                     $self->{$name}->setMarkup("<span ".
                                               $self->{styles}->{$self->{style}->{$name}}->{style}.
-                                              ">".$self->{$name}->cleanMarkup($text).'</span>');
+                                              ">".$self->{$name}->cleanMarkup($text, 1).'</span>');
                 }
                 else
                 {
@@ -1092,6 +1137,13 @@ use strict;
         $self->{deleteButton}->signal_connect("clicked" => \&deleteItem, $self);
         $self->{tooltips}->set_tip($self->{deleteButton}, $self->{parent}->{lang}->{PanelRemoveTip}, '');
         push @{$self->{toDestroy}}, $self->{deleteButton};
+        
+        $self->{refreshButton} = new GCButton($self->{parent}->{lang}->{PanelRefresh});
+        $self->{refreshButton}->signal_connect("clicked" =>  sub {
+            $self->searchItem('refresh');
+            });
+        $self->{tooltips}->set_tip($self->{refreshButton}, $self->{parent}->{lang}->{PanelRefreshTip}, '');
+        push @{$self->{toDestroy}}, $self->{refreshButton};
     }
 
     sub new
@@ -1139,9 +1191,15 @@ use strict;
         my ($self, $pluginType) = @_;
 
         #$self->{parent}->searchItemForPanel($self->{$self->{model}->{commonFields}->{title}}->getValue, $self);
-        $self->{parent}->searchItemForPanel($self, $pluginType);
-
-        $self->showMe;
+        if ($pluginType eq 'refresh')
+        {
+            $self->{parent}->refreshItemForPanel($self, $self->{$self->{model}->{commonFields}->{url}}->getValue);
+        } 
+        else
+        {
+            $self->{parent}->searchItemForPanel($self, $pluginType);
+            $self->showMe;
+        }
     }
 
     sub checkBorrowerButtons
@@ -1219,6 +1277,7 @@ use strict;
         $self->{searchButton}->lock($locked);
         $self->checkBorrowerButtons;
         $self->{deleteButton}->lock($locked);
+        $self->{refreshButton}->lock($locked);
     }
     
     sub setShowOptionForSpecials
@@ -1417,7 +1476,7 @@ use strict;
         }
         elsif ($info->{type} eq 'file')
         {
-            $widget = new GCFile($self);
+            $widget = new GCFile($self, undef, undef, undef, undef, 1, $info->{format});
         }
         elsif ($info->{type} eq 'date')
         {
