@@ -3,7 +3,7 @@
     
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -233,7 +233,8 @@ sub loadAllPlugins
             $self->{pluginsList} = new Gtk2::SimpleList($parent->{lang}->{PluginsName} => "text",
                                                         $parent->{lang}->{PluginsLang} => "text",
                                                         $parent->{lang}->{PluginsSearchFields} => "text",
-                                                        $parent->{lang}->{PluginsAuthor} => "text",);
+                                                        $parent->{lang}->{PluginsAuthor} => "text",
+                                                        $parent->{lang}->{PluginsPreferred} => "pixbuf",);
             $self->{pluginsList}->set_border_width(5);
             $self->{pluginsList}->set_rules_hint(1);
             $self->{pluginsList}->get_column(0)->set_min_width(150);
@@ -245,6 +246,34 @@ sub loadAllPlugins
                 $self->response('ok');
             });
 
+            # Setup tooltips for list control
+            $self->{pluginsList}->set_has_tooltip(1);
+            $self->{pluginsList}->signal_connect (query_tooltip => sub {
+                my ($widget, $x, $y, $keyboard_mode, $tooltip) = @_;
+
+                # Place the tooltip in the right position
+                my $path = $self->{pluginsList}->get_path_at_pos ($x, $y);
+                return 0 unless $path;
+                $self->{pluginsList}->set_tooltip_row($tooltip, $path);
+
+                # If row is for a preferred plugin, set the tooltip
+                my $index = ($path->get_indices)[0];
+                if (${ $self->{pluginsList}->{data} }[$index][4]  == $self->{starPixbuf})
+                {
+                    $tooltip->set_text($parent->{lang}->{PluginsPreferredTooltip});
+                    return 1;
+                }
+                else
+                {
+                    return 0;
+                }
+            });
+
+            # Pixbufs for preferred and standard plugins
+            $self->{starPixbuf} = Gtk2::Gdk::Pixbuf->new_from_file($ENV{GCS_SHARE_DIR}.'/icons/star.png');
+            $self->{blankPixbuf} = Gtk2::Gdk::Pixbuf->new ('rgb', 1, 8, 1, 1);
+            $self->{blankPixbuf}->fill(0x00000000);
+
             $self->{currentPluginList} = undef;
 
             #$self->setModel;
@@ -348,13 +377,30 @@ sub loadAllPlugins
                     my $plugin = $model->getPlugin($_);
                     if ((!$list) || ($plugin->getName eq $plugins_array[$i]))
                     {
+                        # Add plugin to list
+                        # Plugin should be marked as a default if it's both preferred, and for the user's language,
+                        # or if isPreferred is 2 (not language dependant)
                         push @newData, [$plugin->getName, "\n".$plugin->getLang."\n",
-                                        $plugin->getSearchFields($model), $plugin->getAuthor];
+                                        $plugin->getSearchFields($model), $plugin->getAuthor,
+                                        ((($plugin->isPreferred == 1)
+                                            && ($self->{parent}->{options}->lang eq $plugin->getLang))
+                                            || ($plugin->isPreferred == 2))
+                                            ? $self->{starPixbuf} : $self->{blankPixbuf}];
+
                         $i++;
                     }
                 }
             }
-            @{$self->{pluginsList}->{data}} = @newData;
+
+            # Sort list with preferred plugins first
+            @{$self->{pluginsList}->{data}} = sort {
+                if (($a->[4] == $self->{starPixbuf}) && ($b->[4] == $self->{starPixbuf}))
+                    { return lc($a->[0]) cmp lc($b->[0]); }
+                elsif ($a->[4] == $self->{starPixbuf}) { return -1; } 
+                elsif ($b->[4] == $self->{starPixbuf}) { return 1; } 
+                else { return lc($a->[0]) cmp lc($b->[0]); }
+                }  @newData;
+
             $self->{pluginsList}->select(0);
         }
     }
@@ -388,7 +434,7 @@ sub loadAllPlugins
             $self->{parent} = $parent;
             $self->{factory} = $parent->{modelsFactory};
 
-            my @columnsNames = ('Name', 'Lang', 'SearchFields', 'Author');
+            my @columnsNames = ('Name', 'Lang', 'SearchFields', 'Author', 'Preferred');
             $self->{pluginsModel} = new Gtk2::TreeStore(map {'Glib::String'} @columnsNames);
             $self->{pluginsList} = Gtk2::TreeView->new_with_model($self->{pluginsModel});
 
@@ -492,12 +538,22 @@ sub loadAllPlugins
                     my $plugin = $model->getPlugin($_);
                     if ((!$list) || ($plugin->getName eq $plugins_array[$i]))
                     {
-                        push @newData, [$plugin->getName, "\n".$plugin->getLang."\n", $plugin->getAuthor];
+                        push @newData, [$plugin->getName, "\n".$plugin->getLang."\n", $plugin->getAuthor,
+                                        $plugin->isPreferred ? $self->{starPixbuf} : $self->{blankPixbuf}];
                         $i++;
                     }
                 }
             }
-            @{$self->{pluginsList}->{data}} = @newData;
+
+            # Sort list with preferred plugins first
+            @{$self->{pluginsList}->{data}} = sort {
+                if (($a->[4] == $self->{starPixbuf}) && ($b->[4] == $self->{starPixbuf}))
+                    { return lc($a->[0]) cmp lc($b->[0]); }
+                elsif ($a->[4] == $self->{starPixbuf}) { return -1; } 
+                elsif ($b->[4] == $self->{starPixbuf}) { return 1; } 
+                else { return lc($a->[0]) cmp lc($b->[0]); }
+                }  @newData;
+
             $self->{pluginsList}->select(0);
         }
     }
@@ -1572,12 +1628,12 @@ sub loadAllPlugins
             (my $tmpFile = tmpnam) .= $suffix;
             GCUtils::downloadFile($location, $tmpFile, $self->{parent});
             $self->window->set_cursor(Gtk2::Gdk::Cursor->new('left_ptr'));
-            $self->{parent}->launch($tmpFile, 'image');
+            $self->{parent}->launch($tmpFile, 'image', 0, $self);
             $self->{info}->{$field} = $tmpFile;
         }
         else
         {
-            $self->{parent}->launch($location, 'image');
+            $self->{parent}->launch($location, 'image', 0, $self);
         }
     }
     
