@@ -2,7 +2,7 @@ package GCPlugins::GCTVepisodes::GCTvdbFR;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -48,6 +48,13 @@ use GCPlugins::GCTVepisodes::GCTvdb;
         
         return 'fr';
     }
+    
+    sub siteLanguageCode
+    {
+        my $self = shift;
+        
+        return 17;
+    }
 
 }
 
