@@ -2,7 +2,7 @@ package GCPlugins::GCTVepisodes::GCTvdbIT;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -49,6 +49,12 @@ use GCPlugins::GCTVepisodes::GCTvdb;
         return 'it';
     }
 
+    sub siteLanguageCode
+    {
+        my $self = shift;
+        
+        return 15;
+    }
 }
 
 1;
