@@ -2,7 +2,7 @@ package GCPlugins::GCboardgames::GCboardgamegeek;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -60,11 +60,10 @@ use GCPlugins::GCboardgames::GCboardgamesCommon;
                     $self->{itemsList}[$self->{itemIdx}]->{name} = $xml->{'boardgame'}->{$game}->{'name'};
                  }   
                  
-                 # TODO - wait till bgg fixes their api and then see how yearpublished is supposed to work
-                 # if (!ref($xml->{'boardgame'}->{$game}->{'yearpublished'}))
-                 #{
-                 #     $self->{itemsList}[$self->{itemIdx}]->{released} = $xml->{'boardgame'}->{$game}->{'yearpublished'};
-                 #}
+                 if (!ref($xml->{'boardgame'}->{$game}->{'yearpublished'}))
+                 {
+                      $self->{itemsList}[$self->{itemIdx}]->{released} = $xml->{'boardgame'}->{$game}->{'yearpublished'};
+                 }
             }
         }
         else
@@ -177,12 +176,9 @@ use GCPlugins::GCboardgames::GCboardgamesCommon;
         {
             # Url isn't for the bgg api, so we need to find the game id
             # and return a url corresponding to the api page for this game       
-            my $found = index(reverse($url),"/");
-            if ( $found >= 0 )
-            {
-                my $id = substr(reverse($url), 0, $found);
-                $url = "http://www.boardgamegeek.com/xmlapi/boardgame/".reverse($id);
-            }
+            $url =~ /\/([0-9]+)[\/]*/;
+            my $id = $1;
+            $url = "http://www.boardgamegeek.com/xmlapi/boardgame/".$id;
         }
         return $url;
     }
@@ -202,10 +198,10 @@ use GCPlugins::GCboardgames::GCboardgamesCommon;
     sub getSearchUrl
     {
         my ($self, $word) = @_;
-        # Quick and dirty fixes because the bgg api struggles with some words.
-        $word =~ s/the\+/\+/ig;
-        $word =~ s/\+and+/\+/g;
-        $word =~ s/\+of\+/\+/g;
+        # Quick and dirty fixes because the bgg api struggles with some words. Should not be required anymore (7/6/2010)
+        # $word =~ s/the\+/\+/ig;
+        # $word =~ s/\+and+/\+/g;
+        # $word =~ s/\+of\+/\+/g;
 
         return "http://www.boardgamegeek.com/xmlapi/search?search=$word";
     }
