@@ -55,7 +55,7 @@ use GCPlugins::GCbooks::GCbooksCommon;
             }
             elsif (($tagname eq 'meta') && ($self->{itemIdx} eq '-1') && ($self->{searchField} eq 'isbn'))
             {
-                my $html = $self->loadPage($self->{loadedUrl});
+                my $html = $self->loadPage($self->{loadedUrl}, 0, 1);
                 my $found = index($html,"URL=");
                 if ( $found >= 0 )
                 {
@@ -436,7 +436,7 @@ use GCPlugins::GCbooks::GCbooksCommon;
 	# Attention il y a 2 formats differents pour ce site
         if ($url =~ m/counter_livro.asp/i)
         {
-           my $html = $self->loadPage($url);
+           my $html = $self->loadPage($url, 0, 1);
            my $found = index($html,"URL=");
            if ( $found >= 0 )
            {
