@@ -2,7 +2,7 @@ package GCPlugins::GCbooks::GCbooksAdlibrisCommon;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -35,12 +35,12 @@ use GCPlugins::GCbooks::GCbooksCommon;
     sub start
     {
         my ($self, $tagname, $attr, $attrseq, $origtext) = @_;
-	
+
         $self->{inside}->{$tagname}++;
 
         if ($self->{parsingList})
         {
-            if (     (($tagname eq 'span') && ($attr->{id} eq 'ctl00_main_frame_ctrlproduct_lblProductTitle'))
+            if (     (($tagname eq 'div') && ($attr->{class} eq 'productTitleFormat'))
                   || (($tagname eq 'a') && ($attr->{id} eq 'ctl00_main_frame_ctrlproduct_linkProductTitle'))
                )
             {
@@ -65,31 +65,51 @@ use GCPlugins::GCbooks::GCbooksCommon;
         }
         else
         {
-            if (($tagname eq 'a') && ($attr->{id} eq 'ctl00_main_frame_ctrlproduct_linkProductTitle'))
+            if (($tagname eq 'h1'))
             {
                 $self->{isTitle} = 1 ;
             }
-            elsif (($tagname eq 'span') && ($attr->{id} eq 'ctl00_main_frame_ctrlproduct_lblIsbn13'))
+            elsif (($tagname eq 'li') && ($attr->{id} eq 'ctl00_main_frame_ctrlproduct_liISBN13'))
             {
-                $self->{isISBN} = 1 ;
+                $self->{isbnLevel} = 1 ;
             }
-            elsif (($tagname eq 'a') && ($attr->{id} eq 'ctl00_main_frame_ctrlproduct_rptAuthor_ctl01_Label8'))
+            elsif ($self->{isbnLevel} > 0)
+            {
+                if ($self->{isbnLevel} < 5)
+                {
+                    $self->{isbnLevel}++ ;
+                }
+                else
+                {
+                    $self->{isISBN} = 1 ;
+                    $self->{isbnLevel} = 0 ;
+                }
+            }
+            elsif (($tagname eq 'a') && (($attr->{id} eq 'ctl00_main_frame_ctrlproduct_rptAuthor_ctl00_linkAuthor')) || ($attr->{id} eq 'ctl00_main_frame_ctrlproduct_rptAuthor_ctl01_linkAuthor'))
             {
                 $self->{isAuthor} = 1 ;
             }
-            elsif (($tagname eq 'span') && ($attr->{id} eq 'ctl00_main_frame_ctrlproduct_lblPublisherName'))
+            elsif (($tagname eq 'a') && ($attr->{id} eq 'ctl00_main_frame_ctrlproduct_linkPublisher'))
             {
                 $self->{isPublisher} = 1 ;
             }
-            elsif (($tagname eq 'span') && ($attr->{id} eq 'ctl00_main_frame_ctrlproduct_lblPublishedAndPages'))
+            elsif (($tagname eq 'span') && ($attr->{id} eq 'ctl00_main_frame_ctrlproduct_lblPublished'))
             {
-                $self->{isPublicationAndPages} = 1 ;
+                $self->{isPublication} = 1 ;
             }
-            elsif (($tagname eq 'span') && ($attr->{id} eq 'ctl00_main_frame_ctrlproduct_lblFormatAndLanguage'))
+            elsif (($tagname eq 'span') && ($attr->{id} eq 'ctl00_main_frame_ctrlproduct_lblPages'))
             {
-                $self->{isLangAndReliure} = 1 ;
+                $self->{isPages} = 1 ;
             }
-            elsif (($tagname eq 'span') && ($attr->{id} eq 'ctl00_main_frame_ctrlproduct_lblDescription'))
+            elsif (($tagname eq 'span') && ($attr->{id} eq 'ctl00_main_frame_ctrlproduct_lblLanguage'))
+            {
+                $self->{isLanguage} = 1 ;
+            }
+            elsif (($tagname eq 'span') && ($attr->{id} eq 'ctl00_main_frame_ctrlproduct_lblFormat'))
+            {
+                $self->{isReliure} = 1 ;
+            }
+            elsif (($tagname eq 'div') && ($attr->{class} eq 'productDescription'))
             {
                 $self->{isDescription} = 1 ;
             }
@@ -107,6 +127,12 @@ use GCPlugins::GCbooks::GCbooksCommon;
 
         $self->{isFound} = 0 ;
         $self->{inside}->{$tagname}--;
+        if (($self->{isDescription}) && ($tagname eq 'div'))
+        {
+            $self->{isDescription} = 0;
+            $self->{curInfo}->{description} =~ s/^Beskrivning://g ;
+            $self->{curInfo}->{description} =~ s/^Kuvaus://g ;
+        }
     }
 
     sub text
@@ -151,10 +177,11 @@ use GCPlugins::GCbooks::GCbooksCommon;
                 $self->{isFormat} = 0 ;
             }
         }
-       	else
+        else
         {
             # Enleve les blancs en debut de chaine
             $origtext =~ s/^\s+//;
+            $origtext =~ s/\s+$//;
             if ($self->{isTitle})
             {
                 $self->{curInfo}->{title} = $origtext;
@@ -162,15 +189,14 @@ use GCPlugins::GCbooks::GCbooksCommon;
             }
             elsif ($self->{isAuthor})
             {
-                $self->{curInfo}->{authors} = $origtext;
+                $self->{curInfo}->{authors} .= $origtext;
+                $self->{curInfo}->{authors} .= ",";
                 $self->{isAuthor} = 0 ;
             }
             elsif ($self->{isISBN})
             {
                 $self->{curInfo}->{isbn} = $origtext;
-                $self->{curInfo}->{isbn} =~ s/ISBN13//i;
                 $self->{curInfo}->{isbn} =~ s/\s//g;
-                $self->{curInfo}->{isbn} =~ s/://g;
                 $self->{isISBN} = 0 ;
             }
             elsif ($self->{isPublisher})
@@ -178,37 +204,30 @@ use GCPlugins::GCbooks::GCbooksCommon;
                 $self->{curInfo}->{publisher} = $origtext;
                 $self->{isPublisher} = 0 ;
             }
-            elsif ($self->{isPublicationAndPages})
+            elsif ($self->{isPublication})
             {
-                my @publication_pages = split(/,/,$origtext);
-
-                my @publication = split(/:/,$publication_pages[0]);
-                $self->{curInfo}->{publication} = $publication[1];
-                $self->{curInfo}->{publication} =~ s/\s//g;
-                my @page = split(/:/,$publication_pages[1]);
-                $self->{curInfo}->{pages} = $page[1];
-                $self->{curInfo}->{pages} =~ s/\s//g;
-
-                $self->{isPublicationAndPages} = 0 ;
+                $self->{curInfo}->{publication} = $origtext;
+                $self->{curInfo}->{publication} =~ s/(\d\d\d\d)(\d\d)/01\/$2\/$1/g;
+                $self->{isPublication} = 0 ;
             }
-            elsif ($self->{isLangAndReliure})
+            elsif ($self->{isPages})
             {
-                my @reliure_lang = split(/,/,$origtext);
-
-                my @format = split(/:/,$reliure_lang[0]);
-                $self->{curInfo}->{format} = $format[1];
-                $self->{curInfo}->{format} =~ s/\s//g;
-                $self->{curInfo}->{format} = ucfirst($self->{curInfo}->{format});
-                my @lang = split(/:/,$reliure_lang[1]);
-                $self->{curInfo}->{language} = $lang[1];
-                $self->{curInfo}->{language} =~ s/\s//g;
-
-                $self->{isLangAndReliure} = 0 ;
+                $self->{curInfo}->{pages} = $origtext;
+                $self->{isPages} = 0 ;
+            }
+            elsif ($self->{isLanguage})
+            {
+                $self->{curInfo}->{language} = $origtext;
+                $self->{isLanguage} = 0 ;
+            }
+            elsif ($self->{isReliure})
+            {
+                $self->{curInfo}->{format} = $origtext;
+                $self->{isReliure} = 0 ;
             }
             elsif ($self->{isDescription})
             {
-                $self->{curInfo}->{description} = $origtext;
-                $self->{isDescription} = 0 ;
+                $self->{curInfo}->{description} .= $origtext ;
             }
 
         }
@@ -267,24 +286,24 @@ use GCPlugins::GCbooks::GCbooksCommon;
     
     sub getSearchUrl
     {
-		my ($self, $word) = @_;
-	
+                my ($self, $word) = @_;
+
         if ($self->{searchField} eq 'isbn')
         {
-            return "http://www.adlibris.com/" . $self->{isLang} . "/searchresult.aspx?isbn=" . $word. "&amp;fromProduct=true";
+            return "http://www.adlibris.com/" . $self->{isLang} . "/searchresult.aspx?isbn=" . $word. "&amp%3BfromProduct=true";
         }
         else
         {
-            return "http://www.adlibris.com/" . $self->{isLang} . "/searchresult.aspx?title=" . $word. "&amp;fromProduct=true";
+            return "http://www.adlibris.com/" . $self->{isLang} . "/searchresult.aspx?title=" . $word. "&amp%3BfromProduct=true";
         }
 
     }
     
     sub getItemUrl
     {
-		my ($self, $url) = @_;
-		
-        return $url . "&amp;fromProduct=true";
+                my ($self, $url) = @_;
+
+        return $url;
     }
 
     sub getName
