@@ -2,7 +2,7 @@ package GCPlugins::GCfilms::GCAlapage;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -28,6 +28,7 @@ use utf8;
 use GCPlugins::GCfilms::GCfilmsCommon;
 
 {
+
     package GCPlugins::GCfilms::GCPluginAlapage;
 
     use base qw(GCPlugins::GCfilms::GCfilmsPluginsBase);
@@ -35,7 +36,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     sub start
     {
         my ($self, $tagname, $attr, $attrseq, $origtext) = @_;
-	
+
         $self->{inside}->{$tagname}++;
 
         if ($self->{parsingList})
@@ -46,9 +47,9 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 {
                     my $url = $attr->{href};
                     $self->{isMovie} = 1;
-                    $self->{isInfo} = 1;
+                    $self->{isInfo}  = 1;
                     $self->{itemIdx}++;
-                    $self->{itemsList}[$self->{itemIdx}]->{url} = $url;
+                    $self->{itemsList}[ $self->{itemIdx} ]->{url} = $url;
                 }
             }
             elsif ($tagname eq "div")
@@ -69,12 +70,13 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             {
                 if ($attr->{src} =~ /^\/resize\.php\?ref=([0-9]*)/)
                 {
-                    $self->{curInfo}->{image} = "http://imgdata.echo.fr/disque_l?v$1r.jpg";
+                    $self->{curInfo}->{image} =
+                      "http://imgdata.echo.fr/disque_l?v$1r.jpg";
                 }
             }
             elsif ($tagname eq "span")
             {
-                $self->{insideName} = 1 if $attr->{style} eq "color:#414B55;";
+                $self->{insideName}   = 1 if $attr->{style} eq "color:#414B55;";
                 $self->{insideActors} = 1 if $attr->{class} eq "tx11gris";
             }
             elsif ($tagname eq "div")
@@ -86,8 +88,8 @@ use GCPlugins::GCfilms::GCfilmsCommon;
 
     sub end
     {
-		my ($self, $tagname) = @_;
-		
+        my ($self, $tagname) = @_;
+
         $self->{inside}->{$tagname}--;
 
     }
@@ -97,24 +99,28 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         my ($self, $origtext) = @_;
 
         return if length($origtext) < 2;
-           
+
         if ($self->{parsingList})
         {
             if ($self->{isMovie})
             {
-                $self->{itemsList}[$self->{itemIdx}]->{"title"} = $origtext;
-                $self->{isMovie} = 0;
-                $self->{isInfo} = 1;
+                $self->{itemsList}[ $self->{itemIdx} ]->{"title"} = $origtext;
+                $self->{isMovie}                                  = 0;
+                $self->{isInfo}                                   = 1;
                 return;
             }
             elsif ($self->{isActors})
             {
-                $self->{itemsList}[$self->{itemIdx}]->{"actors"} .= $self->{itemsList}[$self->{itemIdx}]->{"actors"} ? ', ' . $self->capWord($origtext) : $self->capWord($origtext);
+                $self->{itemsList}[ $self->{itemIdx} ]->{"actors"} .=
+                  $self->{itemsList}[ $self->{itemIdx} ]->{"actors"}
+                  ? ', ' . $self->capWord($origtext)
+                  : $self->capWord($origtext);
                 $self->{isActors} = 0;
             }
             elsif ($self->{isDirector})
             {
-                $self->{itemsList}[$self->{itemIdx}]->{"director"} = $self->capWord($origtext);
+                $self->{itemsList}[ $self->{itemIdx} ]->{"director"} =
+                  $self->capWord($origtext);
                 $self->{isDirector} = 0;
             }
 
@@ -130,9 +136,10 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             }
             elsif ($self->{insideActors})
             {
-               	$origtext =~ s/avec : (.*) - (?:[^-]* )?DVD/$1/;
+                $origtext =~ s/avec : (.*) - (?:[^-]* )?DVD/$1/;
                 $origtext =~ s/ - /, /g;
-                $self->{curInfo}->{actors} = $self->capWord($origtext) if !$self->{curInfo}->{actors};
+                $self->{curInfo}->{actors} = $self->capWord($origtext)
+                  if !$self->{curInfo}->{actors};
                 $self->{insideActors} = 0;
             }
             elsif ($self->{insideSynopsis})
@@ -144,15 +151,16 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             elsif ($origtext =~ m/R.*alisateur :/)
             {
                 $origtext =~ s/R.*alisateur(?: :)?(.*)/$1/;
-                $origtext  =~ s/ - /, /g;
-                $self->{curInfo}->{director} = $self->capWord($origtext) if !$self->{curInfo}->{director};
+                $origtext =~ s/ - /, /g;
+                $self->{curInfo}->{director} = $self->capWord($origtext)
+                  if !$self->{curInfo}->{director};
             }
             elsif ($origtext =~ m/Genre :/)
             {
                 $origtext =~ s/Genre :(.*)/$1/;
                 $origtext = $self->capWord($origtext);
-                $origtext  =~ s/ \/ /,/g;
-                $origtext  =~ s/,Video//g;
+                $origtext =~ s/ \/ /,/g;
+                $origtext =~ s/,Video//g;
                 $self->{curInfo}->{genre} = $origtext if !$self->{curInfo}->{genre};
             }
             elsif ($origtext =~ m/Année du film :/)
@@ -166,26 +174,26 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 $self->{curInfo}->{time} = $origtext if !$self->{curInfo}->{time};
             }
         }
-    } 
+    }
 
     sub new
     {
         my $proto = shift;
         my $class = ref($proto) || $proto;
         my $self  = $class->SUPER::new();
-        bless ($self, $class);
+        bless($self, $class);
 
         $self->{hasField} = {
-            title => 1,
-            date => 0,
+            title    => 1,
+            date     => 0,
             director => 1,
-            actors => 1,
+            actors   => 1,
         };
 
-        $self->{isInfo} = 0;
+        $self->{isInfo}  = 0;
         $self->{isMovie} = 0;
-       	$self->{curName} = undef;
-        $self->{curUrl} = undef;
+        $self->{curName} = undef;
+        $self->{curUrl}  = undef;
 
         return $self;
     }
@@ -199,6 +207,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         $html =~ s//\.\.\./g;
         #'
 
+#<<< keep perltidy away from these lines
         $html =~ s/<br>/\[br\]/gi;
         $html =~ s/&nbsp;/ /g;
         $html =~ s/<u>|<\/u>|<b>|<\/b>|<i>|<\/i>//gi;
@@ -206,25 +215,24 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         $html =~ s|<A href="/-/Liste/DVD/mot_real_nomprenom=.*?\?id=[0-9]*&donnee_appel=ALAPAGE" class="roll">([^<]*)</A>|<div class="realisateur">$1</div>|gi;
         $html =~ s|<A href="/-/Liste/DVD/mot_art_nomprenom=.*?\?id=[0-9]*&donnee_appel=ALAPAGE" class="roll">([^<]*)</A>|<div class="acteurs">$1</div>|gi;
         $html =~ s/<A href="http\:\/\/www\.alapage\.com\/-\/Liste\/DVD\/mot_(?:art_nomprenom|real_nomprenom|gen_libelle)=[^\/]*\/\?id=[0-9]*&donnee_appel=ALAPAGE[^"]*?" class="roll">([^<]*)<\/A>/$1/gi;
-        #"
         $html =~ s|<A .*?mot_gen_libelle=.*?>(.*?)</A>|$1|gi;
         $html =~ s/<TD valign="top" class="tx12noir[^"]*">([^<]*)<\/TD>[^<]*<TD>([^<]*)<\/TD>/<td>$1 $2<\/td>/gi;
         $html =~ s/<td class="tx12grisbold" align="center" bgcolor="\#E6E6E8">([^<]*)<\/td>[^<]*<TD width="2"><IMG src="\/turbo\/templates\/img\/pix\.gif" width="2" height="25" border="0" alt=""><\/TD>[^<]*<td class="tx10noir" align="center" bgcolor="\#F4F4F6" colspan="3">([0-9]* mn)<\/td>/<td>$1 $2<\/td>/gi;
-
+#>>>
         return $html;
     }
-    
+
     sub getSearchUrl
     {
-		my ($self, $word) = @_;
-	
+        my ($self, $word) = @_;
+
         return "http://alapage.com/mx/?type=41&tp=L&fulltext=" . $word;
     }
-    
+
     sub getItemUrl
     {
-		my ($self, $url) = @_;
-		
+        my ($self, $url) = @_;
+
         return "http://alapage.com" . $url;
     }
 
@@ -232,12 +240,12 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         return "Alapage.com";
     }
-    
+
     sub getAuthor
     {
         return 'MeV';
     }
-    
+
     sub getLang
     {
         return 'FR';
@@ -246,7 +254,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     sub getCharset
     {
         my $self = shift;
-    
+
         return "ISO-8859-1";
     }
 
