@@ -2,7 +2,7 @@ package GCPlugins::GCfilms::GCAmazon;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -53,47 +53,64 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
                     if $attr->{src} =~ /go-button-search/;
             }
             return if ! $self->{beginParsing};
+            if ($tagname eq 'srtitle')
+            {
+                $self->{isTitle} = 1;
+            }
+            elsif ($tagname eq 'publication')
+            {
+                $self->{isPublication} = 1;
+            }
+            elsif ($tagname eq 'actors')
+            {
+                $self->{isActors} = 1;
+            }            
             if ($tagname eq 'a')
             {
-                if (($self->{isItem} eq 1) && ($self->{isUrl}))
+                my $urlId;
+                if ($urlId = $self->isItemUrl($attr->{href}))
                 {
+                    $self->{isTitle} = 2 if $self->{isTitle} eq '1';
+                    return if $self->{alreadyRetrieved}->{$urlId};
+                    $self->{alreadyRetrieved}->{$urlId} = 1;
+                    $self->{currentRetrieved} = $urlId;
+                    my $url = $attr->{href}; 
                     $self->{itemIdx}++;
-                    $self->{itemsList}[$self->{itemIdx}]->{url} = $attr->{href};
-                    $self->{isUrl} = 0 ;
+                    $self->{itemsList}[$self->{itemIdx}]->{url} = $url;
                 }
             }
-            elsif (($tagname eq 'div') && ($attr->{class} eq 'productTitle'))
-            {
-                $self->{isItem} = 1 ;
-                $self->{isUrl} = 1 ;
-                $self->{isName} = 1 ;
-            }
-            elsif (($tagname eq 'span') && ($attr->{class} eq 'binding'))
-            {
-                $self->{inside}->{actors} = 1;
-            }
-            
         }
         else
         {
-            if ($tagname eq "img")
+            if (($tagname eq "img") && (!$self->{curInfo}->{image}))
             {
-                if ($self->{insideAge})
-                {
-                    $self->{curInfo}->{age} = 18 if ($attr->{alt} eq 'R') || ($attr->{src} =~ m|G/01/detail/r|);
-                    $self->{curInfo}->{age} = 13 if ($attr->{alt} =~ /PG\-13/) || ($attr->{src} =~ m|G/01/detail/pg-13|);
-                    $self->{curInfo}->{age} = 5 if ($attr->{alt} eq 'PG') || ($attr->{src} =~ m|G/01/detail/pg\.|);
-                    $self->{curInfo}->{age} = 2 if ($attr->{alt} eq 'G') || ($attr->{src} =~ m|G/01/detail/g|);
-                    $self->{insideAge} = 0;
-                }
-                if (!$self->{curInfo}->{image})
-                {
-                    $self->{curInfo}->{image} = $self->extractImage($attr);
-                }
+                $self->{curInfo}->{image} = $self->extractImage($attr);
             }
-            elsif ($tagname eq "b")
+            elsif (($tagname eq 'div') && ($attr->{class} eq 'content'))
             {
-            	$self->{insideNameAndDate} = 1 if $attr->{class} eq "asinTitle";
+                $self->{insideContent} = 1;
+            }
+            elsif (($tagname eq 'div') && ($attr->{class} eq 'productDescriptionWrapper'))
+            {
+                $self->{insideSynopsis} = 1
+                    if (!$self->{curInfo}->{synopsis});
+            }
+            elsif (($tagname eq 'div') && ($attr->{class} eq 'emptyClear'))
+            {
+                $self->{insideSynopsis} = 0;
+            }
+            elsif (($tagname eq "span") && ($self->{insideAge}) && ($attr->{class} =~ /medSprite/))
+            {
+                $attr->{class} =~ s/\s*$//;
+                $self->{curInfo}->{age} = 2 if ($attr->{class} =~ m/G$/);
+                $self->{curInfo}->{age} = 5 if ($attr->{class} =~ m/PG$/);
+                $self->{curInfo}->{age} = 13 if ($attr->{class} =~ m/PG13$/);
+                $self->{curInfo}->{age} = 18 if ($attr->{class} =~ m/R$/);
+                $self->{insideAge} = 0;
+            }
+            elsif ($tagname eq "span")
+            {
+            	$self->{insideNameAndDate} = 1 if $attr->{id} eq "btAsinTitle";
             }
         }
     }
@@ -102,6 +119,11 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
     {
         my ($self, $tagname) = @_;
         $self->{inside}->{$tagname}--;
+        if ($tagname eq "li")
+        {
+            $self->{insideActors} = 0;
+            $self->{insideDirector} = 0;
+        }
     }
 
     sub text
@@ -113,23 +135,32 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
         if ($self->{parsingList})
         {
             return if ! $self->{beginParsing};
-            if ($self->{isName} && $self->{inside}->{a})
+            if ($self->{isTitle})
             {
                 $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
-                $self->{isName} = 0;
+                $self->{isTitle} = 0;
+                return;
             }
-            elsif ($self->{inside}->{actors})
+            elsif ($self->{isPublication})
             {
-                $origtext =~ s/^\W*//;
+                $origtext =~ m/([0-9]{4})/;
+                $self->{itemsList}[$self->{itemIdx}]->{date} = $1;
+                $self->{isPublication} = 0;
+                return;
+            }
+            elsif ($self->{isActors})
+            {
+                $origtext =~ s/^\s*//;
+                $origtext =~ s/\s*$//;
                 $self->{itemsList}[$self->{itemIdx}]->{actors} = $origtext
                     if ! $self->{itemsList}[$self->{itemIdx}]->{actors};
-                $self->{inside}->{actors} = 0;
+                $self->{isActors} = 0;
                 return;
             }
         }
        	else
         {
-            $origtext =~ s/\s{2,}//g;
+            $origtext =~ s/\s{2,}/ /g;
 
             if ($self->{insideNameAndDate})
             {
@@ -140,20 +171,23 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
                 }
                 $self->{insideNameAndDate} = 0;
             }
-            elsif ($self->{insideActors})
+            elsif (($self->{insideActors}) && ($origtext !~ /^,/))
             {
                 $origtext =~ s/^\s//;
-                $origtext =~ s/,.$//;
                 $origtext =~ s/\s+,/,/;
-                $self->{curInfo}->{actors} = $origtext;
-                $self->{insideActors} = 0;
+                if ($self->{actorsCounter} < $GCPlugins::GCfilms::GCfilmsCommon::MAX_ACTORS)
+                {
+                    push @{$self->{curInfo}->{actors}}, [$origtext];
+                    $self->{actorsCounter}++;
+                }
             }
-            elsif ($self->{insideDirector})
+            elsif (($self->{insideDirector}) && ($origtext !~ /^,/))
             {
                 $origtext =~ s/^\s//;
                 $origtext =~ s/,.$//;
-                $self->{curInfo}->{director} = $origtext;
-                $self->{insideDirector} = 0;
+                $self->{curInfo}->{director} .= ", "
+                    if $self->{curInfo}->{director};
+                $self->{curInfo}->{director} .= $origtext;
             }
             elsif ($self->{insideTime})
             {
@@ -162,19 +196,24 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
                 $self->{curInfo}->{time} = $origtext;
                 $self->{insideTime} = 0;
             }
-            elsif ($self->{insideSynopsis})
+            elsif ($self->{insideGenre})
             {
-                $self->{curInfo}->{synopsis} = $origtext;
-                $self->{insideSynopsis} = 0;
+                $origtext =~ s/\s*$//;
+                $self->{curInfo}->{genre} = $origtext;
+                $self->{insideGenre} = 0;
+            }
+            elsif (($self->{insideSynopsis}) && ($origtext ne ''))
+            {
+                $self->{curInfo}->{synopsis} .= $origtext;
             }
             elsif ($self->{inside}->{b})
             {
-                $self->{insideActors} = 1 if $origtext =~ /(Starring|Actors):/;
-                $self->{insideDirector} = 1 if $origtext =~ /Directors?:/;
+                $self->{insideActors} = 1 if $origtext =~ /Actors:/;
+                $self->{insideDirector} = 1 if $origtext =~ /Directors:/;
                 $self->{insideTime} = 1 if $origtext =~ /Run Time:/;
-                $self->{insideAge} = 1 if $origtext =~ /Rating/;
-                $self->{insideSynopsis} = 1 if $origtext =~ /Plot Synopsis/;
-            }        
+                $self->{insideGenre} = 1 if $origtext =~ /Genre:/;
+                $self->{insideAge} = 1 if $origtext =~ /Rating:/;
+            }
         }
     } 
 
@@ -184,10 +223,9 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
         my $class = ref($proto) || $proto;
         my $self  = $class->SUPER::new();
         bless ($self, $class);
-
         $self->{hasField} = {
             title => 1,
-            date => 0,
+            date => 1,
             director => 0,
             actors => 1,
         };
@@ -207,6 +245,7 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
         if ($self->{parsingList})
         {
             $self->{isItem} = 0;
+            $html =~ s|~(.*?)<span class="bindingBlock">\(<span class="binding">(.*?)</span>( - .*?[0-9]{4})?\)</span>|<actors>$1</actors><format>$2</format><publication>$3</publication>|gsm;
         }
         else
         {
@@ -219,9 +258,7 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
             $html =~ s|<br ?/?>|\n|gi;
             $html =~ s|<a href="/gp/imdb/[^"]*">(.*?)</a>|$1|gm;
             $html =~ s|<a href="[^"]*search-alias=dvd&field-keywords=[^"]*">(.*?)</a>|$1|gm;
-            #"
         }
-
         $self->{parsingEnded} = 0;
         $self->{alreadyRetrieved} = {};
         $self->{beginParsing} = 0;
