@@ -2,7 +2,7 @@ package GCPlugins::GCfilms::GCAmazonDE;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -55,38 +55,56 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
                     if $attr->{src} =~ /go-button-search/;
             }
             return if ! $self->{beginParsing};
+            return if ! $self->{beginParsing};
+            if ($tagname eq 'srtitle')
+            {
+                $self->{isTitle} = 1;
+            }
+            elsif ($tagname eq 'publication')
+            {
+                $self->{isPublication} = 1;
+            }
+            elsif ($tagname eq 'actors')
+            {
+                $self->{isActors} = 1;
+            }            
             if ($tagname eq 'a')
             {
-                if (($self->{isItem} eq 1) && ($self->{isUrl}))
+                my $urlId;
+                if ($urlId = $self->isItemUrl($attr->{href}))
                 {
+                    $self->{isTitle} = 2 if $self->{isTitle} eq '1';
+                    return if $self->{alreadyRetrieved}->{$urlId};
+                    $self->{alreadyRetrieved}->{$urlId} = 1;
+                    $self->{currentRetrieved} = $urlId;
+                    my $url = $attr->{href}; 
                     $self->{itemIdx}++;
-                    $self->{itemsList}[$self->{itemIdx}]->{url} = $attr->{href};
-                    $self->{isUrl} = 0 ;
+                    $self->{itemsList}[$self->{itemIdx}]->{url} = $url;
                 }
             }
-            elsif (($tagname eq 'div') && ($attr->{class} eq 'productTitle'))
-            {
-                $self->{isItem} = 1 ;
-                $self->{isUrl} = 1 ;
-                $self->{isName} = 1 ;
-            }
-            elsif (($tagname eq 'span') && ($attr->{class} eq 'binding'))
-            {
-                $self->{inside}->{actors} = 1;
-            }
         }
         else
         {
-            if ($tagname eq "img")
+            if (($tagname eq "img") && (!$self->{curInfo}->{image}))
             {
-                if (!$self->{curInfo}->{image})
-                {
-                    $self->{curInfo}->{image} = $self->extractImage($attr);
-                }
+                $self->{curInfo}->{image} = $self->extractImage($attr);
             }
-            elsif ($tagname eq "b")
+            elsif (($tagname eq 'div') && ($attr->{class} eq 'content'))
             {
-            	$self->{insideNameAndDate} = 1 if $attr->{class} eq "sans";
+                $self->{insideContent} = 1;
+            }
+            elsif (($tagname eq 'div') && ($attr->{class} eq 'productDescriptionWrapper'))
+            {
+                $self->{insideSynopsis} = 1
+                    if (!$self->{curInfo}->{synopsis});
+            }
+            elsif (($tagname eq 'div') && ($attr->{class} eq 'emptyClear'))
+            {
+                $self->{insideSynopsis} = 0;
+            }
+            elsif ($tagname eq "span")
+            {
+            	$self->{insideNameAndDate} = 1 if $attr->{id} eq "btAsinTitle";
             }
         }
     }
@@ -96,6 +114,11 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
 		my ($self, $tagname) = @_;
 
         $self->{inside}->{$tagname}--;
+        if ($tagname eq "li")
+        {
+            $self->{insideActors} = 0;
+            $self->{insideDirector} = 0;
+        }
     }
 
     sub text
@@ -109,48 +132,54 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
         if ($self->{parsingList})
         {
             return if ! $self->{beginParsing};
-            if ($self->{isName} && $self->{inside}->{a})
+            if ($self->{isTitle})
             {
                 $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
-                $self->{isName} = 0;
+                $self->{isTitle} = 0;
+                return;
             }
-            elsif ($self->{inside}->{actors})
+            elsif ($self->{isPublication})
             {
-                $origtext =~ s/^\W*//;
+                $origtext =~ m/([0-9]{4})/;
+                $self->{itemsList}[$self->{itemIdx}]->{date} = $1;
+                $self->{isPublication} = 0;
+                return;
+            }
+            elsif ($self->{isActors})
+            {
+                $origtext =~ s/^\s*//;
+                $origtext =~ s/\s*$//;
                 $self->{itemsList}[$self->{itemIdx}]->{actors} = $origtext
                     if ! $self->{itemsList}[$self->{itemIdx}]->{actors};
-                $self->{inside}->{actors} = 0;
+                $self->{isActors} = 0;
                 return;
             }
         }
        	else
         {
             $origtext =~ s/\s{2,}//g;
-
             if ($self->{insideNameAndDate})
             {
                 $self->{curInfo}->{title} = $origtext;
                 $self->{insideNameAndDate} = 0;
             }
-            elsif ($self->{insideActors})
+            elsif (($self->{insideActors}) && ($origtext !~ /^,/))
+            {
+                $origtext =~ s/^\s//;
+                $origtext =~ s/\s+,/,/;
+                if ($self->{actorsCounter} < $GCPlugins::GCfilms::GCfilmsCommon::MAX_ACTORS)
+                {
+                    push @{$self->{curInfo}->{actors}}, [$origtext];
+                    $self->{actorsCounter}++;
+                }
+            }
+            elsif (($self->{insideDirector}) && ($origtext !~ /^,/))
             {
                 $origtext =~ s/^\s//;
                 $origtext =~ s/,.$//;
-                $self->{curInfo}->{actors} = $origtext;
-                $self->{insideActors} = 0;
-            }
-            elsif ($self->{insideAge})
-            {
-                $origtext =~ m/([0-9]{1,2})/;
-                $self->{curInfo}->{age} = $1;
-                $self->{insideAge} = 0;
-            }
-            elsif ($self->{insideDirector})
-            {
-                $origtext =~ s/^\s//;
-                $origtext =~ s/,.$//;
-                $self->{curInfo}->{director} = $origtext;
-                $self->{insideDirector} = 0;
+                $self->{curInfo}->{director} .= ", "
+                    if $self->{curInfo}->{director};
+                $self->{curInfo}->{director} .= $origtext;
             }
             elsif ($self->{insideTime})
             {
@@ -159,18 +188,36 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
                 $self->{curInfo}->{time} = $origtext;
                 $self->{insideTime} = 0;
             }
-            elsif ($self->{insideSynopsis})
+            elsif ($self->{insideDate})
             {
-                $self->{curInfo}->{synopsis} = $origtext;
-                $self->{insideSynopsis} = 0;
+                $origtext =~ s/^\s//;
+                $origtext =~ s/\n//g;
+                $origtext =~ s/\-$//;
+                $self->{curInfo}->{date} = $origtext;
+                $self->{insideDate} = 0;
+            }
+            elsif (($self->{insideSynopsis}) && ($origtext ne ''))
+            {
+                $self->{curInfo}->{synopsis} .= $origtext;
+            }
+            elsif ($self->{insideAudio})
+            {
+                $origtext =~ s/^\s//;
+                $self->{curInfo}->{audio} = $origtext;
+                $self->{insideAudio} = 0;
+            }
+            elsif ($self->{insideSubTitle})
+            {
+                $origtext =~ s/^\s//;
+                $self->{curInfo}->{subt} = $origtext;
+                $self->{insideSubTitle} = 0;
             }
             elsif ($self->{inside}->{b})
             {
                 $self->{insideActors} = 1 if $origtext =~ /Darsteller:/;
                 $self->{insideDirector} = 1 if $origtext =~ /Regisseur\(e\):/;
-                $self->{insideAge} = 1 if $origtext =~ /FSK:/;
+                $self->{insideDate} = 1 if $origtext =~ /Erscheinungstermin:/;
                 $self->{insideTime} = 1 if $origtext =~ /Spieldauer:/;
-                $self->{insideSynopsis} = 1 if $origtext =~ /(VideoWoche|Amazon\.de|Movieman\.de|VideoWoche|VideoMarkt|Kurzbeschreibung)/;
             }        
         }
     } 
@@ -184,7 +231,7 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
 
         $self->{hasField} = {
             title => 1,
-            date => 0,
+            date => 1,
             director => 0,
             actors => 1,
         };
@@ -204,6 +251,8 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
         if ($self->{parsingList})
         {
             $self->{isItem} = 0;
+            $html =~ s|~(.*?)<span class="bindingBlock">\(<span class="binding">(.*?)</span>( - .*?[0-9]{4})?\)</span>|<actors>$1</actors><format>$2</format><publication>$3</publication>|gsm;
+
         }
         else
         {
