@@ -29,6 +29,7 @@ use Encode qw(encode);
 use GCPlugins::GCfilms::GCfilmsCommon;
 
 {
+
     package GCPlugins::GCfilms::GCPluginAnimator;
 
     use base qw(GCPlugins::GCfilms::GCfilmsPluginsBase);
@@ -46,12 +47,12 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 {
                     $self->{isMovie} = 1;
                     $self->{itemIdx}++;
-                    $self->{itemsList}[$self->{itemIdx}]->{url} = $url;
+                    $self->{itemsList}[ $self->{itemIdx} ]->{url} = $url;
                 }
-    	    }
-    	}
-    	else
-    	{
+            }
+        }
+        else
+        {
             if ($tagname eq "td" && $attr->{class} eq "FilmName")
             {
                 $self->{insideTitle} = 1;
@@ -67,12 +68,16 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             }
             elsif ($tagname eq "img")
             {
-                $self->{curInfo}->{image} = $attr->{src} if !$self->{curInfo}->{image} && ($attr->{id} eq "SlideShow" || $attr->{width} =~ m/3\d{2}/);
-                $self->{curInfo}->{image} = "http://www.animator.ru/" . $self->{curInfo}->{image} if $self->{curInfo}->{image} =~ m/^\//;
-                $self->{curInfo}->{image} = "http://www.animator.ru/db/" . $self->{curInfo}->{image} if $self->{curInfo}->{image} =~ m/^\.\.\//;
+                $self->{curInfo}->{image} = $attr->{src}
+                  if !$self->{curInfo}->{image}
+                      && ($attr->{id} eq "SlideShow" || $attr->{width} =~ m/3\d{2}/);
+                $self->{curInfo}->{image} = "http://www.animator.ru/" . $self->{curInfo}->{image}
+                  if $self->{curInfo}->{image} =~ m/^\//;
+                $self->{curInfo}->{image} = "http://www.animator.ru/db/" . $self->{curInfo}->{image}
+                  if $self->{curInfo}->{image} =~ m/^\.\.\//;
                 $self->{insideImage} = 0;
             }
-    	}
+        }
     }
 
     sub text
@@ -86,12 +91,12 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 if ($origtext =~ m/«(.*)»\s\(([0-9]*)\s.+\)/)
                 {
                     ($title, $date) = ($1, $2);
-                    $self->{itemsList}[$self->{itemIdx}]->{title} = $title;
-                    $self->{itemsList}[$self->{itemIdx}]->{date} = $date;
+                    $self->{itemsList}[ $self->{itemIdx} ]->{title} = $title;
+                    $self->{itemsList}[ $self->{itemIdx} ]->{date}  = $date;
                 }
                 else
                 {
-                    $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
+                    $self->{itemsList}[ $self->{itemIdx} ]->{title} = $origtext;
                 }
                 $self->{isMovie} = 0;
                 return;
@@ -99,18 +104,18 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         }
         else
         {
-            utf8::decode ($origtext);
+            utf8::decode($origtext);
             $origtext =~ s/^\s+//;
             $origtext =~ s/\s+$//;
             if ($self->{insideTitle})
             {
                 $origtext =~ s/^\W//;
                 $origtext =~ s/\W$//;
-                $origtext = ucfirst (lc ($origtext));
+                $origtext                 = ucfirst(lc($origtext));
                 $self->{curInfo}->{title} = $origtext;
                 $self->{curInfo}->{genre} = "Мультфильм";
                 $self->{curInfo}->{audio} = "русский";
-                $self->{insideTitle} = 0;
+                $self->{insideTitle}      = 0;
             }
             elsif ($self->{insideDate})
             {
@@ -126,7 +131,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                         $self->{curInfo}->{country} = "Россия";
                     }
                     $self->{insideDate} = 0;
-		        }
+                }
             }
             elsif ($self->{insideDirector})
             {
@@ -135,10 +140,12 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             }
             elsif ($self->{insideSynopsis})
             {
-                $self->{curInfo}->{synopsis} .= $self->{curInfo}->{synopsis} ? "\n" . $origtext : $origtext;
+                $self->{curInfo}->{synopsis} .=
+                  $self->{curInfo}->{synopsis} ? "\n" . $origtext : $origtext;
                 $self->{insideSynopsis} = 0;
             }
-            if ($self->{insideTime}) {
+            if ($self->{insideTime})
+            {
                 if ($origtext =~ m/,\s+([0-9]+)\s+мин/)
                 {
                     $self->{curInfo}->{time} = $1;
@@ -163,20 +170,20 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         my $proto = shift;
         my $class = ref($proto) || $proto;
         my $self  = $class->SUPER::new();
-        bless ($self, $class);
+        bless($self, $class);
 
         $self->{hasField} = {
-            title => 1,
-            date => 1,
+            title    => 1,
+            date     => 1,
             director => 0,
-            actors => 0,
+            actors   => 0,
         };
 
-        $self->{isInfo} = 0;
+        $self->{isInfo}  = 0;
         $self->{isMovie} = 0;
         $self->{curName} = undef;
-        $self->{curUrl} = undef;
-	
+        $self->{curUrl}  = undef;
+
         return $self;
     }
 
@@ -218,7 +225,9 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         my ($self, $html) = @_;
         $self->{parsingEnded} = 0;
-        $html =~ tr/АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя/юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ/;
+        $html =~ tr
+            {АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя}
+            {юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ};
         return $html;
     }
 
