@@ -2,7 +2,7 @@ package GCPlugins::GCfilms::GCAnimeNfoA;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -27,6 +27,7 @@ use strict;
 use GCPlugins::GCfilms::GCfilmsCommon;
 
 {
+
     package GCPlugins::GCfilms::GCPluginAnimeNfoA;
 
     use base qw(GCPlugins::GCfilms::GCfilmsPluginsBase);
@@ -34,7 +35,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     sub start
     {
         my ($self, $tagname, $attr, $attrseq, $origtext) = @_;
-	
+
         $self->{inside}->{$tagname}++;
 
         if ($self->{parsingList})
@@ -44,9 +45,9 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 if ($attr->{href} =~ m/animetitle,[0-9]*,[a-z]*,[a-z0-9_]*\.html/)
                 {
                     $self->{isMovie} = 1;
-              		$self->{isInfo} = 1;
-              		$self->{itemIdx}++;
-              		$self->{itemsList}[$self->{itemIdx}]->{url} = $attr->{href};
+                    $self->{isInfo}  = 1;
+                    $self->{itemIdx}++;
+                    $self->{itemsList}[ $self->{itemIdx} ]->{url} = $attr->{href};
                 }
             }
             elsif ($tagname eq "td")
@@ -85,7 +86,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
 
     sub end
     {
-		my ($self, $tagname) = @_;
+        my ($self, $tagname) = @_;
 
         $self->{inside}->{$tagname}--;
     }
@@ -95,19 +96,19 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         my ($self, $origtext) = @_;
 
         return if (length($origtext) < 2) && ($origtext !~ /\d+$/);
-           
+
         if ($self->{parsingList})
         {
             if ($self->{isMovie})
             {
-                $self->{itemsList}[$self->{itemIdx}]->{"title"} = $origtext;
-                $self->{isMovie} = 0;
-                $self->{isInfo} = 1;
+                $self->{itemsList}[ $self->{itemIdx} ]->{"title"} = $origtext;
+                $self->{isMovie}                                  = 0;
+                $self->{isInfo}                                   = 1;
                 return;
             }
             elsif ($self->{couldBeYear})
             {
-                $self->{itemsList}[$self->{itemIdx}]->{"year"} = $origtext if $origtext =~ m/^[0-9]{4}$/;
+                $self->{itemsList}[ $self->{itemIdx} ]->{date} = $origtext if $origtext =~ m/^[0-9]{4}$/;
                 $self->{couldBeYear} = 0;
                 return;
             }
@@ -136,6 +137,10 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 {
                     $self->{insideDirector} = 1;
                 }
+                elsif ($origtext eq "User Rating")
+                {
+                    $self->{insideRating} = 1;
+                }
                 elsif ($origtext =~ m/Description/)
                 {
                     $self->{insideSynopsis} = 1;
@@ -143,7 +148,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 elsif ($self->{insideName})
                 {
                     $self->{curInfo}->{title} = $origtext;
-                	$self->{insideName} = 0;
+                    $self->{insideName} = 0;
                 }
                 elsif ($self->{insideOrig})
                 {
@@ -158,7 +163,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 }
                 elsif ($self->{insideGenre})
                 {
-                    $self->{curInfo}->{genre} .= $origtext.',';
+                    $self->{curInfo}->{genre} .= $origtext . ',';
                     $self->{insideGenre} = 0;
                 }
                 elsif ($self->{insideDate})
@@ -171,6 +176,12 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                     $self->{curInfo}->{director} = $origtext if $origtext ne "US Distribution";
                     $self->{insideDirector} = 0;
                 }
+                elsif ($self->{insideRating})
+                {
+                    $origtext =~ m|([\d\.]+)/10\.0|;
+                    $self->{curInfo}->{ratingpress} = int ($1 + 0.5);
+                    $self->{insideRating} = 0;
+                }
                 elsif ($self->{insideSynopsis})
                 {
                     $self->{curInfo}->{synopsis} = $origtext if !$self->{curInfo}->{synopsis};
@@ -178,26 +189,26 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 }
             }
         }
-    } 
+    }
 
     sub new
     {
         my $proto = shift;
         my $class = ref($proto) || $proto;
         my $self  = $class->SUPER::new();
-        bless ($self, $class);
+        bless($self, $class);
 
         $self->{hasField} = {
-            title => 1,
-            date => 1,
+            title    => 1,
+            date     => 1,
             director => 0,
-            actors => 0,
+            actors   => 0,
         };
 
-        $self->{isInfo} = 0;
+        $self->{isInfo}  = 0;
         $self->{isMovie} = 0;
         $self->{curName} = undef;
-        $self->{curUrl} = undef;
+        $self->{curUrl}  = undef;
 
         return $self;
     }
@@ -215,18 +226,18 @@ use GCPlugins::GCfilms::GCfilmsCommon;
 
         return $html;
     }
-    
+
     sub getSearchUrl
     {
-		my ($self, $word) = @_;
-	
+        my ($self, $word) = @_;
+
         return "http://www.animenfo.com/search.php?option=keywords&queryin=anime_titles&query=$word";
     }
-    
+
     sub getItemUrl
     {
-		my ($self, $url) = @_;
-		
+        my ($self, $url) = @_;
+
         return 'http://www.animenfo.com/' . $url;
     }
 
@@ -234,12 +245,12 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         return "AnimeNfo Anime";
     }
-    
+
     sub getAuthor
     {
         return 'MeV';
     }
-    
+
     sub getLang
     {
         return 'EN';
