@@ -2,7 +2,7 @@ package GCPlugins::GCfilms::GCAnimeka;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -148,7 +148,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
 			elsif ($self->{isYear})
 			{
                 $origtext =~ s/ : ([0-9]{4}) - [0-9]*\s*[A-Z]*/$1/;
-                $self->{itemsList}[$self->{itemIdx}]->{"year"} = $origtext;
+                $self->{itemsList}[ $self->{itemIdx} ]->{date} = $origtext;
                 $self->{isYear} = 0;
 			}
 			elsif ($self->{inside}->{u})
