@@ -28,6 +28,7 @@ use utf8;
 use GCPlugins::GCfilms::GCfilmsCommon;
 
 {
+
     package GCPlugins::GCfilms::GCPluginBeyazPerde;
 
     use base qw(GCPlugins::GCfilms::GCfilmsPluginsBase);
@@ -42,12 +43,12 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         {
             if ($tagname eq "a")
             {
-                if ($attr->{href} =~ /\/film\// && $attr->{class} eq "turuncucizgisiz_11_px" )
+                if ($attr->{href} =~ /\/film\// && $attr->{class} eq "turuncucizgisiz_11_px")
                 {
                     my $url = $attr->{href};
                     $self->{isMovie} = 1;
                     $self->{itemIdx}++;
-                    $self->{itemsList}[$self->{itemIdx}]->{url} = $url;
+                    $self->{itemsList}[ $self->{itemIdx} ]->{url} = $url;
                 }
             }
         }
@@ -57,26 +58,27 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             {
                 if ($attr->{src} =~ /^\/images\/film\//)
                 {
-                    $self->{curInfo}->{image} = "http://beyazperde.mynet.com".$attr->{src} if ! $self->{curInfo}->{image};
+                    $self->{curInfo}->{image} = "http://beyazperde.mynet.com" . $attr->{src}
+                      if !$self->{curInfo}->{image};
                 }
             }
             elsif ($tagname eq "td")
             {
-                if ( $self->{insideSynopsis} == 1 )
+                if ($self->{insideSynopsis} == 1)
                 {
                     $self->{insideSynopsis} = 2;
                 }
             }
             elsif ($tagname eq "h1")
             {
-                if ($attr->{class} eq "baslik_filmadi31" )
+                if ($attr->{class} eq "baslik_filmadi31")
                 {
                     $self->{insideTitle} = 1;
                 }
             }
             elsif ($tagname eq "h2")
             {
-                if ($attr->{class} eq "baslik_filmadi32" )
+                if ($attr->{class} eq "baslik_filmadi32")
                 {
                     $self->{insideTitle} = 2;
                 }
@@ -86,24 +88,24 @@ use GCPlugins::GCfilms::GCfilmsCommon;
 
     sub end
     {
-		my ($self, $tagname) = @_;
+        my ($self, $tagname) = @_;
 
-		$self->{inside}->{$tagname}--;
+        $self->{inside}->{$tagname}--;
 
         if (!$self->{parsingList})
         {
             if ($tagname eq "table")
             {
-                if( $self->{insideActors} )
+                if ($self->{insideActors})
                 {
-                    $self->{insideActors} = 0;
+                    $self->{insideActors}   = 0;
                     $self->{insideSynopsis} = 1;
                 }
                 $self->{insideTime} = 0;
             }
             elsif ($tagname eq "td")
             {
-                if ( $self->{insideSynopsis} == 2 )
+                if ($self->{insideSynopsis} == 2)
                 {
                     $self->{insideSynopsis} = 0;
                 }
@@ -130,25 +132,26 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             }
             elsif ($self->{isMovie} == 1)
             {
-                $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
+                $self->{itemsList}[ $self->{itemIdx} ]->{title} = $origtext;
             }
             elsif ($self->{isMovie} == 2)
             {
-                $self->{itemsList}[$self->{itemIdx}]->{date} = $1 if $origtext =~ m/\(([0-9]*)\)/;
+                $self->{itemsList}[ $self->{itemIdx} ]->{date} = $1 if $origtext =~ m/\(([0-9]*)\)/;
             }
             elsif ($self->{isMovie} == 5)
             {
-                if($origtext eq "Y:"){
+                if ($origtext eq "Y:")
+                {
                     $self->{isMovie}++;
                 }
             }
             elsif ($self->{isMovie} == 7)
             {
-                $self->{itemsList}[$self->{itemIdx}]->{director} = $origtext;
+                $self->{itemsList}[ $self->{itemIdx} ]->{director} = $origtext;
             }
             elsif ($self->{isMovie} == 9)
             {
-                $self->{itemsList}[$self->{itemIdx}]->{actors} = $origtext;
+                $self->{itemsList}[ $self->{itemIdx} ]->{actors} = $origtext;
                 $self->{isMovie} = -1;
             }
 
@@ -173,27 +176,46 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             }
             elsif ($self->{insideTime})
             {
-                if ($self->{insideTime} == 1){
-                    if($self->{inside}->{a}){
+                if ($self->{insideTime} == 1)
+                {
+                    if ($self->{inside}->{a})
+                    {
                         $self->{curInfo}->{date} = $origtext;
                         $self->{insideTime}++;
                     }
-                } elsif ($self->{insideTime} == 2) {
-                    if($self->{inside}->{a}){
+                }
+                elsif ($self->{insideTime} == 2)
+                {
+                    if ($self->{inside}->{a})
+                    {
                         $self->{curInfo}->{country} = $origtext;
                         $self->{insideTime}++;
                     }
-                } elsif ( $origtext =~ / dk\./) {
+                }
+                elsif ($origtext =~ / dk\./)
+                {
                     $origtext =~ s/.*, (.*) dk\./$1 dk\./;
                     $self->{curInfo}->{time} = $origtext;
                     $self->{insideTime} = 0;
                 }
             }
-            elsif (($self->{insideActors}) && ($self->{inside}->{a}))
+            elsif ($self->{insideActors})
             {
-                $self->{curInfo}->{actors} .= $origtext.', '
-                    if ($self->{actorsCounter} < $GCPlugins::GCfilms::GCfilmsCommon::MAX_ACTORS);
-                $self->{actorsCounter}++;
+                if ($self->{inside}->{a})
+                {
+                    push @{$self->{curInfo}->{actors}}, [$origtext]
+                      if ($self->{actorsCounter} <
+                        $GCPlugins::GCfilms::GCfilmsCommon::MAX_ACTORS);
+                    $self->{actorsCounter}++;
+                }
+                elsif ($self->{inside}->{font} && ($origtext =~ m/\((.*)\)/))
+                {
+                    # As we incremented it above, we have one more chance here to add a role
+                    # Without <= we would skip the role for last actor
+                    push @{$self->{curInfo}->{actors}->[$self->{actorsCounter}-1]}, $1
+                      if ($self->{actorsCounter} <=
+                        $GCPlugins::GCfilms::GCfilmsCommon::MAX_ACTORS);
+                }
             }
             elsif ($self->{insideOtherTitles})
             {
@@ -203,12 +225,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                     $self->{insideOtherTitles} = 0;
                 }
             }
-            elsif ($self->{insideRating})
-            {
-                $origtext =~ s/,/./g;
-                $self->{curInfo}->{rating} = int($origtext + .5);
-                $self->{insideRating} = 0;
-            }
             elsif ($self->{insideTitle} == 1)
             {
                 $self->{curInfo}->{title} = $origtext;
@@ -225,8 +241,14 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 $self->{insideDirector} = 1 if $origtext =~ m/Y\xf6netmen : /;
                 $self->{insideGenre} = 1 if $origtext eq "T\xfcr : ";
                 $self->{insideTime} = 1 if $origtext =~ m/Yapım/;
-                $self->{insideActors} = 1 if $origtext =~ m/Oyuncular/ || $origtext =~ m/Seslendirenler/;
-                $self->{insideRating} = 1 if $origtext =~ m/SinePuan/;
+                $self->{insideActors} = 1
+                  if $origtext =~ m/Oyuncular/ || $origtext =~ m/Seslendirenler/;
+                if ($origtext =~ m{SinePuan:\s+(\d+\,\d+)\s+})
+                {
+                    my $rating = $1;
+                    $rating =~ s/,/./;
+                    $self->{curInfo}->{ratingpress} = int($rating + 0.5);
+                }
             }
 
         }
@@ -237,18 +259,18 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         my $proto = shift;
         my $class = ref($proto) || $proto;
         my $self  = $class->SUPER::new();
-        bless ($self, $class);
+        bless($self, $class);
 
         $self->{hasField} = {
-            title => 1,
-            date => 1,
+            title    => 1,
+            date     => 1,
             director => 1,
-            actors => 1,
+            actors   => 1,
         };
 
         $self->{isMovie} = 0;
         $self->{curName} = undef;
-        $self->{curUrl} = undef;
+        $self->{curUrl}  = undef;
 
         return $self;
     }
@@ -265,6 +287,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
 
         $html =~ s/"&#34;/'"/g;
         $html =~ s/&#34;"/"'/g;
+        $html =~ s/&nbsp;/ /g;
         $html =~ s|</a></b><br>|</a><br>|;
 
         return $html;
@@ -272,18 +295,24 @@ use GCPlugins::GCfilms::GCfilmsCommon;
 
     sub getSearchUrl
     {
-		my ($self, $word) = @_;
-		return "http://beyazperde.mynet.com/arama.asp?kat=film&keyword=$word";
+        my ($self, $word) = @_;
+        return "http://beyazperde.mynet.com/arama.asp?kat=film&keyword=$word";
     }
 
     sub getItemUrl
     {
-		my ($self, $url) = @_;
+        my ($self, $url) = @_;
 
         return $url if $url;
         return 'http://beyazperde.mynet.com/';
     }
 
+    sub convertCharset
+    {
+        my ($self, $value) = @_;
+        return $value;
+    }
+
     sub getName
     {
         return "Beyaz Perde";
@@ -303,7 +332,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         my $self = shift;
 
-        return "Windows-1254";
+        return "utf-8";
     }
 
 }
