@@ -2,7 +2,7 @@ package GCPlugins::GCfilms::GCCulturalia;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -95,7 +95,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 if ($origtext =~ /De ([^\(]*) \(([0-9]{4})\)/)
                 {
                     $self->{itemsList}[$self->{itemIdx}]->{"director"} = $1;
-                    $self->{itemsList}[$self->{itemIdx}]->{"year"} = $2;
+                    $self->{itemsList}[ $self->{itemIdx} ]->{"date"}     = $2;
                     $self->{isMovie} = 0;
                     $self->{isInfo} = 1;
                 }
@@ -189,10 +189,12 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         my ($self, $html) = @_;
 
-        $html =~ s/<b>|<\/b>//g;
+        $html =~ s{</?b>}{}g;
         $html =~ s/<br>/, /g;
-        $html =~ s/<a href=\.\.\/art\/ver_e\.php\?nombre=[0-9]*>([^<]*)<\/a>/$1/g;
-        $html =~ s/<font class.=..titulo3.>([^<]*)<\/font>([^<]*)/<font class ='titulo3'>$1 $2<\/font>/g;
+        $html =~ s{<a href=\.\./art/ver_e\.php\?nombre=[0-9]*>([^<]*)</a>}
+                  {$1}g;
+        $html =~ s{<font class.=..titulo3.>([^<]*)</font>([^<]*)}
+                  {<font class ='titulo3'>$1 $2</font>}g;
 
         return $html;
     }
