@@ -316,7 +316,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         my ($self, $word) = @_;
     
-	$word = 'ean:'.$word
+        $word = 'ean:'.$word
 	    if $word =~ /^[\dX]{8}[\dX]*$/;
 
         return "http://www.dvdfr.com/api/search.php?title=$word";
@@ -359,6 +359,11 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return 'Edition';
     }
 
+    sub getEanField
+    {
+        return 'title';
+    }
+
     sub isPreferred
     {
         return 1;
