@@ -2,7 +2,7 @@ package GCPlugins::GCfilms::GCDVDPost;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -23,9 +23,9 @@ package GCPlugins::GCfilms::GCDVDPost;
 ###################################################
 
 ###################################
-#														   #
-#			Plugin soumis par MeV			   #
-#														   #
+#                                 #
+#      Plugin soumis par MeV      #
+#                                 #
 ###################################
 
 use strict;
@@ -34,6 +34,7 @@ use utf8;
 use GCPlugins::GCfilms::GCfilmsCommon;
 
 {
+
     package GCPlugins::GCfilms::GCPluginDVDPost;
 
     use base qw(GCPlugins::GCfilms::GCfilmsPluginsBase);
@@ -41,7 +42,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     sub start
     {
         my ($self, $tagname, $attr, $attrseq, $origtext) = @_;
-	
+
         $self->{inside}->{$tagname}++;
 
         if ($self->{parsingList})
@@ -52,9 +53,9 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 {
                     my $url = $attr->{href};
                     $self->{isMovie} = 1;
-                    $self->{isInfo} = 1;
+                    $self->{isInfo}  = 1;
                     $self->{itemIdx}++;
-                    $self->{itemsList}[$self->{itemIdx}]->{url} = $url;
+                    $self->{itemsList}[ $self->{itemIdx} ]->{url} = $url;
                 }
             }
         }
@@ -62,54 +63,56 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         {
             if ($tagname eq "img")
             {
-			    if ($attr->{src} =~ /http:\/\/images\.dvdpost\.be\/\/dvd/)
-				{
+                if ($attr->{src} =~ /http:\/\/images\.dvdpost\.be\/\/dvd/)
+                {
                     $self->{curInfo}->{image} = $attr->{src};
-				}
-				elsif ($self->{insideAge})
-				{
-				    (my $fileName = $attr->{src}) =~ s|.+/([^/]+)$|$1|;
-   				    $self->{curInfo}->{age} = 2 if $fileName eq 'all.gif';
-   				    $self->{curInfo}->{age} = 12 if $fileName eq '-12.gif';
-				    $self->{curInfo}->{age} = 16 if $fileName eq '-16.gif';
-				    $self->{insideAge} = 0;
-				}
+                }
+                elsif ($self->{insideAge})
+                {
+                    (my $fileName = $attr->{src}) =~ s|.+/([^/]+)$|$1|;
+                    $self->{curInfo}->{age} = 2  if $fileName eq 'all.gif';
+                    $self->{curInfo}->{age} = 12 if $fileName eq '-12.gif';
+                    $self->{curInfo}->{age} = 16 if $fileName eq '-16.gif';
+                    $self->{insideAge}      = 0;
+                }
             }
             elsif ($tagname eq "table")
             {
-                if (($attr->{cellpadding} eq "0") && ($attr->{cellspacing} eq "0")
-                && ($attr->{width} eq "100%") && ($attr->{border} ne "0"))
+                if (   ($attr->{cellpadding} eq "0")
+                    && ($attr->{cellspacing} eq "0")
+                    && ($attr->{width}       eq "100%")
+                    && ($attr->{border} ne "0"))
                 {
-					$self->{insideSynopsisFather} = 1;
-				}
-			}
+                    $self->{insideSynopsisFather} = 1;
+                }
+            }
             elsif ($tagname eq "td")
             {
-              if ($attr->{style} eq "text-align:right;font-size:9px;color:gray")
-            	{
-            		$self->{insideGenre} = 1;
-            	}
-            	elsif (($attr->{class} eq "boxText") && $attr->{align} eq "left")
-            	{
-            		if ($self->{insideSynopsisFather} == 1)
-            		{
-            	  	    $self->{insideSynopsis} = 1;
-            			$self->{insideSynopsisFather} = 0;
-            		}
-            		else
-            		{
-            			$self->{insideSynopsis} = 0;
-            		}
-            	}
+                if ($attr->{style} eq "text-align:right;font-size:9px;color:gray")
+                {
+                    $self->{insideGenre} = 1;
+                }
+                elsif (($attr->{class} eq "boxText") && $attr->{align} eq "left")
+                {
+                    if ($self->{insideSynopsisFather} == 1)
+                    {
+                        $self->{insideSynopsis}       = 1;
+                        $self->{insideSynopsisFather} = 0;
+                    }
+                    else
+                    {
+                        $self->{insideSynopsis} = 0;
+                    }
+                }
             }
         }
     }
 
     sub end
     {
-		my ($self, $tagname) = @_;
-		
-			$self->{inside}->{$tagname}--;
+        my ($self, $tagname) = @_;
+
+        $self->{inside}->{$tagname}--;
 
     }
 
@@ -118,43 +121,43 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         my ($self, $origtext) = @_;
 
         return if length($origtext) < 2;
-           
+
         if ($self->{parsingList})
         {
             if ($self->{isMovie})
             {
-                $self->{itemsList}[$self->{itemIdx}]->{"title"} = $origtext;
-                $self->{isMovie} = 0;
-                $self->{isInfo} = 1;
+                $self->{itemsList}[ $self->{itemIdx} ]->{"title"} = $origtext;
+                $self->{isMovie}                                  = 0;
+                $self->{isInfo}                                   = 1;
                 return;
             }
         }
         else
         {
-			$origtext =~ s/\n*//g if !$self->{insideSynopsis};
-			$origtext =~ s/\s{2,}//g;
+            $origtext =~ s/\n*//g if !$self->{insideSynopsis};
+            $origtext =~ s/\s{2,}//g;
 
-						if ($self->{insideDate})
-			{
-					$self->{curInfo}->{date} = $origtext;
-					$self->{insideDate} = 0;
-			}
+            if ($self->{insideDate})
+            {
+                $self->{curInfo}->{date} = $origtext;
+                $self->{insideDate} = 0;
+            }
             elsif ($self->{insideDirector})
             {
-				$origtext =~ s/ ,/, /g;
-				$origtext =~ s/^(.*), /$1/;
+                $origtext =~ s/ ,/, /g;
+                $origtext =~ s/^(.*), /$1/;
                 $self->{curInfo}->{director} = $origtext if !$self->{curInfo}->{director};
                 $self->{insideDirector} = 0;
             }
             elsif ($self->{insideSynopsis})
             {
                 $self->{curInfo}->{synopsis} = $origtext;
-								$self->{insideSynopsis} = 0;
+                $self->{insideSynopsis} = 0;
             }
             elsif ($self->{insideNat})
             {
                 $self->{curInfo}->{country} = $origtext;
-								$self->{insideNat} = 0;
+                $self->{insideNat} = 0;
             }
             elsif ($self->{insideTime})
             {
@@ -163,8 +166,8 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             }
             elsif ($self->{insideActors})
             {
-				$origtext =~ s/ ,/, /g;
-				$origtext =~ s/^(.*), /$1/;
+                $origtext =~ s/ ,/, /g;
+                $origtext =~ s/^(.*), /$1/;
                 $self->{curInfo}->{actors} = $origtext if !$self->{curInfo}->{actors};
                 $self->{insideActors} = 0;
             }
@@ -173,48 +176,48 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 $self->{curInfo}->{original} = $origtext if !$self->{curInfo}->{original};
                 $self->{insideOrig} = 0;
             }
-			elsif ($self->{inside}->{b})
-			{
+            elsif ($self->{inside}->{b})
+            {
                 $self->{insideDirector} = 1 if $origtext =~ m/R.alisateur/;
-                $self->{insideTime} = 1 if $origtext =~ m/Dur.e/;
-                $self->{insideActors} = 1 if $origtext =~ m/Acteurs/;
-                $self->{insideAge} = 1 if $origtext =~ m/Public/;
+                $self->{insideTime}     = 1 if $origtext =~ m/Dur.e/;
+                $self->{insideActors}   = 1 if $origtext =~ m/Acteurs/;
+                $self->{insideAge}      = 1 if $origtext =~ m/Public/;
+            }
+            elsif ($self->{inside}->{table})
+            {
+                if ($origtext =~ /(.*) \( ([0-9]{4}) \)/)
+                {
+                    $self->{curInfo}->{title} = $1 if !$self->{curInfo}->{title};
+                    $self->{curInfo}->{date}  = $2 if !$self->{curInfo}->{date};
+                }
+                elsif ($self->{insideGenre})
+                {
+                    $origtext =~ s/\|/,/g;
+                    $self->{curInfo}->{genre} = $origtext;
+                    $self->{insideGenre} = 0;
+                }
             }
-    		elsif ($self->{inside}->{table})
-    		{
-    			if ($origtext =~ /(.*) \( ([0-9]{4}) \)/)
-    			{
-    				$self->{curInfo}->{title} = $1 if !$self->{curInfo}->{title};
-    				$self->{curInfo}->{date} = $2 if !$self->{curInfo}->{date};
-    			}
-    			elsif ($self->{insideGenre})
-    			{
-    				$origtext =~ s/\|/,/g;
-    				$self->{curInfo}->{genre} = $origtext;
-    				$self->{insideGenre} = 0;
-    			}
-    		}
         }
-    } 
+    }
 
     sub new
     {
         my $proto = shift;
         my $class = ref($proto) || $proto;
         my $self  = $class->SUPER::new();
-        bless ($self, $class);
+        bless($self, $class);
 
         $self->{hasField} = {
-            title => 1,
-            date => 0,
+            title    => 1,
+            date     => 0,
             director => 0,
-            actors => 0,
+            actors   => 0,
         };
 
-        $self->{isInfo} = 0;
+        $self->{isInfo}  = 0;
         $self->{isMovie} = 0;
         $self->{curName} = undef;
-        $self->{curUrl} = undef;
+        $self->{curUrl}  = undef;
 
         return $self;
     }
@@ -227,35 +230,35 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         $html =~ s/<u>|<\/u>//g;
         $html =~ s/<a href="directors\.php\?directors\_id=[0-9]*">([^<]*)<\/a>/$1/gi;
         $html =~ s/<a href="actors\.php\?actors\_id=[0-9]*">([^<]*)<\/a>/$1/gi;
-        
+
         return $html;
     }
-    
+
     sub getSearchUrl
     {
-		my ($self, $word) = @_;
-	
-			return "http://www.dvdpost.be/advanced_search_result2.php?language=fr&keywords=$word";
+        my ($self, $word) = @_;
+
+        return "http://www.dvdpost.be/advanced_search_result2.php?language=fr&keywords=$word";
     }
-    
+
     sub getItemUrl
     {
-		my ($self, $url) = @_;
-		
-		return "http://www.dvdpost.be/" . $url . "&language=fr" unless $url eq '';
-		return "http://www.dvdpost.be/";
+        my ($self, $url) = @_;
+
+        return "http://www.dvdpost.be/" . $url . "&language=fr" unless $url eq '';
+        return "http://www.dvdpost.be/";
     }
 
     sub getName
     {
         return "DVDPost.be";
     }
-    
+
     sub getAuthor
     {
         return 'MeV';
     }
-    
+
     sub getLang
     {
         return 'FR';
