@@ -2,7 +2,7 @@ package GCPlugins::GCfilms::GCFilmUP;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -28,23 +28,27 @@ use strict;
 use GCPlugins::GCfilms::GCfilmsCommon;
 
 {
+
     package GCPlugins::GCfilms::GCPluginFilmUP;
 
     use base qw(GCPlugins::GCfilms::GCfilmsPluginsBase);
- 
+
     sub getSearchUrl
     {
-		my ($self, $word) = @_;
+        my ($self, $word) = @_;
         my $url;
-        
-        $url = "http://filmup.leonardo.it/cgi-bin/search.cgi?ps=10&fmt=long&q=$word&ul=%25%2Fsc_%25&x=52&y=7&m=all&wf=2221&wm=wrd&sy=0";
-        
-		return $url;
+
+        $url =
+            "http://filmup.leonardo.it/cgi-bin/search.cgi?"
+          . "ps=10&fmt=long&q=$word"
+          . "&ul=%25%2Fsc_%25&x=52&y=7&m=all&wf=2221&wm=wrd&sy=0";
+
+        return $url;
     }
-    
+
     sub getItemUrl
     {
-		my ($self, $url) = @_;
+        my ($self, $url) = @_;
 
         return $url unless $url eq '';
         return 'http://filmup.leonardo.it/';
@@ -54,12 +58,12 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         return "FilmUP";
     }
-    
+
     sub getAuthor
     {
         return 'Tian';
     }
-    
+
     sub getLang
     {
         return 'IT';
@@ -68,14 +72,14 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     sub changeUrl
     {
         my ($self, $url) = @_;
-        
+
         return $url;
     }
 
     sub start
     {
-		my ($self, $tagname, $attr, $attrseq, $origtext) = @_;	
-		$self->{inside}->{$tagname}++;
+        my ($self, $tagname, $attr, $attrseq, $origtext) = @_;
+        $self->{inside}->{$tagname}++;
 
         if ($self->{parsingList})
         {
@@ -83,7 +87,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             {
                 if ($self->{insideInfos})
                 {
-                    $self->{itemsList}[$self->{itemIdx}]->{url} = $self->{lasUrl};
+                    $self->{itemsList}[ $self->{itemIdx} ]->{url} = $self->{lasUrl};
                     $self->{insideInfos} = 0;
                 }
 
@@ -94,43 +98,43 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         {
             if ($tagname eq 'img')
             {
-                $self->{curInfo}->{image} = $self->getItemUrl.$attr->{src}
-                    if $attr->{src} =~ /^locand\// && ($attr->{src} ne 'locand/no.gif');
+                $self->{curInfo}->{image} = $self->getItemUrl . $attr->{src}
+                  if $attr->{src} =~ /^locand\// && ($attr->{src} ne 'locand/no.gif');
             }
         }
     }
 
     sub end
     {
-		my ($self, $tagname) = @_;		
-		$self->{inside}->{$tagname}--;
+        my ($self, $tagname) = @_;
+        $self->{inside}->{$tagname}--;
     }
 
     sub text
     {
         my ($self, $origtext) = @_;
 
-       if ($self->{parsingList})
+        if ($self->{parsingList})
         {
             if ($self->{inside}->{dt} && $self->{inside}->{a})
             {
                 if ($origtext =~ m/FilmUP - Scheda: (.*)/)
                 {
                     $self->{itemIdx}++;
-                    $self->{itemsList}[$self->{itemIdx}]->{title} = $1;
+                    $self->{itemsList}[ $self->{itemIdx} ]->{title} = $1;
                     $self->{insideInfos} = 1;
                 }
             }
-            if ($self->{inside}->{small} 
-             && ($self->{inside}->{table} == 4)
-             && $self->{insideInfos})
+            if (   $self->{inside}->{small}
+                && $self->{inside}->{table}
+                && $self->{insideInfos})
             {
-                $self->{itemsList}[$self->{itemIdx}]->{date} = $1
-                    if $origtext =~ /Anno: ([0-9]+)/;
-                $self->{itemsList}[$self->{itemIdx}]->{director} = $1
-                    if $origtext =~ /Regia: (.*?)((Sito)|$)/;
-                $self->{itemsList}[$self->{itemIdx}]->{actors} = $1
-                    if $origtext =~ /Cast: (.*?)$/;
+                $self->{itemsList}[ $self->{itemIdx} ]->{date} = $1
+                  if $origtext =~ /Anno: ([0-9]+)/;
+                $self->{itemsList}[ $self->{itemIdx} ]->{director} = $1
+                  if $origtext =~ /Regia: (.*?)((Sito)|$)/;
+                $self->{itemsList}[ $self->{itemIdx} ]->{actors} = $1
+                  if $origtext =~ /Cast: (.*?)$/;
             }
         }
         else
@@ -181,14 +185,14 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                     $self->{curInfo}->{actors} = $origtext;
                     $self->{insideActors} = 0;
                 }
-            
+
                 $self->{insideOriginal} = 1 if $origtext =~ /Titolo originale:/;
-                $self->{insideNat} = 1 if $origtext =~ /Nazione:/;
-                $self->{insideDate} = 1 if $origtext =~ /Anno:/;
-                $self->{insideGenre} = 1 if $origtext =~ /Genere:/;
-                $self->{insideTime} = 1 if $origtext =~ /Durata:/;
+                $self->{insideNat}      = 1 if $origtext =~ /Nazione:/;
+                $self->{insideDate}     = 1 if $origtext =~ /Anno:/;
+                $self->{insideGenre}    = 1 if $origtext =~ /Genere:/;
+                $self->{insideTime}     = 1 if $origtext =~ /Durata:/;
                 $self->{insideDirector} = 1 if $origtext =~ /Regia:/;
-                $self->{insideActors} = 1 if $origtext =~ /Cast:/;
+                $self->{insideActors}   = 1 if $origtext =~ /Cast:/;
             }
             if ($self->{inside}->{synopsis})
             {
@@ -204,13 +208,13 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         my $self  = $class->SUPER::new();
 
         $self->{hasField} = {
-            title => 1,
-            date => 1,
+            title    => 1,
+            date     => 1,
             director => 1,
-            actors => 1,
+            actors   => 1,
         };
 
-        bless ($self, $class);
+        bless($self, $class);
         return $self;
     }
 
@@ -219,29 +223,30 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         my ($self, $html) = @_;
 
         $html =~ s/\222/'/g;
-        #'
-        $html =~ s/<font face="arial, helvetica" size="3">(.*?)<\/font>/<h1>$1<\/h1>/g;
-        $html =~ s/<\/table>.<br>.<font face="arial, helvetica" size="2">(.*?)<\/font>/<\/table><synopsis>$1<\/synopsis>/ms;
-        $html =~ s/<font face="arial, helvetica" size="2">Trama:(.*?)<\/font>/<synopsis>$1<\/synopsis>/;
-        $html =~ s/Trama:<br>//;
-        $html =~ s/<span .*?>|<\/span>//g;
-        $html =~ s/<a .*?href="\/?personaggi.*?>(.+?)<\/a>/$1/g;
-        #"
-        $html =~ s/<font .*?>|<\/font>//g;
-        $html =~ s/<b>|<\/b>//g;
+
+        $html =~ s{<font face="arial, helvetica" size="3">(.*?)</font>}
+                  {<h1>$1</h1>}g;
+        $html =~ s{</table>.<br>.<font face="arial, helvetica" size="2">(.*?)</font>}
+                  {</table><synopsis>$1</synopsis>}ms;
+        $html =~ s{<font face="arial, helvetica" size="2">Trama:(.*?)</font>}
+                  {<synopsis>$1</synopsis>};
+        $html =~ s{Trama:<br>}{};
+        $html =~ s{<span .*?>|</span>} {}g;
+        $html =~ s{<a .*?href="\/?personaggi.*?>(.+?)</a>} {$1}g;
+
+        $html =~ s{<font .*?>|</font>} {}g;
+        $html =~ s{</?b>} {}g;
 
         return $html;
     }
-    
+
     sub getCharset
     {
         my $self = shift;
-    
+
         return "Windows-1252";
     }
-  
-  
-    
+
 }
 
 1;
