@@ -29,6 +29,7 @@ use Encode qw(encode);
 use GCPlugins::GCfilms::GCfilmsCommon;
 
 {
+
     package GCPlugins::GCfilms::GCPluginNasheKino;
 
     use base qw(GCPlugins::GCfilms::GCfilmsPluginsBase);
@@ -42,26 +43,29 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             if ($tagname eq "a")
             {
                 my $url = $attr->{href};
-                if ($attr->{class} eq "ab10" && $url =~ m/\/data.movies\?id/) {
+                if ($attr->{class} eq "ab10" && $url =~ m/\/data.movies\?id/)
+                {
                     $self->{isMovie} = 1;
-                    $self->{isDate} = 2;
+                    $self->{isDate}  = 2;
                     $self->{itemIdx}++;
-                    $self->{itemsList}[$self->{itemIdx}]->{url} = $url;
+                    $self->{itemsList}[ $self->{itemIdx} ]->{url} = $url;
                 }
-	       }
-            if ($tagname eq "a" && $attr->{class} eq "ab10" &&
-                $self->{isDate} == 2)
+            }
+            if (   $tagname eq "a"
+                && $attr->{class} eq "ab10"
+                && $self->{isDate} == 2)
             {
                 $self->{isDate} = 1;
             }
         }
         else
         {
-            if ($tagname eq "a" && $attr->{class} eq "ab10" &&
-                $self->{inside}->{h1})
+            if (   $tagname eq "a"
+                && $attr->{class} eq "ab10"
+                && $self->{inside}->{h1})
             {
                 $self->{insideDate} = 1;
-	       }
+            }
         }
     }
 
@@ -72,7 +76,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         {
             if ($self->{isMovie})
             {
-                $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
+                $self->{itemsList}[ $self->{itemIdx} ]->{title} = $origtext;
                 $self->{isMovie} = 0;
                 return;
             }
@@ -80,20 +84,20 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             {
                 if ($origtext =~ m/([0-9]+)\sг/)
                 {
-                    $self->{itemsList}[$self->{itemIdx}]->{date} = $1;
+                    $self->{itemsList}[ $self->{itemIdx} ]->{date} = $1;
                     $self->{isDate} = 0;
                 }
             }
         }
         else
         {
-            utf8::decode ($origtext);
+            utf8::decode($origtext);
             $origtext =~ s/^\s+//;
             $origtext =~ s/\s+$//;
             if ($self->{inside}->{h1})
             {
                 $self->{curInfo}->{title} = $origtext
-                    if !$self->{curInfo}->{title};
+                  if !$self->{curInfo}->{title};
             }
             if ($self->{insideDate})
             {
@@ -128,18 +132,19 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             elsif ($self->{insideActors})
             {
                 $self->{insideActors} = 0 if $origtext =~ m/Сценарий:/;
-                if ($origtext !~ m/^,/ 
-                && $self->{actorsCounter} < $GCPlugins::GCfilms::GCfilmsCommon::MAX_ACTORS)
+                if (   $origtext !~ m/^,/
+                    && $self->{actorsCounter} < $GCPlugins::GCfilms::GCfilmsCommon::MAX_ACTORS)
                 {
-                    $self->{curInfo}->{actors} .=
-                        ($self->{curInfo}->{actors}
+                    $self->{curInfo}->{actors} .= (
+                        $self->{curInfo}->{actors}
                         ? ", " . $origtext
-                        : $origtext);
+                        : $origtext
+                    );
                     $self->{actorsCounter}++;
                 }
             }
             $self->{insideDirector} = 1 if $origtext =~ m/Режиссер\(ы\):/;
-            $self->{insideActors} = 1 if $origtext =~ m/Актер\(ы\):/;
+            $self->{insideActors}   = 1 if $origtext =~ m/Актер\(ы\):/;
             $self->{insideSynopsis} = 1 if $origtext =~ m/О\sфильме:/;
         }
     }
@@ -155,20 +160,20 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         my $proto = shift;
         my $class = ref($proto) || $proto;
         my $self  = $class->SUPER::new();
-        bless ($self, $class);
+        bless($self, $class);
 
         $self->{hasField} = {
-            title => 1,
-            date => 1,
+            title    => 1,
+            date     => 1,
             director => 0,
-            actors => 0,
+            actors   => 0,
         };
 
-        $self->{isInfo} = 0;
+        $self->{isInfo}  = 0;
         $self->{isMovie} = 0;
         $self->{curName} = undef;
-        $self->{curUrl} = undef;
-	
+        $self->{curUrl}  = undef;
+
         return $self;
     }
 
