@@ -10,7 +10,7 @@ package GCPlugins::GCcollection::GCOnet;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -41,20 +41,20 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     package GCPlugins::GCfilms::GCPluginOnet;
 
     use base qw(GCPlugins::GCfilms::GCfilmsPluginsBase);
- 
+
     # getSearchUrl
     # Used to get the URL that to be used to perform searches.
     # $word is the query
     # Returns the full URL.
     sub getSearchUrl
     {
-		my ($self, $word) = @_;
-        
+        my ($self, $word) = @_;
+
         # Your code here
-        
-		return "http://film.onet.pl/filmoteka.html?S=$word";
+
+        return "http://film.onet.pl/filmoteka.html?S=$word";
     }
-    
+
     # getItemUrl
     # Used to get the full URL of an item page.
     # Useful when url on results pages are relative.
@@ -62,20 +62,20 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     # Returns the absolute URL.
     sub getItemUrl
     {
-		my ($self, $url) = @_;
-        
+        my ($self, $url) = @_;
+
         # Your code here
 
         return "http://film.onet.pl/" . $url;
     }
-    
+
     # getCharset
     # Used to convert charset in web pages.
     # Returns the charset as specified in pages.
     sub getCharset
     {
         my $self = shift;
-    
+
         return "ISO-8859-2";
     }
 
@@ -94,7 +94,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         return 'Marek Cendrowicz';
     }
-    
+
     # getLang
     # Used to fill in plugin list with user language plugins
     # Return the language used for this site (2 letters code).
@@ -117,20 +117,20 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     sub changeUrl
     {
         my ($self, $url) = @_;
-        
+
         return $url;
     }
 
     # In processing functions below, self->{parsingList} can be used.
     # If true, we are processing a search results page
     # If false, we are processing a item information page.
-    
+
     # $self->{inside}->{tagname} (with correct value for tagname) can be used to test
     # if we are in the corresponding tag.
-    
+
     # You have a counter $self->{itemIdx} that have to be used when processing search results.
     # It is your responsability to increment it!
-    
+
     # When processing search results, you have to fill the available fields for results
     #
     #  $self->{itemsList}[$self->{movieIdx}]->{field_name}
@@ -139,7 +139,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     # in $self->{curInfo}.
     #
     #  $self->{curInfo}->{field_name}
-    
+
     # start
     # Called each time a new HTML tag begins.
     # $tagname is the tag name.
@@ -149,29 +149,36 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     # Returns nothing
     sub start
     {
-		my ($self, $tagname, $attr, $attrseq, $origtext) = @_;	
-		$self->{inside}->{$tagname}++;
+        my ($self, $tagname, $attr, $attrseq, $origtext) = @_;
+        $self->{inside}->{$tagname}++;
 
         if ($self->{parsingList})
         {
-            if ( $self->{inside}->{list_title} && $tagname eq 'a' ) {
+            if ($self->{inside}->{list_title} && $tagname eq 'a')
+            {
                 $self->{itemIdx}++;
-                $self->{itemsList}[$self->{itemIdx}]->{url} = $attr->{href};
+                $self->{itemsList}[ $self->{itemIdx} ]->{url} = $attr->{href};
                 $self->{listTitle} = 1;
             }
         }
         else
         {
-            if ( $attr->{class} eq 'tyw' ) {
+            if ($attr->{class} eq 'tyw')
+            {
                 $self->{itemTitle} = 1;
             }
-            elsif ( $tagname eq 'div' && $attr->{class} eq 'a2' ) {
+            elsif ($tagname eq 'div' && $attr->{class} eq 'a2')
+            {
                 $self->{itemDescription} = 1;
             }
-            elsif ( $attr->{class} eq 'item_actor' ) {
+            elsif ($attr->{class} eq 'item_actor')
+            {
                 $self->{itemActor} = 1;
             }
-            elsif ( $tagname eq 'img' && $attr->{class} eq 'pic' && ($attr->{alt} eq 'Galeria' || $attr->{alt} eq 'Plakat') ) {
+            elsif ($tagname eq 'img'
+                && $attr->{class} eq 'pic'
+                && ($attr->{alt} eq 'Galeria' || $attr->{alt} eq 'Plakat'))
+            {
                 $self->{curInfo}->{image} = "http://film.onet.pl/" . $attr->{src};
             }
         }
@@ -182,8 +189,8 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     # $tagname is the tag name.
     sub end
     {
-		my ($self, $tagname) = @_;		
-		$self->{inside}->{$tagname}--;
+        my ($self, $tagname) = @_;
+        $self->{inside}->{$tagname}--;
     }
 
     # text
@@ -193,44 +200,56 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         my ($self, $origtext) = @_;
 
-       if ($self->{parsingList})
+        if ($self->{parsingList})
         {
-            if ( $self->{listTitle} ) {
-                $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
+            if ($self->{listTitle})
+            {
+                $self->{itemsList}[ $self->{itemIdx} ]->{title} = $origtext;
                 $self->{listTitle} = 0;
             }
-            elsif ( $self->{inside}->{list_date} ) {
-                ($self->{itemsList}[$self->{itemIdx}]->{date}) = ($origtext =~ m/,\s+(\d+)$/);
+            elsif ($self->{inside}->{list_date})
+            {
+                ($self->{itemsList}[ $self->{itemIdx} ]->{date}) = ($origtext =~ m/,\s+(\d+)$/);
             }
         }
         else
         {
-            if ( $self->{itemTitle} ) {
+            if ($self->{itemTitle})
+            {
                 $self->{curInfo}->{title} = $origtext;
                 $self->{itemTitle} = 0;
             }
-            elsif( $self->{inside}->{item_country} ) {
+            elsif ($self->{inside}->{item_country})
+            {
                 ($self->{curInfo}->{original}) = ($origtext =~ m/(.*)\s+\(/);
-                ($self->{curInfo}->{country}, $self->{curInfo}->{date}) = ($origtext =~ m/(\w+),\s+(\d+)\)/);
+                ($self->{curInfo}->{country}, $self->{curInfo}->{date}) =
+                  ($origtext =~ m/(\w+),\s+(\d+)\)/);
                 $origtext =~ s|/|, |g;
                 ($self->{curInfo}->{genre}) = ($origtext =~ m/\)(.*)/);
             }
-            elsif ( $self->{inside}->{item_time} ) {
-                ($self->{curInfo}->{time}, $self->{curInfo}->{age}) = ($origtext =~ m/czas\s+(\d+).*\s+od\s+(\d+)/);
+            elsif ($self->{inside}->{item_time})
+            {
+                ($self->{curInfo}->{time}, $self->{curInfo}->{age}) =
+                  ($origtext =~ m/czas\s+(\d+).*\s+od\s+(\d+)/);
             }
-            elsif ( $self->{inside}->{item_director} ) {
+            elsif ($self->{inside}->{item_director})
+            {
                 $self->{curInfo}->{director} .= $origtext;
             }
-            elsif ( $self->{itemDescription} ) {
+            elsif ($self->{itemDescription})
+            {
                 $self->{curInfo}->{synopsis} = $origtext;
                 $self->{itemDescription} = 0;
             }
-            elsif ( $self->{itemActor} ) {
-                $self->{curInfo}->{actors} .= $self->{curInfo}->{actors} ? ", " . $origtext : $origtext;
+            elsif ($self->{itemActor})
+            {
+                $self->{curInfo}->{actors} .=
+                  $self->{curInfo}->{actors} ? ", " . $origtext : $origtext;
                 $self->{itemActor} = 0;
             }
-            elsif ( $self->{inside}->{item_rating} ) {
-                ($self->{curInfo}->{rating}) = $origtext =~ m/^(\d+)/;
+            elsif ($self->{inside}->{item_rating})
+            {
+                ($self->{curInfo}->{ratingpress}) = int($origtext * 2 + 0.5);
             }
         }
     }
@@ -251,18 +270,18 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         # (.gcm) and search for tags <field> in
         # /collection/options/fields/results
         $self->{hasField} = {
-            title => 1,
-            date => 1,
+            title    => 1,
+            date     => 1,
             director => 0,
-            actors => 0,          
+            actors   => 0,
         };
-        
-        $self->{itemIdx} = 0;
+
+        $self->{itemIdx}               = 0;
         $self->{itemsList}[0]->{title} = '';
-        $self->{itemsList}[0]->{url} = '';
-        
+        $self->{itemsList}[0]->{url}   = '';
+
         # Do your init stuff here
-        bless ($self, $class);
+        bless($self, $class);
         return $self;
     }
 
@@ -274,26 +293,35 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         my ($self, $html) = @_;
 
-        $html =~ s|<B>(.*?)</B>|$1|gms;
-   
+        $html =~ s{<B>(.*?)</B>}{$1}gms;
+
         if ($self->{parsingList})
         {
 
-            $html =~ s|<TD class=a2 width="100%">(.*?)</TD>|<list_title>$1</list_title>|gms;
-            $html =~ s|<FONT class=a0 color="#993300">(.*?)</FONT>|<list_date>$1</list_date>|gms;          
+            $html =~ s{<TD class=a2 width="100%">(.*?)</TD>}
+                      {<list_title>$1</list_title>}gms;
+            $html =~ s{<FONT class=a0 color="#993300">(.*?)</FONT>}
+                      {<list_date>$1</list_date>}gms;
+        }
+        else
+        {
+            $html =~ s{<BR>}{}g;
+            $html =~ s{<TD class=a2 valign=top width="100%">(.*?)<}
+                      {<item_country>$1</item_country><}gms;
+            $html =~ s{<SPAN class=a1>(.*?)</SPAN>}
+                      {<item_time>$1</item_time>}gms;
+            $html =~ s{Re.yseria:&nbsp;&nbsp;(.*?)Scenariusz}
+                      {<item_director>$1</item_director>}gms;
+            $html =~ s{Re.yseria:&nbsp;&nbsp;(.*?)wi.cej}
+                      {<item_director>$1</item_director>}gms;
+            $html =~ s{a2><A class=u}
+                      {a2><A class=item_actor}gms;
+            $html =~ s{Ocena filmu.*([0-9]\.[0-9]+)/5}
+                      {<item_rating>$1</item_rating>}gms;
         }
-        else {
-            $html =~ s|<BR>||g;
-            $html =~ s|<TD class=a2 valign=top width="100%">(.*?)<|<item_country>$1</item_country><|gms;
-            $html =~ s|<SPAN class=a1>(.*?)</SPAN>|<item_time>$1</item_time>|gms;
-            $html =~ s|Re.yseria:&nbsp;&nbsp;(.*?)Scenariusz|<item_director>$1</item_director>|gms;
-            $html =~ s|Re.yseria:&nbsp;&nbsp;(.*?)wi.cej|<item_director>$1</item_director>|gms;
-            $html =~ s|a2><A class=u|a2><A class=item_actor|gms;
-            $html =~ s|Ocena filmu(.*)/5|<item_rating>$1</item_rating>|gms;
-        }        
         return $html;
     }
-    
+
 }
 
 1;
