@@ -10,7 +10,7 @@ package GCPlugins::GCcollection::GCStopklatka;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -41,20 +41,20 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     package GCPlugins::GCfilms::GCPluginStopklatka;
 
     use base qw(GCPlugins::GCfilms::GCfilmsPluginsBase);
- 
+
     # getSearchUrl
     # Used to get the URL that to be used to perform searches.
     # $word is the query
     # Returns the full URL.
     sub getSearchUrl
     {
-		my ($self, $word) = @_;
-        
+        my ($self, $word) = @_;
+
         # Your code here
-        
-		return "http://www.stopklatka.pl/szukaj/szukaj.asp?kategoria=film&szukaj=$word";
+
+        return "http://www.stopklatka.pl/szukaj/szukaj.asp?kategoria=film&szukaj=$word";
     }
-    
+
     # getItemUrl
     # Used to get the full URL of an item page.
     # Useful when url on results pages are relative.
@@ -62,20 +62,20 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     # Returns the absolute URL.
     sub getItemUrl
     {
-		my ($self, $url) = @_;
-        
+        my ($self, $url) = @_;
+
         # Your code here
 
-        return "http://www.stopklatka.pl/".$url;
+        return "http://www.stopklatka.pl/" . $url;
     }
-    
+
     # getCharset
     # Used to convert charset in web pages.
     # Returns the charset as specified in pages.
     sub getCharset
     {
         my $self = shift;
-    
+
         return "ISO-8859-2";
     }
 
@@ -94,7 +94,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         return 'Marek Cendrowicz';
     }
-    
+
     # getLang
     # Used to fill in plugin list with user language plugins
     # Return the language used for this site (2 letters code).
@@ -117,20 +117,20 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     sub changeUrl
     {
         my ($self, $url) = @_;
-        
+
         return $url;
     }
 
     # In processing functions below, self->{parsingList} can be used.
     # If true, we are processing a search results page
     # If false, we are processing a item information page.
-    
+
     # $self->{inside}->{tagname} (with correct value for tagname) can be used to test
     # if we are in the corresponding tag.
-    
+
     # You have a counter $self->{itemIdx} that have to be used when processing search results.
     # It is your responsability to increment it!
-    
+
     # When processing search results, you have to fill the available fields for results
     #
     #  $self->{itemsList}[$self->{movieIdx}]->{field_name}
@@ -139,7 +139,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     # in $self->{curInfo}.
     #
     #  $self->{curInfo}->{field_name}
-    
+
     # start
     # Called each time a new HTML tag begins.
     # $tagname is the tag name.
@@ -149,47 +149,57 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     # Returns nothing
     sub start
     {
-		my ($self, $tagname, $attr, $attrseq, $origtext) = @_;	
-		$self->{inside}->{$tagname}++;
+        my ($self, $tagname, $attr, $attrseq, $origtext) = @_;
+        $self->{inside}->{$tagname}++;
 
         if ($self->{parsingList})
         {
-            if ( $self->{inside}->{list_details} ) {
-                if ( $tagname eq 'a' ) {
+            if ($self->{inside}->{list_details})
+            {
+                if ($tagname eq 'a')
+                {
                     $self->{itemIdx}++;
-                    $self->{itemsList}[$self->{itemIdx}]->{url} = $attr->{href};
+                    $self->{itemsList}[ $self->{itemIdx} ]->{url} = $attr->{href};
                 }
-                
+
                 $self->{listTitle} = 1
-                    if ( $attr->{class} eq 'searchTitle textB' );
-                    
+                  if ($attr->{class} eq 'searchTitle textB');
+
                 $self->{listYear} = 1
-                    if ( $attr->{class} eq 'searchTitle');
+                  if ($attr->{class} eq 'searchTitle');
             }
         }
         else
         {
-            if ( $attr->{class} eq 'wydarzenie_tytul' ) {
+            if ($attr->{class} eq 'wydarzenie_tytul')
+            {
                 $self->{pre_itemTitle} = 1;
             }
-            elsif ( $self->{pre_itemTitle} ) {
-                if ( $tagname eq 'h1' ) {
+            elsif ($self->{pre_itemTitle})
+            {
+                if ($tagname eq 'h1')
+                {
                     $self->{itemTitle} = 1;
                 }
-                elsif ( $tagname eq 'h2' ) {
+                elsif ($tagname eq 'h2')
+                {
                     $self->{itemOriginalTitle} = 1;
                 }
-                elsif ( $tagname eq 'table' ) {
+                elsif ($tagname eq 'table')
+                {
                     $self->{pre_itemTitle} = 0;
                 }
             }
-            elsif ( $attr->{class} eq 'film_pozycja' ) {
+            elsif ($attr->{class} eq 'film_pozycja')
+            {
                 $self->{pre_itemDetails} = 1;
             }
-            elsif ( $attr->{class} eq 'main_sub_table film' ) {
+            elsif ($attr->{class} eq 'main_sub_table film')
+            {
                 $self->{itemMain} = 1;
             }
-            elsif ( $tagname eq 'img' && $self->{itemMain} ) {
+            elsif ($tagname eq 'img' && $self->{itemMain})
+            {
                 $self->{curInfo}->{image} = $attr->{src};
             }
         }
@@ -200,8 +210,8 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     # $tagname is the tag name.
     sub end
     {
-		my ($self, $tagname) = @_;		
-		$self->{inside}->{$tagname}--;
+        my ($self, $tagname) = @_;
+        $self->{inside}->{$tagname}--;
     }
 
     # text
@@ -211,62 +221,75 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         my ($self, $origtext) = @_;
 
-       if ($self->{parsingList})
+        if ($self->{parsingList})
         {
-            if ( $self->{listTitle} ) {
-               $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
-               $self->{listTitle} = 0;
+            if ($self->{listTitle})
+            {
+                $self->{itemsList}[ $self->{itemIdx} ]->{title} = $origtext;
+                $self->{listTitle} = 0;
             }
-            elsif ( $self->{listYear} ) {
-               $origtext =~ s/\((.*?)\)/$1/gms;
-               $self->{itemsList}[$self->{itemIdx}]->{date} = $origtext;
-               $self->{listYear} = 0;
+            elsif ($self->{listYear})
+            {
+                $origtext =~ s/\((.*?)\)/$1/gms;
+                $self->{itemsList}[ $self->{itemIdx} ]->{date} = $origtext;
+                $self->{listYear} = 0;
             }
         }
         else
         {
-            if ( $self->{itemTitle} ) {
+            if ($self->{itemTitle})
+            {
                 $self->{curInfo}->{title} = $origtext;
                 $self->{itemTitle} = 0;
             }
-            elsif ( $self->{itemOriginalTitle} ) {
+            elsif ($self->{itemOriginalTitle})
+            {
                 $origtext =~ s/\s*\((.*?)\)/$1/gms;
                 $self->{curInfo}->{original} = $origtext;
                 $self->{itemOriginalTitle} = 0;
             }
-            elsif ( $self->{itemDirector} ) {            
+            elsif ($self->{itemDirector})
+            {
                 $self->{curInfo}->{director} = $origtext;
-                $self->{itemDirector} = 0;
-                $self->{pre_itemDetails} = 0;
-            }       
-            elsif ( $self->{itemDetails} ) {            
-                ($self->{curInfo}->{genre}, $self->{curInfo}->{country}, $self->{curInfo}->{date}, $self->{curInfo}->{time}) = split(/, /, $origtext);
+                $self->{itemDirector}        = 0;
+                $self->{pre_itemDetails}     = 0;
+            }
+            elsif ($self->{itemDetails})
+            {
+                (
+                    $self->{curInfo}->{genre}, $self->{curInfo}->{country},
+                    $self->{curInfo}->{date},  $self->{curInfo}->{time}
+                ) = split(/, /, $origtext);
                 $self->{curInfo}->{time} =~ s/ min//;
-                $self->{itemDetails} = 0;
+                $self->{itemDetails}     = 0;
                 $self->{pre_itemDetails} = 0;
             }
-            elsif ( $self->{itemActors} ) {
+            elsif ($self->{itemActors})
+            {
                 $self->{curInfo}->{actors} = $origtext;
-                $self->{itemActors} = 0;
-                $self->{pre_itemDetails} = 0;
-            }                   
-            elsif ( $self->{itemMain} ) {
+                $self->{itemActors}        = 0;
+                $self->{pre_itemDetails}   = 0;
+            }
+            elsif ($self->{itemMain})
+            {
                 $self->{curInfo}->{synopsis} = $origtext;
-                $self->{itemMain}=0;
+                $self->{itemMain} = 0;
             }
-            elsif ( $self->{inside}->{item_rank} ) {
-               $self->{curInfo}->{rating} = $origtext;
-               $self->{pre_itemDetails} = 0;
+            elsif ($self->{inside}->{item_rank})
+            {
+                $self->{curInfo}->{ratingpress} = int($origtext + 0.5);
+                $self->{pre_itemDetails} = 0;
             }
-            elsif ( $self->{pre_itemDetails} ) {
-                $self->{itemDirector}=1
-                    if ( $origtext eq 'reżyseria:' );
+            elsif ($self->{pre_itemDetails})
+            {
+                $self->{itemDirector} = 1
+                  if ($origtext eq 'reżyseria:');
 
-                $self->{itemDetails}=1
-                    if ( $origtext eq 'szczegóły:' );
+                $self->{itemDetails} = 1
+                  if ($origtext eq 'szczegóły:');
 
-                $self->{itemActors}=1
-                    if ( $origtext eq 'obsada:' );
+                $self->{itemActors} = 1
+                  if ($origtext eq 'obsada:');
             }
         }
     }
@@ -287,18 +310,18 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         # (.gcm) and search for tags <field> in
         # /collection/options/fields/results
         $self->{hasField} = {
-            title => 1,
-            date => 1,
+            title    => 1,
+            date     => 1,
             director => 0,
-            actors => 0,          
+            actors   => 0,
         };
-        
-        $self->{itemIdx} = 0;
+
+        $self->{itemIdx}               = 0;
         $self->{itemsList}[0]->{title} = '';
-        $self->{itemsList}[0]->{url} = '';
-        
+        $self->{itemsList}[0]->{url}   = '';
+
         # Do your init stuff here
-        bless ($self, $class);
+        bless($self, $class);
         return $self;
     }
 
@@ -313,17 +336,20 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         # Your code to modify $html here.
         if ($self->{parsingList})
         {
-            $html =~ s|<!-- record_start -->(.*?)<!-- record_end -->|<list_details>$1</list_details>|gms;
+            $html =~
+              s|<!-- record_start -->(.*?)<!-- record_end -->|<list_details>$1</list_details>|gms;
         }
-        else {
+        else
+        {
             $html =~ s|<nobr>(.*?)</nobr>|$1|gms;
             $html =~ s|<span class="bold">(.*?)</span>|$1|gms;
             $html =~ s|<a href="/filmowcy/osoba.*?">(.*?)</a>|$1|gms;
-            $html =~ s|script type="text/javascript">document.write\(getOcena\((.*?)\)\);</script>|<item_rank>$1</item_rank>|gms;
-        }        
+            $html =~
+s|script type="text/javascript">document.write\(getOcena\((.*?)\)\);</script>|<item_rank>$1</item_rank>|gms;
+        }
         return $html;
     }
-    
+
 }
 
 1;
