@@ -2,7 +2,7 @@ package GCPlugins::GCgames::GCGameSpot;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -107,7 +107,7 @@ use GCPlugins::GCgames::GCgamesCommon;
             }
             elsif (($tagname eq 'a') && ($self->{isBox} eq 1))
             {
-                my $html = $self->loadPage($attr->{href}, 0, 1);
+                my $html = $self->loadPage($self->getItemUrl($attr->{href}), 0, 1);
                 my $found = index($html,"id=\"main_image\" src=\"");
                 if ( $found >= 0 )
                 {
@@ -299,6 +299,7 @@ use GCPlugins::GCgames::GCgamesCommon;
                 return if !$origtext;
                 if ($self->{isReleased} eq 2)
                 {
+                    $origtext =~ s/ .$//;
                     $self->{curInfo}->{released} = $origtext;
                     $self->{isReleased} = 0;
                 }
@@ -425,6 +426,10 @@ use GCPlugins::GCgames::GCgamesCommon;
     
         return "ISO-8859-1";
     }
+    sub isPreferred
+    {
+        return 1;
+    }
 }
 
 1;
