@@ -2,7 +2,7 @@ package GCPlugins::GCgames::GCgamesAmazonCommon;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Tian
 #
 #  This file is part of GCstar.
 #
@@ -47,17 +47,15 @@ use GCPlugins::GCstar::GCAmazonCommon;
                 $self->{itemsList}[$self->{itemIdx}]->{url} = $self->{loadedUrl};
                 $self->{isGame} = 2 ;
             }
-            elsif ( ($tagname eq 'div') && ($attr->{class} eq 'productTitle') && ($self->{isGame} ne 2) )
+            elsif ( ($tagname eq 'h1') && ($attr->{class} eq 'headerblocktitle') && ($self->{isGame} ne 2) )
             {
                 $self->{isGame} = 1 ;
                 $self->{isUrl} = 1 ;
-                $self->{isName} = 1 ;
             }
             elsif ( ($tagname eq 'td') && ($attr->{class} eq 'imageColumn') && ($self->{isGame} ne 2) )
             {
                 $self->{isGame} = 1 ;
                 $self->{isUrl} = 1 ;
-                $self->{isName} = 1 ;
             }
             elsif ( ($tagname eq 'a') && ($self->{isGame} eq 1) && ($self->{isUrl}) )
             {
@@ -65,7 +63,11 @@ use GCPlugins::GCstar::GCAmazonCommon;
                 $self->{itemsList}[$self->{itemIdx}]->{url} = $attr->{href};
                 $self->{isUrl} = 0 ;
             }
-            elsif ( ($tagname eq 'span') && ($attr->{class} eq 'format') && ($self->{isGame} eq 1) )
+            elsif ( ($tagname eq 'span') && ($attr->{class} eq 'srTitle') && ($self->{isGame} eq 1) )
+            {
+                $self->{isName} = 1 ;
+            }
+            elsif ( ($tagname eq 'span') && ($attr->{class} eq 'binding') && ($self->{isGame} eq 1) )
             {
                 $self->{isPlatform} = 1 ;
             }
@@ -149,9 +151,9 @@ use GCPlugins::GCstar::GCAmazonCommon;
             {
                 $self->{isDesc} = 1;
             }
-            elsif ( ($tagname eq 'div') && ($attr->{class} eq 'content') && ($self->{isDesc} eq 1))
+            elsif ( ($tagname eq 'div') && ($attr->{class} eq 'bucket') && ($self->{isDesc} eq 1))
             {
-                $self->{isDesc} = 2;
+                $self->{isDesc} = 0;
             }
 
         }
@@ -175,18 +177,11 @@ use GCPlugins::GCstar::GCAmazonCommon;
                 $self->{itemsList}[$self->{itemIdx}]->{platform} = $self->transformPlatform($origtext);
                 $self->{isPlatform} = 0;
             }
-            elsif ($self->{isName} && $self->{inside}->{a})
+            elsif ($self->{isName})
             {
                 $self->{itemsList}[$self->{itemIdx}]->{name} = $origtext;
                 $self->{isName} = 0;
             }
-            elsif ($self->{isGame})
-            {
-                if (!$self->{itemsList}[$self->{itemIdx}]->{platform} && ($origtext =~ /^ - (.*)$/))
-                {
-                    $self->{itemsList}[$self->{itemIdx}]->{platform} = $self->transformPlatform($1);
-                }
-            }
         }
         elsif ($self->{parsingTips})
         {
@@ -195,6 +190,8 @@ use GCPlugins::GCstar::GCAmazonCommon;
         {
             # Enleve les blancs en debut de chaine
             $origtext =~ s/^\s+//;
+            # Enleve les blancs en fin de chaine
+            $origtext =~ s/\s+$//;
 
             if ($self->{isDate})
             {
@@ -209,10 +206,9 @@ use GCPlugins::GCstar::GCAmazonCommon;
                    $self->{isPlatform} = 0;
                 }
             }
-            elsif ($self->{isDesc} eq 2)
+            elsif (($self->{isDesc}) && ($origtext ne ""))
             {
-                $self->{curInfo}->{description} = $origtext;
-                $self->{isDesc} = 0;
+                $self->{curInfo}->{description} .= $origtext ."\n";
             }
         }
     } 
