@@ -2,7 +2,7 @@ package GCUtils;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -524,6 +524,51 @@ sub DateTimeFormatStrToTime
     return $str;
 }
 
+# Our custom natural sort function
+sub gccmp
+{
+    use locale;
+    my ($string1, $string2) = @_;
+    
+    my $test1 = $string1;
+    my $test2 = $string2;
+    
+    # Split strings into arrays by seperating strings from numbers
+    my $nb1 = ($test1 =~ s/(\d+)/\|$+\|/g);
+    my $nb2 = ($test2 =~ s/(\d+)/\|$+\|/g);
+    
+    # If there are no numbers in the test strings, just directly compare
+    return $test1 cmp $test2
+        if ($nb1 == 0) || ($nb2 == 0);
+    
+    my @test = split(/\|/,$test1);
+    my @test2 = split(/\|/,$test2);
+
+    # Compare each element in the strings
+    my $result = 0;
+    for (my $pass = 0; $pass < scalar @test; $pass++)
+    {
+        # Elements are the same, so keep searching
+        next if ($test[$pass] eq $test2[$pass]);
+        
+        # If both elements are numbers, do a numerical compare
+        if (($test[$pass] =~ /\d+/)  && ($test2[$pass] =~ /\d+/))      
+        {
+            # Number test
+            $result = $test[$pass] <=> $test2[$pass];
+        }
+        else
+        {
+            # Test elements as strings
+            $result = lc($test[$pass]) cmp lc($test2[$pass]);
+        }
+        last; 
+    }
+    
+    return $result;
+}
+
+
 our $hasTimeConversion;
 BEGIN {
     $hasTimeConversion = 1;
@@ -546,6 +591,7 @@ BEGIN {
             *timeToStr = sub {return $_[0]};
         }
     }
+    
 }
 
 
